/*
-----------------------------------------------------------------------
  Script............: autoAtualiza.sql
  Objetivo..........: Criar/Atualizar bco pwAcesso 3.10 / pwPonto 3.10
  Compatibilidade...: SQL 2000/2005 e MSDE 2000
  Autor.............: Pointware Informtica Ltda
  ltima atualizao: 28/01/2019
-----------------------------------------------------------------------
*/
SET NOCOUNT ON
GO
SET LANGUAGE English
GO

/*
-------------------------------------
 PASSO 1: CRIAR/ATUALIZAR TABELAS
-------------------------------------
*/

/*
   Vigencia atual
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbVigencia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbVigencia] (
      [leitura] bit NOT NULL,
      [data_ini] datetime NOT NULL,
      [data_fim] datetime NOT NULL
   ) ON [PRIMARY];
end
GO

/*
   Bancos e vigencias
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBcoVig') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBcoVig] (
      [banco] varchar(50) NOT NULL,
      [odbc] varchar(50) NOT NULL,
      [ano_ini] INT NOT NULL,
      [ano_fim] INT NOT NULL,
      [data_ini] datetime NOT NULL,
      [data_fim] datetime NOT NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [PK_tbBcoVig] ON [dbo].[tbBcoVig]([ano_ini]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbBcoVig] ON [dbo].[tbBcoVig]([banco]) ON [PRIMARY];
end;
GO

/*
   Centros Acadmicos - Alunos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCA') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCA] (
      [id_ca] [int] NOT NULL, [descricao] [varchar] (50) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCA] WITH NOCHECK
   ADD CONSTRAINT [PK_tbCA] PRIMARY KEY CLUSTERED ([id_ca]) ON [PRIMARY];
end
GO

/*
   Departamento acadmico - Alunos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDA') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDA] (
      [id_da] [int] NOT NULL,
      [id_ca] [int] NOT NULL, [descricao] [varchar] (50) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbDA] WITH NOCHECK ADD CONSTRAINT [PK_tbDA] PRIMARY KEY CLUSTERED ([id_da]) ON [PRIMARY];
end
GO


/*
   Tipos de Curso - Alunos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTC') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTC] (
   [id_tc] [int] NOT NULL ,
      [descricao] [varchar] (30) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTC] WITH NOCHECK
   ADD CONSTRAINT [PK_tbTC] PRIMARY KEY CLUSTERED ([id_tc]) ON [PRIMARY];
end
GO

/*
   Cursos - Alunos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCurso') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCurso] (
      [id_curso] [int] NOT NULL ,
      [id_tc] [int] NOT NULL,
      [id_da] [int] NOT NULL,
      [descricao] [varchar] (30) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCurso] WITH NOCHECK
   ADD CONSTRAINT [PK_tbCurso] PRIMARY KEY CLUSTERED ([id_curso]) ON [PRIMARY];
end
GO

/*
   Tabela de Alunos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAlun') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAlun] (
      [id_pass] int NOT NULL,
      [matricula] varchar(20) NULL,
      [serie] tinyint NOT NULL,
      [grau] tinyint NOT NULL,
      [sala] varchar(4) NULL,
      [resp1] int NULL, [resp2] int NULL,
      [resp3] int NULL, [resp4] int NULL,
      [resp5] int NULL, [resp6] int NULL,
      [resp7] int NULL, [resp8] int NULL,
      [fone] varchar(15) NULL,   [fone1] varchar(15) NULL,
      [fone2] varchar(15) NULL,  [fone3] varchar(15) NULL,
      [obs] varchar(250) NULL,
      [sairesp] bit NULL,
      [id_curso] int NULL,  [id_pestuda] int NULL,
      [turma] varchar(5) NULL,
      [id_bolsa] int NULL, [dtingresso] datetime null,
      [doc_rg] varchar(50) null, [doc_cpf] varchar(50) null, [doc_outros] varchar(50) null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAlun] WITH NOCHECK ADD CONSTRAINT [DF_tbAlun_serie] DEFAULT (0) FOR [serie],CONSTRAINT [DF_tbAlun_grau] DEFAULT (0) FOR [grau],CONSTRAINT [DF_tbAlun_sairesp] DEFAULT (0) FOR [sairesp],CONSTRAINT [PK_tbAlun] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY];
end;
GO

/*
   Auxiliar para transferncia de alunos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAlunTransf') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAlunTransf] (
      [id_pass] int NOT NULL,
      [trans_num] int IDENTITY (1, 1) NOT NULL ,
      [dataocorrencia] [smalldatetime] NOT NULL,
      [serie_old] tinyint NOT NULL, [grau_old] tinyint NOT NULL,
      [sala_old] varchar(4) NOT NULL ,    [serie_new] tinyint NOT NULL,
      [grau_new] tinyint NOT NULL,     [sala_new] varchar(4) NOT NULL ,
      [observacao] varchar(7000) NULL,    [id_usuario] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE tbAlunTransf WITH NOCHECK ADD CONSTRAINT [PK_tbAlunTransf] PRIMARY KEY CLUSTERED ( [id_pass], [trans_num] )  ON [PRIMARY];
   ALTER TABLE tbAlunTransf WITH NOCHECK ADD CONSTRAINT [DF_tbAlunTransf_dataocorrencia] DEFAULT (getdate()) FOR [dataocorrencia];
end;
GO

/*
   Configuraes padres para os Bloqueios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbModelosBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].tbModelosBloq (
      [id_modelo] int NOT NULL,
      [descricao] varchar(15) NOT NULL,
      [comunicacao] int NOT NULL,
      [sentido] varchar(1) NULL, [senha] tinyint NULL,
      [atuac] tinyint NULL,      [entr] bit NULL,           [said] bit NULL,
      [stpass] bit NULL,         [travasequencia] bit NULL,
      [flaghorario] bit NULL,    [flagvisitante] bit NULL,
      [flagsecundario] bit NULL, [leitor1] int NULL,
      [leitor2] int NULL,        [leitor3] int NULL,
      [acessosenha] bit NULL,    [confirmacao] int NULL,
      [tmpaciona] int null,      [mensagem] varchar(32) null,
      [padraoCracha] varchar(15) null, [listas] varchar(16) null,
      [tmpAtuac] varchar(4) null, [tmpConf] varchar(4) null,
      [funcoes] varchar(16) null, [tiposFxs] varchar(8) null,
      [tiposLib] varchar(8) null, [program] varchar(10) null,
      [bloq_senhas] varchar(16) null,
      [md_cracha] bit null, [md_codcracha] bit null, [md_autcracha] int null,
      [md_pers] int null, [md_cpers] int null, [md_qpers] int null, [md_impavanc] int null,
      [md_impcort] int null, [md_teclado] bit null, [md_codteclado] bit null, [md_auttecla] int null,
      [md_b1pn] bit null, [md_autbio] int null, [md_apenasbio] bit null, [md_fmtl1] varchar(20) null,
      [md_fmtl2] varchar(20) null, [md_fmtl3] varchar(20) null, [md_fmtl4] varchar(20) null,
      [md_fmtl5] varchar(20) null, [md_fmtl6] varchar(20) null, [md_fmtl7] varchar(20) null,
      [md_fmtl8] varchar(20) null, [md_fmtl9] varchar(20) null, [md_cripto] int null,
      [md_vet1a] int null, [md_vet1b] int null, [md_vet2a] int null, [md_vet2b] int null,
      [md_esp1] bit null, [md_esp2] bit null, [md_scid] bit null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbModelosBloq] WITH NOCHECK ADD
      CONSTRAINT [PK_tbModelosBloq] PRIMARY KEY CLUSTERED ([id_modelo]) ON [PRIMARY];
end;
GO

delete from tbModelosBloq;
GO
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 1,'<Outro>', 99);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 2,'Dimep Serial', 0);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 3,'Dimep IP', 1);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 4,'ZK On-line', 4);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 5,'XPCom', 5);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 6,'Virtual', 6);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 7,'Madis REP', 7);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 8,'RW REP', 7);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES ( 9,'REP Padro', 99);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (10,'ZK Padro', 8);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (11,'BIOIP', 11);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (12,'MicroPoint S', 12);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (13,'MicroPoint XP', 13);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (14,'Gertec REP', 14);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (15,'MicroPoint IP', 15);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (16,'TRIX REP', 7);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (17,'Henry Primme', 17);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (18,'Henry Argos', 18);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (19,'ZK InBio', 19);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (20,'Trix DC-730', 20);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (21,'ControlID', 21);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (22,'CID REP', 22);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (23,'ZK BIO', 23);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (24,'Madis 0705', 24);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (25,'Opener', 25);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (26,'WinPak', 26);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (27,'TopData Inner', 27);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (28,'Madis EVO', 7);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (29,'Kurumim', 29);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (30,'Madis ECO', 7);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (31,'Henry P-SF', 31);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (32,'InforComp', 32);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (33,'Madis 0706', 33);
INSERT INTO tbModelosBloq (id_modelo, descricao, comunicacao) VALUES (34,'ZK C3', 34);
GO

/*
   Tabela dos Bloqueios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloq] (
      [id_bloq] smallint NOT NULL,
      [st_bloq] tinyint NOT NULL,
      [descricao] varchar(20) NOT NULL ,
      [tipo] tinyint NOT NULL,
      [funis] tinyint NOT NULL,
      [sentido] varchar(1) NOT NULL ,
      [id_gbloq] int NOT NULL,
      [senha] tinyint NOT NULL,
      [refei] tinyint NOT NULL,
      [atuac] tinyint NOT NULL,
      [entr] bit NOT NULL,
      [said] bit NOT NULL,
      [stpass] bit NOT NULL,
      [qtdpass] int NOT NULL,
      [ip] [char](15) NULL,
      [travasequencia] bit NOT NULL,
      [flaghorario] bit NOT NULL,
      [flagvisitante] bit NOT NULL,
      [flagsecundario] bit NOT NULL,
      [comunicacao] int NOT NULL,
      [endereco] int NULL,
      [leitor1] int NULL,
      [leitor2] int NULL,
      [leitor3] int NULL,
      [acessosenha] bit NULL,
      [confirmacao] int NULL,
      [evento] tinyint NULL,
      [tipo_controle] [char](1) NULL,
      [modelo] varchar(15) null,
      [tipocom] int null,
      [portacom] int null,
      [portaip] int null,
      [rate] int null,
      [tmpaciona] int null,
      [mensagem] varchar(32) null,
      [padraoCracha] varchar(15) null,
      [listas] varchar(16) null,
      [tmpAtuac] varchar(4) null, [tmpConf] varchar(4) null,
      [funcoes] varchar(16) null,
      [tiposFxs] varchar(8) null,
      [tiposLib] varchar(8) null,
      [ponto] tinyint NOT NULL,
      [program] varchar(10) null,
      [bloq_senhas] varchar(16) null, [path_relog] varchar(80) null,
      [digitais] int null, [rep_serie] varchar(17) null,
      [id_empresa] int null,
      [id_modelo] int NULL, [md_cracha] bit null, [md_codcracha] bit null, [md_autcracha] int null,
      [md_pers] int null, [md_cpers] int null, [md_qpers] int null, [md_impavanc] int null,
      [md_impcort] int null, [md_teclado] bit null, [md_codteclado] bit null, [md_auttecla] int null,
      [md_b1pn] bit null, [md_autbio] int null, [md_apenasbio] bit null, [md_fmtl1] varchar(20) null,
      [md_fmtl2] varchar(20) null, [md_fmtl3] varchar(20) null, [md_fmtl4] varchar(20) null,
      [md_fmtl5] varchar(20) null, [md_fmtl6] varchar(20) null, [md_fmtl7] varchar(20) null,
      [md_fmtl8] varchar(20) null, [md_fmtl9] varchar(20) null, [md_cripto] int null,
      [md_vet1a] int null, [md_vet1b] int null, [md_vet2a] int null, [md_vet2b] int null,
      [md_esp1] bit null, [md_esp2] bit null, [md_scid] bit null,
      [reg_manual] bit null, [ace_comb] tinyint,
      [bloq_cvinc] bit null, [ult_nsr] CHAR(9) NULL,
      [id_grefeit] int null, [rep_cpf] varchar(12) null,
      [id_modbio] int null, [bio_auto] bit NULL,
      [leitor4] int NULL, [leitor5] int NULL,
      [host] varchar(30) null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloq] WITH NOCHECK ADD
      CONSTRAINT [DF_tbBloq_id_gbloq] DEFAULT (0) FOR [id_gbloq],
      CONSTRAINT [DF_tbBloq_senha] DEFAULT (0) FOR [senha],
      CONSTRAINT [DF_tbBloq_refei] DEFAULT (0) FOR [refei],
      CONSTRAINT [DF_tbBloq_atuac] DEFAULT (0) FOR [atuac],
      CONSTRAINT [DF__tbBloq__entr__28ED12D1] DEFAULT (0) FOR [entr],
      CONSTRAINT [DF__tbBloq__said__29E1370A] DEFAULT (0) FOR [said],
      CONSTRAINT [DF__tbBloq__stpass__2AD55B43] DEFAULT (0) FOR [stpass],
      CONSTRAINT [DF__tbBloq__qtdpass__39237A9A] DEFAULT (0) FOR [qtdpass],
      CONSTRAINT [DF__tbBloq__ip__14270015] DEFAULT ('___.___.___.___') FOR [ip],
      CONSTRAINT [DF_tbBloq_travasequencia] DEFAULT (0) FOR [travasequencia],
      CONSTRAINT [DF_tbBloq_flaghorario] DEFAULT (0) FOR [flaghorario],
      CONSTRAINT [DF_tbBloq_flagvisitante] DEFAULT (0) FOR [flagvisitante],
      CONSTRAINT [DF_tbBloq_flagsecundario] DEFAULT (0) FOR [flagsecundario],
      CONSTRAINT [DF_tbBloq_comunicacao] DEFAULT (0) FOR [comunicacao],
      CONSTRAINT [PK_tbBloq] PRIMARY KEY CLUSTERED ([id_bloq])  ON [PRIMARY];
   CREATE  INDEX [IX_tbBloq] ON [dbo].[tbBloq]([id_gbloq]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'ponto')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [ponto] tinyint NULL;
   exec('UPDATE tbBloq SET ponto = 0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'program')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [program] varchar(10) null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'bloq_senhas')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [bloq_senhas] varchar(16) null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'path_relog')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [path_relog] varchar(80) null;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'fun_pto')
BEGIN
   ALTER TABLE [dbo].[tbBloq] DROP COLUMN [fun_pto], [pto_priult];
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'rep_serie')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [rep_serie] varchar(17) null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'digitais')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [digitais] INT null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'id_empresa')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [id_empresa] INT null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'id_modelo')
BEGIN
   ALTER TABLE tbBloq ADD [id_modelo] int NULL, [md_cracha] bit null, [md_codcracha] bit null, [md_autcracha] int null,
      [md_pers] int null, [md_cpers] int null, [md_qpers] int null, [md_impavanc] int null,
      [md_impcort] int null, [md_teclado] bit null, [md_codteclado] bit null, [md_auttecla] int null,
      [md_b1pn] bit null, [md_autbio] int null, [md_apenasbio] bit null, [md_fmtl1] varchar(20) null,
      [md_fmtl2] varchar(20) null, [md_fmtl3] varchar(20) null, [md_fmtl4] varchar(20) null,
      [md_fmtl5] varchar(20) null, [md_fmtl6] varchar(20) null, [md_fmtl7] varchar(20) null,
      [md_fmtl8] varchar(20) null, [md_fmtl9] varchar(20) null, [md_cripto] int null,
      [md_vet1a] int null, [md_vet1b] int null, [md_vet2a] int null, [md_vet2b] int null,
      [md_esp1] bit null, [md_esp2] bit null, [md_scid] bit null;
   exec('UPDATE tbBloq SET id_modelo=(case when isnull(comunicacao,99)=0 then 2 when isnull(comunicacao,99)=1 then 3 when isnull(comunicacao,99)>=4 then comunicacao else 1 end)');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'reg_manual')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [reg_manual] bit null, [ace_comb] tinyint;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'bloq_cvinc')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [bloq_cvinc] bit null;
   exec('UPDATE tbBloq SET bloq_cvinc=1');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'ult_nsr')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [ult_nsr] CHAR(9) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'id_grefeit')
BEGIN
   ALTER TABLE dbo.tbBloq ADD [id_grefeit] INT null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'rep_cpf')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [rep_cpf] varchar(12) null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'id_modbio')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [id_modbio] int null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'bio_auto')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [bio_auto] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'leitor4')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [leitor4] int NULL;
   ALTER TABLE [dbo].[tbBloq] ADD [leitor5] int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloq') and name = 'host')
BEGIN
   ALTER TABLE [dbo].[tbBloq] ADD [host] varchar(30) null;
END;
GO

/*
   Configurao de leitores
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqLeitor') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqLeitor] (
      [id_bloq] smallint NOT NULL,
      [leitor]  int NOT NULL,
      [tipo]    int NOT NULL, -- 1: Barras, 2: Proximidade, 3:Biometria, 4:Teclado
      [endereco] int NOT NULL,
      [entrada] bit NOT NULL,
      [saida]   bit NOT NULL,
      [cofre]   bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqLeitor] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqLeitor] PRIMARY KEY CLUSTERED ([id_bloq],[leitor])  ON [PRIMARY];
end
GO

/*
   Acionamento de relays
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqRelay') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqRelay] (
      [id_bloq] smallint NOT NULL,
      [sentido]  int NOT NULL, -- 1:Entrada, 2:Sada, 3:Cofre
      [relay]    int NOT NULL,
      [tempo]    int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqRelay] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqRelay] PRIMARY KEY CLUSTERED ([id_bloq],[sentido],[relay])  ON [PRIMARY];
end
GO

/*
   Confirmao de sensores
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqSWT') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqSWT] (
      [id_bloq] smallint NOT NULL,
      [sentido] int NOT NULL, -- 1:Entrada, 2:Sada, 3:Cofre
      [swt]     int NOT NULL,
      [tempo]   int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqSWT] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqSWT] PRIMARY KEY CLUSTERED ([id_bloq],[sentido],[swt])  ON [PRIMARY];
end
GO

/*
   Configurao de bloqueio, modelo 20
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqM20') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqM20] (
      [id_bloq] smallint NOT NULL,
      [serie]    varchar(255) NOT NULL,
      [serv_bio] varchar(255) NOT NULL,
      [port_bio] int NOT NULL,
      [id_lbio] int NULL --1: (500) Outros, 2: (505) Testech/Bio-I, 3: (512) Digital Persona, 4: (620) NK-FP3/FP4
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqM20] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqM20] PRIMARY KEY CLUSTERED ([id_bloq])  ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBloqM20') and name = 'id_lbio')
BEGIN
   ALTER TABLE [dbo].[tbBloqM20] ADD [id_lbio] int NULL;
   EXEC('UPDATE tbBloqM20 SET id_lbio=2');
END;
GO

/*
   Dispositivos Win-Pak
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqWP') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqWP] (
      [id_device] int NOT NULL,
      [descricao] varchar(50) NOT NULL,
      [id_bloq] smallint NOT NULL,
      [leitor]  int NOT NULL,
      [entrada] bit NOT NULL,
      [saida]   bit NOT NULL,
      [bloqueado] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqWP] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqWP] PRIMARY KEY CLUSTERED ([id_device])  ON [PRIMARY];
   CREATE UNIQUE INDEX IX_tbBloqWP ON dbo.tbBloqWP(id_device, id_bloq, leitor);
end
GO

/*
   Bancos Win-Pak
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBcoWP') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBcoWP] (
      [servidor] varchar(80) NOT NULL,
      [banco] varchar(50) NOT NULL,
      [nt] bit NOT NULL,
      [usr] varchar(50) NOT NULL,
      [pwd] varchar(50) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBcoWP] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBcoWP] PRIMARY KEY CLUSTERED ([servidor], [banco])  ON [PRIMARY];
end
GO

/*
   Status de comunicao dos Bloqueios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbStatusBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbStatusBloq] (
      id_bloq smallint NOT NULL,
      data datetime NOT NULL,
      comunicacao tinyint not null,
      dt_enviado  datetime null,
      dt_recebido datetime null,
      firmware    varchar(50) null,
      ult_alerta  varchar(100) null,
      ult_ocorr   varchar(100) null,
      ult_cracha  varchar(20) null,
      ult_nome    varchar(100) null,
      ult_sentido  char(1) null,
      dt_ult_cracha  datetime null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbStatusBloq] WITH NOCHECK ADD
      CONSTRAINT [PK_tbStatusBloq] PRIMARY KEY CLUSTERED (id_bloq,data)  ON [PRIMARY];
end
GO

/*
   Vnculo de bloqueio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqVinc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqVinc] (
      id_bloq smallint NOT NULL,
      leitor  smallint NOT NULL,
      id_vinc smallint NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqVinc] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqVinc] PRIMARY KEY CLUSTERED (id_bloq, leitor)  ON [PRIMARY];
   CREATE INDEX IX_tbBloqVinc ON dbo.tbBloqVinc(id_bloq);
   CREATE INDEX IX_tbBloqVinc_id_vinc ON dbo.tbBloqVinc(id_vinc);
end
GO

/*
   Comandos para bloqueios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCMDBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCMDBloq] (
      id_bloq int not null,
      comando int not null,
      data    datetime not null,
      status  int not null,
      param1  int null,
      param2  varchar(2000) null,
      codret  int null,
      msgret  varchar(2000) null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCMDBloq] WITH NOCHECK ADD
      CONSTRAINT [PK_tbCMDBloq] PRIMARY KEY CLUSTERED (id_bloq)  ON [PRIMARY];
end
GO

/*
   Lista de funcionrios no bloqueio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFunBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFunBloq] (
      id_bloq int not null,
      data    datetime not null,
      excluir tinyint not null,
      id_pass int null,
      nome    varchar(100) null,
      nivel   varchar(20) null,
      cracha  varchar(20) null,
      pis     varchar(20) null,
      obs     varchar(200) null
   ) ON [PRIMARY];
   CREATE INDEX IX_tbFunBloq ON dbo.tbFunBloq(id_bloq);
end
GO

/*
   Informaes de status de comunicao dos bloqueios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbInfoBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbInfoBloq] (
      id_bloq int NOT NULL,
      descricao varchar(100) NOT NULL,
      tipo_info tinyint not null,
      valor int not null,
      desc_valor varchar(100) NOT NULL,
      dt_persiste datetime NULL,
      data datetime NOT NULL,
      dt_validade datetime NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbInfoBloq] WITH NOCHECK ADD
      CONSTRAINT [PK_tbInfoBloq] PRIMARY KEY CLUSTERED (id_bloq,descricao)  ON [PRIMARY];
end
GO

/*
   Controle de acesso combinado
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqAcComb') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqAcComb] (
      [id_bloq] smallint NOT NULL,
      [id_movim] bigint NOT NULL,
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqAcComb] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqAcComb] PRIMARY KEY CLUSTERED (id_bloq, id_movim) ON [PRIMARY];
end
GO

/*
   Controle de sequencia de acesso em estacionamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBloqSPark') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBloqSPark] (
      [id_bloq] smallint NOT NULL,
      [id_pass] int NOT NULL,
      [id_auto] int NOT NULL,
      [cracha] float NOT NULL,
      [data] datetime NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBloqSPark] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBloqSPark] PRIMARY KEY CLUSTERED (id_bloq) ON [PRIMARY];
end
GO

/*
   Transferncia temporria de funcionrios entre bloqueios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTransfBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTransfBloq] (
      [id_bloq] smallint NOT NULL,
      [id_transf] smallint NOT NULL,
      [data_ini] datetime NOT NULL,
      [data_fim] datetime NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTransfBloq] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTransfBloq] PRIMARY KEY CLUSTERED ([id_bloq])  ON [PRIMARY];
   CREATE INDEX IX_tbTransfBloq ON dbo.tbTransfBloq(id_transf);
end
GO

/*
   Crachs mestre
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCMestre') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCMestre] (
      [cracha] [float] NOT NULL,
      [via] tinyint NOT NULL,
      [descricao] varchar(35) NULL,
    [bloqueado] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCMestre] WITH NOCHECK ADD CONSTRAINT [PK_tbCMestre] PRIMARY KEY CLUSTERED ([cracha],[via]) ON [PRIMARY], CONSTRAINT [DF_tbCMestre_descricao] DEFAULT ('') FOR [descricao];
end
GO

/*
   Tabela de condminos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCond') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCond] (
      [id_pass] int NOT NULL,
      [bloco] varchar(4) NULL, [vagas] varchar(15) NULL,
      [fone_com] varchar(15) NULL,[fone_res] varchar(15) NULL,
      [ramais] varchar(8) NULL,[interf] varchar(4) NULL,
      [ender] varchar(50) NULL,[obs] varchar(250) NULL,[email] varchar(40) NULL,
      [filiacao1] varchar(50) NULL,[filiacao2] varchar(50) NULL,
      [doc_rg] varchar(50) null,[doc_cpf] varchar(50) null,[doc_outros] varchar(50) null,[doc_cnh] varchar(20) null,
      [natural] varchar(20) NULL, [bairro] varchar(50) NULL, [compl] varchar(50) NULL,
      [cidade] varchar(50) NULL, [cep] varchar(10) NULL, [uf] varchar(2) NULL,[apelido] varchar(20) NULL, [nivel] tinyint null,
      [rg_orgao] varchar(10) NULL, [rg_emissao] datetime NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCond] WITH NOCHECK ADD CONSTRAINT [PK_tbCond] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY]
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCond') and name = 'email')
BEGIN
   ALTER TABLE [dbo].[tbCond] ADD [email] varchar(40) NULL,
      [filiacao1]  varchar(50) NULL, [filiacao2] varchar(50) NULL,
      [doc_rg]     varchar(50) NULL, [doc_cpf]   varchar(50) NULL,
      [doc_outros] varchar(50) NULL, [doc_cnh]   varchar(20) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCond') and name = 'natural')
BEGIN
   ALTER TABLE [dbo].[tbCond] ADD [natural] varchar(20) NULL, [bairro] varchar(50) NULL, [compl] varchar(50) NULL,
      [cidade] varchar(50) NULL, [cep] varchar(10) NULL, [uf] varchar(2) NULL,[apelido] varchar(20) NULL, [nivel] tinyint null,
      [rg_orgao] varchar(10) NULL, [rg_emissao] datetime NULL;
   ALTER TABLE [dbo].[tbCond] ALTER COLUMN [ender] varchar(50);
END;
GO

/*
   Classificao de unidade
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUClasse') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUClasse] (
      [id_uclasse] int NOT NULL, [descricao] varchar(20) NOT NULL,[uso] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUClasse] WITH NOCHECK ADD
   CONSTRAINT [PK_tbUClasse] PRIMARY KEY CLUSTERED ([id_uclasse]) ON [PRIMARY];
end
GO
--Valores padres
if not exists(select * from tbUClasse)
begin
   insert into tbUClasse(id_uclasse,descricao,uso) values(1,'Apartamento',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(2,'Cobertura',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(3,'Loja',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(4,'Sala',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(5,'Sobreloja',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(6,'Unidade',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(7,'Garagem',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(8,'Casa',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(9,'Lote',1);
   insert into tbUClasse(id_uclasse,descricao,uso) values(10,'Chcara',1);
end;


/*
   Tipos de ocupao de unidade
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTpOcup') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTpOcup] (
      [id_tpocup] int NOT NULL, [descricao] varchar(20) NOT NULL,
      [ocupado] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTpOcup] WITH NOCHECK ADD
   CONSTRAINT [PK_tbTpOcup] PRIMARY KEY CLUSTERED ([id_tpocup]) ON [PRIMARY];
end
GO
--Valores padres
if not exists(select * from tbTpOcup)
begin
   insert into tbTpOcup(id_tpocup,descricao,ocupado) values(1,'Morador',1);
   insert into tbTpOcup(id_tpocup,descricao,ocupado) values(2,'Unidade alugada',1);
   insert into tbTpOcup(id_tpocup,descricao,ocupado) values(3,'Desocupada',0);
   insert into tbTpOcup(id_tpocup,descricao,ocupado) values(4,'Em reforma',0);
   insert into tbTpOcup(id_tpocup,descricao,ocupado) values(5,'Em construo',0);
   insert into tbTpOcup(id_tpocup,descricao,ocupado) values(6,'Embargada',0);
   insert into tbTpOcup(id_tpocup,descricao,ocupado) values(7,'Viagem',0);
end;

/*
   Categorias de condmino
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCtgCond') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCtgCond] (
      [id_ctgcond] int NOT NULL, [descricao] varchar(20) NOT NULL,
      [tipo] tinyint NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCtgCond] WITH NOCHECK ADD
   CONSTRAINT [PK_tbCtgCond] PRIMARY KEY CLUSTERED ([id_ctgcond]) ON [PRIMARY];
end
GO
--Valores padres
if not exists(select * from tbCtgCond)
begin
   insert into tbCtgCond (id_ctgcond,descricao,tipo) values(1,'Proprietrio',0);
   insert into tbCtgCond (id_ctgcond,descricao,tipo) values(2,'Familiar',1);
   insert into tbCtgCond (id_ctgcond,descricao,tipo) values(3,'Morador',2);
   insert into tbCtgCond (id_ctgcond,descricao,tipo) values(4,'Inquilino',3);
   insert into tbCtgCond (id_ctgcond,descricao,tipo) values(5,'Diarista/Domstica',4);
end;

/*
   Cadastro de unidades
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUnidades') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUnidades](
      [id_unidade] int NOT NULL,
      [quadra] varchar(5) NOT NULL, [lote] varchar(5) NOT NULL, [bloco] varchar(5) NOT NULL, [unidade] varchar(5) NOT NULL,
      [classe] tinyint NOT NULL, [id_tpocup] int NOT NULL, [obs] varchar(250) NULL,
      [fone_com] varchar(15) NULL, [ramais] varchar(8) NULL, [fone_res] varchar(15) NULL, [interf] varchar(4) NULL,
      [rest_ini] datetime NULL, [rest_fim] datetime NULL, [mtv_rest] varchar(50) NULL,
      [area_util] int NULL, [area_total] int NULL,
      [agua] varchar(15) NULL, [luz] varchar(15) NULL, [gas] varchar(15) NULL,
      [urbanismo] varchar(250) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUnidades] WITH NOCHECK ADD
      CONSTRAINT [PK_tbUnidades] PRIMARY KEY CLUSTERED ([id_unidade])  ON [PRIMARY];
   CREATE INDEX IX_tbUnidades_unidade ON dbo.tbUnidades(unidade);
   CREATE INDEX IX_tbUnidades_quadra ON dbo.tbUnidades(quadra);
   CREATE INDEX IX_tbUnidades_lote ON dbo.tbUnidades(lote);
   CREATE INDEX IX_tbUnidades_bloco ON dbo.tbUnidades(bloco);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUnidades') and name = 'area_util')
BEGIN
   ALTER TABLE [dbo].[tbUnidades] ADD [area_util] int NULL, [area_total] int NULL, [agua] varchar(15) NULL, [luz] varchar(15) NULL, [gas] varchar(15) NULL, [urbanismo] varchar(250) NULL;
END;
GO


/*
   Vagas das unidades
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUnidVagas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUnidVagas](
      [id_unidade] int NOT NULL, [id_vaga] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUnidVagas] WITH NOCHECK ADD
      CONSTRAINT [PK_tbUnidVagas] PRIMARY KEY CLUSTERED ([id_unidade], [id_vaga])  ON [PRIMARY];
   CREATE INDEX IX_tbUnidVagas_id_vaga ON dbo.tbUnidVagas(id_vaga);
end
GO

/*
   Relacional Condmino x Unidades
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPassUnid') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPassUnid](
      [id_pass] int NOT NULL,
      [id_unidade] int NOT NULL, [id_ctgcond] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPassUnid] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPassUnid] PRIMARY KEY CLUSTERED ([id_pass],[id_unidade])  ON [PRIMARY];
   CREATE INDEX IX_tbPassUnid_id_pass ON dbo.tbPassUnid(id_pass);
   CREATE INDEX IX_tbPassUnid_id_unidade ON dbo.tbPassUnid(id_unidade);
end
GO

/*
   Visitantes autorizados na restrio de acesso
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRestAce') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRestAce](
      [restricao] tinyint NOT NULL,
      [id_unidade] int NULL,
      [id_pass] int NULL,
      [vis_nome] varchar(50) NULL,
      [doc_rg] varchar(50) NULL,
      [doc_cpf]  varchar(50) NULL,
      [doc_outros] varchar(50) NULL
   ) ON [PRIMARY];
   CREATE INDEX IX_tbRestAce_restricao ON dbo.tbRestAce(restricao);
   CREATE INDEX IX_tbRestAce_id_unidade ON dbo.tbRestAce(id_unidade);
   CREATE INDEX IX_tbRestAce_id_pass ON dbo.tbRestAce(id_pass);
end
GO

/*
   Animais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAnimais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAnimais](
      [id_animal] INT NOT NULL,
      [foto] varchar(25) NULL,
      [tipo] TINYINT NOT NULL, [raca] VARCHAR(15) NULL,
      [cor] VARCHAR(15) NULL,  [nome] VARCHAR(15) NOT NULL,
      [obs] VARCHAR(250) NULL, [macho] BIT NOT NULL,
      [dt_vacina] DATETIME NULL, [dt_validade] DATETIME NULL,
      [id_unidade] INT NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAnimais] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAnimais] PRIMARY KEY CLUSTERED ([id_animal])  ON [PRIMARY];
   CREATE INDEX IX_tbAnimais_id_unidade ON dbo.tbAnimais(id_unidade);
end
GO

/*
   Notificaes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUNotif') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUNotif] (
      [id_unotif] int NOT NULL, [data] datetime NOT NULL,
      [motivo] varchar(50) NOT NULL,
      [cabec] varchar(500) NULL,
      [id_unidade] int NOT NULL, [descricao] varchar(4000) NOT NULL,
      [assina] varchar(250) NULL,
      [valor] varchar(15) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUNotif] WITH NOCHECK ADD
      CONSTRAINT [PK_tbUNotif] PRIMARY KEY CLUSTERED ([id_unotif]) ON [PRIMARY];
   CREATE INDEX IX_tbUNotif_id_unidade ON dbo.tbUNotif(id_unidade);
   CREATE INDEX IX_tbUNotif_motivo ON dbo.tbUNotif(motivo);
end
GO

/*
   Tabelas de consistncia
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbConsist') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbConsist] (
      [id_consist] int NOT NULL,
      [id_empresa] int NOT NULL,
      [descricao] varchar(30) NOT NULL ,
      [geral] bit NOT NULL,
      [c6] bit NULL,    [c7] bit NULL,
      [c8] bit NULL,    [c10] bit NULL,
      [c11] bit NULL,   [c12] bit NULL,
      [c13] bit NULL,   [c14] bit NULL,
      [c15] bit NULL,   [c16] bit NULL,
      [c17] bit NULL,   [c29] bit NULL,
      [c30] bit NULL,   [c31] bit NULL,
      [c32] bit NULL,   [c9] bit NULL,
      [c33] bit NULL,   [c34] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbConsist] WITH NOCHECK ADD
      CONSTRAINT [DF__tbConsist_c6] DEFAULT (0) FOR [c6],
      CONSTRAINT [DF__tbConsist_c7] DEFAULT (0) FOR [c7],
      CONSTRAINT [DF__tbConsist_c8] DEFAULT (0) FOR [c8],
      CONSTRAINT [DF__tbConsist_c10] DEFAULT (0) FOR [c10],
      CONSTRAINT [DF__tbConsist_c11] DEFAULT (0) FOR [c11],
      CONSTRAINT [DF__tbConsist_c12] DEFAULT (0) FOR [c12],
      CONSTRAINT [DF__tbConsist_c13] DEFAULT (0) FOR [c13],
      CONSTRAINT [DF__tbConsist_c14] DEFAULT (0) FOR [c14],
      CONSTRAINT [DF__tbConsist_c15] DEFAULT (0) FOR [c15],
      CONSTRAINT [DF__tbConsist_c16] DEFAULT (0) FOR [c16],
      CONSTRAINT [DF__tbConsist_c17] DEFAULT (0) FOR [c17],
      CONSTRAINT [DF__tbConsist_c29] DEFAULT (0) FOR [c29],
      CONSTRAINT [DF__tbConsist_c30] DEFAULT (0) FOR [c30],
      CONSTRAINT [DF__tbConsist_c31] DEFAULT (0) FOR [c31],
      CONSTRAINT [DF__tbConsist_c32] DEFAULT (0) FOR [c32],
      CONSTRAINT [PK_tbConsist] PRIMARY KEY CLUSTERED ([id_consist]) ON [PRIMARY]
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbConsist') and name = 'c9')
BEGIN
   ALTER TABLE [dbo].[tbConsist] ADD c9 bit NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbConsist') and name = 'c33')
BEGIN
   ALTER TABLE [dbo].[tbConsist] ADD c33 bit NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbConsist') and name = 'c34')
BEGIN
   ALTER TABLE [dbo].[tbConsist] ADD c34 bit NULL;
END
GO

/*
   Tabela dos departamentos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDepart') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDepart] (
      [id_depart] int NOT NULL,
      [id_empresa] int NOT NULL,
      [codigo] varchar(8) NOT NULL ,
      [descricao] varchar(50) NOT NULL ,
      [geral] bit NOT NULL,
      [cor_tarja] [float] NOT NULL,
      [cor_fonte] [float] NOT NULL,
      [contador] int NULL,
      [limite_dias_depto] int NULL,
      [id_phorario] int NULL,
      [id_arredonda] int NULL,
      [id_dsr] int NULL,
      [id_he] int NULL,
      [id_adicional] int NULL,
      [id_hnormais] int NULL,
      [id_tolera] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbDepart] WITH NOCHECK ADD
      CONSTRAINT [DF_tbDepart_id_empresa] DEFAULT (0) FOR [id_empresa],
      CONSTRAINT [DF_tbDepart_codigo] DEFAULT ('') FOR [codigo],
      CONSTRAINT [DF_tbDepart_cor_tarja] DEFAULT (0) FOR [cor_tarja],
      CONSTRAINT [DF_tbDepart_cor_fonte] DEFAULT (0) FOR [cor_fonte],
      CONSTRAINT [DF_tbDepart_contador] DEFAULT (0) FOR [contador],
      CONSTRAINT [PK_tbDepart] PRIMARY KEY CLUSTERED ([id_depart])  ON [PRIMARY];
   CREATE INDEX [IX_tbDepart] ON [dbo].[tbDepart]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDepart') and name = 'id_phorario')
BEGIN
   ALTER TABLE [dbo].[tbDepart] ADD id_phorario int NULL;
   ALTER TABLE [dbo].[tbDepart] ADD id_arredonda int NULL;
   ALTER TABLE [dbo].[tbDepart] ADD id_dsr int NULL;
   ALTER TABLE [dbo].[tbDepart] ADD id_he int NULL;
   ALTER TABLE [dbo].[tbDepart] ADD id_adicional int NULL;
   ALTER TABLE [dbo].[tbDepart] ADD id_hnormais int NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDepart') and name = 'id_tolera')
BEGIN
   ALTER TABLE [dbo].[tbDepart] ADD id_tolera int NULL;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDepart') and name = 'descricao' and length <> 50)
BEGIN
   ALTER TABLE [dbo].[tbDepart] ALTER COLUMN descricao VARCHAR(50) NOT NULL;
END;
GO

/*
   Tabela das empresas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEmpresas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEmpresas] (
      [id_empresa] int NOT NULL,
      [sai_lib] bit NOT NULL,
      [descricao] varchar(70) NOT NULL ,
      [codigo] varchar(8) NOT NULL ,
      [local] varchar(40) NOT NULL ,
      [func] bit NOT NULL, [func_ini] [float] NOT NULL,  [func_fim] [float] NOT NULL,
      [terc] bit NOT NULL, [terc_ini] [float] NOT NULL,  [terc_fim] [float] NOT NULL,
      [visi] bit NOT NULL, [visi_ini] [float] NOT NULL,  [visi_fim] [float] NOT NULL,
      [alun] bit NOT NULL, [alun_ini] [float] NOT NULL,  [alun_fim] [float] NOT NULL,
      [cond] bit NOT NULL, [cond_ini] [float] NOT NULL,  [cond_fim] [float] NOT NULL,
      [soci] bit NOT NULL, [soci_ini] [float] NOT NULL,  [soci_fim] [float] NOT NULL,
      [pais] bit NOT NULL, [pais_ini] [float] NOT NULL,  [pais_fim] [float] NOT NULL,
      [nome_fantasia] varchar(70) NULL,
      [cod_folha] varchar(10) NULL,
      [cnpj] varchar(20) NULL,
      [inscricao] varchar(20) NULL,
      [cei] varchar(20) NULL,
      [endereco] varchar(70) NULL,  [bairro] varchar(70) NULL, [cidade] varchar(70) NULL,
      [cep] varchar(10) NULL, [uf] varchar(2) NULL,
      [batidas_multiplas] int NULL, [he_permitida] bit NULL,
      [nrmc] int null, [inativo] bit null, [gmt] smallint null,
      [hverao_ini] datetime null, [hverao_fim] datetime null, [inativo_ace] bit null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEmpresas] WITH NOCHECK ADD
      CONSTRAINT [DF_tbEmpresas_codigo] DEFAULT ('') FOR [codigo],
      CONSTRAINT [DF_tbEmpresas_local] DEFAULT ('') FOR [local],
      CONSTRAINT [DF_tbEmpresas_func_ini] DEFAULT (0) FOR [func_ini],
      CONSTRAINT [DF_tbEmpresas_func_fim] DEFAULT (0) FOR [func_fim],
      CONSTRAINT [DF_tbEmpresas_terc_ini] DEFAULT (0) FOR [terc_ini],
      CONSTRAINT [DF_tbEmpresas_terc_fim] DEFAULT (0) FOR [terc_fim],
      CONSTRAINT [DF_tbEmpresas_visi_ini] DEFAULT (0) FOR [visi_ini],
      CONSTRAINT [DF_tbEmpresas_visi_fim] DEFAULT (0) FOR [visi_fim],
      CONSTRAINT [DF_tbEmpresas_alun_ini] DEFAULT (0) FOR [alun_ini],
      CONSTRAINT [DF_tbEmpresas_alun_fim] DEFAULT (0) FOR [alun_fim],
      CONSTRAINT [DF_tbEmpresas_cond_ini] DEFAULT (0) FOR [cond_ini],
      CONSTRAINT [DF_tbEmpresas_cond_fim] DEFAULT (0) FOR [cond_fim],
      CONSTRAINT [DF_tbEmpresas_soci_ini] DEFAULT (0) FOR [soci_ini],
      CONSTRAINT [DF_tbEmpresas_soci_fim] DEFAULT (0) FOR [soci_fim],
      CONSTRAINT [DF_tbEmpresas_pais_ini] DEFAULT (0) FOR [pais_ini],
      CONSTRAINT [DF_tbEmpresas_pais_fim] DEFAULT (0) FOR [pais_fim],
      CONSTRAINT [PK_tbEmpresas] PRIMARY KEY CLUSTERED ([id_empresa])  ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEmpresas') and name = 'nome_fantasia')
BEGIN
   ALTER TABLE [dbo].[tbEmpresas] ADD nome_fantasia varchar(70) NULL, cod_folha varchar(10) NULL,
            cnpj varchar(20) NULL, inscricao varchar(20) NULL, cei varchar(20) NULL, endereco varchar(70) NULL,
            bairro varchar(70) NULL, cidade varchar(70) NULL,  cep varchar(10) NULL, uf varchar(2) NULL,
            batidas_multiplas int NULL, he_permitida bit null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEmpresas') and name = 'nrmc')
BEGIN
   ALTER TABLE tbEmpresas ADD [nrmc] int null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEmpresas') and name = 'inativo')
BEGIN
   ALTER TABLE tbEmpresas ADD [inativo] bit null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEmpresas') and name = 'gmt')
BEGIN
   ALTER TABLE tbEmpresas ADD [gmt] smallint null, [hverao_ini] datetime null, [hverao_fim] datetime null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEmpresas') and name = 'inativo_ace')
BEGIN
   ALTER TABLE tbEmpresas ADD [inativo_ace] bit null;
   EXEC('UPDATE tbEmpresas SET inativo_ace=isnull(inativo,0)');
END
GO

/*
   Tabela de perodos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPerEmpresas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPerEmpresas] (
      [id_empresa] int NOT NULL ,
      [ano] int NOT NULL ,         [mes] int NOT NULL ,
      [fechamento_ini] datetime NULL ,
      [fechamento_fim] datetime NULL ,
      [he_ini] datetime NULL ,     [he_fim] datetime NULL ,
      [tolerancia_ini] datetime NULL , [tolerancia_fim] datetime NULL ,
      [banco_ini] datetime NULL , [banco_fim] datetime NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [PK_tbPerEmpresas] ON [dbo].[tbPerEmpresas]([id_empresa],[ano],[mes]) ON [PRIMARY];
   CREATE INDEX [IX_tbPerEmpresas_Banco] ON [dbo].[tbPerEmpresas]([id_empresa],[banco_ini],[banco_fim]) ON [PRIMARY];
end
GO

/*
   Tabela de encerramentos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEncEmp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEncEmp] (
      [id_empresa] int NOT NULL,
      [ano] int NOT NULL, [mes] int NOT NULL,
      [ult_data] datetime NOT NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [PK_tbEncEmp] ON [dbo].[tbEncEmp]([id_empresa]) ON [PRIMARY];
   CREATE INDEX [IX_tbEncEmp_ultper] ON [dbo].[tbEncEmp]([id_empresa],[ano],[mes]) ON [PRIMARY];
   CREATE INDEX [IX_tbEncEmp_ultdata] ON [dbo].[tbEncEmp]([id_empresa],[ult_data]) ON [PRIMARY];
   CREATE INDEX [IX_tbEncEmp_data] ON [dbo].[tbEncEmp]([ult_data]) ON [PRIMARY];
end
GO

/*
   Agrupamentos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAgrupamentos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAgrupamentos] (
      [id_agrupamento] int NOT NULL ,
      [descricao] varchar(50) NOT NULL,
      [id_phorario] int NULL,  [id_arredonda] int NULL,
      [id_dsr] int NULL,       [id_he] int NULL,
      [id_adicional] int NULL, [id_hnormais] int NULL,
      [codigo] int NOT NULL, [id_tolera] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAgrupamentos] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAgrupamentos] PRIMARY KEY CLUSTERED ([id_agrupamento]) ON [PRIMARY];
   CREATE INDEX [IX_tbAgrupamentos] ON [dbo].[tbAgrupamentos]([descricao]) ON [PRIMARY];
   CREATE INDEX [IX_tbAgrupamentos_codigo] ON [dbo].[tbAgrupamentos]([codigo]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAgrupamentos') and name = 'codigo')
BEGIN
   ALTER TABLE [dbo].[tbAgrupamentos] ADD codigo int NULL;
   exec('UPDATE tbAgrupamentos SET codigo = id_agrupamento');
   exec('ALTER TABLE tbAgrupamentos ALTER COLUMN codigo INT NOT NULL');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAgrupamentos') and name = 'id_tolera')
BEGIN
   ALTER TABLE [dbo].[tbAgrupamentos] ADD id_tolera int NULL;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAgrupamentos') and name = 'descricao' and length <> 50)
BEGIN
   ALTER TABLE [dbo].[tbAgrupamentos] ALTER COLUMN descricao VARCHAR(50) NOT NULL;
END;
GO

/*
   Tabela das escalas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEscalas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEscalas] (
      [id_empresa] int NOT NULL,
      [id_escala] int NOT NULL,
      [descricao] varchar(100) NOT NULL ,
      [id_horario] int NOT NULL, [geral] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEscalas] WITH NOCHECK ADD CONSTRAINT [PK_tbEscalas] PRIMARY KEY CLUSTERED ([id_escala])  ON [PRIMARY]
end
GO
--Atualizao
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEscalas') and name = 'descricao' and length < 100)
BEGIN
   ALTER TABLE tbEscalas ALTER COLUMN descricao VARCHAR(100);
END;
GO


/*
   Relacional da tabela das escalas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEscalasHorarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEscalasHorarios] (
      [id_escala] int NOT NULL,
      [data] datetime NOT NULL,
      [folga] bit NOT NULL, [id_horario] int NOT NULL
   ) ON [PRIMARY];
   CREATE INDEX [tbEscalasHorarios_data] ON [dbo].[tbEscalasHorarios]([id_escala], [data]) ON [PRIMARY]
end
GO

/*
   Tabela dos tipos de visitas para cadastramento de visitantes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEventVisi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEventVisi] (
      [id_eventvisi] int NOT NULL,
      [descricao] varchar(20) NOT NULL, [codigo] varchar(5) NULL,
      [aces_lmt] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEventVisi] WITH NOCHECK ADD CONSTRAINT [PK_tbEventVisi] PRIMARY KEY CLUSTERED (  [id_eventvisi])  ON [PRIMARY] ;
   ALTER TABLE [dbo].[tbEventVisi] WITH NOCHECK ADD
      CONSTRAINT [DF_tbEventVisi_id_eventvisi] DEFAULT (0) FOR [id_eventvisi],
      CONSTRAINT [DF_tbEventVisi_descricao] DEFAULT ('') FOR [descricao],
      CONSTRAINT [DF_tbEventVisi_codigo] DEFAULT ('') FOR [codigo];
end
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEventVisi') and name = 'aces_lmt')
BEGIN
   ALTER TABLE tbEventVisi ADD [aces_lmt] int NULL;
END
GO

/*
   Mensagens padres utilizadas na comunicao com os bloqueios
*/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEventoSist') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   DROP TABLE [dbo].[tbEventoSist];
end
GO
CREATE TABLE [dbo].[tbEventoSist] (
   [id_evento] int NOT NULL,
   [descricao] varchar(200) NULL, [flagimpedimento] bit NOT NULL
) ON [PRIMARY];
ALTER TABLE [dbo].[tbEventoSist] WITH NOCHECK ADD CONSTRAINT [DF_tbEventoSist_flagimpedimento] DEFAULT (0) FOR [flagimpedimento];
GO

CREATE INDEX IX_tbEventoSist ON dbo.tbEventoSist (id_evento, flagimpedimento);
GO

--Registros padres
delete from tbEventoSist;
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (01, 'LIBERADO ACESSO COMUM', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (02, 'LIBERADO ACESSO AUTORIZADO', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (03, 'TIME-OUT', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (04, 'LIBERADO ACESSO CRACHA MESTRE', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (05, 'LIBERADO CAPTURA EM BATCH', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (06, 'IMPEDIDO VERSAO DE CRACHA INVALIDA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (07, 'IMPEDIDO FORA DO HORARIO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (08, 'IMPEDIDO BLOQUEADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (09, 'IMPEDIDO FORA DO GRUPO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (10, 'IMPEDIDO FORA DO PERIODO DE PERMANENCIA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (11, 'IMPEDIDO AFASTADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (12, 'IMPEDIDO FERIADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (13, 'IMPEDIDO ESTOURO DE NRO. DE ACESSOS', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (14, 'IMPEDIDO TENTATIVA DE REENTRADA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (15, 'IMPEDIDO TENTATIVA DE SADA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (16, 'IMPEDIDO ALUNO SEM RESPONSVEL DENTRO DA EMPRESA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (17, 'IMPEDIDO CAPTURA EM BATCH', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (24, 'LIBERADO ACESSO EM REFEITORIO', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (25, 'IMPEDIDO FIM DE REFEICOES (EM REFEITORIO, EX. COMPROU 20 REF. E TERMINOU)', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (26, 'IMPEDIDO REFEICAO J EFETUADA (EM REF., estourou o nro. de aces. desta tab.)', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (27, 'IMPEDIDO FORA DE TABELA ==> FORA DO HORARIO DE REF. OU TAB DE REF.  ENCONTRADA (EM REFEITORIO)', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (28, 'IMPEDIDO FORA DO PERODO ==> FORA DO PERODO DE DATA DETERMINADO PARA REF.', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (29, 'IMPEDIDO HORRIO INDEVIDO (ENTRADA OU SADA ANTES DO PERODO DE ESPERA)', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (30, 'IMPEDIDO ENTREGAR PROVISORIO (ACESSO COM PROVISORIO APS PERIODO CADASTRADO)', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (31, 'IMPEDIDO CRACHA INVALIDO (ACESSO COM CARTO COMUM QUANDO H PROVISORIO CADASTRADO)', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (32, 'IMPEDIDO VERSO DE PROV INVLIDA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (33, 'IMPEDIDO SENHA INVLIDA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (34, 'IMPEDIDO GRP BLOQUEIO BLOQUEADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (35, 'IMPEDIDO BLOQ FORA HORRIO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (36, 'IMPEDIDO FORA DA SEQUNCIA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (37, 'SENTIDO PROIBIDO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (38, 'ACESSO PROIBIDO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (39, 'IMPEDIDO ESTOURO DO LIMITE DE DIAS SEM ACESSO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (40, 'IMPEDIDO ESTOURO DO LIMITE DE ACESSOS POR DIA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (41, 'IMPEDIDO ESTOURO DO LIMITE DE VISITANTES POR SUB-LOCAL', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (42, 'IMPEDIDO ESTOURO DO LIMITE DE VISITANTES POR VISITADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (43, 'IMPEDIDO LEITOR INVALIDO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (44, 'IMPEDIDO TIPO DE PASSANTE PROIBIDO NESTE BLOQUEIO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (45, 'IMPEDIDO LIMITE DE INTERVALO NO RESPEITADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (46, 'IMPEDIDO MARCAES MLTIPLAS', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (47, 'IMPEDIDO AUSNCIA MNIMA (ACESSO ANTES DA AUSNCIA MNIMA)', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (48, 'IMPEDIDO - REVISTA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (50, 'LIBERADO POR REGISTRO MANUAL', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (51, 'AGUARDANDO ACESSO COMBINADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (52, 'LIBERADO EM ACESSO COMBINADO', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (53, 'IMPEDIDO EM ACESSO COMBINADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (54, 'IMPEDIDO EM ESPERA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (55, 'IMPEDIDO INTEGRAO VENCIDA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (80, 'MARCAO IMPORTADA VIA AFD', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (91, 'REFEIO CANCELADA', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (92, 'REFEIO INCLUDA', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (99, 'IMPEDIDO NO CADASTRADO', 1);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (100, 'CAPTURA EM BATCH E CRACH NO CADASTRADO', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (101, 'LIBERADO ACESSO EM REFEITORIO - (CAPTURA EM BACTH, NUMERO DE REFEIES EXCEDIDA)', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (102, 'CAPTURA EM BATCH, CARTO MESTRE, FORA DO HORRIO', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (103, 'CAPTURA EM BATCH, PASSANTE COM DIREITO A REFEIO, FORA DO HORRIO', 0);
Insert tbEventoSist (id_evento, descricao, flagimpedimento) Values (104, 'CAPTURA EM BATCH, PASSANTE SEM DIREITO A REFEIO, FORA DO HORRIO', 0);
GO

/*
   Cadastro de eventos de abono
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEvsAbono') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEvsAbono] (
      [id_eveabo] int NOT NULL,
      [descricao] varchar (30) NOT NULL, [grp_acesso] varchar(5) NOT NULL,
      [cod_folha] varchar (5) NULL,  [abreviacao] varchar (7) NULL,
      [banco]     bit NOT NULL,      [calculo]    bit NOT NULL,
      [tipo_exp]  varchar(1) NOT NULL,
      [nao_exp]   bit NOT NULL,      [espelho]    bit NOT NULL,
      [obs]       varchar(100) NULL, [afasta]     bit NOT NULL,
      [calc_hn]   bit NOT NULL,      [sistema]    bit NOT NULL,
      [oldcod]    int null,          [opt_cid]    tinyint NULL,
      [absent]    bit null,          [abo_banco]  bit NULL,
      [retira_folga]  bit NULL, [retira_abono]  bit NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbEvsAbono] WITH NOCHECK ADD
      CONSTRAINT [PK_tbEvsAbono] PRIMARY KEY CLUSTERED ([id_eveabo]) ON [PRIMARY];
    CREATE INDEX [IX_tbEvsAbono] ON [dbo].[tbEvsAbono]([descricao]) ON [PRIMARY];
    CREATE INDEX [IX_tbEvsAbono_banco] ON [dbo].[tbEvsAbono]([id_eveabo],[banco]) ON [PRIMARY];
    CREATE INDEX [IX_tbEvsAbono_grp_acesso] ON [dbo].[tbEvsAbono]([grp_acesso]) ON [PRIMARY];
    CREATE INDEX [IX_tbEvsAbono_calculo] ON [dbo].[tbEvsAbono]([id_eveabo],[calculo]) ON [PRIMARY];
end
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'bloq_pto')
BEGIN
   EXEC('ALTER TABLE [dbo].[tbEvsAbono] DROP COLUMN [bloq_pto], [bloq_ace]');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'sistema')
BEGIN
   ALTER TABLE tbEvsAbono ADD [sistema] bit NULL, [oldcod] int null;
   EXEC('UPDATE tbEvsAbono SET sistema=0');
   EXEC('UPDATE tbEvsAbono SET sistema=1 WHERE descricao in (''Frias'',''Abonado'',''Folga'',''Afastamento'',''Inativo'')');
   EXEC('ALTER TABLE tbEvsAbono ALTER COLUMN sistema BIT NOT NULL');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'opt_cid')
BEGIN
   ALTER TABLE tbEvsAbono ADD [opt_cid] tinyint NULL;
END
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'abreviacao' and length <> 7)
BEGIN
   ALTER TABLE [dbo].[tbEvsAbono] ALTER COLUMN abreviacao VARCHAR(7) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'absent')
BEGIN
   ALTER TABLE [dbo].[tbEvsAbono] ADD [absent] bit null;
   EXEC('UPDATE tbEvsAbono SET absent=1;');
   EXEC('UPDATE tbEvsAbono SET absent=0 WHERE upper(descricao) IN (''FRIAS'',''FOLGA'',''SERVIO EXTERNO'',''GREVE DE NIBUS'',''INATIVO'',''FALECIMENTO'',''COMPENSADO'',''H.EXTRA NO AUTORIZADA'',''ESQUECEU DE MARCAR PONTO'','' COMPENSAR'',''SEM CRACH'',''PAGAMENTO'',''SUSPENSO'') or upper(descricao) LIKE ''LICENA%'';');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'abo_banco')
BEGIN
   ALTER TABLE [dbo].[tbEvsAbono] ADD [abo_banco] bit null;
   EXEC('UPDATE tbEvsAbono SET abo_banco=banco');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'retira_folga')
BEGIN
   ALTER TABLE [dbo].[tbEvsAbono] ADD [retira_folga]  bit NULL;
   EXEC('UPDATE tbEvsAbono SET retira_folga=0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEvsAbono') and name = 'retira_abono')
BEGIN
   ALTER TABLE [dbo].[tbEvsAbono] ADD [retira_abono]  bit NULL;
   EXEC('UPDATE tbEvsAbono SET retira_abono=0');
END;
GO
if not exists (select top 1 * from dbo.tbEvsAbono)
begin
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (1, 'Frias',                  'ABONO',1,0,1,'H',1,1,1,0,1,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (2, 'Abonado',                 'ABONO',1,0,1,'H',1,1,0,0,1,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (3, 'Folga',                   'ABONO',1,0,1,'H',1,1,1,0,1,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (4, 'Atestado',                'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (5, 'Auxilio doena',          'ABONO',1,0,1,'H',1,1,1,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (6, 'Licena Paternidade',     'ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (7, 'Licena Maternidade',     'ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (8, 'Servio Externo',         'ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (9, 'Greve de nibus',         'ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (10,'Consulta Mdica',         'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (11,'Esqueceu de Marcar Ponto','ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (12,'Sem Crach',              'ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (13,'H.Extra no Autorizada',  'ABONO',0,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (14,'Falecimento',             'ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (15,'Viagem',                  'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (16,'Atraso de Conduo',      'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (17,'Pagamento',               'ABONO',1,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (18,'Compensado',              'ABONO',0,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (19,' Compensar',             'ABONO',0,0,1,'H',1,1,0,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (20,'Particular',              'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (21,'Doao de Sangue',        'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (22,'Servio Militar',         'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (23,'Afastamento T.R.E',       'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (24,'Afastamento P.Judiciario','ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (25,'Suspenso',               'ABONO',1,0,1,'H',1,1,1,0,0,0);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (26,'Licena p/ casar',        'ABONO',1,0,1,'H',1,1,0,0,0,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (27,'Afastamento',             'ABONO',1,0,1,'H',1,1,1,0,1,1);
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (28,'Banco de Horas',          'ABONO',0,1,1,'H',1,1,0,0,0,0);
end
GO
if not exists (SELECT top 1 * FROM dbo.tbEvsAbono WHERE id_eveabo=50) begin
   INSERT INTO tbEvsAbono (id_eveabo, descricao, grp_acesso, abo_banco, banco, calculo, tipo_exp, nao_exp, espelho, afasta, calc_hn, sistema, absent) VALUES (50,'Inativo','ABONO',1,0,1,'H',1,0,1,0,1,0);
end;
GO

/*
   Divergncias de Apontamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDivergencias') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDivergencias] (
    [id_diverg]  int NOT NULL,
    [descricao]  varchar (40) NOT NULL,
    [cod_folha]  varchar (5) NULL,
    [abreviacao] varchar (7) NULL,   [ativada]    bit NOT NULL ,
    [banco]      bit NOT NULL,       [percbco]    float NOT NULL,
    [tipo_exp]   varchar(1) NOT NULL,
    [nao_exp]    bit NOT NULL,       [espelho]    bit NOT NULL,
    [soma]       bit NOT NULL,
    [tipo_he]    tinyint NULL,       [perche]     float NULL,
    [classe]     tinyint NOT NULL,   [oldcod]     int null, [oldtidi] varchar(3),
    [apt_manu]   bit NULL,
    [cp_auto]    bit NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbDivergencias] WITH NOCHECK ADD
      CONSTRAINT [PK_tbDivergencias] PRIMARY KEY CLUSTERED ([id_diverg]) ON [PRIMARY];
    CREATE INDEX [IX_tbDivergencias] ON [dbo].[tbDivergencias]([descricao]) ON [PRIMARY];
    CREATE INDEX [IX_tbDivergencias_ativada] ON [dbo].[tbDivergencias]([id_diverg],[ativada]) ON [PRIMARY];
    CREATE INDEX [IX_tbDivergencias_banco] ON [dbo].[tbDivergencias]([id_diverg],[banco],[ativada]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDivergencias') and name = 'tipo_he')
BEGIN
   ALTER TABLE [dbo].[tbDivergencias] ADD [tipo_he] tinyint NULL, [perche] float NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDivergencias') and name = 'classe')
BEGIN
   ALTER TABLE [dbo].[tbDivergencias] ADD [classe] tinyint NULL;
   EXEC('UPDATE tbDivergencias SET classe=0 WHERE id_diverg < 1000');
   EXEC('UPDATE tbDivergencias SET classe=1 WHERE id_diverg in (34, 35, 48, 49)');
   EXEC('UPDATE tbDivergencias SET classe=9 WHERE id_diverg >= 1000');
   EXEC('ALTER TABLE tbDivergencias ALTER COLUMN classe tinyint NOT NULL');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDivergencias') and name = 'oldcod')
BEGIN
   ALTER TABLE tbDivergencias ADD [oldcod] int null, [oldtidi] varchar(3);
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDivergencias') and name = 'apt_manu')
BEGIN
   ALTER TABLE [dbo].[tbDivergencias] ADD [apt_manu] bit NULL;
END
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDivergencias') and name = 'abreviacao' and length <> 7)
BEGIN
   ALTER TABLE [dbo].[tbDivergencias] ALTER COLUMN abreviacao VARCHAR(7) NULL;
END;
GO

if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 52) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (52, 'HORA REDUZIDA SOBRE H.E.', 1, 0, 1, 'H', 1, 1, 1, 0);
END;
GO
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 53) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (53, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE', 1, 0, 1, 'H', 1, 1, 1, 0);
END;
GO
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 54) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (54, 'DBITO DE V.R.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (55, 'CRDITO DE V.R.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (56, 'DBITO DE V.T.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (57, 'CRDITO DE V.T.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (58, 'VALE REFEIO', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (59, 'VALE TRANSPORTE', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (70, 'DBITO DE CESTA / V.A.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (71, 'CESTA BSICA / V.A.', 0, 0, 1, 'Q', 1, 0, 1, 2);
END;
GO
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 36) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (36, 'SALDO POSITIVO DE BANCO BANCO DE HORAS', 0, 0, 1, 'H', 1, 1, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (37, 'SALDO NEGATIVO DE BANCO BANCO DE HORAS', 0, 0, 1, 'H', 1, 1, 0, 1);
end;
GO
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 81) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (81, 'ADICIONAL NOTURNO (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (82, 'ADICIONAL NOTURNO (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (83, 'ADICIONAL NOTURNO (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (84, 'ADICIONAL NOTURNO (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (85, 'ADICIONAL NOTURNO SOBRE HE. (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (86, 'ADICIONAL NOTURNO SOBRE HE. (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (87, 'ADICIONAL NOTURNO SOBRE HE. (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (88, 'ADICIONAL NOTURNO SOBRE HE. (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
end;

if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 89) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (89, 'HORA REDUZIDA (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (90, 'HORA REDUZIDA (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (91, 'HORA REDUZIDA (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (92, 'HORA REDUZIDA (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (93, 'HORA REDUZIDA SOBRE H.E. (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (94, 'HORA REDUZIDA SOBRE H.E. (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (95, 'HORA REDUZIDA SOBRE H.E. (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (96, 'HORA REDUZIDA SOBRE H.E. (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (97, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (98, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (99, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (100, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
end;

if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 101) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (101, 'DESCONTOS NO COMPENSADOS', 1, 0, 1, 'H', 1, 1, 0, 0);
end;
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 102) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (102, 'SADA APS HORRIO EM BLOQUEIO PRIMRIO', 0, 0, 1, 'H', 1, 0, 1, 1);
end;
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 103) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (103, 'DIA LIVRE SEM PONTO EM BLOQUEIO PRIMRIO', 0, 0, 1, 'H', 1, 0, 1, 1);
end;
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 104) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (104, 'DESCONTO TOLERADO', 0, 0, 1, 'H', 1, 1, 0, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (105, 'ACRSCIMO TOLERADO', 0, 0, 1, 'H', 1, 1, 1, 1);
end;
if NOT EXISTS(SELECT id_diverg FROM tbDivergencias WHERE id_diverg = 106) begin
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (106, 'DIFERENA DE INTERJORNADA', 0, 0, 1, 'H', 1, 1, 1, 0);
end else begin
   UPDATE tbDivergencias SET classe = 0 WHERE id_diverg = 106;
end;

declare @conta int;
select @conta=0;
SELECT @conta=isnull(COUNT(id_diverg),0) FROM tbDivergencias WHERE id_diverg < 1000;
if @conta < 95 begin
   DELETE FROM tbDivergencias WHERE id_diverg < 1000;
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 1, 'FALTA NO 1 PERODO', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 2, 'FALTA NO 2 PERODO', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 3, 'FALTA NO 3 PERODO', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 4, 'FALTA NO 4 PERODO', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 5, 'FALTA MARCAO DE ENTRADA (1 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 6, 'FALTA MARCAO DE ENTRADA (2 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 7, 'FALTA MARCAO DE ENTRADA (3 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 8, 'FALTA MARCAO DE ENTRADA (4 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES ( 9, 'FALTA MARCAO DE SADA (1 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (10, 'FALTA MARCAO DE SADA (2 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (11, 'FALTA MARCAO DE SADA (3 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (12, 'FALTA MARCAO DE SADA (4 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (13, 'ATRASO NA ENTRADA (1 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (14, 'ATRASO NA ENTRADA (2 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (15, 'ATRASO NA ENTRADA (3 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (16, 'ATRASO NA ENTRADA (4 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (17, 'SADA ANTES DO HORRIO (1 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (18, 'SADA ANTES DO HORRIO (2 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (19, 'SADA ANTES DO HORRIO (3 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (20, 'SADA ANTES DO HORRIO (4 PERODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (21, 'ENTRADA ANTES DO HORRIO (1 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (22, 'ENTRADA ANTES DO HORRIO (2 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (23, 'ENTRADA ANTES DO HORRIO (3 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (24, 'ENTRADA ANTES DO HORRIO (4 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (25, 'SADA DEPOIS DO HORRIO (1 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (26, 'SADA DEPOIS DO HORRIO (2 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (27, 'SADA DEPOIS DO HORRIO (3 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (28, 'SADA DEPOIS DO HORRIO (4 PERODO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (29, 'FALTA (INTEGRAL)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (30, 'FALTA MARCAO (INTERVALO)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (31, 'HORAS ADICIONAIS DE INTERV. FLEX.', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (32, 'DESCONTO DE INTERV. EM H. FLEX.', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (33, 'DIA LIVRE TRABALHADO', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (34, 'PAGAMENTO DE BANCO DE HORAS', 1, 0, 1, 'H', 1, 1, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (35, 'DESCONTO DE BANCO DE HORAS', 1, 0, 1, 'H', 1, 1, 0, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (36, 'SALDO POSITIVO DE BANCO BANCO DE HORAS', 0, 0, 1, 'H', 1, 1, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (37, 'SALDO NEGATIVO DE BANCO BANCO DE HORAS', 0, 0, 1, 'H', 1, 1, 0, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (44, 'HORAS NORMAIS', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (45, 'ADICIONAL NOTURNO', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (46, 'ADICIONAL NOTURNO SOBRE HE.', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (47, 'HORA REDUZIDA', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (48, 'DIAS NORMAIS', 0, 0, 1, 'H', 1, 1, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (49, 'HORAS REAIS TRABALHADAS', 0, 0, 1, 'H', 1, 0, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (50, 'ACRSCIMO DE D.S.R.', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (51, 'DESCONTO DE D.S.R.', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (52, 'HORA REDUZIDA SOBRE H.E.', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (53, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (54, 'DBITO DE V.R.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (55, 'CRDITO DE V.R.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (56, 'DBITO DE V.T.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (57, 'CRDITO DE V.T.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (58, 'VALE REFEIO', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (59, 'VALE TRANSPORTE', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (60, 'INCIO DE INTERVALO ANTECIPADO', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (61, 'TRMINO DE INTERVALO COM ATRASO', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (62, 'INCIO DE INTERVALO COM ATRASO', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (63, 'TRMINO DE INTERVALO ANTECIPADO', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (64, 'FALTA MARCAO (VOLTA DO INTERV. FLEX.)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (65, 'FALTA MARCAO (SADA P/ INTERV. FLEX.)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (66, 'DESCONTO DE HORRIO FLEXVEL', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (67, 'ACRSCIMO DE HORRIO FLEXVEL', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (68, 'INTERVALO EXCEDENTE (H. FLEXVEL)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (69, 'ACRSC. DIA LIVRE (H. FLEXVEL)', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (70, 'DBITO DE CESTA / V.A.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (71, 'CESTA BSICA / V.A.', 0, 0, 1, 'Q', 1, 0, 1, 2);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (73, 'ACRSCIMO DE INTERV. EM H. FLEX.', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (75, 'FERIADO TRABALHADO', 1, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (76, 'FALTA MARCAO', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (77, 'INTERVALO INDEVIDO (1 PERIODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (78, 'INTERVALO INDEVIDO (2 PERIODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (79, 'INTERVALO INDEVIDO (3 PERIODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (80, 'INTERVALO INDEVIDO (4 PERIODO)', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (81, 'ADICIONAL NOTURNO (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (82, 'ADICIONAL NOTURNO (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (83, 'ADICIONAL NOTURNO (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (84, 'ADICIONAL NOTURNO (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (85, 'ADICIONAL NOTURNO SOBRE HE. (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (86, 'ADICIONAL NOTURNO SOBRE HE. (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (87, 'ADICIONAL NOTURNO SOBRE HE. (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (88, 'ADICIONAL NOTURNO SOBRE HE. (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (89, 'HORA REDUZIDA (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (90, 'HORA REDUZIDA (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (91, 'HORA REDUZIDA (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (92, 'HORA REDUZIDA (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (93, 'HORA REDUZIDA SOBRE H.E. (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (94, 'HORA REDUZIDA SOBRE H.E. (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (95, 'HORA REDUZIDA SOBRE H.E. (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (96, 'HORA REDUZIDA SOBRE H.E. (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (97, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%A)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (98, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%B)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (99, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%C)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (100, 'HORA REDUZIDA SOBRE H.E. DIA LIVRE (%D)', 0, 0, 1, 'H', 1, 1, 1, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (101, 'DESCONTOS NO COMPENSADOS', 1, 0, 1, 'H', 1, 1, 0, 0);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (102, 'SADA APS HORRIO EM BLOQUEIO PRIMRIO', 0, 0, 1, 'H', 1, 0, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (103, 'DIA LIVRE SEM PONTO EM BLOQUEIO PRIMRIO', 0, 0, 1, 'H', 1, 0, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (104, 'DESCONTO TOLERADO', 0, 0, 1, 'H', 1, 1, 0, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (105, 'ACRSCIMO TOLERADO', 0, 0, 1, 'H', 1, 1, 1, 1);
   INSERT INTO tbDivergencias (id_diverg, descricao, ativada, banco, percbco, tipo_exp, nao_exp, espelho, soma, classe) VALUES (106, 'DIFERENA DE INTERJORNADA', 0, 0, 1, 'H', 1, 1, 1, 0);
end;

IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDivergencias') and name = 'cp_auto')
BEGIN
   ALTER TABLE [dbo].[tbDivergencias] ADD cp_auto BIT NULL;
   EXEC('UPDATE tbDivergencias SET cp_auto=0');
   EXEC('UPDATE tbDivergencias SET cp_auto=1 WHERE id_diverg IN (1,2,3,4,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,33,66,67,69,75)');
   EXEC('UPDATE tbDivergencias SET cp_auto=1 WHERE id_diverg IN (SELECT a.id_divassoc FROM tbDivAssoc a WHERE a.id_diverg IN (1,2,3,4,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,33,66,67,69,75))');
   EXEC('UPDATE tbDivergencias SET cp_auto=1 WHERE isnull(tipo_he,0)>0');
END;
GO

/*
   Colunas de Resumo
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbClResumo') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbClResumo] (
    [id_empresa] int NOT NULL, [id_clresumo] tinyint NOT NULL,
    [descricao]  varchar (20) NOT NULL, [banco] bit NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbClResumo] WITH NOCHECK ADD
      CONSTRAINT [PK_tbClResumo] PRIMARY KEY CLUSTERED ([id_empresa],[id_clresumo]) ON [PRIMARY];
   CREATE INDEX [IX_tbClResumo_id_empresa] ON [dbo].[tbClResumo]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbClResumo') and name = 'banco')
BEGIN
   ALTER TABLE [dbo].[tbClResumo] ADD [banco] bit NULL;
   exec('UPDATE tbClResumo SET banco=0');
   exec('ALTER TABLE [dbo].[tbClResumo] ALTER COLUMN [banco] bit NOT NULL');
END
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbClResumoDiv') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbClResumoDiv] (
    [id_empresa] int NOT NULL, [id_clresumo] tinyint NOT NULL,
    [id_diverg]  int NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbClResumoDiv] WITH NOCHECK ADD
      CONSTRAINT [PK_tbClResumoDiv] PRIMARY KEY CLUSTERED ([id_empresa],[id_clresumo],[id_diverg]) ON [PRIMARY];
    CREATE INDEX [IX_tbClResumoDiv_id_diverg] ON [dbo].[tbClResumoDiv]([id_empresa],[id_diverg]) ON [PRIMARY];
    CREATE INDEX [IX_tbClResumoDiv_id_empresa] ON [dbo].[tbClResumoDiv]([id_empresa]) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbClResumoAbo') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbClResumoAbo] (
    [id_empresa] int NOT NULL, [id_clresumo] tinyint NOT NULL,
    [id_eveabo]  int NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbClResumoAbo] WITH NOCHECK ADD
      CONSTRAINT [PK_tbClResumoAbo] PRIMARY KEY CLUSTERED ([id_empresa],[id_clresumo],[id_eveabo]) ON [PRIMARY];
    CREATE INDEX [IX_tbClResumoAbo_id_eveabo] ON [dbo].[tbClResumoAbo]([id_empresa],[id_eveabo]) ON [PRIMARY];
    CREATE INDEX [IX_tbClResumoAbo_id_empresa] ON [dbo].[tbClResumoAbo]([id_empresa]) ON [PRIMARY];
end;
GO


/*
   Auxiliar das divergncias associadas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDivAssoc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDivAssoc] (
      [id_divassoc] int NOT NULL, [id_diverg]   int NOT NULL
   ) ON [PRIMARY];
    CREATE INDEX [IX_tbDivAssoc] ON [dbo].[tbDivAssoc]([id_divassoc]) ON [PRIMARY];
end
GO

/*
   vwDivAcrDsc - Divergncias de acrscimo e de desconto
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.vwDivAcrDsc') AND (xtype='V' or xtype='U')) BEGIN DROP VIEW dbo.vwDivAcrDsc; END;
GO
CREATE VIEW dbo.vwDivAcrDsc AS
   SELECT * FROM tbDivergencias
   WHERE id_diverg NOT IN (SELECT DISTINCT a1.id_diverg FROM tbDivAssoc a1) AND (
   id_diverg < 34
   OR id_diverg IN (60,61,62,63,64,65,66,67,68,69,73,77,78,79,80)
   OR isnull(tipo_he,0)>0
   OR id_diverg IN (
      SELECT a.id_divassoc FROM tbDivAssoc a
      WHERE a.id_diverg IN (
         SELECT d.id_diverg FROM tbDivergencias d
         WHERE d.id_diverg < 34 OR d.id_diverg IN (60,61,62,63,64,65,66,67,68,69,73,77,78,79,80)
      )
     )
   )
GO


/*
   Apontamentos Manuais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAptManuais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAptManuais] (
    [id_pass]    int NOT NULL,
    [ano]        int NOT NULL, [mes]        int NOT NULL,
    [id_diverg]  int NOT NULL, [valor] varchar(7) NOT NULL, [m_valor] int NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbAptManuais] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAptManuais] PRIMARY KEY CLUSTERED ([id_pass], [ano], [mes], [id_diverg]) ON [PRIMARY];
end
GO

/*
   Arredondamentos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbArredonda') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbArredonda] (
      [id_empresa] int NOT NULL,
      [geral] bit NOT NULL, [id_arredonda] int NOT NULL ,
      [descricao] varchar(40) NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbArredonda] WITH NOCHECK ADD
      CONSTRAINT [PK_tbArredonda] PRIMARY KEY CLUSTERED ([id_arredonda]) ON [PRIMARY];
end
GO

/*
   Faixas de Arredondamentos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbArredFxs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbArredFxs] (
      [id_arredonda] int NOT NULL,
      [id_diverg]    int NOT NULL,
      [minutos]      bit NOT NULL,
      [m_faixa_ini]  int NOT NULL, [m_faixa_fim]  int NOT NULL,
      [m_arredonda]  int NOT NULL,
      [faixa_ini]    varchar(6) NOT NULL, [faixa_fim]    varchar(6) NOT NULL,
      [arredonda]    varchar(6) NOT NULL
   ) ON [PRIMARY];
    CREATE INDEX [IX_tbArredFxs] ON [dbo].[tbArredFxs]([id_arredonda],[id_diverg]) ON [PRIMARY];
end
GO


/*
   Adicional noturno
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAdicNot') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAdicNot] (
      [id_empresa] int NOT NULL,
      [geral] bit NOT NULL,
      [id_adicional]     int NOT NULL,
      [descricao]   varchar(40) NOT NULL,
      [periodo_ini]      varchar(6) NOT NULL,
      [periodo_fim]      varchar(6) NOT NULL,
      [m_periodo_ini]    int NOT NULL,
      [m_periodo_fim]    int NOT NULL,
      [extender_periodo] bit NOT NULL,
      [minimo_entrada]   varchar(6) NOT NULL,
      [minimo_saida]     varchar(6) NOT NULL,
      [m_minimo_entrada] int NOT NULL,
      [m_minimo_saida]   int NOT NULL,
      [intervalo]        bit NOT NULL,
      [somar_reduzida]   bit NOT NULL,
      [fator]            float NOT NULL,
      [w_hn]             char(10) NOT NULL,
      [w_he]             char(10) NOT NULL,
      [redhen]           bit NULL,
      [reduzida]         bit NULL,
      [tolera]           bit NULL
   ) ON [PRIMARY];
    CREATE INDEX [IX_tbAdicNot] ON [dbo].[tbAdicNot]([id_adicional]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAdicNot') and name = 'redhen')
BEGIN
   ALTER TABLE [dbo].[tbAdicNot] ADD [redhen] bit NULL;
   exec('UPDATE tbAdicNot SET redhen=0');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAdicNot') and name = 'reduzida')
BEGIN
   ALTER TABLE [dbo].[tbAdicNot] ADD [reduzida] bit NULL;
   exec('UPDATE tbAdicNot SET reduzida=(case when isnull(somar_reduzida,0)=1 then 0 else 1 end)');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAdicNot') and name = 'tolera')
BEGIN
   ALTER TABLE [dbo].[tbAdicNot] ADD [tolera] bit NULL;
   exec('UPDATE tbAdicNot SET tolera=1');
END
GO

/*
   Faixas de adicional
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFxsAdc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFxsAdc] (
      [id_adicional] int NOT NULL ,
      [normal] bit NOT NULL ,
      [dia]   int NOT NULL ,
      [opcao] int NOT NULL ,
      [contafx] int NOT NULL,
      [faixa_ini] varchar(6) NOT NULL,
      [faixa_fim] varchar(6) NOT NULL,
      [m_faixa_ini] int NOT NULL,
      [m_faixa_fim] int NOT NULL,
      [id_diverg]   int NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [PK_tbFxsAdc] ON [dbo].[tbFxsAdc]([id_adicional],[normal],[dia],[contafx]) ON [PRIMARY];
   exec('insert into tbFxsAdc select id_adicional, 0, 0, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 1, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 2, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 3, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 4, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 5, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 6, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 7, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 8, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 0, 9, 0, 0, ''000:00'', ''999:59'',0, 59999, 46 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 0, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 1, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 2, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 3, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 4, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 5, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 6, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 7, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 8, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
   exec('insert into tbFxsAdc select id_adicional, 1, 9, 0, 0, ''000:00'', ''999:59'',0, 59999, 45 from  tbAdicNot');
end
GO

/*
   Tabela de banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabBco') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabBco] (
      [id_empresa] int NOT NULL,
      [geral] bit NOT NULL,
      [id_tabbco] int NOT NULL,
      [descricao] varchar(40) NOT NULL,
      [validade_cre] tinyint null,
      [validade_deb] tinyint null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTabBco] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabBco] PRIMARY KEY CLUSTERED ([id_tabbco]) ON [PRIMARY];
   exec('INSERT INTO tbTabBco (id_empresa, geral, id_tabbco, descricao) VALUES (1,1,1,''BANCO DE HORAS'')');
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTabBco') and name = 'validade_cre')
BEGIN
   ALTER TABLE [dbo].[tbTabBco] ADD [validade_cre] tinyint null;
   ALTER TABLE [dbo].[tbTabBco] ADD [validade_deb] tinyint null;
   EXEC('UPDATE tbTabBco SET validade_cre=ISNULL((SELECT TOP 1 validade_cre FROM tbEmpresas WHERE isnull(validade_cre,0) > 0 ),validade_cre)');
   EXEC('UPDATE tbTabBco SET validade_deb=ISNULL((SELECT TOP 1 validade_deb FROM tbEmpresas WHERE isnull(validade_deb,0) > 0 ),validade_deb)');
   EXEC('ALTER TABLE [dbo].[tbEmpresas] DROP COLUMN [validade_cre]');
   EXEC('ALTER TABLE [dbo].[tbEmpresas] DROP COLUMN [validade_deb]');
END
GO

/*
   Tabela perodos para pagamento de crditos do banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabBcoPag') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabBcoPag] (
      [id_tabbco] int NOT NULL,
      [per_bco] int NOT NULL,
      [cred] bit NOT NULL,
      [deb] bit NOT NULL,
      [creditos] varchar(8) NULL,
      [debitos] varchar(8) NULL,
      [m_creditos] int NULL,
      [m_debitos] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTabBcoPag] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabBcoPag] PRIMARY KEY CLUSTERED ([id_tabbco],[per_bco]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTabBcoPag') and name = 'creditos')
BEGIN
   ALTER TABLE [dbo].[tbTabBcoPag] ADD [creditos] varchar(8) NULL, [debitos] varchar(8) NULL, [m_creditos] int NULL, [m_debitos] int NULL;
END
GO


/*
   Divergncias de banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDivsBco') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDivsBco] (
      [id_tabbco] int NOT NULL,
      [id_diverg] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbDivsBco] WITH NOCHECK ADD
      CONSTRAINT [PK_tbDivsBco] PRIMARY KEY CLUSTERED ([id_tabbco],[id_diverg]) ON [PRIMARY];
   exec('INSERT INTO tbDivsBco (id_tabbco, id_diverg) SELECT 1, d.id_diverg FROM tbDivergencias d WHERE d.banco=1');
end
GO

/*
   DSR
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDSR') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDSR] (
      [id_empresa] int NOT NULL ,
      [geral] bit NOT NULL ,
      [id_dsr]     int NOT NULL ,
      [descricao]  varchar(40) NOT NULL ,
      [domingo]    varchar(6) NOT NULL ,
      [feriado]    varchar(6) NOT NULL ,
      [folga]      varchar(6) NOT NULL ,
      [m_domingo]  int NOT NULL ,
      [m_feriado]  int NOT NULL ,
      [m_folga]    int NOT NULL ,
      [desc_proporcional] bit NOT NULL,
      [desc_semavaliar] int NOT NULL,
      [desc_semdescontar] int NOT NULL,
      [calc_dias] bit NOT NULL,
      [dias_semana] int NOT NULL,
      [pagar_dsr]   bit NOT NULL,
      [tolera_valor] varchar(6) NOT NULL ,
      [m_tolera_valor] int NOT NULL ,
      [tolera_qtde] int NOT NULL ,
      [per_dsr] int null,
      [folg_prox] int null,
      [tolera_dia] varchar(6) NOT NULL ,
      [m_tolera_dia] int NOT NULL,
      [prop_diver] bit NOT NULL,
      [dia_dsr] int NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbDSR] WITH NOCHECK ADD
      CONSTRAINT [PK_tbDSR] PRIMARY KEY CLUSTERED ([id_dsr]) ON [PRIMARY];
   CREATE INDEX [IX_tbDSR] ON [dbo].[tbDSR]([id_dsr],[desc_semdescontar]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDSR') and name = 'per_dsr')
BEGIN
   ALTER TABLE [dbo].[tbDSR] ADD [per_dsr] int NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDSR') and name = 'folg_prox')
BEGIN
   ALTER TABLE [dbo].[tbDSR] ADD [folg_prox] int null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDSR') and name = 'tolera_dia')
BEGIN
   ALTER TABLE [dbo].[tbDSR] ADD [tolera_dia] varchar(6) NULL, [m_tolera_dia] int NULL;
   EXEC('UPDATE tbDSR SET tolera_dia=''__:__'', m_tolera_dia=-1');
   EXEC('ALTER TABLE [dbo].[tbDSR] ALTER COLUMN [tolera_dia] varchar(6) NOT NULL');
   EXEC('ALTER TABLE [dbo].[tbDSR] ALTER COLUMN [m_tolera_dia] int NOT NULL');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDSR') and name = 'prop_diver')
BEGIN
   ALTER TABLE [dbo].[tbDSR] ADD [prop_diver] BIT NULL;
   EXEC('UPDATE tbDSR SET prop_diver=0');
   EXEC('ALTER TABLE [dbo].[tbDSR] ALTER COLUMN [prop_diver] BIT NOT NULL');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDSR') and name = 'dia_dsr')
BEGIN
   ALTER TABLE [dbo].[tbDSR] ADD [dia_dsr] int null;
END
GO

/*
   Divergncias que descontam DSR
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDivDescDSR') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDivDescDSR] (
      [id_dsr]     int NOT NULL ,
      [id_diverg]  int NOT NULL ,
      [ignora_abono_total] int NOT NULL,
      [ignora_abono_parcial] int NOT NULL
   ) ON [PRIMARY];
    CREATE INDEX [IX_tbDivDescDSR] ON [dbo].[tbDivDescDSR]([id_dsr]) ON [PRIMARY];
end
GO

/*
   Horas Extras
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHE') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHE] (
      [id_empresa] int NOT NULL ,
      [geral] bit NOT NULL ,
      [id_he]     int NOT NULL ,
      [descricao]  varchar(40) NOT NULL ,
      [somar_fora_per] bit NOT NULL,
      [he_itv] bit NOT NULL,
      [quebra] bit NOT NULL,
      [abater_vl] varchar(6),
      [abater_ht] varchar(6),
      [m_abater_ht] int NOT NULL ,
      [m_abater_vl] int NOT NULL ,
      [folga_dia] bit NULL,
      [quebra_b] bit NULL,
      [quebra_c] bit NULL,
      [he_ace] bit NULL,
      [quebra_d] bit NULL,
      [quebra_e] bit NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbHE] WITH NOCHECK ADD
      CONSTRAINT [PK_tbHE] PRIMARY KEY CLUSTERED ([id_he]) ON [PRIMARY];
end
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHE') and name = 'somar_dia_noite')
BEGIN
   ALTER TABLE [dbo].[tbHE] DROP COLUMN [somar_dia_noite];
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHE') and name = 'folga_dia')
BEGIN
   ALTER TABLE [dbo].[tbHE] ADD [folga_dia] BIT NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHE') and name = 'quebra_b')
BEGIN
   ALTER TABLE [dbo].[tbHE] ADD [quebra_b] bit NULL, [quebra_c] bit NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHE') and name = 'he_ace')
BEGIN
   ALTER TABLE [dbo].[tbHE] ADD [he_ace] bit NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHE') and name = 'quebra_d')
BEGIN
   ALTER TABLE [dbo].[tbHE] ADD [quebra_d] bit NULL, [quebra_e] bit NULL;
   EXEC('UPDATE tbHE SET quebra_d=quebra, quebra_e=quebra');
END
GO

/*
   Faixas de hora extra
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFxsHE') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFxsHE] (
      [id_he] int NOT NULL ,
      [dia]   int NOT NULL ,
      [opcao] int NOT NULL ,
      [periodo] int NOT NULL ,
      [contafx] int NOT NULL,
      [faixa_ini] varchar(6) NOT NULL,
      [faixa_fim] varchar(6) NOT NULL,
      [m_faixa_ini] int NOT NULL,
      [m_faixa_fim] int NOT NULL,
      [id_divdia]   int NULL,
      [id_divdia_fora] int NULL,
      [id_divnoite] int NULL,
      [id_divnoite_fora] int NULL
   ) ON [PRIMARY];
    CREATE CLUSTERED INDEX [IX_tbFxsHE_Opt] ON [dbo].[tbFxsHE]([id_he],[dia]) ON [PRIMARY];
    CREATE INDEX [IX_tbFxsHE] ON [dbo].[tbFxsHE]([id_he],[opcao],[contafx]) ON [PRIMARY];
end
GO
--Atualizaes
if EXISTS(select name from dbo.sysobjects where id = object_id(N'dbo.tbVersao') and OBJECTPROPERTY(id, N'IsUserTable') = 1) begin
   IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVersao') and name = 'databco') begin
      if exists(SELECT * FROM tbVersao WHERE databco < '2013-01-22') begin
         UPDATE tbFxsHE SET faixa_ini = '000:00', m_faixa_ini=0 WHERE m_faixa_ini=1;
      end;
   end;
end;
GO

/*
   Horas Normais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHNormais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHNormais] (
      [id_empresa] int NOT NULL ,
      [geral] bit NOT NULL ,
      [id_hnormais]   int NOT NULL ,
      [descricao]    varchar(40) NOT NULL ,
      [metodo]       tinyint NOT NULL ,
      [abate_dia]    bit NOT NULL,
      [hn_mes_01]    varchar(6) NOT NULL ,
      [hn_mes_02]    varchar(6) NOT NULL ,
      [hn_mes_03]    varchar(6) NOT NULL ,
      [hn_mes_04]    varchar(6) NOT NULL ,
      [hn_mes_05]    varchar(6) NOT NULL ,
      [hn_mes_06]    varchar(6) NOT NULL ,
      [hn_mes_07]    varchar(6) NOT NULL ,
      [hn_mes_08]    varchar(6) NOT NULL ,
      [hn_mes_09]    varchar(6) NOT NULL ,
      [hn_mes_10]    varchar(6) NOT NULL ,
      [hn_mes_11]    varchar(6) NOT NULL ,
      [hn_mes_12]    varchar(6) NOT NULL ,
      [hn_mes_13]    varchar(6) NOT NULL ,
      [m_hn_mes_01]  int NOT NULL ,
      [m_hn_mes_02]  int NOT NULL ,
      [m_hn_mes_03]  int NOT NULL ,
      [m_hn_mes_04]  int NOT NULL ,
      [m_hn_mes_05]  int NOT NULL ,
      [m_hn_mes_06]  int NOT NULL ,
      [m_hn_mes_07]  int NOT NULL ,
      [m_hn_mes_08]  int NOT NULL ,
      [m_hn_mes_09]  int NOT NULL ,
      [m_hn_mes_10]  int NOT NULL ,
      [m_hn_mes_11]  int NOT NULL ,
      [m_hn_mes_12]  int NOT NULL ,
      [m_hn_mes_13]  int NOT NULL ,
      [hn_dia_01]    varchar(5) NOT NULL ,
      [hn_dia_02]    varchar(5) NOT NULL ,
      [hn_dia_03]    varchar(5) NOT NULL ,
      [hn_dia_04]    varchar(5) NOT NULL ,
      [hn_dia_05]    varchar(5) NOT NULL ,
      [hn_dia_06]    varchar(5) NOT NULL ,
      [hn_dia_07]    varchar(5) NOT NULL ,
      [hn_dia_08]    varchar(5) NOT NULL ,
      [hn_dia_09]    varchar(5) NOT NULL ,
      [hn_dia_10]    varchar(5) NOT NULL ,
      [hn_dia_11]    varchar(5) NOT NULL ,
      [hn_dia_12]    varchar(5) NOT NULL ,
      [hn_dia_13]    varchar(5) NOT NULL ,
      [m_hn_dia_01]  int NOT NULL ,
      [m_hn_dia_02]  int NOT NULL ,
      [m_hn_dia_03]  int NOT NULL ,
      [m_hn_dia_04]  int NOT NULL ,
      [m_hn_dia_05]  int NOT NULL ,
      [m_hn_dia_06]  int NOT NULL ,
      [m_hn_dia_07]  int NOT NULL ,
      [m_hn_dia_08]  int NOT NULL ,
      [m_hn_dia_09]  int NOT NULL ,
      [m_hn_dia_10]  int NOT NULL ,
      [m_hn_dia_11]  int NOT NULL ,
      [m_hn_dia_12]  int NOT NULL ,
      [m_hn_dia_13]  int NOT NULL ,
      [per_hn]       int NULL,
      [id_divassoc]  int NULL,
      [abate_dsr]    bit NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbHNormais] WITH NOCHECK ADD
      CONSTRAINT [PK_tbHNormais] PRIMARY KEY CLUSTERED ([id_hnormais]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHNormais') and name = 'per_hn')
BEGIN
   ALTER TABLE [dbo].[tbHNormais] ADD [per_hn] int NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHNormais') and name = 'id_divassoc')
BEGIN
   ALTER TABLE [dbo].[tbHNormais] ADD [id_divassoc] int NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHNormais') and name = 'abate_dsr')
BEGIN
   ALTER TABLE [dbo].[tbHNormais] ADD [abate_dsr] bit NULL;
END
GO

/*
   Divergncias das tabelas de horas normais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHNDivs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHNDivs] (
      [id_hnormais] int NOT NULL ,
      [id_diverg]  int NOT NULL
   ) ON [PRIMARY];
    CREATE CLUSTERED INDEX [IX_tbHNDivs] ON [dbo].[tbHNDivs]([id_hnormais],[id_diverg]) ON [PRIMARY];
end
GO

/*
   Cadastro de Classes DE CIDs
*/
if NOT exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbClasseCID') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbClasseCID] (
      id_classe_cid int NOT NULL, [cid_ini] varchar(10) NOT NULL, [cid_fim] varchar(10) NOT NULL, [descricao] varchar(150) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbClasseCID] WITH NOCHECK ADD CONSTRAINT [PK_tbClasseCID] PRIMARY KEY CLUSTERED ([id_classe_cid]) ON [PRIMARY];
end;
GO
DELETE FROM tbClasseCID;
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 1, '          ', '          ','Sem classificao');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 2, 'A00       ', 'B99ZZZZZZZ','Algumas doenas infecciosas e parasitrias');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 3, 'C00       ', 'D48ZZZZZZZ','Neoplasmas (tumores)');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 4, 'D50       ', 'D89ZZZZZZZ','Doenas do sangue e dos rgos hematopoticos e alguns transtornos imunitrios');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 5, 'E00       ', 'E90ZZZZZZZ','Doenas endcrinas, nutricionais e metablicas');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 6, 'F00       ', 'F99ZZZZZZZ','Transtornos mentais e comportamentais');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 7, 'G00       ', 'G99ZZZZZZZ','Doenas do sistema nervoso');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 8, 'H00       ', 'H59ZZZZZZZ','Doenas do olho e anexos');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES ( 9, 'H60       ', 'H95ZZZZZZZ','Doenas do ouvido e da apfise mastide');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (10, 'I00       ', 'I99ZZZZZZZ','Doenas do aparelho circulatrio');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (11, 'J00       ', 'J99ZZZZZZZ','Doenas do aparelho respiratrio');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (12, 'K00       ', 'K93ZZZZZZZ','Doenas do aparelho digestivo');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (13, 'L00       ', 'L99ZZZZZZZ','Doenas da pele e do tecido subcutneo');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (14, 'M00       ', 'M99ZZZZZZZ','Doenas do sistema osteomuscular e do tecido conjuntivo');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (15, 'N00       ', 'N99ZZZZZZZ','Doenas do aparelho geniturinrio');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (16, 'O00       ', 'O99ZZZZZZZ','Gravidez, parto e puerprio');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (17, 'P00       ', 'P96ZZZZZZZ','Algumas afeces originadas no perodo perinatal');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (18, 'Q00       ', 'Q99ZZZZZZZ','Malformaes congnitas, deformidades e anomalias cromossmicas');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (19, 'R00       ', 'R99ZZZZZZZ','Sintomas, sinais e achados anormais de exames clnicos e de laboratrio');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (20, 'S00       ', 'T98ZZZZZZZ','Leses, envenenamentos e algumas outras conseqncias de causas externas');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (21, 'V01       ', 'Y98ZZZZZZZ','Causas externas de morbidade e de mortalidade');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (22, 'Z00       ', 'Z99ZZZZZZZ','Fatores que influenciam o estado de sade e o contato com os servios de sade');
INSERT INTO tbClasseCID (id_classe_cid, cid_ini, cid_fim, descricao) VALUES (23, 'U00       ', 'U99ZZZZZZZ','Cdigos para propsitos especiais');
GO

/*
   Cadastro de CIDs
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCadCID') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCadCID] (
      [cid] varchar(10) NOT NULL, [descricao] varchar(150) NOT NULL, [id_classe_cid] int NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbCadCID] WITH NOCHECK ADD CONSTRAINT [PK_tbCadCID] PRIMARY KEY CLUSTERED ([cid]) ON [PRIMARY];
end;
GO

/*
   Calendrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCalendario') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCalendario] (
   [id_empresa]    int NOT NULL ,
   [id_pass]       int NOT NULL ,
   [data]          datetime NOT NULL ,
   [tipo]          [char](1) NOT NULL ,
   [desc_feriado]  varchar(20) NULL ,
   [id_phorario]   int NULL,
   [id_horario]    int NULL,
   [id_eveabo]     int NULL,
   [horas_abono]   varchar(7) NULL,
   [m_horas_abono] int NULL,
   [id_usuario]    int NULL,
   [cid]           varchar(10) NULL,
   [obs]           varchar(30) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCalendario] WITH NOCHECK ADD
      CONSTRAINT [PK_tbCalendario] PRIMARY KEY CLUSTERED ([id_empresa],[id_pass],[data],[tipo]) ON [PRIMARY];
   CREATE INDEX IX_tbCalendarioIdPass ON dbo.tbCalendario (id_pass, data);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCalendario') and name = 'id_usuario')
BEGIN
   ALTER TABLE [dbo].[tbCalendario] ADD [id_usuario] int NULL;
   exec('UPDATE tbCalendario SET id_usuario=0');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCalendario') and name = 'cid')
BEGIN
   ALTER TABLE [dbo].[tbCalendario] ADD [cid] varchar(10) NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCalendario') and name = 'obs')
BEGIN
   ALTER TABLE [dbo].[tbCalendario] ADD [obs] varchar(30) NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbCalendario') and name = 'IX_tbCalendarioIdPass')
BEGIN
   CREATE INDEX IX_tbCalendarioIdPass ON dbo.tbCalendario (id_pass, data);
END;
GO

--Eliminar tbFeriados
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFeriados') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   exec('insert into tbCalendario (id_empresa, id_pass, data, tipo, desc_feriado) select 0,0,f.data,''V'', left(f.descricao,20) from tbFeriados f');
   exec('drop table tbFeriados');
end;

/*
   Permisso de HE
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPerHE') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPerHE] (
   [id_empresa]   int NOT NULL,
   [id_pass]      int NOT NULL,
   [data]         datetime NOT NULL,
   [tipo]         [char](1) NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbPerHE] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPerHE] PRIMARY KEY CLUSTERED ([id_empresa],[id_pass],[data],[tipo]) ON [PRIMARY];
   CREATE INDEX IX_tbPerHEIdPass ON dbo.tbPerHE (id_pass, data);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPerHE') and name = 'IX_tbPerHEIdPass')
BEGIN
   CREATE INDEX IX_tbPerHEIdPass ON dbo.tbPerHE (id_pass, data);
END;
GO


/*
   Tabela das escalas do ponto
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPEscalas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPEscalas] (
      [id_empresa] int NOT NULL ,
      [id_pescala] int NOT NULL ,
      [descricao] varchar (100) NOT NULL ,
      [id_phorario] int NOT NULL ,
      [geral] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPEscalas] WITH NOCHECK ADD CONSTRAINT [PK_tbPEscalas] PRIMARY KEY CLUSTERED ([id_pescala])  ON [PRIMARY]
end
GO
--Atualizao
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPEscalas') and name = 'descricao' and length < 100)
BEGIN
   ALTER TABLE tbPEscalas ALTER COLUMN descricao VARCHAR(100);
END;
GO

/*
   Relacional da tabela das escalas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPEscalasHorarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPEscalasHorarios] (
      [id_pescala] int NOT NULL ,
      [data] datetime NOT NULL ,
      [folga] bit NOT NULL ,
      [id_phorario] int NOT NULL
   ) ON [PRIMARY];
   CREATE INDEX [tbPEscalasHorarios_data] ON [dbo].[tbPEscalasHorarios]([id_pescala], [data]) ON [PRIMARY];
end
GO

/*
   Folgas dominicais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPEscFDom') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPEscFDom] (
      [id_pass] int NOT NULL ,
      [data] datetime NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPEscFDom] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPEscFDom] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end
GO

/*
   Tabelas horrias de ponto
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPGHorarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPGHorarios] (
      [id_empresa]  int NOT NULL ,
      [geral]       bit NOT NULL ,
      [id_phorario] int NOT NULL ,
      [descricao]   varchar(100) NOT NULL ,
      [tipo]        varchar(1) NOT NULL,
      [inativo]     bit,
      [codigo]      int NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbPGHorarios] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPGHorarios] PRIMARY KEY CLUSTERED ([id_phorario]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPGHorarios') and name = 'inativo')
BEGIN
   ALTER TABLE [dbo].[tbPGHorarios] ADD inativo BIT;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPGHorarios') and name = 'descricao' and length < 100)
BEGIN
   ALTER TABLE tbPGHorarios ALTER COLUMN descricao VARCHAR(100);
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPGHorarios') and name = 'codigo')
BEGIN
   ALTER TABLE tbPGHorarios ADD [codigo] int NULL;
   exec('UPDATE tbPGHorarios SET codigo=isnull((SELECT TOP 1 codigo from tbPHorarios WHERE tbPHorarios.id_phorario=tbPGHorarios.id_phorario),codigo)');
   exec('UPDATE tbPGHorarios SET codigo=isnull((SELECT TOP 1 codigo from tbPHorFlex WHERE tbPHorFlex.id_pflex=tbPGHorarios.id_phorario),codigo)');
END;
GO



/*
   Tabela de horrio fixo
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPHorarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPHorarios] (
      [id_empresa]  int NOT NULL ,
      [geral]       bit NOT NULL ,
      [id_phorario] int NOT NULL ,
      [codigo]      int NOT NULL ,
      [descricao]   varchar(100) NOT NULL ,
      [enquadra_antes]  varchar(6) NOT NULL,
      [enquadra_depois]  varchar(6) NOT NULL,
      [m_enquadra_antes]  int NOT NULL,
      [m_enquadra_depois]  int NOT NULL,
      [acresce_falta] bit NOT NULL,
      [feriado_normal] bit NOT NULL,
      [excede_flex] bit NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbPHorarios] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPHorarios] PRIMARY KEY CLUSTERED ([id_phorario]) ON [PRIMARY];
    CREATE INDEX [IX_tbPHorarios] ON [dbo].[tbPHorarios]([codigo]) ON [PRIMARY];
end
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorarios') and name = 'onhe00')
BEGIN
   ALTER TABLE [dbo].[tbPHorarios] DROP COLUMN onhe00, onhe01, onhe02, onintv, ondc00, ondc01, ondc02, m_onhe00, m_onhe01, m_onhe02, m_onintv, m_ondc00, m_ondc01, m_ondc02;
END;
GO
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFxPtoNO') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
   DROP TABLE [dbo].[tbFxPtoNO];
   DROP TABLE [dbo].[tbFxRelog];
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorarios') and name = 'descricao' and length < 100)
BEGIN
   ALTER TABLE tbPHorarios ALTER COLUMN descricao VARCHAR(100);
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorarios') and name = 'excede_flex')
BEGIN
   ALTER TABLE tbPHorarios ADD excede_flex BIT NULL;
END;
GO

/*
   Faixas dos horrios fixos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFxPHorarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFxPHorarios] (
      [id_phorario] int NOT NULL ,
      [wdia]        int NOT NULL ,
      [entrada1]    varchar(6) NOT NULL,
      [saida1]      varchar(6) NOT NULL,
      [entrada2]    varchar(6) NOT NULL,
      [saida2]      varchar(6) NOT NULL,
      [entrada3]    varchar(6) NOT NULL,
      [saida3]      varchar(6) NOT NULL,
      [entrada4]    varchar(6) NOT NULL,
      [saida4]      varchar(6) NOT NULL,
      [flex_ini]    varchar(6) NOT NULL,
      [flex_fim]    varchar(6) NOT NULL,
      [flex_tempo]  varchar(6) NOT NULL,
      [m_entrada1]    int NOT NULL ,
      [m_saida1]      int NOT NULL ,
      [m_entrada2]    int NOT NULL ,
      [m_saida2]      int NOT NULL ,
      [m_entrada3]    int NOT NULL ,
      [m_saida3]      int NOT NULL ,
      [m_entrada4]    int NOT NULL ,
      [m_saida4]      int NOT NULL ,
      [m_flex_ini]     int NOT NULL ,
      [m_flex_fim]     int NOT NULL ,
      [m_flex_tempo]   int NOT NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [IX_tbFxPHorarios] ON [dbo].[tbFxPHorarios]([id_phorario]) ON [PRIMARY];
end
GO

/*
   Tabelas gerais com descrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabDesc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabDesc] (
      [id_tabdesc] int NOT NULL,
      [tipo] int NOT NULL, --0 dependentes
      [descricao] varchar(100) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTabDesc] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabDesc] PRIMARY KEY CLUSTERED ([id_tabdesc])  ON [PRIMARY];
   CREATE INDEX [IX_tbTabDesc] ON [dbo].[tbTabDesc]([tipo]) ON [PRIMARY];
end;
GO
--Valores padres
if not exists(select * from tbTabDesc where tipo = 0)
begin
   if not exists(select * from tbTabDesc)
   begin
      insert into tbTabDesc (id_tabdesc, tipo, descricao) values (1,0,'Cnjugue');
   end else begin
      insert into tbTabDesc (id_tabdesc, tipo, descricao) select max(id_tabdesc)+1, 0,'Cnjugue' from tbTabDesc;
   end;
   insert into tbTabDesc (id_tabdesc, tipo, descricao) select max(id_tabdesc)+1, 0,'Filho(a)' from tbTabDesc;
end;
GO

/*
   Tolerncias
*/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTolera') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
   and exists(SELECt name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTolera') and name = 'id_phorario')
begin
   if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tmp_tbTolera') and OBJECTPROPERTY(id, N'IsUserTable') = 1) begin
      drop table tmp_tbTolera;
   end;

   CREATE TABLE [dbo].[tmp_tbTolera] (
      [id_phorario] int NOT NULL ,
      [desc_ent1_dia] varchar(6) NOT NULL , [desc_sai1_dia] varchar(6) NOT NULL ,
      [desc_ent2_dia] varchar(6) NOT NULL , [desc_sai2_dia] varchar(6) NOT NULL ,
      [desc_soma_dia] varchar(6) NOT NULL ,
      [desc_soma_sem] varchar(6) NOT NULL , [desc_soma_mes] varchar(6) NOT NULL ,
      [desc_soma_qsem] int NOT NULL ,       [desc_soma_qmes] int NOT NULL ,
      [acre_ent1_dia]   varchar(6) NOT NULL , [acre_sai1_dia]   varchar(6) NOT NULL ,
      [acre_ent2_dia]   varchar(6) NOT NULL , [acre_sai2_dia]   varchar(6) NOT NULL ,
      [acre_soma_dia]   varchar(6) NOT NULL , [m_desc_ent1_dia]   int NOT NULL ,
      [m_desc_sai1_dia]   int NOT NULL , [m_desc_ent2_dia]   int NOT NULL ,
      [m_desc_sai2_dia]   int NOT NULL , [m_desc_soma_dia]   int NOT NULL ,
      [m_desc_soma_sem]   int NOT NULL , [m_desc_soma_mes]   int NOT NULL ,
      [m_acre_ent1_dia]   int NOT NULL , [m_acre_sai1_dia]   int NOT NULL ,
      [m_acre_ent2_dia]   int NOT NULL , [m_acre_sai2_dia]   int NOT NULL ,
      [m_acre_soma_dia]   int NOT NULL ,
      [opstols1]          bit NULL     , [opstols2]          bit NULL     ,
      [opstols3]          bit NULL     , [opstols4]          bit NULL     ,
      [opstolm1]          bit NULL     , [opstolm2]          bit NULL     ,
      [opstolm3]          bit NULL     , [opstolm4]          bit NULL
   );
   exec('insert into tmp_tbTolera (id_phorario, desc_ent1_dia, desc_sai1_dia, desc_ent2_dia, desc_sai2_dia, desc_soma_dia, desc_soma_sem, desc_soma_mes, desc_soma_qsem, desc_soma_qmes, acre_ent1_dia,
          acre_sai1_dia, acre_ent2_dia, acre_sai2_dia, acre_soma_dia, m_desc_ent1_dia, m_desc_sai1_dia, m_desc_ent2_dia, m_desc_sai2_dia, m_desc_soma_dia, m_desc_soma_sem, m_desc_soma_mes,
          m_acre_ent1_dia, m_acre_sai1_dia, m_acre_ent2_dia, m_acre_sai2_dia, m_acre_soma_dia)
   select id_phorario, desc_ent1_dia, desc_sai1_dia, desc_ent2_dia, desc_sai2_dia, desc_soma_dia, desc_soma_sem, desc_soma_mes, desc_soma_qsem, desc_soma_qmes, acre_ent1_dia, acre_sai1_dia,
      acre_ent2_dia, acre_sai2_dia, acre_soma_dia, m_desc_ent1_dia, m_desc_sai1_dia, m_desc_ent2_dia, m_desc_sai2_dia, m_desc_soma_dia, m_desc_soma_sem, m_desc_soma_mes, m_acre_ent1_dia, m_acre_sai1_dia, m_acre_ent2_dia,
      m_acre_sai2_dia, m_acre_soma_dia from tbTolera
   where desc_soma_qsem>0 or desc_soma_qmes>0 or m_desc_ent1_dia>0 or m_desc_sai1_dia>0 or m_desc_ent2_dia>0 or m_desc_sai2_dia>0 or m_desc_soma_dia>0 or m_desc_soma_sem>0 or m_desc_soma_mes>0 or m_acre_ent1_dia>0 or m_acre_sai1_dia>0 or m_acre_ent2_dia>0 or m_acre_sai2_dia>0 or m_acre_soma_dia>0');
   if not exists(select id_phorario from tmp_tbTolera) begin
      drop table tmp_tbTolera;
   end;
   drop table tbTolera;
end;
GO
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTolera') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTolera] (
      [id_tolera] int NOT NULL ,
      [id_empresa] int NOT NULL ,
      [geral] bit NOT NULL,
      [descricao] varchar(40) NOT NULL,
      [desc_ent1_dia] varchar(6) NOT NULL ,
      [desc_sai1_dia] varchar(6) NOT NULL ,
      [desc_ent2_dia] varchar(6) NOT NULL ,
      [desc_sai2_dia] varchar(6) NOT NULL ,
      [desc_soma_dia] varchar(6) NOT NULL ,
      [desc_soma_sem] varchar(6) NOT NULL ,
      [desc_soma_mes] varchar(6) NOT NULL ,
      [desc_soma_qsem] int NOT NULL ,
      [desc_soma_qmes] int NOT NULL ,
      [acre_ent1_dia]   varchar(6) NOT NULL ,
      [acre_sai1_dia]   varchar(6) NOT NULL ,
      [acre_ent2_dia]   varchar(6) NOT NULL ,
      [acre_sai2_dia]   varchar(6) NOT NULL ,
      [acre_soma_dia]   varchar(6) NOT NULL ,
      [m_desc_ent1_dia]   int NOT NULL ,
      [m_desc_sai1_dia]   int NOT NULL ,
      [m_desc_ent2_dia]   int NOT NULL ,
      [m_desc_sai2_dia]   int NOT NULL ,
      [m_desc_soma_dia]   int NOT NULL ,
      [m_desc_soma_sem]   int NOT NULL ,
      [m_desc_soma_mes]   int NOT NULL ,
      [m_acre_ent1_dia]   int NOT NULL ,
      [m_acre_sai1_dia]   int NOT NULL ,
      [m_acre_ent2_dia]   int NOT NULL ,
      [m_acre_sai2_dia]   int NOT NULL ,
      [m_acre_soma_dia]   int NOT NULL ,
      [min_comp_dia] varchar(6) NULL, [m_min_comp_dia] int NULL,
      [opstols1] bit NULL, [opstols2] bit NULL, [opstols3] bit NULL, [opstols4] bit NULL,
      [opstolm1] bit NULL, [opstolm2] bit NULL, [opstolm3] bit NULL, [opstolm4] bit NULL,
      [min2_comp_dia] varchar(6) NULL, [m_min2_comp_dia] int NULL,
      [opstols1a]         bit NULL     , [opstols2a]         bit NULL     ,
      [opstols3a]         bit NULL     , [opstols4a]         bit NULL     ,
      [opstolm1a]         bit NULL     , [opstolm2a]         bit NULL     ,
      [opstolm3a]         bit NULL     , [opstolm4a]         bit NULL     ,
      [acre_soma_sem]     varchar(6) NULL , [acre_soma_mes] varchar(6) NULL ,
      [acre_soma_qsem]    int NULL ,       [acre_soma_qmes] int NULL ,
      [m_acre_soma_sem]   int NULL ,      [m_acre_soma_mes] int NULL ,
      [desc_exc] tinyint null, [acre_exc] tinyint null,
      [min_comp_dia_qsem]   int NULL ,
      [min_comp_dia_itv]   bit NULL ,
      [min2_comp_dia_qsem]  int NULL
   ) ON [PRIMARY];
   CREATE INDEX [IX_tbTolera] ON [dbo].[tbTolera]([id_tolera]) ON [PRIMARY];
end;
GO
--Atualizaes
if not exists(select * from tbTolera)
   and exists (select * from dbo.sysobjects where id = object_id(N'dbo.tmp_tbTolera') and OBJECTPROPERTY(id, N'IsUserTable') = 1) begin
   exec('insert into tbTolera  (id_tolera, id_empresa, geral, descricao, desc_ent1_dia, desc_sai1_dia, desc_ent2_dia, desc_sai2_dia, desc_soma_dia, desc_soma_sem, desc_soma_mes, desc_soma_qsem, desc_soma_qmes, acre_ent1_dia, acre_sai1_dia,
      acre_ent2_dia, acre_sai2_dia, acre_soma_dia, m_desc_ent1_dia, m_desc_sai1_dia, m_desc_ent2_dia, m_desc_sai2_dia, m_desc_soma_dia, m_desc_soma_sem, m_desc_soma_mes, m_acre_ent1_dia, m_acre_sai1_dia, m_acre_ent2_dia,
      m_acre_sai2_dia, m_acre_soma_dia)
   select t.id_phorario, 0, 1, ''Tolerncia [T'' + rtrim(ltrim(str(t.id_phorario)))+'']'',
      t.desc_ent1_dia,t.desc_sai1_dia,t.desc_ent2_dia,t.desc_sai2_dia,t.desc_soma_dia,t.desc_soma_sem,
      t.desc_soma_mes,t.desc_soma_qsem,t.desc_soma_qmes,t.acre_ent1_dia,t.acre_sai1_dia,t.acre_ent2_dia,t.acre_sai2_dia,
      t.acre_soma_dia,t.m_desc_ent1_dia,t.m_desc_sai1_dia,t.m_desc_ent2_dia,t.m_desc_sai2_dia,t.m_desc_soma_dia,
      t.m_desc_soma_sem,t.m_desc_soma_mes,t.m_acre_ent1_dia,t.m_acre_sai1_dia,t.m_acre_ent2_dia,t.m_acre_sai2_dia,t.m_acre_soma_dia from tmp_tbTolera t');
   drop table tmp_tbTolera;
end;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTolera') and name = 'min_comp_dia')
BEGIN
   ALTER TABLE [dbo].[tbTolera] ADD min_comp_dia varchar(6) NULL, m_min_comp_dia int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTolera') and name = 'opstols1')
BEGIN
   ALTER TABLE [dbo].[tbTolera] ADD [opstols1] bit NULL, [opstols2] bit NULL, [opstols3] bit NULL, [opstols4] bit NULL,
                                    [opstolm1] bit NULL, [opstolm2] bit NULL, [opstolm3] bit NULL, [opstolm4] bit NULL;
   exec('UPDATE tbTolera SET opstols1=1,opstols2=1,opstols3=1,opstols4=1,opstolm1=1,opstolm2=1,opstolm3=1,opstolm4=1');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTolera') and name = 'min2_comp_dia')
BEGIN
   ALTER TABLE [dbo].[tbTolera] ADD min2_comp_dia varchar(6) NULL, m_min2_comp_dia int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTolera') and name = 'opstols1a')
BEGIN
   ALTER TABLE [dbo].[tbTolera] ADD [opstols1a]         bit NULL     , [opstols2a]         bit NULL     ,
      [opstols3a]         bit NULL     , [opstols4a]         bit NULL     ,
      [opstolm1a]         bit NULL     , [opstolm2a]         bit NULL     ,
      [opstolm3a]         bit NULL     , [opstolm4a]         bit NULL     ,
      [acre_soma_sem]     varchar(6) NULL , [acre_soma_mes] varchar(6) NULL ,
      [acre_soma_qsem]    int NULL ,       [acre_soma_qmes] int NULL ,
      [m_acre_soma_sem]   int NULL ,      [m_acre_soma_mes] int NULL;
   exec('UPDATE tbTolera SET opstols1a=0,opstols2a=0,opstols3a=0,opstols4a=0,opstolm1a=0,opstolm2a=0,opstolm3a=0,opstolm4a=0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTolera') and name = 'desc_exc')
BEGIN
   ALTER TABLE [dbo].[tbTolera] ADD [desc_exc] tinyint null, [acre_exc] tinyint null;
   exec('UPDATE tbTolera SET desc_exc=0, acre_exc=0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTolera') and name = 'min_comp_dia_qsem')
BEGIN
   ALTER TABLE [dbo].[tbTolera] ADD [min_comp_dia_qsem] int NULL, [min_comp_dia_itv] bit NULL, [min2_comp_dia_qsem] int NULL;
END;
GO

/*
   Tabela de horrio flexvel
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPHorFlex') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPHorFlex] (
      [id_empresa]  int NOT NULL ,
      [geral]       bit NOT NULL ,
      [id_pflex] int NOT NULL ,
      [codigo]      int NOT NULL ,
      [descricao]   varchar(100) NOT NULL ,
      [apura_tipo]  int NOT NULL,
      [dias_normais] varchar(10) NOT NULL,
      [intervalo]  varchar(6) NOT NULL,
      [m_intervalo]  int NOT NULL,
      [he_intervalo] bit NOT NULL,
      [fm_intervalo] bit NOT NULL,
      [tipo_enquadra] int NOT NULL,
      [enquadra_limite]  varchar(6) NOT NULL,
      [m_enquadra_limite]  int NOT NULL,
      [enquadra_antes] varchar(6) NOT NULL,
      [m_enquadra_antes] int NOT NULL,
      [enquadra_depois] varchar(6) NOT NULL,
      [m_enquadra_depois] int NOT NULL,
      [enquadra_funcao] int NOT NULL,
      [tolera_desc] varchar(6) NOT NULL,
      [m_tolera_desc] int NOT NULL,
      [tolera_acre] varchar(6) NOT NULL,
      [m_tolera_acre] int NOT NULL,
      [descanso_sab] varchar(6) NOT NULL,
      [descanso_dom] varchar(6) NOT NULL,
      [descanso_fol] varchar(6) NOT NULL,
      [descanso_fer] varchar(6) NOT NULL,
      [descanso_pon] varchar(6) NOT NULL,
      [m_descanso_sab] int NOT NULL,
      [m_descanso_dom] int NOT NULL,
      [m_descanso_fol] int NOT NULL,
      [m_descanso_fer] int NOT NULL,
      [m_descanso_pon] int NOT NULL,
      [diario_dm] varchar(6) NOT NULL,
      [diario_sg] varchar(6) NOT NULL,
      [diario_tr] varchar(6) NOT NULL,
      [diario_qa] varchar(6) NOT NULL,
      [diario_qi] varchar(6) NOT NULL,
      [diario_sx] varchar(6) NOT NULL,
      [diario_sb] varchar(6) NOT NULL,
      [semanal] varchar(6) NOT NULL,
      [mensal_jan] varchar(6) NOT NULL,
      [mensal_fev] varchar(6) NOT NULL,
      [mensal_fev29] varchar(6) NOT NULL,
      [mensal_mar] varchar(6) NOT NULL,
      [mensal_abr] varchar(6) NOT NULL,
      [mensal_mai] varchar(6) NOT NULL,
      [mensal_jun] varchar(6) NOT NULL,
      [mensal_jul] varchar(6) NOT NULL,
      [mensal_ago] varchar(6) NOT NULL,
      [mensal_set] varchar(6) NOT NULL,
      [mensal_out] varchar(6) NOT NULL,
      [mensal_nov] varchar(6) NOT NULL,
      [mensal_dez] varchar(6) NOT NULL,
      [m_diario_dm] int NOT NULL,
      [m_diario_sg] int NOT NULL,
      [m_diario_tr] int NOT NULL,
      [m_diario_qa] int NOT NULL,
      [m_diario_qi] int NOT NULL,
      [m_diario_sx] int NOT NULL,
      [m_diario_sb] int NOT NULL,
      [m_semanal] int NOT NULL,
      [m_mensal_jan] int NOT NULL,
      [m_mensal_fev] int NOT NULL,
      [m_mensal_fev29] int NOT NULL,
      [m_mensal_mar] int NOT NULL,
      [m_mensal_abr] int NOT NULL,
      [m_mensal_mai] int NOT NULL,
      [m_mensal_jun] int NOT NULL,
      [m_mensal_jul] int NOT NULL,
      [m_mensal_ago] int NOT NULL,
      [m_mensal_set] int NOT NULL,
      [m_mensal_out] int NOT NULL,
      [m_mensal_nov] int NOT NULL,
      [m_mensal_dez] int NOT NULL,
      [ini_sema] int NOT NULL,
      [ap_falta] bit NULL,
      [ab_reduz] bit NULL,
      [descanso_afa] varchar(6) NOT NULL,
      [m_descanso_afa] int NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbPHorFlex] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPHorFlex] PRIMARY KEY CLUSTERED ([id_pflex]) ON [PRIMARY];
    CREATE INDEX [IX_tbPHorFlex] ON [dbo].[tbPHorFlex]([codigo]) ON [PRIMARY];
end
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorFlex') and name = 'onintv')
BEGIN
   ALTER TABLE [dbo].[tbPHorFlex] DROP COLUMN onintv, m_onintv;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorFlex') and name = 'descricao' and length < 100)
BEGIN
   ALTER TABLE tbPHorFlex ALTER COLUMN descricao VARCHAR(100);
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorFlex') and name = 'ap_falta')
BEGIN
   ALTER TABLE tbPHorFlex ADD [ap_falta] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorFlex') and name = 'ab_reduz')
BEGIN
   ALTER TABLE tbPHorFlex ADD [ab_reduz] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPHorFlex') and name = 'descanso_afa')
BEGIN
   ALTER TABLE tbPHorFlex ADD [descanso_afa] varchar(6) NULL, [m_descanso_afa] int NULL;
   EXEC('UPDATE tbPHorFlex SET descanso_afa=''__:__'',m_descanso_afa=-1');
   EXEC('ALTER TABLE tbPHorFlex ALTER COLUMN [descanso_afa] varchar(6) NOT NULL');
   EXEC('ALTER TABLE tbPHorFlex ALTER COLUMN [m_descanso_afa] int NOT NULL');
END;
GO

/*
   Custos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCustos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCustos] (
      [id_custo] int NOT NULL ,
      [descricao] varchar(50) NOT NULL,
      [id_phorario] int NULL,
      [id_arredonda] int NULL,
      [id_dsr] int NULL,
      [id_he] int NULL,
      [id_adicional] int NULL,
      [id_hnormais] int NULL, [codigo] varchar(10) NOT NULL,
      [id_tolera] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCustos] WITH NOCHECK ADD
      CONSTRAINT [PK_tbCustos] PRIMARY KEY CLUSTERED ([id_custo]) ON [PRIMARY];
   CREATE INDEX [IX_tbCustos] ON [dbo].[tbCustos]([descricao]) ON [PRIMARY];
   CREATE INDEX [IX_tbCustos_codigo] ON [dbo].[tbCustos]([codigo]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCustos') and name = 'codigo')
BEGIN
   ALTER TABLE [dbo].[tbCustos] ADD codigo VARCHAR(10) NULL;
   exec('UPDATE tbCustos SET codigo = ltrim(convert(varchar(10),id_custo))');
   exec('ALTER TABLE tbCustos ALTER COLUMN codigo VARCHAR(10) NOT NULL');
END;
GO
IF EXISTS(SELECT type FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCustos') and name = 'codigo' and type=56)
BEGIN
   drop index dbo.tbCustos.IX_tbCustos_codigo;
   ALTER TABLE tbCustos ALTER COLUMN codigo VARCHAR(10) NOT NULL;
   exec('UPDATE tbCustos SET codigo = ltrim(codigo)');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCustos') and name = 'id_tolera')
BEGIN
   ALTER TABLE [dbo].[tbCustos] ADD id_tolera int NULL;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCustos') and name = 'descricao' and length <> 50)
BEGIN
   ALTER TABLE [dbo].[tbCustos] ALTER COLUMN descricao VARCHAR(50) NOT NULL;
END;
GO

/*
   Tabelas de vale transporte
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabVT') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabVT] (
      [id_tabvt] int NOT NULL,
      [geral] bit NOT NULL,
      [id_empresa] int NULL,
      [descricao] varchar(50) NOT NULL ,
      [valor] [float] NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTabVT] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabVT] PRIMARY KEY CLUSTERED ([id_tabvt])  ON [PRIMARY];
end
GO

/*
   Tabelas de vale refeio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabVR') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabVR] (
      [id_tabvr] int NOT NULL,
      [descricao] varchar(50) NOT NULL ,
      [geral] bit NOT NULL,
      [id_empresa] int NULL,
      [valor] [float] NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTabVR] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabVR] PRIMARY KEY CLUSTERED ([id_tabvr])  ON [PRIMARY];
end
GO

/*
   Tabelas de plano de sade
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabPS') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabPS] (
      [id_tabps] int NOT NULL,
      [descricao] varchar(50) NOT NULL,
      [geral] bit NOT NULL,
      [id_empresa] int NULL,
      [valor] [float] NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTabPS] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabPS] PRIMARY KEY CLUSTERED ([id_tabps])  ON [PRIMARY];
end
GO

/*
   Tabelas de Cesta / V.A.
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabCesta') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabCesta] (
      [id_tabcesta] int NOT NULL,
      [descricao] varchar(50) NOT NULL ,
      [geral] bit NOT NULL,
      [id_empresa] int NULL,
      [valor] [float] NOT NULL,
      [tipo] tinyint NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTabCesta] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabCesta] PRIMARY KEY CLUSTERED ([id_tabcesta])  ON [PRIMARY];
end
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabBenf') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbTabBenf (
      id_tabbenf INT NOT NULL,
      id_empresa INT NOT NULL,
      geral      BIT NOT NULL,
      descricao  VARCHAR(30) NOT NULL,
      codigo     INT NOT NULL,
      vr BIT NOT NULL, vr_dia_livre BIT NOT NULL,  vr_falta BIT NOT NULL,
      vt BIT NOT NULL, vt_dia_livre BIT NOT NULL,  vt_falta BIT NOT NULL,
      ps BIT NOT NULL,
      cesta BIT NOT NULL,
      acm_dia_hrs VARCHAR(5) NOT NULL, m_acm_dia_hrs INT NOT NULL,
      acm_per_hrs VARCHAR(5) NOT NULL, m_acm_per_hrs INT NOT NULL,
      acm_per_qtd INT NOT NULL,
      id_tabvr INT NOT NULL,
      id_tabps INT NOT NULL,
      id_tabcesta INT NOT NULL
   )
   ALTER TABLE [dbo].[tbTabBenf] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTabBenf] PRIMARY KEY CLUSTERED ([id_tabbenf]) ON [PRIMARY];
      CREATE UNIQUE INDEX IX_tbTabBenf ON dbo.tbTabBenf(codigo);
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDivsCesta') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbDivsCesta (
      id_tabbenf INT NOT NULL,
      id_diverg  INT NOT NULL,
      tolera     TINYINT NOT NULL,
      dia_hrs    VARCHAR(6) NOT NULL, m_dia_hrs INT NOT NULL,
      per_hrs    VARCHAR(6) NOT NULL, m_per_hrs INT NOT NULL,
      per_qtd    INT NOT NULL
   )
   ALTER TABLE [dbo].[tbDivsCesta] WITH NOCHECK ADD CONSTRAINT [PK_tbDivsCesta] PRIMARY KEY CLUSTERED ([id_tabbenf],[id_diverg]) ON [PRIMARY];
end;
GO

/*
   Vales Transp. do funcionario
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFunVT') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFunVT] (
      [id_pass] int NOT NULL,
      [id_tabvt]int NOT NULL,
      [qtde_dia]int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbFunVT] WITH NOCHECK ADD
      CONSTRAINT [PK_tbFunVT] PRIMARY KEY CLUSTERED ([id_pass],[id_tabvt])  ON [PRIMARY];
end
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBenf') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBenf] (
      [id_pass]  int NOT NULL,
      [ano]      int NOT NULL, [mes] tinyint NOT NULL,
      [data]     datetime NOT NULL,
      [dias_mes] tinyint NOT NULL,
      [cred_vr]  tinyint NOT NULL,
      [deb_vr]   tinyint NOT NULL,
      [tot_vr]   tinyint NOT NULL,
      [cred_vt]  tinyint NOT NULL,
      [deb_vt]   tinyint NOT NULL,
      [tot_vt]   tinyint NOT NULL,
      [cesta]    bit NOT NULL,
      [tot_desc] varchar(7) NOT NULL,
      [m_tot_desc] int NOT NULL,
      [qtd_desc] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBenf] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoBenf] PRIMARY KEY CLUSTERED ([id_pass],[ano],[mes]) ON [PRIMARY];
   CREATE  INDEX [IX_tbPtoBenf] ON [dbo].[tbPtoBenf]([id_pass],[data]) ON [PRIMARY];
end
GO

/*
   Locais de atestados
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLAtest') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLAtest] (
      [id_latest] int NOT NULL,
      [descricao] VARCHAR(70) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLAtest] WITH NOCHECK ADD CONSTRAINT [PK_tbLAtest] PRIMARY KEY CLUSTERED ([id_latest])  ON [PRIMARY];
end
GO

/*
   Histrico de atestados
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHAtest') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHAtest] (
      [id_hatest] int NOT NULL,
      [id_tatest] int NOT NULL,  --1:atestado mdico, 2:declarao
      [id_latest] int NOT NULL,
      [crm] VARCHAR(15) NOT NULL,
      [nome_crm] VARCHAR(70) NOT NULL,
      [id_pass] int NOT NULL,
      [data] [datetime] NOT NULL,
      [dataini] [datetime] NOT NULL,
      [datafim] [datetime] NOT NULL,
      [cid] VARCHAR(10) NOT NULL,
      [dtcad] [datetime] NOT NULL,
      [id_usuario] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHAtest] WITH NOCHECK ADD CONSTRAINT [PK_tbHAtest] PRIMARY KEY CLUSTERED ([id_hatest])  ON [PRIMARY];
   CREATE INDEX [IX_tbHAtestData] ON [dbo].[tbHAtest]([id_pass],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbHAtestCRM] ON [dbo].[tbHAtest]([crm]) ON [PRIMARY];
end
GO
--Atualizao
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbHAtest') and name = 'IX_tbHAtest')
BEGIN
   EXEC('DROP INDEX tbHAtest.IX_tbHAtest');
   EXEC('CREATE INDEX [IX_tbHAtestData] ON [dbo].[tbHAtest]([id_pass],[data]) ON [PRIMARY]');
END;
GO

/*
   Afastamentos dos passantes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAfast') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAfast] (
      [id_pass] int NOT NULL,
      [id_eveabo] int NOT NULL,
      [dataini] [smalldatetime] NOT NULL,
      [datafim] [smalldatetime] NOT NULL,
      [cid] VARCHAR(10) NULL,
      [obs] VARCHAR(30) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAfast] WITH NOCHECK ADD CONSTRAINT [PK_tbAfast] PRIMARY KEY CLUSTERED ([id_pass],[dataini],  [datafim])  ON [PRIMARY];
end
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAfast') and name = 'motivo')
BEGIN
   ALTER TABLE dbo.tbAfast ADD [id_eveabo] int null;
   exec('UPDATE dbo.tbAfast SET id_eveabo = 27');
   exec('ALTER TABLE dbo.tbAfast ALTER COLUMN [id_eveabo] INT NOT NULL');
   ALTER TABLE dbo.tbAfast DROP COLUMN motivo;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAfast') and name = 'cid')
BEGIN
   ALTER TABLE dbo.tbAfast ADD [cid] VARCHAR(10) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAfast') and name = 'obs')
BEGIN
   ALTER TABLE dbo.tbAfast ADD [obs] VARCHAR(30) NULL;
END;
GO

/*
   Tabela dos grupos de bloqueio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbGBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbGBloq] (
      [id_gbloq] int NOT NULL,
      [id_horario] int NOT NULL,
      [descricao] varchar(20) NOT NULL ,
      [entrada] bit NOT NULL,
      [saida] bit NOT NULL,
      [bloqueado] bit NOT NULL,
      [primario] bit NOT NULL,
      [flaghorario] bit NULL,
      [valida_itv] bit NULL,
      [bloq_itv] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbGBloq] WITH NOCHECK ADD
      CONSTRAINT [DF_tbGBloq_id_horario] DEFAULT (1) FOR [id_horario],
      CONSTRAINT [DF_tbGBloq_flaghorario] DEFAULT (0) FOR [flaghorario],
      CONSTRAINT [PK_tbGBloq] PRIMARY KEY CLUSTERED ([id_gbloq])  ON [PRIMARY];
   CREATE  INDEX [IX_tbGBloq] ON [dbo].[tbGBloq]([id_horario]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbGBloq') and name = 'valida_itv')
BEGIN
   ALTER TABLE tbGBloq ADD [valida_itv] bit NULL, [bloq_itv] bit NULL;
END;

/*
   Informaes sobre a ltima visita de cada visitante
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHistVisi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHistVisi] (
      [id_empresa] int NOT NULL,
      [id_pass] int NOT NULL,
      [cracha] [float] NOT NULL,
      [data_ini] [smalldatetime] NOT NULL,
      [hora_ini] [smalldatetime] NOT NULL,
      [data_ent] [smalldatetime] NULL,
      [hora_ent] [smalldatetime] NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHistVisi] WITH NOCHECK ADD CONSTRAINT [PK_tbHistVisi] PRIMARY KEY CLUSTERED ([id_empresa],   [id_pass],  [cracha],   [data_ini], [hora_ini])  ON [PRIMARY];
end
GO

/*
   Histrico de Tabelas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHistTab') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHistTab] (
      [id_pass] int NOT NULL ,
      [data] datetime NOT NULL,
      [tabela] tinyint NOT NULL,
      [id_tab] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHistTab] WITH NOCHECK ADD
      CONSTRAINT [PK_tbHistTab] PRIMARY KEY CLUSTERED ([id_pass],[data],[tabela]) ON [PRIMARY];
end
GO

/*
   Uso interno
*/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBranca') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
  DROP TABLE [dbo].[tbBranca];
end
CREATE TABLE [dbo].[tbBranca] (
      [codigo] int NOT NULL,
      [branca] [nvarchar] (50) NULL
   ) ON [PRIMARY];
GO

/*
   Tabela dos horrios, relacional da tbGHorarios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHorarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHorarios] (
      [id_horario] int NOT NULL,
      [id_empresa] int NOT NULL,
      [descricao] varchar(100) NOT NULL ,
      [codigo] varchar(8) NOT NULL ,
      [geral] bit NOT NULL,
      [c1e1] [char](5) NOT NULL, [c1e2] [char](5) NOT NULL, [c1e3] [char](5) NOT NULL,
      [c1e4] [char](5) NOT NULL, [c1e5] [char](5) NOT NULL, [c1e6] [char](5) NOT NULL,
      [c1s1] [char](5) NOT NULL, [c1s2] [char](5) NOT NULL, [c1s3] [char](5) NOT NULL,
      [c1s4] [char](5) NOT NULL, [c1s5] [char](5) NOT NULL, [c1s6] [char](5) NOT NULL, [prx1] [char](5) NOT NULL default '__:__',
      [c2e1] [char](5) NOT NULL, [c2e2] [char](5) NOT NULL, [c2e3] [char](5) NOT NULL,
      [c2e4] [char](5) NOT NULL, [c2e5] [char](5) NOT NULL, [c2e6] [char](5) NOT NULL,
      [c2s1] [char](5) NOT NULL, [c2s2] [char](5) NOT NULL, [c2s3] [char](5) NOT NULL,
      [c2s4] [char](5) NOT NULL, [c2s5] [char](5) NOT NULL, [c2s6] [char](5) NOT NULL, [prx2] [char](5) NOT NULL default '__:__',
      [c3e1] [char](5) NOT NULL, [c3e2] [char](5) NOT NULL, [c3e3] [char](5) NOT NULL,
      [c3e4] [char](5) NOT NULL, [c3e5] [char](5) NOT NULL, [c3e6] [char](5) NOT NULL,
      [c3s1] [char](5) NOT NULL, [c3s2] [char](5) NOT NULL, [c3s3] [char](5) NOT NULL,
      [c3s4] [char](5) NOT NULL, [c3s5] [char](5) NOT NULL, [c3s6] [char](5) NOT NULL, [prx3] [char](5) NOT NULL default '__:__',
      [c4e1] [char](5) NOT NULL, [c4e2] [char](5) NOT NULL, [c4e3] [char](5) NOT NULL,
      [c4e4] [char](5) NOT NULL, [c4e5] [char](5) NOT NULL, [c4e6] [char](5) NOT NULL,
      [c4s1] [char](5) NOT NULL, [c4s2] [char](5) NOT NULL, [c4s3] [char](5) NOT NULL,
      [c4s4] [char](5) NOT NULL, [c4s5] [char](5) NOT NULL, [c4s6] [char](5) NOT NULL, [prx4] [char](5) NOT NULL default '__:__',
      [c5e1] [char](5) NOT NULL, [c5e2] [char](5) NOT NULL, [c5e3] [char](5) NOT NULL,
      [c5e4] [char](5) NOT NULL, [c5e5] [char](5) NOT NULL, [c5e6] [char](5) NOT NULL,
      [c5s1] [char](5) NOT NULL, [c5s2] [char](5) NOT NULL, [c5s3] [char](5) NOT NULL,
      [c5s4] [char](5) NOT NULL, [c5s5] [char](5) NOT NULL, [c5s6] [char](5) NOT NULL, [prx5] [char](5) NOT NULL default '__:__',
      [c6e1] [char](5) NOT NULL, [c6e2] [char](5) NOT NULL, [c6e3] [char](5) NOT NULL,
      [c6e4] [char](5) NOT NULL, [c6e5] [char](5) NOT NULL, [c6e6] [char](5) NOT NULL,
      [c6s1] [char](5) NOT NULL, [c6s2] [char](5) NOT NULL, [c6s3] [char](5) NOT NULL,
      [c6s4] [char](5) NOT NULL, [c6s5] [char](5) NOT NULL, [c6s6] [char](5) NOT NULL, [prx6] [char](5) NOT NULL default '__:__',
      [c7e1] [char](5) NOT NULL, [c7e2] [char](5) NOT NULL, [c7e3] [char](5) NOT NULL,
      [c7e4] [char](5) NOT NULL, [c7e5] [char](5) NOT NULL, [c7e6] [char](5) NOT NULL,
      [c7s1] [char](5) NOT NULL, [c7s2] [char](5) NOT NULL, [c7s3] [char](5) NOT NULL,
      [c7s4] [char](5) NOT NULL, [c7s5] [char](5) NOT NULL, [c7s6] [char](5) NOT NULL, [prx7] [char](5) NOT NULL default '__:__',
      [c8e1] [char](5) NOT NULL, [c8e2] [char](5) NOT NULL, [c8e3] [char](5) NOT NULL,
      [c8e4] [char](5) NOT NULL, [c8e5] [char](5) NOT NULL, [c8e6] [char](5) NOT NULL,
      [c8s1] [char](5) NOT NULL, [c8s2] [char](5) NOT NULL, [c8s3] [char](5) NOT NULL,
      [c8s4] [char](5) NOT NULL, [c8s5] [char](5) NOT NULL, [c8s6] [char](5) NOT NULL, [prx8] [char](5) NOT NULL default '__:__',
      [itv_fxi] [char](5) NULL,  [itv_fxf] [char](5) NULL,  [itv_min] [char](5) NULL, [itv_max] [char](5) NULL,
      [ace_sema] tinyint NULL, [fx_secundario] bit NOT NULL default 0
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHorarios] WITH NOCHECK ADD
      CONSTRAINT [DF_tbHorarios_id_empresa] DEFAULT (0) FOR [id_empresa],
      CONSTRAINT [DF_tbHorarios_codigo] DEFAULT ('') FOR [codigo], CONSTRAINT [DF_tbHorarios_c1e1] DEFAULT ('__:__') FOR [c1e1],
      CONSTRAINT [DF_tbHorarios_c1e2] DEFAULT ('__:__') FOR [c1e2], CONSTRAINT [DF_tbHorarios_c1e3] DEFAULT ('__:__') FOR [c1e3],
      CONSTRAINT [DF_tbHorarios_c1e4] DEFAULT ('__:__') FOR [c1e4], CONSTRAINT [DF_tbHorarios_c1e5] DEFAULT ('__:__') FOR [c1e5],
      CONSTRAINT [DF_tbHorarios_c1e6] DEFAULT ('__:__') FOR [c1e6], CONSTRAINT [DF_tbHorarios_c1s1] DEFAULT ('__:__') FOR [c1s1],
      CONSTRAINT [DF_tbHorarios_c1s2] DEFAULT ('__:__') FOR [c1s2], CONSTRAINT [DF_tbHorarios_c1s3] DEFAULT ('__:__') FOR [c1s3],
      CONSTRAINT [DF_tbHorarios_c1s4] DEFAULT ('__:__') FOR [c1s4], CONSTRAINT [DF_tbHorarios_c1s5] DEFAULT ('__:__') FOR [c1s5],
      CONSTRAINT [DF_tbHorarios_c1s6] DEFAULT ('__:__') FOR [c1s6], CONSTRAINT [DF_tbHorarios_c2e1] DEFAULT ('__:__') FOR [c2e1],
      CONSTRAINT [DF_tbHorarios_c2e2] DEFAULT ('__:__') FOR [c2e2], CONSTRAINT [DF_tbHorarios_c2e3] DEFAULT ('__:__') FOR [c2e3],
      CONSTRAINT [DF_tbHorarios_c2e4] DEFAULT ('__:__') FOR [c2e4], CONSTRAINT [DF_tbHorarios_c2e5] DEFAULT ('__:__') FOR [c2e5],
      CONSTRAINT [DF_tbHorarios_c2e6] DEFAULT ('__:__') FOR [c2e6], CONSTRAINT [DF_tbHorarios_c2s1] DEFAULT ('__:__') FOR [c2s1],
      CONSTRAINT [DF_tbHorarios_c2s2] DEFAULT ('__:__') FOR [c2s2], CONSTRAINT [DF_tbHorarios_c2s3] DEFAULT ('__:__') FOR [c2s3],
      CONSTRAINT [DF_tbHorarios_c2s4] DEFAULT ('__:__') FOR [c2s4], CONSTRAINT [DF_tbHorarios_c2s5] DEFAULT ('__:__') FOR [c2s5],
      CONSTRAINT [DF_tbHorarios_c2s6] DEFAULT ('__:__') FOR [c2s6], CONSTRAINT [DF_tbHorarios_c3e1] DEFAULT ('__:__') FOR [c3e1],
      CONSTRAINT [DF_tbHorarios_c3e2] DEFAULT ('__:__') FOR [c3e2], CONSTRAINT [DF_tbHorarios_c3e3] DEFAULT ('__:__') FOR [c3e3],
      CONSTRAINT [DF_tbHorarios_c3e4] DEFAULT ('__:__') FOR [c3e4], CONSTRAINT [DF_tbHorarios_c3e5] DEFAULT ('__:__') FOR [c3e5],
      CONSTRAINT [DF_tbHorarios_c3e6] DEFAULT ('__:__') FOR [c3e6], CONSTRAINT [DF_tbHorarios_c3s1] DEFAULT ('__:__') FOR [c3s1],
      CONSTRAINT [DF_tbHorarios_c3s2] DEFAULT ('__:__') FOR [c3s2], CONSTRAINT [DF_tbHorarios_c3s3] DEFAULT ('__:__') FOR [c3s3],
      CONSTRAINT [DF_tbHorarios_c3s4] DEFAULT ('__:__') FOR [c3s4], CONSTRAINT [DF_tbHorarios_c3s5] DEFAULT ('__:__') FOR [c3s5],
      CONSTRAINT [DF_tbHorarios_c3s6] DEFAULT ('__:__') FOR [c3s6], CONSTRAINT [DF_tbHorarios_c4e1] DEFAULT ('__:__') FOR [c4e1],
      CONSTRAINT [DF_tbHorarios_c4e2] DEFAULT ('__:__') FOR [c4e2], CONSTRAINT [DF_tbHorarios_c4e3] DEFAULT ('__:__') FOR [c4e3],
      CONSTRAINT [DF_tbHorarios_c4e4] DEFAULT ('__:__') FOR [c4e4], CONSTRAINT [DF_tbHorarios_c4e5] DEFAULT ('__:__') FOR [c4e5],
      CONSTRAINT [DF_tbHorarios_c4e6] DEFAULT ('__:__') FOR [c4e6], CONSTRAINT [DF_tbHorarios_c4s1] DEFAULT ('__:__') FOR [c4s1],
      CONSTRAINT [DF_tbHorarios_c4s2] DEFAULT ('__:__') FOR [c4s2], CONSTRAINT [DF_tbHorarios_c4s3] DEFAULT ('__:__') FOR [c4s3],
      CONSTRAINT [DF_tbHorarios_c4s4] DEFAULT ('__:__') FOR [c4s4], CONSTRAINT [DF_tbHorarios_c4s5] DEFAULT ('__:__') FOR [c4s5],
      CONSTRAINT [DF_tbHorarios_c4s6] DEFAULT ('__:__') FOR [c4s6], CONSTRAINT [DF_tbHorarios_c5e1] DEFAULT ('__:__') FOR [c5e1],
      CONSTRAINT [DF_tbHorarios_c5e2] DEFAULT ('__:__') FOR [c5e2], CONSTRAINT [DF_tbHorarios_c5e3] DEFAULT ('__:__') FOR [c5e3],
      CONSTRAINT [DF_tbHorarios_c5e4] DEFAULT ('__:__') FOR [c5e4], CONSTRAINT [DF_tbHorarios_c5e5] DEFAULT ('__:__') FOR [c5e5],
      CONSTRAINT [DF_tbHorarios_c5e6] DEFAULT ('__:__') FOR [c5e6], CONSTRAINT [DF_tbHorarios_c5s1] DEFAULT ('__:__') FOR [c5s1],
      CONSTRAINT [DF_tbHorarios_c5s2] DEFAULT ('__:__') FOR [c5s2], CONSTRAINT [DF_tbHorarios_c5s3] DEFAULT ('__:__') FOR [c5s3],
      CONSTRAINT [DF_tbHorarios_c5s4] DEFAULT ('__:__') FOR [c5s4], CONSTRAINT [DF_tbHorarios_c5s5] DEFAULT ('__:__') FOR [c5s5],
      CONSTRAINT [DF_tbHorarios_c5s6] DEFAULT ('__:__') FOR [c5s6], CONSTRAINT [DF_tbHorarios_c6e1] DEFAULT ('__:__') FOR [c6e1],
      CONSTRAINT [DF_tbHorarios_c6e2] DEFAULT ('__:__') FOR [c6e2], CONSTRAINT [DF_tbHorarios_c6e3] DEFAULT ('__:__') FOR [c6e3],
      CONSTRAINT [DF_tbHorarios_c6e4] DEFAULT ('__:__') FOR [c6e4], CONSTRAINT [DF_tbHorarios_c6e5] DEFAULT ('__:__') FOR [c6e5],
      CONSTRAINT [DF_tbHorarios_c6e6] DEFAULT ('__:__') FOR [c6e6], CONSTRAINT [DF_tbHorarios_c6s1] DEFAULT ('__:__') FOR [c6s1],
      CONSTRAINT [DF_tbHorarios_c6s2] DEFAULT ('__:__') FOR [c6s2], CONSTRAINT [DF_tbHorarios_c6s3] DEFAULT ('__:__') FOR [c6s3],
      CONSTRAINT [DF_tbHorarios_c6s4] DEFAULT ('__:__') FOR [c6s4], CONSTRAINT [DF_tbHorarios_c6s5] DEFAULT ('__:__') FOR [c6s5],
      CONSTRAINT [DF_tbHorarios_c6s6] DEFAULT ('__:__') FOR [c6s6], CONSTRAINT [DF_tbHorarios_c7e1] DEFAULT ('__:__') FOR [c7e1],
      CONSTRAINT [DF_tbHorarios_c7e2] DEFAULT ('__:__') FOR [c7e2], CONSTRAINT [DF_tbHorarios_c7e3] DEFAULT ('__:__') FOR [c7e3],
      CONSTRAINT [DF_tbHorarios_c7e4] DEFAULT ('__:__') FOR [c7e4], CONSTRAINT [DF_tbHorarios_c7e5] DEFAULT ('__:__') FOR [c7e5],
      CONSTRAINT [DF_tbHorarios_c7e6] DEFAULT ('__:__') FOR [c7e6], CONSTRAINT [DF_tbHorarios_c7s1] DEFAULT ('__:__') FOR [c7s1],
      CONSTRAINT [DF_tbHorarios_c7s2] DEFAULT ('__:__') FOR [c7s2], CONSTRAINT [DF_tbHorarios_c7s3] DEFAULT ('__:__') FOR [c7s3],
      CONSTRAINT [DF_tbHorarios_c7s4] DEFAULT ('__:__') FOR [c7s4], CONSTRAINT [DF_tbHorarios_c7s5] DEFAULT ('__:__') FOR [c7s5],
      CONSTRAINT [DF_tbHorarios_c7s6] DEFAULT ('__:__') FOR [c7s6], CONSTRAINT [DF_tbHorarios_c8e1] DEFAULT ('__:__') FOR [c8e1],
      CONSTRAINT [DF_tbHorarios_c8e2] DEFAULT ('__:__') FOR [c8e2], CONSTRAINT [DF_tbHorarios_c8e3] DEFAULT ('__:__') FOR [c8e3],
      CONSTRAINT [DF_tbHorarios_c8e4] DEFAULT ('__:__') FOR [c8e4], CONSTRAINT [DF_tbHorarios_c8e5] DEFAULT ('__:__') FOR [c8e5],
      CONSTRAINT [DF_tbHorarios_c8e6] DEFAULT ('__:__') FOR [c8e6], CONSTRAINT [DF_tbHorarios_c8s1] DEFAULT ('__:__') FOR [c8s1],
      CONSTRAINT [DF_tbHorarios_c8s2] DEFAULT ('__:__') FOR [c8s2], CONSTRAINT [DF_tbHorarios_c8s3] DEFAULT ('__:__') FOR [c8s3],
      CONSTRAINT [DF_tbHorarios_c8s4] DEFAULT ('__:__') FOR [c8s4], CONSTRAINT [DF_tbHorarios_c8s5] DEFAULT ('__:__') FOR [c8s5],
      CONSTRAINT [DF_tbHorarios_c8s6] DEFAULT ('__:__') FOR [c8s6],
      CONSTRAINT [PK_tbHorarios] PRIMARY KEY CLUSTERED ([id_horario])  ON [PRIMARY];
   CREATE  INDEX [IX_tbHorarios] ON [dbo].[tbHorarios]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHorarios') and name = 'prx1')
BEGIN
   ALTER TABLE dbo.tbHorarios ADD [prx1] [char](5) NULL default '__:__', [prx2] [char](5) NULL default '__:__', [prx3] [char](5) NULL default '__:__',
      [prx4] [char](5) NULL default '__:__', [prx5] [char](5) NULL default '__:__', [prx6] [char](5) NULL default '__:__',
      [prx7] [char](5) NULL default '__:__', [prx8] [char](5) NULL default '__:__';
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHorarios') and name = 'itv_fxi')
BEGIN
   ALTER TABLE dbo.tbHorarios ADD [itv_fxi] [char](5) NULL, [itv_fxf] [char](5) NULL,[itv_min] [char](5) NULL,[itv_max] [char](5) NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHorarios') and name = 'ace_sema')
BEGIN
   ALTER TABLE dbo.tbHorarios ADD [ace_sema] tinyint NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHorarios') and name = 'fx_secundario')
BEGIN
   ALTER TABLE dbo.tbHorarios ADD [fx_secundario] bit NOT NULL default 0;
END
GO

/*
   Horrios e Escalas Cadastrados (as tabelas tbHorarios e tbEscala so relacionais desta tabela)
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbGHorarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbGHorarios] (
      [id_empresa] int NOT NULL,
      [id_horario] int NOT NULL,
      [escala] bit NOT NULL,
      [descricao] varchar(100) NOT NULL ,
      [geral] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbGHorarios] WITH NOCHECK ADD CONSTRAINT [PK_tbGHorarios] PRIMARY KEY CLUSTERED ([id_horario]) ON [PRIMARY];
end
GO
--Registros padres
IF NOT EXISTS(SELECT id_horario FROM dbo.tbGHorarios) and EXISTS(SELECT id_horario FROM dbo.tbHorarios)
BEGIN
   INSERT INTO dbo.tbGHorarios (id_empresa, id_horario, escala, descricao, geral) SELECT id_empresa, id_horario, 0, descricao, geral from dbo.tbHorarios;
END
GO

/*
   Lay-outs para exportao de dados cadastrais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayCad') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayCad] (
      [id_laycad] int NOT NULL,
      [id_empresa] int NULL,
      [geral] bit NOT NULL,
      [descricao] varchar(35) NOT NULL ,
      [sep] varchar(1) NULL,
      [maiusc] bit NOT NULL,
      [cont_ini] smallint NULL,
      [for_data] tinyint NULL,
      [adic1] varchar(99) NULL, [adic2] varchar(99) NULL, [adic3] varchar(99) NULL,
      [adic4] varchar(99) NULL, [adic5] varchar(99) NULL,
      [od_0] tinyint NULL, [od_1] tinyint NULL, [od_2] tinyint NULL, [od_3] tinyint NULL,
      [od_4] tinyint NULL, [od_5] tinyint NULL, [od_6] tinyint NULL, [od_7] tinyint NULL,
      [od_8] tinyint NULL, [od_9] tinyint NULL, [od_10] tinyint NULL, [od_11] tinyint NULL,
      [od_12] tinyint NULL, [od_13] tinyint NULL, [od_14] tinyint NULL, [od_15] tinyint NULL,
      [od_16] tinyint NULL, [od_17] tinyint NULL, [od_18] tinyint NULL, [od_19] tinyint NULL,
      [od_20] tinyint NULL, [od_21] tinyint NULL, [od_22] tinyint NULL, [od_23] tinyint NULL,
      [od_24] tinyint NULL, [od_25] tinyint NULL,
      [tm_0] tinyint NULL, [tm_1] tinyint NULL, [tm_2] tinyint NULL, [tm_3] tinyint NULL,
      [tm_4] tinyint NULL, [tm_5] tinyint NULL, [tm_6] tinyint NULL, [tm_7] tinyint NULL,
      [tm_8] tinyint NULL, [tm_9] tinyint NULL, [tm_10] tinyint NULL, [tm_11] tinyint NULL,
      [tm_12] tinyint NULL, [tm_13] tinyint NULL, [tm_14] tinyint NULL, [tm_15] tinyint NULL,
      [tm_16] tinyint NULL, [tm_17] tinyint NULL, [tm_18] tinyint NULL, [tm_19] tinyint NULL,
      [tm_20] tinyint NULL, [tm_21] tinyint NULL, [tm_22] tinyint NULL, [tm_23] tinyint NULL,
      [tm_24] tinyint NULL, [tm_25] tinyint NULL,
      [zr_0] bit NOT NULL, [zr_1] bit NOT NULL, [zr_2] bit NOT NULL, [zr_3] bit NOT NULL,
      [zr_4] bit NOT NULL, [zr_5] bit NOT NULL, [zr_6] bit NOT NULL, [zr_7] bit NOT NULL,
      [zr_8] bit NOT NULL, [zr_9] bit NOT NULL, [zr_10] bit NOT NULL, [zr_11] bit NOT NULL,
      [zr_12] bit NOT NULL, [zr_13] bit NOT NULL, [zr_14] bit NOT NULL, [zr_15] bit NOT NULL,
      [zr_16] bit NOT NULL, [zr_17] bit NOT NULL, [zr_18] bit NOT NULL, [zr_19] bit NOT NULL,
      [zr_20] bit NOT NULL, [zr_21] bit NOT NULL, [zr_22] bit NOT NULL, [zr_23] bit NOT NULL,
      [zr_24] bit NOT NULL, [zr_25] bit NOT NULL,
      [expfoto] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayCad] WITH NOCHECK ADD CONSTRAINT [PK_tbLayCad] PRIMARY KEY CLUSTERED ([id_laycad])  ON [PRIMARY] ;
   CREATE  INDEX [IX_tbLayCad] ON [dbo].[tbLayCad]([id_empresa]) ON [PRIMARY];
end
GO

/*
   Lay-outs para importao de dados cadastrais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayImp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayImp] (
      [id_layimp] [int] NOT NULL ,
      [id_empresa] [int] NULL ,
      [geral] [bit] NOT NULL ,
      [descricao] [varchar] (35) NOT NULL ,
      [bit_inc] [varchar] (1) NULL ,
      [bit_alt] [varchar] (1) NULL ,
      [bit_del] [varchar] (1) NULL ,
      [bit_true] [varchar] (1) NULL ,
      [bit_false] [varchar] (1) NULL ,
      [maiusc] [bit] NOT NULL ,
      [for_data] [tinyint] NOT NULL ,
      [posini_0] [smallint] NULL, [posini_1] [smallint] NULL,
      [posini_2] [smallint] NULL, [posini_3] [smallint] NULL,
      [posini_4] [smallint] NULL, [posini_5] [smallint] NULL,
      [posini_6] [smallint] NULL, [posini_7] [smallint] NULL,
      [posini_8] [smallint] NULL, [posini_9] [smallint] NULL,
      [posini_10] [smallint] NULL, [posini_11] [smallint] NULL,
      [posini_12] [smallint] NULL, [posini_13] [smallint] NULL,
      [posini_14] [smallint] NULL, [posini_15] [smallint] NULL,
      [posini_16] [smallint] NULL, [posini_17] [smallint] NULL,
      [posini_18] [smallint] NULL, [posini_19] [smallint] NULL,
      [posini_20] [smallint] NULL, [posini_21] [smallint] NULL,
      [posini_22] [smallint] NULL, [posini_23] [smallint] NULL,
      [posini_24] [smallint] NULL, [posini_25] [smallint] NULL,
      [posini_26] [smallint] NULL, [posini_27] [smallint] NULL,
      [posini_28] [smallint] NULL, [posini_29] [smallint] NULL,
      [posini_30] [smallint] NULL, [posini_31] [smallint] NULL,
      [posini_32] [smallint] NULL, [posini_33] [smallint] NULL,
      [posini_34] [smallint] NULL, [posini_35] [smallint] NULL,
      [posini_36] [smallint] NULL, [posini_37] [smallint] NULL,
      [posini_38] [smallint] NULL, [posini_39] [smallint] NULL,
      [posini_40] [smallint] NULL, [posini_41] [smallint] NULL,
      [posini_42] [smallint] NULL, [posini_43] [smallint] NULL,
      [posini_44] [smallint] NULL, [posini_45] [smallint] NULL,
      [posfim_0] [smallint] NULL,
      [posfim_1] [smallint] NULL, [posfim_2] [smallint] NULL,
      [posfim_3] [smallint] NULL, [posfim_4] [smallint] NULL,
      [posfim_5] [smallint] NULL, [posfim_6] [smallint] NULL,
      [posfim_7] [smallint] NULL, [posfim_8] [smallint] NULL,
      [posfim_9] [smallint] NULL, [posfim_10] [smallint] NULL,
      [posfim_11] [smallint] NULL, [posfim_12] [smallint] NULL,
      [posfim_13] [smallint] NULL, [posfim_14] [smallint] NULL,
      [posfim_15] [smallint] NULL, [posfim_16] [smallint] NULL,
      [posfim_17] [smallint] NULL, [posfim_18] [smallint] NULL,
      [posfim_19] [smallint] NULL, [posfim_20] [smallint] NULL,
      [posfim_21] [smallint] NULL, [posfim_22] [smallint] NULL,
      [posfim_23] [smallint] NULL, [posfim_24] [smallint] NULL,
      [posfim_25] [smallint] NULL, [posfim_26] [smallint] NULL,
      [posfim_27] [smallint] NULL, [posfim_28] [smallint] NULL,
      [posfim_29] [smallint] NULL, [posfim_30] [smallint] NULL,
      [posfim_31] [smallint] NULL, [posfim_32] [smallint] NULL,
      [posfim_33] [smallint] NULL, [posfim_34] [smallint] NULL,
      [posfim_35] [smallint] NULL, [posfim_36] [smallint] NULL,
      [posfim_37] [smallint] NULL, [posfim_38] [smallint] NULL,
      [posfim_39] [smallint] NULL, [posfim_40] [smallint] NULL,
      [posfim_41] [smallint] NULL, [posfim_42] [smallint] NULL,
      [posfim_43] [smallint] NULL, [posfim_44] [smallint] NULL,
      [posfim_45] [smallint] NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayImp] WITH NOCHECK ADD CONSTRAINT [PK_tbLayImp] PRIMARY KEY CLUSTERED ([id_layimp])  ON [PRIMARY] ;
   CREATE  INDEX [IX_tbLayImp] ON [dbo].[tbLayImp]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayImp') and name = 'posini_38')
BEGIN
   ALTER TABLE dbo.tbLayImp ADD posini_38 smallint null, posfim_38 smallint null, posini_39 smallint null, posfim_39 smallint null;
   ALTER TABLE dbo.tbLayImp ADD posini_40 smallint null, posfim_40 smallint null, posini_41 smallint null, posfim_41 smallint null;
   ALTER TABLE dbo.tbLayImp ADD posini_42 smallint null, posfim_42 smallint null, posini_43 smallint null, posfim_43 smallint null;
   ALTER TABLE dbo.tbLayImp ADD posini_44 smallint null, posfim_44 smallint null, posini_45 smallint null, posfim_45 smallint null;
END
GO

/*
   Lay-outs para exportao de marcaes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayMov') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayMov] (
      [id_laymov] int NOT NULL,
      [id_empresa] int NULL,
      [geral] bit NOT NULL,
      [descricao] varchar(35) NOT NULL ,
      [sep] varchar(1) NULL,
      [maiusc] bit NOT NULL,
      [cont_ini] smallint NULL,
      [for_data] tinyint NOT NULL,
      [adic1] varchar(99) NULL, [adic2] varchar(99) NULL, [adic3] varchar(99) NULL,
      [adic4] varchar(99) NULL, [adic5] varchar(99) NULL,
      [od_0] tinyint NOT NULL, [od_1] tinyint NOT NULL, [od_2] tinyint NOT NULL,
      [od_3] tinyint NOT NULL, [od_4] tinyint NOT NULL, [od_5] tinyint NOT NULL,
      [od_6] tinyint NOT NULL, [od_7] tinyint NOT NULL, [od_8] tinyint NOT NULL,
      [od_9] tinyint NULL, [od_10] tinyint NULL, [od_11] tinyint NULL,
      [od_12] tinyint NULL, [od_13] tinyint NULL, [od_14] tinyint NULL,
      [od_15] tinyint NULL, [od_16] tinyint NULL, [od_17] tinyint NULL,
      [od_18] tinyint NULL, [od_19] tinyint NULL, [od_20] tinyint NULL,
      [tm_0] tinyint NULL, [tm_1] tinyint NULL, [tm_2] tinyint NULL,
      [tm_3] tinyint NULL, [tm_4] tinyint NULL, [tm_5] tinyint NULL,
      [tm_6] tinyint NULL, [tm_7] tinyint NULL, [tm_8] tinyint NULL,
      [tm_9] tinyint NULL, [tm_10] tinyint NULL, [tm_11] tinyint NULL,
      [tm_12] tinyint NULL, [tm_13] tinyint NULL, [tm_14] tinyint NULL,
      [tm_15] tinyint NULL, [tm_16] tinyint NULL, [tm_17] tinyint NULL,
      [tm_18] tinyint NULL, [tm_19] tinyint NULL, [tm_20] tinyint NULL,
      [zr_0] bit NOT NULL, [zr_1] bit NOT NULL, [zr_2] bit NOT NULL,
      [zr_3] bit NOT NULL, [zr_4] bit NOT NULL, [zr_5] bit NOT NULL,
    [zr_6] bit NOT NULL, [zr_7] bit NOT NULL, [zr_8] bit NOT NULL,
      [zr_9] bit NOT NULL, [zr_10] bit NOT NULL, [zr_11] bit NOT NULL,
      [zr_12] bit NOT NULL, [zr_13] bit NOT NULL, [zr_14] bit NOT NULL,
      [zr_15] bit NOT NULL, [zr_16] bit NOT NULL, [zr_17] bit NOT NULL,
      [zr_18] bit NOT NULL, [zr_19] bit NOT NULL, [zr_20] bit NULL,
      [afd] bit NULL,
      [tm_21] tinyint NULL, [od_21] tinyint NULL, [zr_21] bit NULL,
      [tm_22] tinyint NULL, [od_22] tinyint NULL, [zr_22] bit NULL,
      [tm_23] tinyint NULL, [od_23] tinyint NULL, [zr_23] bit NULL,
      [tm_24] tinyint NULL, [od_24] tinyint NULL, [zr_24] bit NULL,
      [tm_25] tinyint NULL, [od_25] tinyint NULL, [zr_25] bit NULL,
      [adic6] varchar(99) NULL, [adic7] varchar(99) NULL,
      [tm_26] tinyint NULL, [od_26] tinyint NULL, [zr_26] bit NULL,
      [tm_27] tinyint NULL, [od_27] tinyint NULL, [zr_27] bit NULL,
      [tm_28] tinyint NULL, [od_28] tinyint NULL, [zr_28] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayMov] WITH NOCHECK ADD CONSTRAINT [PK_tbLayMov] PRIMARY KEY CLUSTERED ([id_laymov])  ON [PRIMARY];
   CREATE INDEX [IX_tbLayMov] ON [dbo].[tbLayMov]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayMov') and name = 'afd')
BEGIN
   ALTER TABLE [dbo].[tbLayMov] ADD [afd] bit NULL,
      [tm_21] tinyint NULL, [od_21] tinyint NULL, [zr_21] bit NULL,
      [tm_22] tinyint NULL, [od_22] tinyint NULL, [zr_22] bit NULL,
      [tm_23] tinyint NULL, [od_23] tinyint NULL, [zr_23] bit NULL,
      [tm_24] tinyint NULL, [od_24] tinyint NULL, [zr_24] bit NULL,
      [tm_25] tinyint NULL, [od_25] tinyint NULL, [zr_25] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayMov') and name = 'adic6')
BEGIN
   ALTER TABLE [dbo].[tbLayMov] ADD [adic6] varchar(99) NULL, [adic7] varchar(99) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayMov') and name = 'tm_26')
BEGIN
   ALTER TABLE [dbo].[tbLayMov] ADD [tm_26] tinyint NULL, [od_26] tinyint NULL, [zr_26] bit NULL,
      [tm_27] tinyint NULL, [od_27] tinyint NULL, [zr_27] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayMov') and name = 'tm_28')
BEGIN
   ALTER TABLE [dbo].[tbLayMov] ADD [tm_28] tinyint NULL, [od_28] tinyint NULL, [zr_28] bit NULL;
END;
GO

/*
   Lay-outs para exportao de marcaes de refeitrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayRef') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayRef] (
      [id_layref] int NOT NULL,
      [id_empresa] int NULL,
      [geral] bit NOT NULL,
      [descricao] varchar(35) NOT NULL ,
      [sep] varchar(1) NULL,
      [maiusc] bit NOT NULL,
      [cont_ini] smallint NULL,
      [for_data] tinyint NOT NULL,
      [adic1] varchar(99) NULL, [adic2] varchar(99) NULL, [adic3] varchar(99) NULL,
      [adic4] varchar(99) NULL, [adic5] varchar(99) NULL,
      [od_0] tinyint NOT NULL, [od_1] tinyint NOT NULL, [od_2] tinyint NOT NULL,
      [od_3] tinyint NOT NULL, [od_4] tinyint NOT NULL, [od_5] tinyint NOT NULL,
      [od_6] tinyint NOT NULL, [od_7] tinyint NOT NULL, [od_8] tinyint NOT NULL,
      [od_9] tinyint NULL, [od_10] tinyint NULL, [od_11] tinyint NULL,
      [od_12] tinyint NULL, [od_13] tinyint NULL, [od_14] tinyint NULL,
      [od_15] tinyint NULL, [od_16] tinyint NULL, [od_17] tinyint NULL,
      [od_18] tinyint NULL, [od_19] tinyint NULL, [od_20] tinyint NULL,
      [od_21] tinyint NULL, [od_22] tinyint NULL, [od_23] tinyint NULL,
      [od_24] tinyint NULL,
      [tm_0] tinyint NULL, [tm_1] tinyint NULL, [tm_2] tinyint NULL,
      [tm_3] tinyint NULL, [tm_4] tinyint NULL, [tm_5] tinyint NULL,
      [tm_6] tinyint NULL, [tm_7] tinyint NULL, [tm_8] tinyint NULL,
      [tm_9] tinyint NULL, [tm_10] tinyint NULL, [tm_11] tinyint NULL,
      [tm_12] tinyint NULL, [tm_13] tinyint NULL, [tm_14] tinyint NULL,
      [tm_15] tinyint NULL, [tm_16] tinyint NULL, [tm_17] tinyint NULL,
      [tm_18] tinyint NULL, [tm_19] tinyint NULL, [tm_20] tinyint NULL,
      [tm_21] tinyint NULL, [tm_22] tinyint NULL, [tm_23] tinyint NULL,
      [tm_24] tinyint NULL,
      [zr_0] bit NOT NULL, [zr_1] bit NOT NULL, [zr_2] bit NOT NULL,
      [zr_3] bit NOT NULL, [zr_4] bit NOT NULL, [zr_5] bit NOT NULL,
      [zr_6] bit NOT NULL, [zr_7] bit NOT NULL, [zr_8] bit NOT NULL,
      [zr_9] bit NOT NULL, [zr_10] bit NOT NULL, [zr_11] bit NOT NULL,
      [zr_12] bit NOT NULL, [zr_13] bit NOT NULL, [zr_14] bit NOT NULL,
      [zr_15] bit NOT NULL, [zr_16] bit NOT NULL, [zr_17] bit NOT NULL,
      [zr_18] bit NOT NULL, [zr_19] bit NOT NULL, [zr_20] bit NULL,
      [zr_21] bit NULL, [zr_22] bit NULL, [zr_23] bit NULL,
      [zr_24] bit NULL, [tipo_exp] tinyint null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayRef] WITH NOCHECK ADD CONSTRAINT [PK_tbLayRef] PRIMARY KEY CLUSTERED ([id_layref])  ON [PRIMARY] ;
   CREATE INDEX [IX_tbLayRef] ON [dbo].[tbLayRef]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayRef') and name = 'tipo_exp')
BEGIN
   ALTER TABLE [dbo].[tbLayRef] ADD [tipo_exp] tinyint null
   exec('UPDATE tbLayRef SET tipo_exp=0');
END;
GO

/*
   Histrico de exportaes de refeitrio efetuadas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHExpRef') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHExpRef] (
      [id_hexpref] int NOT NULL,
      [descricao]  varchar(50) NOT NULL ,
      [id_layref]  int NOT NULL,
      [data]       datetime NOT NULL,    [data_de] datetime NULL, [data_ate] datetime NULL,
      [nome_arq]   varchar(30) NOT NULL, [path_arq] varchar(200) NOT NULL,
      [cabecario]  varchar(300) NULL,    [tipos_pas] varchar(40) NOT NULL,
      [cracha_de]  [float] NULL,           [cracha_ate] [float] NULL,
      [codass_de]  varchar(15) NULL,     [codass_ate] varchar(15) NULL,
      [id_depart]  [float] NULL,           [filtra_nome] varchar(60) NULL,
      [entradas]   bit NOT NULL,         [saidas] bit NOT NULL,
      [bloqueadas] bit NOT NULL,         [soh_totais] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHExpRef] WITH NOCHECK ADD CONSTRAINT [PK_tbHExpRef] PRIMARY KEY CLUSTERED ([id_hexpref])  ON [PRIMARY] ;
end
GO

/*
   Histrico de exportaes de refeitrio efetuadas - tipos de refeio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHExpRefTiposRefeit') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHExpRefTiposRefeit] (
      [id_hexpref] int NOT NULL, [id_refeit] int NOT NULL
   ) ON [PRIMARY];
   CREATE INDEX [IX_tbHExpRefTiposRefeit] ON [dbo].[tbHExpRefTiposRefeit]([id_hexpref]) ON [PRIMARY];
end
GO

/*
   Histrico de exportaes de refeitrio efetuadas - bloqueios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHExpRefBloqs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHExpRefBloqs] (
      [id_hexpref] int NOT NULL, [id_bloq] int NOT NULL
   ) ON [PRIMARY];
   CREATE INDEX [IX_tbHExpRefBloqs] ON [dbo].[tbHExpRefBloqs]([id_hexpref]) ON [PRIMARY];
end
GO

/*
   Histrico de exportaes de refeitrio efetuadas - empresas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHExpRefEmpresas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHExpRefEmpresas] (
      [id_hexpref] int NOT NULL, [id_empresa] int NOT NULL
   ) ON [PRIMARY];
   CREATE INDEX [IX_tbHExpRefEmpresas] ON [dbo].[tbHExpRefEmpresas]([id_hexpref]) ON [PRIMARY];
end
GO

/*
   Lay-outs para importao de marcaes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayRel') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayRel] (
      [id_layrel] int NOT NULL,
      [id_empresa] int NULL,
      [descricao] varchar(40) NULL,
      [geral] bit NOT NULL,
      [posini0] smallint NULL, [posini1] smallint NULL, [posini2] smallint NULL,
      [posini3] smallint NULL, [posini4] smallint NULL, [posini5] smallint NULL,
      [posini6] smallint NULL, [posini7] smallint NULL, [posini8] smallint NULL,
      [posfin0] smallint NULL, [posfin1] smallint NULL, [posfin2] smallint NULL,
      [posfin3] smallint NULL, [posfin4] smallint NULL, [posfin5] smallint NULL,
      [posfin6] smallint NULL, [posfin7] smallint NULL, [posfin8] smallint NULL,
      [stentra] varchar(1) NULL, [stsaida] varchar(1) NULL, [ignoracab] bit NULL, [ignorardp] bit NULL, [afd] bit null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayRel] WITH NOCHECK ADD CONSTRAINT [PK_tbLayRel] PRIMARY KEY CLUSTERED ([id_layrel])  ON [PRIMARY] ;
   CREATE  INDEX [IX_tbLayRel] ON [dbo].[tbLayRel]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayRel') and name = 'afd')
BEGIN
   ALTER TABLE [dbo].[tbLayRel] ADD [afd] bit null, ignorardp bit null
   exec('UPDATE tbLayRel SET afd=0,ignorardp=0');
END;
GO
--delete from tbLayRel WHERE descricao='MD PEN DRIVE'
IF NOT EXISTS(SELECT * FROM tbLayRel WHERE descricao='MD PEN DRIVE')
begin
   declare @id_layrel int;
   if EXISTS(SELECT * FROM tbLayRel) begin
      select @id_layrel = max(id_layrel)+1 from tbLayRel;
   end;
   select @id_layrel=isnull(@id_layrel,1);
   INSERT INTO tbLayRel (id_layrel, id_empresa, descricao, geral, posini0, posini1, posini2, posini3, posini4, posini5, posini6, posini7, posini8, posfin0, posfin1, posfin2, posfin3, posfin4, posfin5, posfin6, posfin7, posfin8, stentra, stsaida, ignoracab, afd, ignorardp)
   VALUES (@id_layrel,1,'MD PEN DRIVE',1,1,13,15,17,21,23,25,42,0,12,14,16,20,22,24,41,50,0,null,null,0,1,0)
end;
GO

/*
   Lay-outs de exportao para Folha
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayFolha') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayFolha] (
      [id_layfolha] int NOT NULL, [tam_linha] int NOT NULL,
      [id_empresa] int NULL, [descricao] varchar(40) NULL, [geral] bit NOT NULL,
      [cabec] varchar(1000) NULL, [rodape] varchar(1000) NULL,
      [centesimos] bit NOT NULL, [sep_cps] char(1) NULL, [sep_hra] char(1) NULL,
      [cod_emp_tam] tinyint NOT NULL, [cod_emp_col] tinyint NOT NULL, [cod_emp_zro] bit NOT NULL,
      [cracha_tam] tinyint NOT NULL, [cracha_col] tinyint NOT NULL, [cracha_zro] bit NOT NULL,
      [assoc_tam] tinyint NOT NULL, [assoc_col] tinyint NOT NULL, [assoc_zro] bit NOT NULL,
      [custo_tam] tinyint NOT NULL, [custo_col] tinyint NOT NULL, [custo_zro] bit NOT NULL,
      [data_tam] tinyint NOT NULL, [data_col] tinyint NOT NULL, [data_zro] bit NOT NULL,
      [conta_tam] tinyint NOT NULL, [conta_col] tinyint NOT NULL, [conta_zro] bit NOT NULL, [conta_nro] int NOT NULL,
      [posi_cod_tam] tinyint NOT NULL, [posi_cod_col] tinyint NOT NULL, [posi_cod_zro] bit NOT NULL,
      [posi_hra_tam] tinyint NOT NULL, [posi_hra_col] tinyint NOT NULL, [posi_hra_zro] bit NOT NULL,
      [posi_qtd_tam] tinyint NOT NULL, [posi_qtd_col] tinyint NOT NULL, [posi_qtd_zro] bit NOT NULL,
      [neg_cod_tam] tinyint NOT NULL, [neg_cod_col] tinyint NOT NULL, [neg_cod_zro] bit NOT NULL,
      [neg_hra_tam] tinyint NOT NULL, [neg_hra_col] tinyint NOT NULL, [neg_hra_zro] bit NOT NULL,
      [neg_qtd_tam] tinyint NOT NULL, [neg_qtd_col] tinyint NOT NULL, [neg_qtd_zro] bit NOT NULL,
      [adc01_tam] tinyint NOT NULL, [adc01_col] tinyint NOT NULL, [adc01_zro] bit NOT NULL, [adc01_txt] varchar(100) NULL, [adc01_dir] bit NOT NULL,
      [adc02_tam] tinyint NOT NULL, [adc02_col] tinyint NOT NULL, [adc02_zro] bit NOT NULL, [adc02_txt] varchar(100) NULL, [adc02_dir] bit NOT NULL,
      [adc03_tam] tinyint NOT NULL, [adc03_col] tinyint NOT NULL, [adc03_zro] bit NOT NULL, [adc03_txt] varchar(100) NULL, [adc03_dir] bit NOT NULL,
      [adc04_tam] tinyint NOT NULL, [adc04_col] tinyint NOT NULL, [adc04_zro] bit NOT NULL, [adc04_txt] varchar(100) NULL, [adc04_dir] bit NOT NULL,
      [adc05_tam] tinyint NOT NULL, [adc05_col] tinyint NOT NULL, [adc05_zro] bit NOT NULL, [adc05_txt] varchar(100) NULL, [adc05_dir] bit NOT NULL,
      [adc06_tam] tinyint NOT NULL, [adc06_col] tinyint NOT NULL, [adc06_zro] bit NOT NULL, [adc06_txt] varchar(100) NULL, [adc06_dir] bit NOT NULL,
      [adc07_tam] tinyint NOT NULL, [adc07_col] tinyint NOT NULL, [adc07_zro] bit NOT NULL, [adc07_txt] varchar(100) NULL, [adc07_dir] bit NOT NULL,
      [adc08_tam] tinyint NOT NULL, [adc08_col] tinyint NOT NULL, [adc08_zro] bit NOT NULL, [adc08_txt] varchar(100) NULL, [adc08_dir] bit NOT NULL,
      [adc09_tam] tinyint NOT NULL, [adc09_col] tinyint NOT NULL, [adc09_zro] bit NOT NULL, [adc09_txt] varchar(100) NULL, [adc09_dir] bit NOT NULL,
      [adc10_tam] tinyint NOT NULL, [adc10_col] tinyint NOT NULL, [adc10_zro] bit NOT NULL, [adc10_txt] varchar(100) NULL, [adc10_dir] bit NOT NULL,
      [adc11_tam] tinyint NOT NULL, [adc11_col] tinyint NOT NULL, [adc11_zro] bit NOT NULL, [adc11_txt] varchar(100) NULL, [adc11_dir] bit NOT NULL,
      [adc12_tam] tinyint NOT NULL, [adc12_col] tinyint NOT NULL, [adc12_zro] bit NOT NULL, [adc12_txt] varchar(100) NULL, [adc12_dir] bit NOT NULL,
      [adc13_tam] tinyint NOT NULL, [adc13_col] tinyint NOT NULL, [adc13_zro] bit NOT NULL, [adc13_txt] varchar(100) NULL, [adc13_dir] bit NOT NULL,
      [adc14_tam] tinyint NOT NULL, [adc14_col] tinyint NOT NULL, [adc14_zro] bit NOT NULL, [adc14_txt] varchar(100) NULL, [adc14_dir] bit NOT NULL,
      [adc15_tam] tinyint NOT NULL, [adc15_col] tinyint NOT NULL, [adc15_zro] bit NOT NULL, [adc15_txt] varchar(100) NULL, [adc15_dir] bit NOT NULL,
      [totais] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayFolha] WITH NOCHECK ADD CONSTRAINT [PK_tbLayFolha] PRIMARY KEY CLUSTERED ([id_layfolha])  ON [PRIMARY] ;
   CREATE  INDEX [IX_tbLayFolha] ON [dbo].[tbLayFolha]([id_empresa]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayFolha') and name = 'totais')
BEGIN
   ALTER TABLE [dbo].[tbLayFolha] ADD [totais] BIT NULL;
   exec('UPDATE tbLayFolha SET totais=1');
END;
GO


/*
   Lay-outs para exportao de marcaes de refeitrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayoutRefeitorio') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayoutRefeitorio] (
      [id_layout] int NOT NULL, [id_empresa] int NOT NULL, [flagtodos] bit NOT NULL,
      [descricao] [nvarchar] (50) NOT NULL , [separador] [char](1) NULL, [id_formatodata] int NOT NULL,
      [flagmaiuscula] bit NOT NULL, [squery] varchar(7000) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE dbo.tbLayoutRefeitorio WITH NOCHECK ADD CONSTRAINT [PK_tbLayoutRefeitorio] PRIMARY KEY CLUSTERED (id_layout);
   ALTER TABLE dbo.tbLayoutRefeitorio WITH NOCHECK ADD
      CONSTRAINT [DF_tbLayoutRefeitorio_flagtodos] DEFAULT (0) FOR [flagtodos],
      CONSTRAINT [DF_tbLayoutRefeitorio_separador] DEFAULT (';') FOR [separador],
      CONSTRAINT [DF_tbLayoutRefeitorio_flagmaiuscula] DEFAULT (0) FOR [flagmaiuscula];
end
GO

/*
   Auxiliar dos lay-outs para exportao de marcaes de refeitrio
*/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayoutRefeitorioData') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   DROP TABLE tbLayoutRefeitorioData;
end
GO
CREATE TABLE [dbo].[tbLayoutRefeitorioData] (
   [id_data] int NOT NULL, [mascara] [nvarchar] (60) NOT NULL
) ON [PRIMARY];
ALTER TABLE dbo.tbLayoutRefeitorioData WITH NOCHECK ADD CONSTRAINT [PK_tbLayoutRefeitorioData] PRIMARY KEY CLUSTERED (id_data);
GO
--Registros padres
delete from tbLayoutRefeitorioData;
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (1, 'DD-MM-YYYY HH:MM:SS')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (2, 'DD/MM/YYYY HH:MM:SS')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (3, 'MM-DD-YYYY HH:MM:SS')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (4, 'MM/DD/YYYY HH:MM:SS')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (5, 'DD-MM-YYYY')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (6, 'DD/MM/YYYY')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (7, 'MM-DD-YYYY')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (8, 'MM/DD/YYYY')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (9, 'HH:MM:SS')
Insert Into tbLayoutRefeitorioData(id_data, mascara) Values (10,'HH:MM')

/*
   Relacional dos lay-outs para exportao de marcaes de refeitrio
*/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayoutRefeitorioFields') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   drop table tbLayoutRefeitorioFields;
end
GO
CREATE TABLE [dbo].[tbLayoutRefeitorioFields] (
   [id_fields] int NOT NULL, [descricao] [nvarchar] (100) NOT NULL,
   [tamanho] int NOT NULL, [expressao] varchar(3800) NOT NULL,
   [grupo] [nvarchar] (1900) NULL
) ON [PRIMARY];
ALTER TABLE dbo.tbLayoutRefeitorioFields WITH NOCHECK ADD CONSTRAINT [PK_tbLayoutField] PRIMARY KEY CLUSTERED (id_fields);
ALTER TABLE dbo.tbLayoutRefeitorioFields WITH NOCHECK ADD CONSTRAINT [DF_tbLayoutField_tamanho] DEFAULT (0) FOR tamanho;
GO
--Registros padres
delete from tbLayoutRefeitorioFields;
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '100', 'ID Empresa', '5', 'tbMRefeit.id_empresa,', 'tbMRefeit.id_empresa,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '200', 'Razao Social', '50', 'CASE tbMRefeit.id_empresa  WHEN 0 THEN *** CARTO MESTRE *** ELSE tbEmpresas.descricao END AS desc_emp,', 'tbMRefeit.id_empresa,tbEmpresas.descricao,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '300', 'ID Passante', '5', 'tbMRefeit.id_pass,', 'tbMRefeit.id_pass,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '400', 'Crach', '15', 'CASE ISNULL((CASE tbMRefeit.id_pass WHEN 0 THEN tbCMestre.cracha ELSE tbPass.cracha END ),-1) WHEN -1 THEN tbVisiBai.cracha WHEN tbCMestre.cracha THEN tbCMestre.cracha ELSE tbPass.cracha END AS cracha,', 'tbMRefeit.id_pass, tbCMestre.cracha, tbPass.cracha, tbVisiBai.cracha,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '500', 'Via Cracha', '2', 'CASE ISNULL((CASE tbMRefeit.id_pass WHEN 0 THEN tbCMestre.cracha ELSE tbPass.cracha END ),-1) WHEN -1 THEN tbVisiBai.via WHEN tbCMestre.via THEN tbCMestre.via ELSE tbPass.via END AS via,', 'tbMRefeit.id_pass, tbCMestre.cracha, tbPass.cracha, tbVisiBai.via, tbCMestre.via, tbPass.via,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '600', 'Tipo Passante', '1', 'CASE ISNULL((CASE tbMRefeit.id_pass WHEN 0 THEN tbCMestre.cracha ELSE tbPass.cracha END ),-1) WHEN -1 THEN B WHEN tbCMestre.cracha THEN M ELSE tbPass.tipo END AS tipo,', 'tbMRefeit.id_pass, tbCMestre.cracha, tbPass.cracha, tbPass.tipo,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '700', 'Cod.Associado', '10', 'CASE ISNULL((CASE tbMRefeit.id_pass WHEN 0 THEN tbCMestre.cracha ELSE tbPass.cracha END ),-1) WHEN -1 THEN tbVisiBai.codass WHEN tbCMestre.cracha THEN 0 ELSE tbPass.codass END AS codass,', 'tbMRefeit.id_pass, tbCMestre.cracha, tbPass.cracha, tbVisiBai.codass, tbPass.codass,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '800', 'Nome Passante', '50', 'CASE ISNULL((CASE tbMRefeit.id_pass WHEN 0 THEN tbCMestre.cracha ELSE tbPass.cracha END ),-1) WHEN -1 THEN tbVisiBai.nome WHEN tbCMestre.cracha THEN tbCMestre.descricao ELSE tbPass.nome END AS nome,', 'tbMRefeit.id_pass, tbCMestre.cracha, tbPass.cracha, tbVisiBai.nome, tbCMestre.descricao, tbPass.nome,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '900', 'Saldo Refeio', '9', 'Count(*) as NumRefeicao,', '');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1000', 'Valor Refeio (R$)', '16', 'tbMRefeit.valor_refeit,', 'tbMRefeit.valor_refeit,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1100', 'Saldo Refeio (R$)', '16', 'Count(*) * tbMRefeit.valor_refeit as saldo,', 'tbMRefeit.valor_refeit,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1200', 'Data Marcao', '10', 'tbMRefeit.data,', 'tbMRefeit.data,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1300', 'Hora Marcao', '10', 'tbMRefeit.hora,', 'tbMRefeit.hora,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1400', 'ID Refeio', '5', 'tbMRefeit.id_refeit,', 'tbMRefeit.id_refeit,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1500', 'Desc. Refeio', '50', 'CASE tbMRefeit.id_refeit WHEN 0 THEN Outros ELSE tbRefeit.descricao END AS desc_refeit,', 'tbMRefeit.id_refeit, tbRefeit.descricao,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1600', 'ID Evento', '5', 'tbMRefeit.evento,', 'tbMRefeit.evento,');
Insert Into tbLayoutRefeitorioFields( id_fields, descricao, tamanho, expressao, grupo ) Values ( '1700', 'Desc.Evento', '200', 'tbEventoSist.descricao as desc_evento,', 'tbEventoSist.descricao,');

/*
   Relacional dos lay-outs para exportao de marcaes de refeitrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayoutRefeitorioItem') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayoutRefeitorioItem] (
      [id_layout] int NOT NULL, [id_fields] int NOT NULL,
      [pos_ini] int NOT NULL,   [pos_fim] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE dbo.tbLayoutRefeitorioItem WITH NOCHECK ADD CONSTRAINT [PK_tbLayoutRefeitorioItem] PRIMARY KEY CLUSTERED (id_layout,id_fields);
   ALTER TABLE dbo.tbLayoutRefeitorioItem WITH NOCHECK ADD
      CONSTRAINT [DF_tbLayoutRefeitorioItem_pos_ini] DEFAULT (0) FOR [pos_ini],
      CONSTRAINT [DF_tbLayoutRefeitorioItem_pos_fim] DEFAULT (0) FOR [pos_fim];
end
GO

/*
   Lanamento de liberao de acesso para determinados passantes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLibAcesso') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLibAcesso] (
      [id_empresa] int NOT NULL,
      [id_pass] int NOT NULL,
      [grupo] varchar(250) NULL,
      [id_usuario] int NULL,
      [data] datetime NOT NULL,
      [dataf] datetime NULL,
      [justif] varchar(6000) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLibAcesso] WITH NOCHECK ADD CONSTRAINT [PK_tbLibAcesso] PRIMARY KEY CLUSTERED ([id_empresa],[id_pass],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbLibAcesso] ON [dbo].[tbLibAcesso]([id_usuario]) ON [PRIMARY];
end
GO

/*
   Movimentao de acessos em refeitrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMRefeit') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMRefeit] (
      [id_pass] int NOT NULL,
      [id_empresa] int NOT NULL,
      [data] datetime NOT NULL,
      [hora] datetime NOT NULL,
      [cracha] [float] NOT NULL,
      [id_refeit] int NOT NULL,
      [relogio] smallint NOT NULL,
      [status] tinyint NOT NULL,
      [evento] tinyint NOT NULL,
      [funcao] tinyint NULL,
      [valor_refeit] [float] NOT NULL,
      [tipo] [char](1) NULL,
      [id_credref] BIGINT NULL,
      [id_mrefeit] BIGINT NOT NULL IDENTITY(1,1),
      [valor_repasse] [float] NULL,
      [id_depart] int NULL,
      [id_custo] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMRefeit] WITH NOCHECK ADD CONSTRAINT [PK_tbMRefeit] PRIMARY KEY CLUSTERED ([id_pass],[id_empresa],[data],[hora],[cracha],[relogio],[status],[valor_refeit])  ON [PRIMARY];
   ALTER TABLE [dbo].[tbMRefeit] WITH NOCHECK ADD CONSTRAINT [DF_tbMRefeit_valor_refeit] DEFAULT (0) FOR [valor_refeit];
   CREATE INDEX IX_tbMRefeit ON dbo.tbMRefeit (id_empresa,data,hora);
   CREATE INDEX IX_tbMRefeitStatus ON dbo.tbMRefeit (id_pass,data,status);
   CREATE INDEX IX_tbMRefeitDataStatus ON dbo.tbMRefeit (data,status);
   CREATE INDEX [IX_tbMRefeit_id_credref] ON [dbo].[tbMRefeit]([id_credref]);
   CREATE INDEX [IX_tbMRefeit_id_mrefeit] ON [dbo].[tbMRefeit]([id_mrefeit]);
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbMRefeit') and name = 'id_credref')
BEGIN
   ALTER TABLE dbo.tbMRefeit ADD [id_credref] BIGINT NULL;
   CREATE INDEX [IX_tbMRefeit_id_credref] ON [dbo].[tbMRefeit]([id_credref]);
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbMRefeit') and name = 'id_mrefeit')
BEGIN
   ALTER TABLE dbo.tbMRefeit ADD [id_mrefeit] BIGINT NOT NULL IDENTITY(1,1);
   CREATE INDEX [IX_tbMRefeit_id_mrefeit] ON [dbo].[tbMRefeit]([id_mrefeit]);
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbMRefeit') and name = 'valor_repasse')
BEGIN
   ALTER TABLE dbo.tbMRefeit ADD [valor_repasse] [float] NULL;
   EXEC('UPDATE tbMRefeit SET valor_repasse=valor_refeit');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbMRefeit') and name = 'id_depart')
BEGIN
   ALTER TABLE dbo.tbMRefeit ADD [id_depart] int NULL, [id_custo] int NULL;
   EXEC('UPDATE tbMRefeit SET id_depart = ISNULL((SELECT TOP 1 p.id_depart FROM tbPass p WHERE p.id_pass = tbMRefeit.id_pass),id_depart) WHERE tipo<>''V''');
   EXEC('UPDATE tbMRefeit SET id_depart = ISNULL((SELECT TOP 1 v.id_depart FROM tbVisiBai v WHERE v.id_pass = tbMRefeit.id_pass),id_depart) WHERE tipo=''V''');
   EXEC('UPDATE tbMRefeit SET id_custo = ISNULL((SELECT TOP 1 p.id_custo FROM tbPass p WHERE p.id_pass = tbMRefeit.id_pass),id_custo) WHERE tipo<>''V''');
   EXEC('UPDATE tbMRefeit SET id_custo = ISNULL((SELECT TOP 1 v.id_custo FROM tbVisiBai v WHERE v.id_pass = tbMRefeit.id_pass),id_custo) WHERE tipo=''V''');
END
GO

/*
   Mensagens padres para o display dos relgios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMsgRel') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMsgRel] (
      [id_msgrel] tinyint NOT NULL, [descricao] varchar(20) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMsgRel] WITH NOCHECK ADD
      CONSTRAINT [DF_tbMsgRel_descricao] DEFAULT ('') FOR [descricao],
      CONSTRAINT [PK_tbMsgRel] PRIMARY KEY CLUSTERED ([id_msgrel])  ON [PRIMARY];
end
GO
--Registros padres
if exists(select count(0) as a from dbo.tbMsgRel having count(id_msgrel) < 30)
begin
   DELETE FROM tbMsgRel;
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 1, 'Mensagem 1' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 2, 'Mensagem 2' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 3, 'Mensagem 3' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 4, 'Mensagem 4' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 5, 'Mensagem 5' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 6, 'Mensagem 6' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 7, 'Mensagem 7' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 8, 'Mensagem 8' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 9, 'Mensagem 9' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 10, 'Mensagem 10' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 11, 'Mensagem 11' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 12, 'Mensagem 12' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 13, 'Mensagem 13' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 14, 'Mensagem 14' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 15, 'Mensagem 15' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 16, 'Mensagem 16' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 17, 'Mensagem 17' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 18, 'Mensagem 18' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 19, 'Mensagem 19' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 20, 'Mensagem 20' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 21, 'Mensagem 21' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 22, 'Mensagem 22' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 23, 'Mensagem 23' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 24, 'Mensagem 24' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 25, 'Mensagem 25' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 26, 'Mensagem 26' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 27, 'Mensagem 27' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 28, 'Mensagem 28' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 29, 'Mensagem 29' );
   INSERT INTO tbMsgRel (id_msgrel, descricao) VALUES ( 30, 'Mensagem 30' );
end
GO

/*
   Relacional das mensagens padres para o display dos relgios
 */
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMsgTela') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMsgTela] (
      [id_msgtela] int NOT NULL, [descricao] varchar(20) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMsgTela] WITH NOCHECK ADD
      CONSTRAINT [DF_tbMsgTela_descricao] DEFAULT ('') FOR [descricao],
      CONSTRAINT [PK_tbMsgTela] PRIMARY KEY CLUSTERED ([id_msgtela])  ON [PRIMARY] ;
end
GO
--Registros padres
if not exists(select descricao from tbMsgTela)
begin
   INSERT INTO tbMsgTela (id_msgtela, descricao) VALUES ( 1, 'Mensagem 1' );
end
GO

/*
   Cadastro de pais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPais] (
      [id_pass] int NOT NULL,
      [fone_com] varchar(15) NULL,
      [fone_res] varchar(15) NULL,
      [ramais] varchar(8) NULL,
      [obs] varchar(250) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPais] WITH NOCHECK ADD CONSTRAINT [PK_tbPais] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY] ;
end
GO

/*
   Parmetros padres para cadastramentos dos passantes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbParPass') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbParPass] (
      [id_empresa] int NOT NULL,
      [tipo] varchar(1) NOT NULL ,
      [via] tinyint NOT NULL,
      [vip] bit NOT NULL,
      [bloqueado] bit NOT NULL,
      [per_indet] bit NOT NULL,
      [qtd_dias] int NOT NULL,
      [feriado] bit NOT NULL,
      [aces_p] smallint NOT NULL,
      [id_horario] int NOT NULL,
      [id_msgrel] tinyint NOT NULL,
      [id_msgtela] int NOT NULL,
      [msg_qtd_p] smallint NOT NULL,
      [g_bloq] varchar(255) NOT NULL ,
      [geral] tinyint NOT NULL,
      [id_consist] int NOT NULL,
      [membership] bit NULL,
      [cartaoimpresso] bit NULL,
      [via_provisorio] int NULL,
      [acessos_ref] int NULL,
      [refs_autorizadas] int NULL,
      [venc_tipo] int NULL,
      [venc_cred_data] datetime NULL,
      [venc_cred_dias] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbParPass] WITH NOCHECK ADD
      CONSTRAINT [DF_tbParPass_via] DEFAULT (0) FOR [via],
      CONSTRAINT [DF_tbParPass_qtd_dias] DEFAULT (1) FOR [qtd_dias],
      CONSTRAINT [DF_tbParPass_aces_p] DEFAULT (1) FOR [aces_p],
      CONSTRAINT [DF_tbParPass_id_horario] DEFAULT (1) FOR [id_horario],
      CONSTRAINT [DF_tbParPass_id_msgrel] DEFAULT (1) FOR [id_msgrel],
      CONSTRAINT [DF_tbParPass_id_msgtela] DEFAULT (1) FOR [id_msgtela],
      CONSTRAINT [DF_tbParPass_msg_qtd_p] DEFAULT (1) FOR [msg_qtd_p],
      CONSTRAINT [DF_tbParPass_g_bloq] DEFAULT ('') FOR [g_bloq],
      CONSTRAINT [DF_tbParPass_id_consist] DEFAULT (1) FOR [id_consist],
      CONSTRAINT [PK_tbParPass] PRIMARY KEY CLUSTERED ([id_empresa],[tipo],[geral])  ON [PRIMARY];
   CREATE  INDEX [IX_idhorario] ON [dbo].[tbParPass]([id_horario]) ON [PRIMARY];
   CREATE  INDEX [IX_idmsgrel] ON [dbo].[tbParPass]([id_msgrel]) ON [PRIMARY];
   CREATE  INDEX [IX_idmsgtela] ON [dbo].[tbParPass]([id_msgtela]) ON [PRIMARY];
   CREATE  INDEX [IX_idconsist] ON [dbo].[tbParPass]([id_consist]) ON [PRIMARY];
end;
GO

/*
   Parmetros do sistema
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbParSist') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbParSist] (
      [realtime] bit NOT NULL,
      [geramarc] bit NOT NULL,
      [comm9600] bit NOT NULL,
      [por_serial] tinyint NOT NULL,
      [msgresp] bit NOT NULL,
      [arm_imp] bit NOT NULL,
      [checagem] bit NOT NULL,
      [versao] bit NOT NULL,
      [digitos] tinyint NOT NULL,
      [personal] smallint NOT NULL,
      [imgfundo] varchar(100) NOT NULL ,
      [tamfundo] int NOT NULL,
      [corfundo] [float] NOT NULL,
      [logo] varchar(100) NOT NULL ,
      [tamlogo] int NOT NULL,
      [forma] tinyint NOT NULL,
      [t_tip_pass] bit NOT NULL,
      [func] bit NOT NULL, [visi] bit NOT NULL,
      [terc] bit NOT NULL, [alun] bit NOT NULL,
      [cond] bit NOT NULL, [soci] bit NOT NULL,
      [pais] bit NOT NULL, [veic] bit NOT NULL,
      [cor_t_func] [float] NOT NULL, [cor_f_func] [float] NOT NULL,
      [cor_t_terc] [float] NOT NULL, [cor_f_terc] [float] NOT NULL,
      [cor_t_visi] [float] NOT NULL, [cor_f_visi] [float] NOT NULL,
      [cor_t_alun] [float] NOT NULL, [cor_f_alun] [float] NOT NULL,
      [cor_t_cond] [float] NOT NULL, [cor_f_cond] [float] NOT NULL,
      [cor_t_soci] [float] NOT NULL, [cor_f_soci] [float] NOT NULL,
      [cor_t_pais] [float] NOT NULL, [cor_f_pais] [float] NOT NULL,
      [baixa_manual] bit NOT NULL,
      [consdoc] tinyint NOT NULL,
      [espentr] int NULL, [espsaida] int NULL,
      [com_tot] bit NOT NULL, [stretch] bit NOT NULL,
      [exibirsaldorefeit] bit NULL,
      [hextra] int NOT NULL, [wextra] int NOT NULL,
      [travaseq] bit NULL,
      [limite_dias_func] int NULL, [limite_dias_visi] int NULL,
      [limite_dias_terc] int NULL, [limite_dias_alun] int NULL,
      [limite_dias_cond] int NULL, [limite_dias_soci] int NULL,
      [limite_dias_pais] int NULL, [ver_limite_depto] bit NULL,
      [refeitcred] bit NULL, [audit_cracha] bit NULL,
      [audit_cadastral] bit NULL, [hrs_lsta] varchar(20) NULL,
      [cvinculo] varchar(10) NULL,
      [ult_reapon] datetime NULL, [ult_reapon_status] int NULL, [ult_reapon_perc] float NULL,
      [tipo_cracha] tinyint null, [ult_status] datetime NULL,
      [cvauto] bit, [ult_id_pass] int NULL,
      [busca_cmp] varchar(20) NULL,
      [doc_cmp] varchar(10) NULL,
      [ausencia_ini] varchar(5) NULL,
      [ausencia_lmt] varchar(5) NULL,
      [imp_cracha] bit NULL,
      [readonly] int null --0:falso, 1:Cadastro 2:Importacao, 3:Manutencao
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbParSist] WITH NOCHECK ADD
      CONSTRAINT [DF_tbParSist_digitos] DEFAULT (5) FOR [digitos],
      CONSTRAINT [DF_tbParSist_personal] DEFAULT (0) FOR [personal],
      CONSTRAINT [DF_tbParSist_imgfundo] DEFAULT ('') FOR [imgfundo],
      CONSTRAINT [DF_tbParSist_tamfundo] DEFAULT (0) FOR [tamfundo],
      CONSTRAINT [DF_tbParSist_corfundo] DEFAULT (0) FOR [corfundo],
      CONSTRAINT [DF_tbParSist_logo] DEFAULT ('') FOR [logo],
      CONSTRAINT [DF_tbParSist_tamlogo] DEFAULT (0) FOR [tamlogo],
      CONSTRAINT [DF_tbParSist_forma] DEFAULT (0) FOR [forma],
      CONSTRAINT [DF_tbParSist_cor_t_func] DEFAULT (0) FOR [cor_t_func],
      CONSTRAINT [DF_tbParSist_cor_f_func] DEFAULT (0) FOR [cor_f_func],
      CONSTRAINT [DF_tbParSist_cor_t_terc] DEFAULT (0) FOR [cor_t_terc],
      CONSTRAINT [DF_tbParSist_cor_f_terc] DEFAULT (0) FOR [cor_f_terc],
      CONSTRAINT [DF_tbParSist_cor_t_visi] DEFAULT (0) FOR [cor_t_visi],
      CONSTRAINT [DF_tbParSist_cor_f_visi] DEFAULT (0) FOR [cor_f_visi],
      CONSTRAINT [DF_tbParSist_cor_t_alun] DEFAULT (0) FOR [cor_t_alun],
      CONSTRAINT [DF_tbParSist_cor_f_alun] DEFAULT (0) FOR [cor_f_alun],
      CONSTRAINT [DF_tbParSist_cor_t_cond] DEFAULT (0) FOR [cor_t_cond],
      CONSTRAINT [DF_tbParSist_cor_f_cond] DEFAULT (0) FOR [cor_f_cond],
      CONSTRAINT [DF_tbParSist_cor_t_soci] DEFAULT (0) FOR [cor_t_soci],
      CONSTRAINT [DF_tbParSist_cor_f_soci] DEFAULT (0) FOR [cor_f_soci],
      CONSTRAINT [DF_tbParSist_cor_t_pais] DEFAULT (0) FOR [cor_t_pais],
      CONSTRAINT [DF_tbParSist_cor_f_pais] DEFAULT (0) FOR [cor_f_pais],
      CONSTRAINT [DF__tbParSist__com_t__318258D2] DEFAULT (0) FOR [com_tot],
      CONSTRAINT [DF__tbParSist__stret__3A179ED3] DEFAULT (0) FOR [stretch],
      CONSTRAINT [DF__tbParSist__hextr__5BE2A6F2] DEFAULT (0) FOR [hextra],
      CONSTRAINT [DF__tbParSist__wextr__5CD6CB2B] DEFAULT (0) FOR [wextra],
      CONSTRAINT [DF__tbParSist__trava__6383C8BA] DEFAULT (0) FOR [travaseq];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') and name = 'cvinculo')
BEGIN
   ALTER TABLE tbParSist ADD [cvinculo] varchar(10) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'ult_reapon')
BEGIN
   ALTER TABLE tbParSist ADD ult_reapon datetime NULL, ult_reapon_status int NULL, ult_reapon_perc float NULL;
END;
GO
IF EXISTS(SELECT * FROM dbo.sysconstraints WHERE id = object_id(N'dbo.tbParSist') and constid = object_id(N'DF__tbParSist__espen__2F9A1060'))
BEGIN
   ALTER TABLE dbo.tbParSist DROP CONSTRAINT DF__tbParSist__espen__2F9A1060;
   ALTER TABLE dbo.tbParSist DROP CONSTRAINT DF__tbParSist__espsa__308E3499;
END
GO
IF NOT EXISTS(SELECT name, type, * FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'espentr' AND xtype=56)
BEGIN
   ALTER TABLE tbParSist ALTER COLUMN [espentr] int NULL;
   ALTER TABLE tbParSist ALTER COLUMN [espsaida] int NULL;
   UPDATE tbParSist SET espentr=ISNULL(espentr,0)*60, espsaida=ISNULL(espsaida,0)*60;
END;
GO
IF EXISTS(SELECT name, xtype FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') and name = 'consdoc' and xtype <> 48)
BEGIN
   ALTER TABLE tbParSist ALTER COLUMN consdoc tinyint NOT NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') and name = 'tipo_cracha')
BEGIN
   ALTER TABLE tbParSist ADD [tipo_cracha] tinyint null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'ult_status')
BEGIN
   ALTER TABLE tbParSist ADD ult_status datetime NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'cvauto')
BEGIN
   ALTER TABLE tbParSist ADD cvauto bit;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'ult_id_pass')
BEGIN
   ALTER TABLE tbParSist ADD [ult_id_pass] int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'busca_cmp')
BEGIN
   ALTER TABLE tbParSist ADD [busca_cmp] varchar(20) NULL, [doc_cmp] varchar(10) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'ausencia_ini')
BEGIN
   ALTER TABLE tbParSist ADD [ausencia_ini] varchar(5) NULL;
   ALTER TABLE tbParSist ADD [ausencia_lmt] varchar(5) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'imp_cracha')
BEGIN
   ALTER TABLE tbParSist ADD [imp_cracha] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbParSist') AND name = 'readonly')
BEGIN
   ALTER TABLE tbParSist ADD [readonly] int null;
END;
GO
EXEC('UPDATE tbParSist SET ult_reapon_status=0, ausencia_ini=ISNULL(ausencia_ini,''06:00''), ausencia_lmt=ISNULL(ausencia_lmt,''11:00'')');
GO
--Registro padro
IF NOT EXISTS(SELECT msgresp FROM tbParSist)
BEGIN
   INSERT INTO tbParSist (msgresp, arm_imp, realtime, geramarc, checagem, versao, digitos, personal, consdoc, imgfundo, tamfundo, corfundo, logo, tamlogo, forma, cor_t_func, cor_f_func, cor_t_terc, cor_f_terc, cor_t_visi, cor_f_visi, cor_t_alun, cor_f_alun, cor_t_cond, cor_f_cond, cor_t_soci, cor_f_soci, cor_t_pais, cor_f_pais, t_tip_pass, func, terc, visi, alun, cond, soci, pais, veic, baixa_manual, comm9600, por_serial, exibirsaldorefeit, audit_cadastral) VALUES (1, 1, 1, 0, 1, 0, 5, 0, 1, '', 0, 0, '', 0, 1, 14737632, 0, 14737632, 0, 14737632, 0, 14737632, 0, 14737632, 0, 14737632, 0, 14737632, 0, 0, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 0, 0, 1);
END
GO

/*
   Parmetros do mdulo de hospitais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbParHVisi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbParHVisi] (
      [modelo] int NOT NULL,
      [empresa] int NOT NULL,
      [fixar_emp] bit NOT NULL,
      [visiveis] varchar(200) NULL,
      [obrigatorios] varchar(200) NULL,
      [cad_paci] bit NULL
   ) ON [PRIMARY];
end
GO

/*
   Parmetros do mdulo de condomnio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbParCond') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbParCond] (
      [categ_unid1] varchar(10) NULL,
      [categ_unid2] varchar(10) NULL,
      [categ_unid3] varchar(10) NULL,
      [categ_unid4] varchar(10) NULL
   ) ON [PRIMARY];
end
GO
--Registro padro
IF NOT EXISTS(SELECT categ_unid1 FROM tbParCond)
BEGIN
   INSERT INTO tbParCond (categ_unid1,categ_unid2,categ_unid3,categ_unid4) VALUES ('Quadra','Lote','Bloco','Unidade');
END
GO

/*
   Parmetros do mdulo de alertas de ponto
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoAlerta') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoAlerta] (
      [alerta] BIT NOT NULL,
      [interjor] BIT NOT NULL,
      [min_interjor] INT NOT NULL,
      [he_intervalo] BIT NOT NULL,
      [min_intervalo] INT NOT NULL,
      [he_dia] BIT NOT NULL,
      [min_he_dia] INT NOT NULL,
      [atraso_dia] BIT NOT NULL,
      [min_atraso_dia] INT NOT NULL,
      [falta_dia] BIT NOT NULL,
      [env_servidor] VARCHAR(50) NOT NULL,
      [env_remetente] VARCHAR(80) NOT NULL,
      [env_autenticacao] BIT NOT NULL,
      [env_usuario] VARCHAR(80) NOT NULL,
      [env_senha] VARCHAR(75) NOT NULL,
      [env_porta] INT NOT NULL,
      [env_ssl] BIT NOT NULL,
      [todosf]  BIT NOT NULL
   ) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoAlerta') and name = 'todosf')
BEGIN
   ALTER TABLE [dbo].[tbPtoAlerta] ADD [todosf] tinyint NULL;
   exec('UPDATE tbPtoAlerta SET todosf = 1');
END;
GO
--Registro padro
IF NOT EXISTS(SELECT alerta FROM tbPtoAlerta)
BEGIN
   INSERT INTO tbPtoAlerta (alerta, interjor, min_interjor, he_intervalo, min_intervalo, he_dia, min_he_dia, atraso_dia, min_atraso_dia, falta_dia, env_servidor, env_remetente, env_autenticacao, env_usuario, env_senha, env_porta, env_ssl, todosf) VALUES (0,0,0,0,0,0,0,0,0,0,'','',0,'','',0,0,1);
END
GO


/*
   Tabela de crachs mestres, provisrios e visitantes, para acesso em batch
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCrachasBatch') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCrachasBatch] (
         [id_pass] INT NOT NULL,
         [cracha] BIGINT NOT NULL,
         [tipo] varchar(1) NOT NULL --# M: mestre, N: provisrio, V: visitante
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCrachasBatch] WITH NOCHECK ADD
      CONSTRAINT [PK_tbCrachasBatch] PRIMARY KEY ([id_pass]) ON [PRIMARY];
   CREATE INDEX [IX_tbCrachasBatch_cracha] ON [dbo].[tbCrachasBatch]([cracha]) ON [PRIMARY];
end
GO

/*
   Tabela dos passantes para gernciamento dos acessos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPass') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPass] (
      [id_pass] int NOT NULL,
      [id_empresa] int NOT NULL,
      [cracha] [float] NOT NULL,
      [via] tinyint NOT NULL,
      [tipo] varchar(1) NOT NULL ,
      [nome] varchar(100) NOT NULL ,
      [vip] bit NOT NULL,
      [nasc] [smalldatetime] NULL,
      [indesejado] bit NOT NULL,
      [bloqueado] bit NOT NULL,
      [id_horario] int NOT NULL,
      [id_depart] int NULL,
      [per_indet] bit NOT NULL,
      [data_ini] [smalldatetime] NULL,
      [data_fim] [smalldatetime] NULL,
      [provisorio] [float] NULL,
      [prov_ini] [smalldatetime] NULL,
      [prov_fim] [smalldatetime] NULL,
      [id_msgrel] tinyint NULL,
      [id_msgtela] int NULL,
      [msg_qtd_p] smallint NOT NULL,
      [foto] varchar(25) NULL,
      [fotodoc] varchar(25) NULL,
      [g_bloq] varchar(255) NOT NULL ,
      [data] [smalldatetime] NOT NULL,
      [horario] [smalldatetime] NOT NULL,
      [usu_resp] int NOT NULL,
      [status] varchar(1) NOT NULL ,
      [feriado] bit NOT NULL,
      [afast_ini] [smalldatetime] NULL,
      [afast_fim] [smalldatetime] NULL,
      [ult_acess] datetime NULL,
      [reinic] bit NOT NULL,
      [indgbloq] varchar(300) NULL,
      [id_consist] int NOT NULL,
      [senha] [float] NULL,
      [codass] varchar(15) NULL,
      [ult_acessd] datetime NULL,
      [ult_idbloq] int NOT NULL,
      [ult_direc] tinyint NOT NULL,
      [doc] varchar(50) NULL,
      [sequencia] varchar(1600) NULL,
      [contador] int NOT NULL,
      [membership] tinyint NOT NULL,
      [cartaoimpresso] tinyint NOT NULL,
      [fotodocVerso] varchar(25) NULL,
      [via_provisorio] int NULL,
      [acessos_dia] int NULL,
      [id_local] int NULL,
      [id_sublocal] int NULL,
      [pass_visi] int NULL,
      [visitado] varchar(50) NULL,
      [paci_visi] int NULL,
      [id_phorario] [float] NULL,
      [id_agrupamento] int NULL,
      [id_custo] int NULL,
      [inativo] bit NULL,
      [stat_inativo] bit NULL,
      [id_colab] [int] NULL,
      [ult_lib] datetime NULL,
      [id_phalt1] [float] NULL,
      [id_phalt2] [float] NULL,
      [id_phalt3] [float] NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPass] WITH NOCHECK ADD
      CONSTRAINT [DF_tbPass_id_pass] DEFAULT (0) FOR [id_pass],
      CONSTRAINT [DF_tbPass_via] DEFAULT (0) FOR [via],
      CONSTRAINT [DF_tbPass_id_horario] DEFAULT (1) FOR [id_horario],
      CONSTRAINT [DF_tbPass_id_depart] DEFAULT (1) FOR [id_depart],
      CONSTRAINT [DF_tbPass_provisorio] DEFAULT (0) FOR [provisorio],
      CONSTRAINT [DF_tbPass_id_msgrel] DEFAULT (0) FOR [id_msgrel],
      CONSTRAINT [DF_tbPass_id_msgtela] DEFAULT (0) FOR [id_msgtela],
      CONSTRAINT [DF_tbPass_msg_qtd_p] DEFAULT (0) FOR [msg_qtd_p],
      CONSTRAINT [DF_tbPass_foto] DEFAULT ('') FOR [foto],
      CONSTRAINT [DF_tbPass_g_bloq] DEFAULT ('') FOR [g_bloq],
      CONSTRAINT [DF_tbPass_status] DEFAULT ('N') FOR [status],
      CONSTRAINT [DF_tbPass_id_consist] DEFAULT (1) FOR [id_consist],
      CONSTRAINT [DF_tbPass_senha] DEFAULT (0) FOR [senha],
      CONSTRAINT [DF_tbPass_codass] DEFAULT ('') FOR [codass],
      CONSTRAINT [DF__tbPass__ult_idbl__2CBDA3B5] DEFAULT (0) FOR [ult_idbloq],
      CONSTRAINT [DF__tbPass__ult_dire__2DB1C7EE] DEFAULT (0) FOR [ult_direc],
      CONSTRAINT [DF_tbPass_sequencia] DEFAULT (',') FOR [sequencia],
      CONSTRAINT [DF_tbPass_contador] DEFAULT (1) FOR [contador],
      CONSTRAINT [DF_tbPass_membership] DEFAULT (0) FOR [membership],
      CONSTRAINT [DF_tbPass_cartaoimpresso] DEFAULT (0) FOR [cartaoimpresso],
      CONSTRAINT [DF__tbPass__doc__6477ECF3] DEFAULT ('0') FOR [doc],
      CONSTRAINT [PK_tbPass] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY];
   CREATE INDEX [IX_tbPass_cracha] ON [dbo].[tbPass]([cracha]) ON [PRIMARY];
   CREATE INDEX [IX_tbPass_provisorio] ON [dbo].[tbPass]([provisorio]) ON [PRIMARY];
   CREATE INDEX [IX_idempresa] ON [dbo].[tbPass]([id_empresa]) ON [PRIMARY];
   --CREATE INDEX [IX_idhorario] ON [dbo].[tbPass]([id_horario]) ON [PRIMARY];
   --CREATE INDEX [IX_iddepart] ON [dbo].[tbPass]([id_depart]) ON [PRIMARY];
   --CREATE INDEX [IX_idsublocal] ON [dbo].[tbPass]([id_sublocal]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPass') and name = 'id_phorario')
BEGIN
   ALTER TABLE dbo.tbPass ADD [id_phorario] [float] NULL;
   ALTER TABLE dbo.tbPass ADD [id_agrupamento] int NULL;
   ALTER TABLE dbo.tbPass ADD [id_custo] int NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPass') and name = 'inativo')
BEGIN
   ALTER TABLE dbo.tbPass ADD [inativo] bit NULL;
   EXEC('UPDATE tbPass SET inativo=1 WHERE cracha=0');
END;
GO
EXEC('UPDATE tbPass SET inativo=0 WHERE inativo IS null');
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPass') and name = 'nome' and length < 100)
BEGIN
   ALTER TABLE tbPass ALTER COLUMN nome VARCHAR(100);
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPass') and name = 'stat_inativo')
BEGIN
   ALTER TABLE tbPass ADD [stat_inativo] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPass') and name = 'id_colab')
BEGIN
   ALTER TABLE tbPass ADD [id_colab] int NULL;
END ELSE BEGIN
   ALTER TABLE tbPass ALTER COLUMN [id_colab] int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPass') and name = 'ult_lib')
BEGIN
   ALTER TABLE tbPass ADD [ult_lib] datetime NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPass') and name = 'id_phalt1')
BEGIN
   ALTER TABLE tbPass ADD id_phalt1 float NULL, id_phalt2 float NULL, id_phalt3 float NULL;
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPass') and name = 'IX_idhorario')
BEGIN
   EXEC('DROP INDEX tbPass.IX_idhorario');
   EXEC('DROP INDEX tbPass.IX_iddepart');
   EXEC('DROP INDEX tbPass.IX_idsublocal');
END;
GO

/*
   Tabela dos funcionarios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFunc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFunc] (
      [id_pass] int NOT NULL,
      [apelido] varchar(20) NULL,
      [fone] varchar(15) NULL,
      [ramais] varchar(8) NULL,
      [obs] varchar(250) NULL,
      [admissao] datetime NULL,
      [doc_rg] varchar(50) null,
      [doc_cpf] varchar(50) null,
      [doc_outros] varchar(50) null,
      [id_cargo] int NULL,
      [doc_ctps] varchar(20) null,
      [categoria] tinyint null, [sexo] tinyint null,
      [banco] bit null,
      [dtini_aviso] datetime null,
      [dtfim_aviso] datetime null,[dtdemissao] datetime NULL,
      [salbse] float NULL, [salefe] float NULL,
      [id_arredonda] int NULL, [id_dsr] int NULL, [id_he] int NULL, [id_adicional] int NULL,
      [id_hnormais] int NULL, [id_benef] int NULL, [id_tabvr] int NULL, [id_tabps] int NULL,
      [per_bco_ini] int NULL, [ult_apt] datetime null, [doc_pis] varchar(20) null, [nivel] tinyint null, [email] varchar(40) NULL,
      [natural] varchar(20) NULL, [filiacao1] varchar(50) NULL, [filiacao2] varchar(50) NULL,
      [rg_orgao] varchar(10) NULL, [rg_emissao] datetime NULL,
      [endereco] varchar(50) NULL, [bairro] varchar(50) NULL, [compl] varchar(50) NULL,
      [cidade] varchar(50) NULL,   [cep] varchar(10) NULL, [uf] varchar(2) NULL,[doc_cnh] varchar(20) null,
      [regime] tinyint null,
      [id_tolera] int NULL, [id_tabbenf] INT NULL, [id_tabcesta] INT NULL,
      [feriado_normal] BIT, [gera_itv] BIT, [pto_obrig] BIT,
      [id_rede] varchar(15) null, [login_rede] varchar(50) null, [id_tabbco] int NULL, [gera_itv_l] BIT null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbFunc] WITH NOCHECK ADD
      CONSTRAINT [DF_tbFunc_apelido] DEFAULT ('') FOR [apelido],
      CONSTRAINT [DF_tbFunc_fone] DEFAULT ('') FOR [fone],
      CONSTRAINT [DF_tbFunc_ramais] DEFAULT ('') FOR [ramais],
      CONSTRAINT [DF_tbFunc_obs] DEFAULT ('') FOR [obs],
      CONSTRAINT [PK_tbFunc] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY]
   CREATE INDEX [IX_tbFunc_Banco] ON [dbo].[tbFunc]([id_pass],[banco]) ON [PRIMARY];
   CREATE INDEX [IX_tbFunc_ult_apt] ON [dbo].[tbFunc]([ult_apt]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'doc_ctps')
BEGIN
   ALTER TABLE dbo.tbFunc ADD [doc_ctps] varchar(20) null,
      [categoria] tinyint null, [sexo] tinyint, [banco] bit null,
      [dtini_aviso] datetime null, [dtfim_aviso] datetime null, [dtdemissao] datetime NULL,
      [salbse] float NULL, [salefe] float NULL, [id_arredonda] int NULL, [id_dsr] int NULL,
      [id_he] int NULL, [id_adicional] int NULL, [id_hnormais] int NULL, [id_benef] int NULL,
      [id_tabvr] int NULL, [id_tabps] int NULL, [per_bco_ini] int NULL, [ult_apt] datetime null;
   CREATE INDEX [IX_tbFunc_ult_apt] ON [dbo].[tbFunc]([ult_apt]) ON [PRIMARY];
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'doc_pis')
BEGIN
   ALTER TABLE dbo.tbFunc ADD [doc_pis] varchar(20) null, [nivel] tinyint null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'email')
BEGIN
   ALTER TABLE [dbo].[tbFunc] ADD [email] varchar(40) NULL,
      [natural] varchar(20) NULL, [filiacao1] varchar(50) NULL, [filiacao2] varchar(50) NULL,
      [rg_orgao] varchar(10) NULL, [rg_emissao] datetime NULL,
      [endereco] varchar(50) NULL, [bairro] varchar(50) NULL, [compl] varchar(50) NULL,
      [cidade] varchar(50) NULL,   [cep] varchar(10) NULL, [uf] varchar(2) NULL, [doc_cnh] varchar(20) null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'regime')
BEGIN
   ALTER TABLE dbo.tbFunc ADD [regime] tinyint null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'pto_obrig')
BEGIN
   ALTER TABLE dbo.tbFunc ADD [pto_obrig] BIT null;
   exec('UPDATE dbo.tbFunc SET pto_obrig=1');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'id_tolera')
BEGIN
   ALTER TABLE dbo.tbFunc ADD [id_tolera] int null;
   exec('UPDATE tbFunc SET id_tolera=isnull((select p.id_phorario from tbPass p inner join tbTolera t on p.id_phorario=t.id_tolera where p.id_pass=tbFunc.id_pass),0)');
   declare @id_tolera_pri int; declare @id_tolera int; declare @achou bit; declare @sql varchar(500);
   select @id_tolera_pri=0, @id_tolera=0;
   select @id_tolera_pri=isnull(min(id_tolera),0) from tbTolera;
   select @id_tolera=@id_tolera_pri;
   while @id_tolera_pri>0 and exists(select id_tolera from tbTolera where id_tolera=@id_tolera_pri)
   begin
      select @id_tolera=@id_tolera+1, @achou=0;
      select @achou=1 from tbTolera t inner join
         tbTolera t0 on t.desc_soma_qsem=t0.desc_soma_qsem and t.desc_soma_qmes=t0.desc_soma_qmes and
         t.m_desc_ent1_dia=t0.m_desc_ent1_dia and t.m_desc_sai1_dia=t0.m_desc_sai1_dia and
         t.m_desc_ent2_dia=t0.m_desc_ent2_dia and t.m_desc_sai2_dia=t0.m_desc_sai2_dia and
         t.m_desc_soma_dia=t0.m_desc_soma_dia and t.m_desc_soma_sem=t0.m_desc_soma_sem and
         t.m_desc_soma_mes=t0.m_desc_soma_mes and t.m_acre_ent1_dia=t0.m_acre_ent1_dia and
         t.m_acre_sai1_dia=t0.m_acre_sai1_dia and t.m_acre_ent2_dia=t0.m_acre_ent2_dia and
         t.m_acre_sai2_dia=t0.m_acre_sai2_dia and t.m_acre_soma_dia=t0.m_acre_soma_dia
      where t.id_tolera=@id_tolera and t0.id_tolera=@id_tolera_pri;
      if @achou=1 begin
         delete from tbTolera where id_tolera=@id_tolera;
         select @sql='UPDATE tbFunc SET id_tolera='+ltrim(rtrim(str(@id_tolera_pri)))+' WHERE id_tolera='+ltrim(rtrim(str(@id_tolera)));
         exec(@sql);
      end else begin
         select @id_tolera_pri=@id_tolera;
      end;
   end;
   exec('delete from tbTolera where id_tolera not in (select tbFunc.id_tolera from tbFunc)');
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'ult_cracha')
BEGIN
   exec('UPDATE tbPass SET cracha = ISNULL((SELECT f.ult_cracha FROM tbFunc f WHERE f.id_pass = tbPass.id_pass),0) WHERE tbPass.cracha=0');
   ALTER TABLE dbo.tbFunc DROP COLUMN ult_cracha;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'id_tabbenf')
BEGIN
   ALTER TABLE dbo.tbFunc ADD id_tabbenf INT NULL, id_tabcesta INT NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'feriado_normal')
BEGIN
   ALTER TABLE tbFunc ADD feriado_normal BIT;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'gera_itv')
BEGIN
   ALTER TABLE tbFunc ADD [gera_itv] BIT;
   exec('UPDATE tbFunc SET gera_itv=0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'id_rede')
BEGIN
   ALTER TABLE tbFunc ADD [id_rede] varchar(15) null, [login_rede] varchar(50) null;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'quebra1')
BEGIN
   ALTER TABLE tbFunc DROP COLUMN quebra1;
   ALTER TABLE tbFunc DROP COLUMN quebra2;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'id_tabbco')
BEGIN
   ALTER TABLE tbFunc ADD [id_tabbco] int NULL;
   exec('UPDATE tbFunc SET id_tabbco=1 WHERE banco=1');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbFunc') and name = 'gera_itv_l')
BEGIN
   ALTER TABLE tbFunc ADD [gera_itv_l] BIT;
   exec('UPDATE tbFunc SET gera_itv_l=isnull(gera_itv,0)');
END;
GO

/*
   Troca de PIS
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFHistPIS') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFHistPIS] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [doc_pis] varchar(20) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbFHistPIS] WITH NOCHECK ADD
      CONSTRAINT [PK_tbFHistPIS] PRIMARY KEY ([id_pass],[data],[doc_pis])  ON [PRIMARY];
   CREATE INDEX [IX_tbFHistPIS] ON [dbo].[tbFHistPIS]([doc_pis]) ON [PRIMARY];
end
GO

/*
   Dependentes do funcionrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFDepen') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFDepen] (
      [id_pass] int NOT NULL,
      [nome] varchar(100) NOT NULL,
      [dtnasc] datetime NOT NULL,
      [id_tabdesc] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbFDepen] WITH NOCHECK ADD
      CONSTRAINT [PK_tbFDepen] PRIMARY KEY CLUSTERED ([id_pass],[nome])  ON [PRIMARY];
end
GO

/*
   Motivos de advertncia
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMAdvert') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMAdvert] (
      [id_madvert] int NOT NULL,
      [descricao] VARCHAR(50) NOT NULL,
      [susp_d] int NOT NULL,
      [dem_t] int  NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMAdvert] WITH NOCHECK ADD CONSTRAINT [PK_tbMAdvert] PRIMARY KEY CLUSTERED ([id_madvert])  ON [PRIMARY];
end
GO

/*
   Obsevaes dos motivos de advertncia
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMObsAdvert') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMObsAdvert] (
      [id_madvert] int NOT NULL,
      [id_tadvert] int NOT NULL,
      [obs] VARCHAR(2000) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMObsAdvert] WITH NOCHECK ADD CONSTRAINT [PK_tbMObsAdvert] PRIMARY KEY CLUSTERED ([id_madvert],[id_tadvert])  ON [PRIMARY];
end
GO

/*
   Divergncias de advertncia
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMDivAdvert') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMDivAdvert] (
      [id_madvert] int NOT NULL,
      [id_diverg] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMDivAdvert] WITH NOCHECK ADD CONSTRAINT [PK_tbMDivAdvert] PRIMARY KEY CLUSTERED ([id_madvert],[id_diverg])  ON [PRIMARY];
end
GO

/*
   Apontamentos no histrico de advertncias
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAptAdvert') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAptAdvert] (
      [id_hadvert] int NOT NULL,
      [data] datetime NOT NULL,
      [previsto] varchar(200) NOT NULL,
      [marcado] varchar(200) NOT NULL,
      [m_acre_dia] integer NOT NULL,
      [acre_dia] varchar(8) NOT NULL,
      [m_desc_dia] integer NOT NULL,
      [desc_dia] varchar(8) NOT NULL,
      [acre_diverg] varchar(40) NULL,
      [desc_diverg] varchar(40) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAptAdvert] WITH NOCHECK ADD CONSTRAINT [PK_tbAptAdvert] PRIMARY KEY CLUSTERED ([id_hadvert],[data])  ON [PRIMARY];
end
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAptAdvert') and name = 'acre_diverg')
BEGIN
   ALTER TABLE tbAptAdvert ADD [acre_diverg] varchar(40) NULL, [desc_diverg] varchar(40) NULL;
   UPDATE tbAptAdvert SET acre_dia = '+ ' + ltrim(rtrim(acre_dia)) WHERE len(acre_dia)>0;
   UPDATE tbAptAdvert SET desc_dia = '- ' + ltrim(rtrim(desc_dia)) WHERE len(desc_dia)>0;
END;
GO

/*
   Histrico de advertncias
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHAdvert') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHAdvert] (
      [id_hadvert] int NOT NULL,
      [id_tadvert] int NOT NULL,  -- 1: verbal, 2: escrita, 3: suspenso, 4: demisso
      [id_madvert] int NOT NULL,
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [susp_d] int NOT NULL,
      [susp_i] datetime NOT NULL,
      [susp_f] datetime NOT NULL,
      [susp_r] datetime NOT NULL,
      [dem_t] int  NOT NULL,
      [dem_d] datetime  NOT NULL,
      [dem_c] datetime NOT NULL,
      [obs] varchar(2000) NOT NULL,
      [obs_fmt] varchar(3000) NOT NULL,
      [assina] varchar(120) NOT NULL,
      [cidade] varchar(120) NOT NULL,
      [test_a] varchar(120) NOT NULL,
      [test_b] varchar(120) NOT NULL,
      [opt_apt] int  NOT NULL,
      [dtcad] datetime NOT NULL,
      [id_usuario] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHAdvert] WITH NOCHECK ADD CONSTRAINT [PK_tbHAdvert] PRIMARY KEY CLUSTERED ([id_hadvert])  ON [PRIMARY];
   CREATE INDEX [IX_tbHAdvert] ON [dbo].[tbHAdvert]([id_pass],[data]) ON [PRIMARY];
end
GO

/*
   Tabela dos crachs provisrios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbProvisorios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbProvisorios] (
      [cracha] [float] NOT NULL,
      [via] tinyint NOT NULL,
      [prov_ini] [smalldatetime] NOT NULL,
      [prov_fim] [smalldatetime] NOT NULL,
      [id_pass] int NOT NULL,
      [tipo] varchar(1) NOT NULL ,
      [status] tinyint NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbProvisorios] WITH NOCHECK ADD
      CONSTRAINT [DF_tbProvisorios_cracha] DEFAULT (0) FOR [cracha],
      CONSTRAINT [DF_tbProvisorios_status] DEFAULT (0) FOR [status];
   CREATE INDEX IX_tbProvisorios_Limpeza ON dbo.tbProvisorios (id_pass, prov_ini, status);
   CREATE INDEX IX_tbProvisorios_Baixa ON dbo.tbProvisorios (cracha, prov_ini, prov_fim, id_pass, status);
end
GO
--Atualizaes
if EXISTS(select name from dbo.sysobjects where id = object_id(N'dbo.tbVersao') and OBJECTPROPERTY(id, N'IsUserTable') = 1) begin
   if EXISTS(select Atual from tbVersao where Atual < 306) begin
      UPDATE tbProvisorios SET prov_fim = getdate() WHERE status <> 0 and prov_fim > getdate();
   end;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbProvisorios') and name = 'IX_tbProvisorios_Limpeza')
BEGIN
   CREATE INDEX IX_tbProvisorios_Limpeza ON dbo.tbProvisorios (id_pass, prov_ini, status);
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbProvisorios') and name = 'IX_tbProvisorios_Baixa')
BEGIN
   CREATE INDEX IX_tbProvisorios_Baixa ON dbo.tbProvisorios (cracha, prov_ini, prov_fim, id_pass, status);
END;
GO

/*
   Categorias de refeio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRefeit') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRefeit] (
      [id_refeit] int NOT NULL,
      [id_empresa] int NOT NULL,
      [geral] tinyint NOT NULL,
      [descricao] varchar(20) NOT NULL ,
      [hora_ini] datetime NULL,
      [hora_fim] datetime NULL,
      [d1] tinyint NOT NULL,
      [d2] tinyint NOT NULL,
      [d3] tinyint NOT NULL,
      [d4] tinyint NOT NULL,
      [d5] tinyint NOT NULL,
      [d6] tinyint NOT NULL,
      [d7] tinyint NOT NULL,
      [feriado] tinyint NOT NULL,
      [valor] [char](5) NOT NULL ,
      [codigo] varchar(5) NULL ,
      [vendas] [bit] NULL ,
      [valor2] [char](5) NULL,
      [id_diverg] INT null,
      [id_grefeit] INT null,
      [repasse] [char](5) NULL,
      [repasse2] [char](5) NULL,
      [tp_pass] [varchar](15) NULL,
      [ordem] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbRefeit] WITH NOCHECK ADD CONSTRAINT [PK_tbrefeit] PRIMARY KEY CLUSTERED ([id_refeit])  ON [PRIMARY] ;
   ALTER TABLE [dbo].[tbRefeit] WITH NOCHECK ADD
      CONSTRAINT [DF_tbRefeit_geral] DEFAULT (0) FOR [geral],
      CONSTRAINT [DF_tbRefeit_d1] DEFAULT (0) FOR [d1],
      CONSTRAINT [DF_tbRefeit_d2] DEFAULT (0) FOR [d2],
      CONSTRAINT [DF_tbRefeit_d3] DEFAULT (0) FOR [d3],
      CONSTRAINT [DF_tbRefeit_d4] DEFAULT (0) FOR [d4],
      CONSTRAINT [DF_tbRefeit_d5] DEFAULT (0) FOR [d5],
      CONSTRAINT [DF_tbRefeit_d6] DEFAULT (0) FOR [d6],
      CONSTRAINT [DF_tbRefeit_d7] DEFAULT (0) FOR [d7],
      CONSTRAINT [DF_tbRefeit_feriado] DEFAULT (0) FOR [feriado];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRefeit') and name = 'vendas')
BEGIN
   ALTER TABLE dbo.tbRefeit ADD [vendas] [bit] NULL;
   EXEC('UPDATE tbRefeit SET vendas=1');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRefeit') and name = 'valor2')
BEGIN
   ALTER TABLE dbo.tbRefeit ADD [valor2] [char](5) NULL, [id_diverg] INT null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRefeit') and name = 'id_grefeit')
BEGIN
   ALTER TABLE dbo.tbRefeit ADD [id_grefeit] INT null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRefeit') and name = 'repasse')
BEGIN
   ALTER TABLE dbo.tbRefeit ADD [repasse] [char](5) NULL, [repasse2] [char](5) NULL, [tp_pass] [varchar](15) NULL;
   EXEC('UPDATE tbRefeit SET repasse=valor, repasse2=valor2');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRefeit') and name = 'ordem')
BEGIN
   ALTER TABLE dbo.tbRefeit ADD [ordem] int NULL;
END
GO

/*
   Faixas horrias para as categorias de refeio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRefeitHors') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRefeitHors] (
      [id_refeit] int NOT NULL,
      [hora_ini] datetime NULL, [hora_fim] datetime NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX  IX_tbRefeitHors_id_refeit ON dbo.tbRefeitHors (id_refeit);
   EXEC('insert into tbRefeitHors select f.id_refeit, f.hora_ini, f.hora_fim from tbRefeit f');
end
GO

/*
   Valores de refeio por agrupamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRefAgrup') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRefAgrup] (
      [id_refeit] int NOT NULL,
      [id_agrupamento] int NOT NULL,
      [valor] [char](5) NOT NULL,
      [valor2] [char](5) NULL,
      [repasse] [char](5) NULL,
      [repasse2] [char](5) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbRefAgrup] WITH NOCHECK ADD CONSTRAINT [PK_tbRefAgrup] PRIMARY KEY CLUSTERED ([id_refeit], [id_agrupamento]) ON [PRIMARY] ;
end
GO


/*
   Habilitao dos passantes para uso do refeitrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRefeitPass') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRefeitPass] (
      [id_pass] int NOT NULL,
      [acessos] tinyint NOT NULL,
      [livre_a] tinyint NOT NULL,
      [nro_ref] tinyint NOT NULL,
      [livre_r] tinyint NOT NULL,
      [refeit] varchar(250) NULL,
      [dataini] datetime NULL,
      [datafim] datetime NULL,
      [naoexpw1] bit NULL, [naoexpw2] bit NULL, [naoexpw3] bit NULL,
      [naoexpw4] bit NULL, [naoexpw5] bit NULL, [naoexpw6] bit NULL,
      [naoexpw7] bit NULL, [naoexpw8] bit null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbRefeitPass] WITH NOCHECK ADD CONSTRAINT [PK_tbrefeitpass] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY] ;
end
GO

/*
   Agendamento de refeio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAgRefeit') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAgRefeit] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_refeit] int NOT NULL,
      [dt_agenda] datetime NOT NULL,
      [novo] bit NOT NULL default 1
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAgRefeit] WITH NOCHECK ADD CONSTRAINT [PK_tbAgRefeit] PRIMARY KEY CLUSTERED ([id_pass],[data],[id_refeit])  ON [PRIMARY] ;
   CREATE INDEX IX_tbAgRefeit ON dbo.tbAgRefeit (id_pass, id_refeit, data);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAgRefeit') and name = 'novo')
BEGIN
   ALTER TABLE [dbo].[tbAgRefeit] ADD [novo] bit NOT NULL default 1;
   EXEC('UPDATE tbAgRefeit SET novo = 0 WHERE data < dateadd(d,-15,getdate())');
END
GO

/*
   Tabelas dos scios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSoci') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbSoci] (
      [id_pass] int NOT NULL,
      [titulo] varchar(20) NULL,
      [titular] int NULL,
      [fone_com] varchar(15) NULL,
      [fone_res] varchar(15) NULL,
      [ramais] varchar(8) NULL,
      [obs] varchar(250) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbSoci] WITH NOCHECK ADD CONSTRAINT [PK_tbSoci] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY] ;
end
GO

/*
   Formatos de data
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabela') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabela] (
      [codigo] int NOT NULL,
      [item] int NOT NULL,
      [descricao] varchar(50) NULL
   ) ON [PRIMARY];
end
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTabela') and name = 'descricao' and isnullable = 0)
BEGIN
   ALTER TABLE [dbo].[tbTabela] ALTER COLUMN descricao varchar(50) NULL;
END
GO
--Registros padres
DELETE FROM tbTabela;
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 1, 'dd/mm/yyyy');
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 2, 'dd/mm/yy');
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 3, 'mm/dd/yyyy');
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 4, 'mm/dd/yy');
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 5, 'ddmmyyyy');
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 6, 'ddmmyy');
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 7, 'mmddyyyy');
INSERT INTO tbTabela (codigo, item, descricao) VALUES ( 1, 8, 'mmddyy');
GO

/*
   Tabela dos terceiros
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTerc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTerc] (
      [id_pass] int NOT NULL,
      [empresa] varchar(70) NULL,
      [id_depart] int NULL, [fone] varchar(15) NULL,
      [ramais] varchar(8) NULL, [obs] varchar(250) NULL,
      [id_cargo] int NULL, [admissao] datetime NULL,
      [doc_rg] varchar(50) null, [doc_cpf] varchar(50) null, [doc_outros] varchar(50) null,
      [email] varchar(40) NULL,
      [natural] varchar(20) NULL,  [filiacao1] varchar(50) NULL, [filiacao2] varchar(50) NULL,
      [rg_orgao] varchar(10) NULL, [rg_emissao] datetime NULL,
      [endereco] varchar(50) NULL, [bairro] varchar(50) NULL, [compl] varchar(50) NULL,
      [cidade] varchar(50) NULL,   [cep] varchar(10) NULL, [uf] varchar(2) NULL,[doc_cnh] varchar(20) null,
      [sexo] tinyint null, [apelido] varchar(20) NULL, [nivel] tinyint null,
      [id_rede] varchar(15) null, [login_rede] varchar(50) null,
      [id_empterc] int null,
      [doc_pis] varchar(20) null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTerc] WITH NOCHECK ADD CONSTRAINT [PK_tbTerc] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY];
   CREATE INDEX [IX_iddepart] ON [dbo].[tbTerc]([id_depart]) ON [PRIMARY];
   CREATE INDEX IX_tbTerc_id_empterc ON [dbo].[tbTerc] (id_empterc);
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTerc') and name = 'email')
BEGIN
   ALTER TABLE [dbo].[tbTerc] ADD [email] varchar(40) NULL,
      [natural] varchar(20) NULL,  [filiacao1] varchar(50) NULL, [filiacao2] varchar(50) NULL,
      [rg_orgao] varchar(10) NULL, [rg_emissao] datetime NULL,
      [endereco] varchar(50) NULL, [bairro] varchar(50) NULL, [compl] varchar(50) NULL,
      [cidade] varchar(50) NULL,   [cep] varchar(10) NULL, [uf] varchar(2) NULL,[doc_cnh] varchar(20) null,
      [sexo] tinyint null, [apelido] varchar(20) NULL, [nivel] tinyint null;
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTerc') and name = 'ult_cracha')
BEGIN
   exec('UPDATE tbPass SET cracha = ISNULL((SELECT t.ult_cracha FROM tbTerc t WHERE t.id_pass = tbPass.id_pass),0) WHERE tbPass.cracha=0');
   ALTER TABLE dbo.tbTerc DROP COLUMN ult_cracha;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTerc') and name = 'id_rede')
BEGIN
   ALTER TABLE tbTerc ADD [id_rede] varchar(15) null, [login_rede] varchar(50) null;
END;
GO
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEmpTerc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   --Criar uma tabela auxiliar
   if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEmpTerc_aux') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
   begin
      exec('drop table tbEmpTerc_aux');
   end;
   CREATE TABLE [dbo].[tbEmpTerc_aux] (
      [id_empterc] [int] IDENTITY (1, 1) NOT NULL ,
      [descricao] [varchar] (100) NOT NULL ,
   ) ON [PRIMARY];
   --Popular a tabela
   exec ('UPDATE tbTerc SET empresa = rtrim(ltrim(upper(isnull(empresa,''''))))');
   exec ('INSERT INTO tbEmpTerc_aux (descricao) select distinct empresa from tbTerc where empresa <> '''' order by empresa');

   --Criar a tabela oficial
   CREATE TABLE [dbo].[tbEmpTerc] (
      [id_empterc] [int] NOT NULL ,
      [descricao] [varchar] (100) NOT NULL ,
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEmpTerc] WITH NOCHECK ADD
         CONSTRAINT [PK_tbEmpTerc] PRIMARY KEY NONCLUSTERED ([id_empterc]) ON [PRIMARY];
   CREATE INDEX IX_tbEmpTerc_descricao ON dbo.tbEmpTerc (descricao);

   --Obter os registros
   exec ('INSERT INTO tbEmpTerc (id_empterc, descricao) select a.id_empterc, a.descricao from tbEmpTerc_aux a order by a.descricao');

   --Excluir auxiliar
   exec ('drop table tbEmpTerc_aux');
end
GO
--Atualizaes na tbTerc
IF not EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTerc') and name = 'id_empterc')
BEGIN
   alter table [dbo].[tbTerc] add id_empterc [int] NULL;
   exec ('update tbTerc set id_empterc = (select e.id_empterc from tbEmpTerc e where tbTerc.empresa = left(e.descricao,70))');
   exec ('CREATE INDEX IX_tbTerc_id_empterc ON dbo.tbTerc (id_empterc)');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbTerc') and name = 'doc_pis')
BEGIN
   ALTER TABLE dbo.tbTerc ADD [doc_pis] varchar(20) null;
END;
GO


/*
   Tabela dos usurios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUsuarios') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUsuarios] (
      [id_usuario] int NOT NULL,
      [id_empresa] int NOT NULL,
      [nome] varchar(40) NOT NULL ,
      [usuario] varchar(20) NOT NULL ,
      [senha] varchar(40) NOT NULL ,
      [nivel] tinyint NOT NULL,
      [telas] varchar(2000) NULL,
      [relat] varchar(2000) NULL,
      [geral] bit NOT NULL,
      [poll] bit NOT NULL,
      [refpass] tinyint NULL,
      [ins] varchar(2000) NOT NULL ,
      [alt] varchar(2000) NOT NULL ,
      [del] varchar(2000) NULL ,
      [acesso_credref] BIT NULL,
      [todos_gbloqs] BIT NULL,
      [nivel_p] tinyint NULL,
      [telas_p] varchar (2000) NULL,
      [relat_p] varchar (2000) NULL,
      [bloqueado] bit NULL,
      [trocaprox] bit NULL,
      [expiradias] tinyint NULL,
      [repwd] tinyint NULL,
      [pwdseg] bit NULL,
      [id_pass] int NULL, [ck_afa] bit NULL, [ck_per] bit NULL,
      [email] varchar(40) NULL,
      [alrtp_tipo_usu] tinyint NULL,
      [alrtp_area] varchar(80) NULL,
      [alrtp_semana] tinyint NULL,
      [alrtp_mes] tinyint NULL,
      [alrtp_ordem_s] tinyint NULL,
      [alrtp_ordem_m] tinyint NULL,
      [alrtp_totais_s] bit NULL,
      [alrtp_totais_m] bit NULL,
      [bloq_simult]  bit NULL,
      [bloq_simult_p]  bit NULL,
      [max_maq] TINYINT NULL,
      [max_maq_p] TINYINT NULL,
      [valida_ad]  bit NULL,
      [dominio] varchar(50) NULL,
      [vld_senha] varchar(30) NULL,
      [vld_passo] int NULL,
      [dom_port] int NULL,
      [codass_i] varchar(15) NULL,
      [codass_f] varchar(15) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUsuarios] WITH NOCHECK ADD
      CONSTRAINT [DF_tbUsuarios_refpass] DEFAULT (0) FOR [refpass],
      CONSTRAINT [DF__tbUsuarios__ins__3B0BC30C] DEFAULT ('') FOR [ins],
      CONSTRAINT [DF__tbUsuarios__alt__3BFFE745] DEFAULT ('') FOR [alt],
      CONSTRAINT [DF__tbUsuarios__del__3CF40B7E] DEFAULT ('') FOR [del],
      CONSTRAINT [PK_tbUsuarios] PRIMARY KEY CLUSTERED ([id_usuario]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'nivel_p')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [nivel_p] tinyint NULL;
   EXEC('ALTER TABLE [dbo].[tbUsuarios] ADD [telas_p] varchar (2000) NULL');
   EXEC('ALTER TABLE [dbo].[tbUsuarios] ADD [relat_p] varchar (2000) NULL');
END
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'telas' and length < 2000)
BEGIN
   EXEC('ALTER TABLE [dbo].[tbUsuarios] ALTER COLUMN telas varchar (2000) NULL');
   EXEC('ALTER TABLE [dbo].[tbUsuarios] ALTER COLUMN relat varchar (2000) NULL');
   EXEC('ALTER TABLE [dbo].[tbUsuarios] ALTER COLUMN ins varchar (2000) NULL');
   EXEC('ALTER TABLE [dbo].[tbUsuarios] ALTER COLUMN alt varchar (2000) NULL');
   EXEC('ALTER TABLE [dbo].[tbUsuarios] ALTER COLUMN del varchar (2000) NULL');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'bloqueado')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [bloqueado] bit NULL;
   EXEC('UPDATE tbUsuarios SET bloqueado = 0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'trocaprox')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [trocaprox] bit NULL, [expiradias] tinyint NULL, [repwd] tinyint NULL, [pwdseg] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'id_pass')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [id_pass] int NULL, [ck_afa] bit NULL, [ck_per] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'email')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [email] varchar(40) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'alrtp_tipo_usu')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [alrtp_tipo_usu] tinyint NULL, [alrtp_area] varchar(80) NULL, [alrtp_semana] tinyint NULL, [alrtp_mes] tinyint NULL, [alrtp_ordem_s] tinyint NULL, [alrtp_ordem_m] tinyint NULL, [alrtp_totais_s] bit NULL, [alrtp_totais_m] bit NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'bloq_simult')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [bloq_simult]  bit NULL, [bloq_simult_p]  bit NULL, [max_maq] TINYINT NULL, [max_maq_p] TINYINT NULL;
   EXEC('UPDATE tbUsuarios SET bloq_simult=0, bloq_simult_p=0, max_maq=0, max_maq_p=0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'valida_ad')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [valida_ad]  bit NULL, [dominio] varchar(50) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'vld_senha')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [vld_senha] varchar(30) NULL, [vld_passo] int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'dom_port')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [dom_port] int NULL;
   EXEC('UPDATE tbUsuarios SET dom_port=389');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuarios') and name = 'codass_i')
BEGIN
   ALTER TABLE [dbo].[tbUsuarios] ADD [codass_i] varchar(15) NULL;
   ALTER TABLE [dbo].[tbUsuarios] ADD [codass_f] varchar(15) NULL;
END;
GO

--Registros padres
IF NOT EXISTS(SELECT id_usuario FROM tbUsuarios)
BEGIN
   INSERT INTO tbUsuarios ( id_usuario, id_empresa, geral, nome, usuario, senha, nivel, telas, relat, poll, ins, alt, del, nivel_p ) VALUES (1, 1,0, 'Pointware Informtica Ltda', 'pointware', 'ONHMSV@QDQPJOUXBSF!!!!!!!!!!!',     1, '101,102,103,104,105,201,202,203,204,205,206,207,208,209,210,211,212,213,301,302,401,501,502,303,304,503,305,106,107,306,214,504,307,308,218,402,406,403,405,407,404,309,',    '101,102,103,104,105,201,202,203,204,205,206,207,208,209,210,211,212,213,301,302,401,501,502,303,304,503,305,106,107,306,214,504,307,308,218,402,406,403,405,407,404,309,',1,'','','', 1);
END
GO
UPDATE tbUsuarios SET telas = '101,102,103,104,105,201,202,203,204,205,206,207,208,209,210,211,212,213,301,302,401,501,502,303,304,503,305,106,107,306,214,504,307,308,218,402,406,403,405,407,404,309,' where rtrim(isnull(telas ,'')) = '';
GO
UPDATE tbUsuarios SET relat = '101,102,103,104,105,201,202,203,204,205,206,207,208,209,210,211,212,213,301,302,401,501,502,303,304,503,305,106,107,306,214,504,307,308,218,402,406,403,405,407,404,309,' where rtrim(isnull(relat ,'')) = '';
GO
IF NOT EXISTS(SELECT id_usuario FROM tbUsuarios WHERE NOT nivel_p IS NULL )
BEGIN
   UPDATE tbUsuarios SET nivel_p = 1 WHERE nivel = 1;
END;
GO

/*
   Troca de senhas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHTUsu') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHTUsu] (
      [id_usuario] int NOT NULL, [data] datetime NOT NULL, [senha] varchar(40) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHTUsu] WITH NOCHECK ADD
      CONSTRAINT [PK_tbHTUsu] PRIMARY KEY CLUSTERED ([id_usuario], [data]) ON [PRIMARY];
   EXEC('INSERT INTO tbHTUsu select u.id_usuario, getdate(), u.senha from tbUsuarios u');
end
GO

/*
   Opes da tela de apontamento p/ usurio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUsuApont') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUsuApont] (
      [id_usuario] int NOT NULL,
      [acessa_tela] bit NOT NULL,
      [altera_calend] bit NOT NULL,
      [altera_he] bit NOT NULL,
      [altera_divs] bit NOT NULL,
      [altera_abon] bit NOT NULL,
      [altera_marc] bit NOT NULL,
      [altera_enq] bit NOT NULL,
      [repoc_apon] bit NOT NULL,
      [banco] bit NOT NULL,
      [repoc_bco] bit NOT NULL,
      [afasta] bit NOT NULL,
      [altera_afasta] bit NOT NULL,
      [grp_acesso] varchar(5) NULL,
      [altera_itv] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUsuApont] WITH NOCHECK ADD
      CONSTRAINT [PK_tbUsuApont] PRIMARY KEY CLUSTERED ([id_usuario]) ON [PRIMARY];
   CREATE INDEX [IX_tbUsuApont] ON [dbo].[tbUsuApont]([grp_acesso]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbUsuApont') and name = 'altera_itv')
BEGIN
   ALTER TABLE [dbo].[tbUsuApont] ADD altera_itv bit NULL;
   EXEC('UPDATE tbUsuApont SET altera_itv=altera_marc');
END
GO

/*
  Tabela de agrupamentos do usurio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUsuGrupos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUsuGrupos] (
      [id_usuario] int NOT NULL ,
      [id_agrupamento] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUsuGrupos] WITH NOCHECK ADD
      CONSTRAINT [PK_tbUsuGrupos] PRIMARY KEY CLUSTERED ([id_usuario],[id_agrupamento])  ON [PRIMARY];
end
GO

/*
   Grupos de Bloqueios dos usurios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUsuarioGBloqs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE dbo.tbUsuarioGBloqs (
      id_usuario int NOT NULL, id_gbloq int NOT NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [IX_tbUsuarioGBloqs] ON [dbo].[tbUsuarioGBloqs]([id_usuario],[id_gbloq]) ON [PRIMARY];
end
GO

/*
   Usurios vinculados para alerta
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAlertasUsu') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE dbo.tbAlertasUsu (
      id_usuario_ref int NOT NULL, tipo_ordem tinyint NOT NULL, id_usuario_vin int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAlertasUsu] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAlertasUsu] PRIMARY KEY CLUSTERED (id_usuario_ref, tipo_ordem, id_usuario_vin) ON [PRIMARY];
end
GO

/*
   Tabela dos instncias
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSisExec') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbSisExec] (
      [id_sisexec] BIGINT NOT NULL IDENTITY(1,1),
      [sistema] VARCHAR(30) NOT NULL,
      [computador] VARCHAR(255) NOT NULL,
      [mac] VARCHAR(30) NOT NULL,
      [ip] VARCHAR(20) NOT NULL,
      [id_usuario] INT NOT NULL,
      [usuario] VARCHAR(30) NOT NULL,
      [dt_aberto] DATETIME NOT NULL,
      [dt_atual] DATETIME NOT NULL,
      [dt_fechado] DATETIME NULL,
      [tela] VARCHAR(50) NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbSisExec] WITH NOCHECK ADD
      CONSTRAINT [PK_tbSisExec] PRIMARY KEY CLUSTERED ([id_sisexec])  ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbSisExec') and name = 'tela')
BEGIN
   ALTER TABLE [dbo].[tbSisExec] ADD [tela] VARCHAR(50) NULL;
END
GO

/*
   Computadores dos usurios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbUsuMaq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbUsuMaq] (
      [id_usuario]    int NOT NULL,
      [sistema] VARCHAR(30) NOT NULL,
      [mac] VARCHAR(30) NOT NULL,
      [computador] VARCHAR(255) NOT NULL,
      [ip] VARCHAR(20) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbUsuMaq] WITH NOCHECK ADD
      CONSTRAINT [PK_tbUsuMaq] PRIMARY KEY CLUSTERED ([id_usuario],[sistema],[mac]) ON [PRIMARY];
end;
GO

/*
   Tabela de Licenas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLicencas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE dbo.tbLicencas (
    id_cliente int NOT NULL ,
      computador varchar(255) NULL,
      mac varchar(50) NULL,
      ip varchar(50) NULL,
      sistema varchar(50) NULL,
    semkey int null,
    cksum varchar(255) NOT NULL
   ) ON [PRIMARY];
end
GO

/*
   Tabela de vagas para o cadastro de veculos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbVagas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbVagas] (
      [id_vaga] int NOT NULL,
      [descricao] varchar(15) NOT NULL, [status] bit NOT NULL,
      [codigo] varchar(5) NOT NULL, [id_auto] int NULL, [id_unidade] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbVagas] WITH NOCHECK ADD
      CONSTRAINT [DF_tbVagas_status] DEFAULT (0) FOR [status],
      CONSTRAINT [PK_tbVagas] PRIMARY KEY CLUSTERED ([id_vaga])  ON [PRIMARY];
   CREATE UNIQUE INDEX IX_tbVagas_codigo ON dbo.tbVagas(codigo);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVagas') and name = 'codigo')
BEGIN
   ALTER TABLE [dbo].[tbVagas] ADD [codigo] varchar(5) NULL, [id_auto] int NULL, [id_unidade] int NULL;
   EXEC('UPDATE tbVagas SET codigo=right(''000''+ltrim(str(id_vaga)),3)');
   EXEC('UPDATE tbVagas SET id_auto=isnull((SELECT a.id_auto FROM tbAuto a WHERE a.id_vaga=tbVagas.id_vaga),0), id_unidade=0');
   EXEC('ALTER TABLE [dbo].[tbVagas] ALTER COLUMN [codigo] varchar(5) NOT NULL');
   EXEC('CREATE UNIQUE INDEX IX_tbVagas_codigo ON dbo.tbVagas(codigo)');
END
GO

/*
   Veculos do controle de estacionamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAuto') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAuto] (
      [id_auto]   int NOT NULL,
      [placa_pri] varchar(10) NOT NULL,
      [placa_sec] varchar(10) NULL,
      [desc_sec]  varchar(15) NULL,
      [descricao] varchar(50) NOT NULL,
      [cor]       varchar(15) NOT NULL,
      [obs]       varchar(500) NULL,
      [status]    varchar(1) NOT NULL ,
      [id_pass]   int NULL,
      [identificacao] varchar(10) NULL,
      [id_vaga]   int NULL,
      [ult_acessd]  datetime NULL,
      [ult_idbloq]  int NOT NULL,
      [ult_direc]   tinyint NOT NULL,
      [ult_id_pass] int NOT NULL,
      [cracha]    float NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAuto] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAuto] PRIMARY KEY CLUSTERED ([id_auto])  ON [PRIMARY];
   CREATE INDEX IX_tbAuto_placa_pri ON dbo.tbAuto(placa_pri);
   CREATE INDEX IX_tbAuto_identificacao ON dbo.tbAuto(identificacao);
   CREATE INDEX IX_tbAuto_cracha ON dbo.tbAuto(cracha);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAuto') and name = 'cracha')
BEGIN
   ALTER TABLE [dbo].[tbAuto] ADD [cracha] float NULL;
   EXEC('DROP INDEX dbo.tbAuto.IX_tbAuto_status');
   EXEC('DROP INDEX dbo.tbAuto.IX_tbAuto_placa_sec');
   EXEC('DROP INDEX dbo.tbAuto.IX_tbAuto_id_vaga');
   EXEC('CREATE INDEX IX_tbAuto_cracha ON dbo.tbAuto(cracha)');
END
GO


/*
   Histrico de cadastramento de veculos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHistAuto') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHistAuto] (
      [id_auto] int NOT NULL,
      [placa_sec] varchar(10) NULL,
      [desc_sec] varchar(15) NULL,
      [id_pass] int NOT NULL,
      [id_vaga] int NOT NULL,
      [id_empvisi] int NULL,
      [data_ini] datetime NOT NULL,
      [data_fim] datetime NULL,
      [identificacao] varchar(10) NULL,
      [inativo] bit null,
      [cracha] float NULL,
      [id_hauto] BIGINT NOT NULL IDENTITY(1,1)
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHistAuto] WITH NOCHECK ADD CONSTRAINT [PK_tbHistAuto] PRIMARY KEY ([id_hauto]) ON [PRIMARY];
   CREATE INDEX IX_tbHistAuto_id_auto ON dbo.tbHistAuto (id_auto, id_pass);
   CREATE INDEX IX_tbHistAuto_id_pass ON dbo.tbHistAuto (id_pass);
   CREATE INDEX IX_tbHistAuto_id_pass_d ON dbo.tbHistAuto (id_pass, data_fim);
   CREATE INDEX IX_tbHistAuto_id_auto_d ON dbo.tbHistAuto (id_auto, data_fim);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHistAuto') and name = 'inativo')
BEGIN
   ALTER TABLE [dbo].[tbHistAuto] ADD inativo bit NULL;
   exec('CREATE INDEX IX_tbHistAuto_id_auto ON dbo.tbHistAuto (id_auto, id_pass)');
   exec('CREATE INDEX IX_tbHistAuto_id_pass ON dbo.tbHistAuto (id_pass)');
   exec('CREATE INDEX IX_tbHistAuto_id_pass_d ON dbo.tbHistAuto (id_pass, data_fim)');
   exec('CREATE INDEX IX_tbHistAuto_id_auto_d ON dbo.tbHistAuto (id_auto, data_fim)');
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHistAuto') and name = 'cracha')
BEGIN
   ALTER TABLE [dbo].[tbHistAuto] ADD [cracha] float NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHistAuto') and name = 'id_hauto')
BEGIN
   ALTER TABLE dbo.tbHistAuto ADD [id_hauto] BIGINT NOT NULL IDENTITY(1,1);
   ALTER TABLE [dbo].[tbHistAuto] WITH NOCHECK ADD CONSTRAINT [PK_tbHistAuto] PRIMARY KEY ([id_hauto]);
END
GO

/*
   Auxiliar de cadastramento de veculos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTabsAuto') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTabsAuto] (
      [tipo_tab] int NOT NULL,
   [descricao] varchar(50) NOT NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX IX_tbTabsAuto ON dbo.tbTabsAuto(tipo_tab,descricao);
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Branca');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Preta');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Azul');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Cinza');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Verde');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Vermelha');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Prata');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Vinho');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Amarela');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Marrom');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Bege');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Dourado');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Turquesa');
   insert into tbTabsAuto(tipo_tab, descricao) values (1,'Rosa');
end
GO

/*
   Verso do software
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbVersao') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbVersao] (
    [Atual] int NULL, [AtualPto] int NULL
   ) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVersao') and name = 'AtualPto')
BEGIN
   ALTER TABLE [dbo].[tbVersao] ADD AtualPto int NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVersao') and name = 'databco')
BEGIN
   ALTER TABLE [dbo].[tbVersao] ADD databco datetime NULL;
END
GO

/*
   Tabela dos visitantes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbVisi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbVisi] (
      [id_pass] int NOT NULL,
      [nome] varchar(100) NOT NULL ,
      [empresa] varchar(40) NOT NULL ,
      [doc_rg] varchar(50) NULL,
      [doc_cic] varchar(50) NULL,
      [doc_outros] varchar(50) NULL,
      [dtnasc] datetime NULL,
      [pass_visi] int NOT NULL,
      [paci_visi] int NULL,
      [id_depart] int NULL,
      [aces_p] smallint NOT NULL,
      [obs] varchar(250) NOT NULL ,
      [id_eventvisi] int NULL,
      [dtcad] datetime NULL,
      [foto] varchar(25) NULL,
      [fotodoc] varchar(25) NULL,
      [fotodocverso] varchar(25) NULL,
      [id_empvisi] int NULL,
      [aces_lmt] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbVisi] WITH NOCHECK ADD
      CONSTRAINT [DF_tbVisi_empresa] DEFAULT ('') FOR [empresa],
      CONSTRAINT [DF_tbVisi_pass_visi] DEFAULT (0) FOR [pass_visi],
      CONSTRAINT [DF_tbVisi_id_depart] DEFAULT (1) FOR [id_depart],
      CONSTRAINT [DF_tbVisi_aces_p] DEFAULT (1) FOR [aces_p],
      CONSTRAINT [DF_tbVisi_obs] DEFAULT ('') FOR [obs],
      CONSTRAINT [DF_tbVisi_id_eventvisi] DEFAULT (1) FOR [id_eventvisi],
      CONSTRAINT [PK_tbVisi] PRIMARY KEY CLUSTERED ([id_pass]) ON [PRIMARY];
   CREATE INDEX IX_tbVisi_nome ON dbo.tbVisi (nome);
   CREATE INDEX IX_tbVisi_id_pass ON dbo.tbVisi (id_pass);
   CREATE  INDEX [IX_doc_rg] ON [dbo].[tbVisi]([doc_rg]) ON [PRIMARY];
   CREATE  INDEX [IX_doc_cic] ON [dbo].[tbVisi]([doc_cic]) ON [PRIMARY];
   CREATE  INDEX [IX_doc_outros] ON [dbo].[tbVisi]([doc_outros]) ON [PRIMARY];
   CREATE  INDEX [IX_dtcad] ON [dbo].[tbVisi]([dtcad]) ON [PRIMARY];
   CREATE INDEX IX_tbVisi_empresa ON dbo.tbVisi (empresa);
   CREATE INDEX IX_tbVisi_id_empvisi ON dbo.tbVisi (id_empvisi);
end
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVisi') and name = 'nome' and length < 100)
BEGIN
   IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbVisi') and name = 'IX_tbVisi_nome')
   BEGIN
      DROP INDEX dbo.tbVisi.IX_tbVisi_nome;
   END
   ALTER TABLE tbVisi ALTER COLUMN nome VARCHAR(100);
   CREATE INDEX IX_tbVisi_nome ON dbo.tbVisi (nome);
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVisi') and name = 'aces_lmt')
BEGIN
   ALTER TABLE tbVisi ADD [aces_lmt] int NULL;
END
GO

/*
   Empresa do visitante
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEmpVisi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEmpVisi] (
      [id_empvisi] int NOT NULL, [descricao] varchar(100) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEmpVisi] WITH NOCHECK ADD
         CONSTRAINT [PK_tbEmpVisi] PRIMARY KEY CLUSTERED ([id_empvisi]) ON [PRIMARY];
   CREATE INDEX IX_tbEmpVisi_descricao ON dbo.tbEmpVisi (descricao);
end;
GO

/*
   Empresa do terceiro
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEmpTerc') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEmpTerc] (
      [id_empterc] int NOT NULL, [descricao] varchar(100) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEmpTerc] WITH NOCHECK ADD
         CONSTRAINT [PK_tbEmpTerc] PRIMARY KEY CLUSTERED ([id_empterc]) ON [PRIMARY];
   CREATE INDEX IX_tbEmpTerc_descricao ON dbo.tbEmpTerc (descricao);
end;
GO

/*
   Tabela dos visitantes com crachs baixados
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbVisiBai') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbVisiBai] (
      [id_pass] int NOT NULL,
      [id_empresa] int NOT NULL,
      [cracha] [float] NOT NULL,
      [via] tinyint NOT NULL,
      [tipo] varchar(1) NOT NULL ,
      [nome] varchar(100) NOT NULL ,
      [vip] bit NOT NULL,
      [nasc] [smalldatetime] NULL,
      [indesejado] bit NOT NULL,
      [bloqueado] bit NOT NULL,
      [id_horario] int NOT NULL,
      [id_depart] int NULL,
      [per_indet] bit NOT NULL,
      [data_ini] [smalldatetime] NULL,
      [data_fim] [smalldatetime] NULL,
      [id_msgrel] tinyint NOT NULL,
      [id_msgtela] int NOT NULL,
      [msg_qtd_p] smallint NOT NULL,
      [foto] varchar(25) NULL,
      [fotodoc] varchar(25) NULL,
      [fotodocVerso] varchar(25) NULL,
      [g_bloq] varchar(255) NOT NULL ,
      [feriado] bit NOT NULL,
      [status] [char](1) NOT NULL ,
      [data] [smalldatetime] NOT NULL,
      [usu_resp] int NOT NULL,
      [data_bai] [smalldatetime] NULL,
      [resp_bai] int NOT NULL,
      [ult_acess] datetime NULL,
      [indgbloq] varchar(300) NULL,
      [id_consist] int NOT NULL,
      [senha] smallint NOT NULL,
      [codass] varchar(15) NULL,
      [ult_acessd] datetime NULL,
      [ult_idbloq] int NULL,
      [ult_direc] tinyint NULL,
      [doc] varchar(50) NULL,
      [reinic] bit NOT NULL,
      [provisorio] [float] NULL,
      [contador] int NOT NULL,
      [sequencia] varchar(1600) NULL,
      [acessos_dia] int NULL,
      [id_local] int NULL,
      [id_sublocal] int NULL,
      [pass_visi] int NULL,
      [visitado] varchar(50) NULL,
      [paci_visi] int NULL,
      [id_agrupamento] int NULL,
      [id_custo] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbVisiBai] WITH NOCHECK ADD
      CONSTRAINT [DF_tbVisiBai_id_pass] DEFAULT (0) FOR [id_pass],
      CONSTRAINT [DF_tbVisiBai_id_empresa] DEFAULT (0) FOR [id_empresa],
      CONSTRAINT [DF_tbVisiBai_id_horario] DEFAULT (1) FOR [id_horario],
      CONSTRAINT [DF_tbVisiBai_id_depart] DEFAULT (1) FOR [id_depart],
      CONSTRAINT [DF_tbVisiBai_id_msgrel] DEFAULT (1) FOR [id_msgrel],
      CONSTRAINT [DF_tbVisiBai_id_msgtela] DEFAULT (1) FOR [id_msgtela],
      CONSTRAINT [DF_tbVisiBai_msg_qtd_p] DEFAULT (0) FOR [msg_qtd_p],
      CONSTRAINT [DF_tbVisiBai_foto] DEFAULT ('') FOR [foto],
      CONSTRAINT [DF_tbVisiBai_g_bloq] DEFAULT ('') FOR [g_bloq],
      CONSTRAINT [DF_tbVisiBai_status] DEFAULT ('N') FOR [status],
      CONSTRAINT [DF_tbVisiBai_usu_resp] DEFAULT (0) FOR [usu_resp],
      CONSTRAINT [DF_tbVisiBai_resp_bai] DEFAULT (0) FOR [resp_bai],
      CONSTRAINT [DF_tbVisiBai_id_consist] DEFAULT (1) FOR [id_consist],
      CONSTRAINT [DF_tbVisiBai_senha] DEFAULT (0) FOR [senha],
      CONSTRAINT [DF__tbVisiBai__codas__3DE82FB7] DEFAULT ('') FOR [codass],
      CONSTRAINT [DF__tbVisiBai__ult_i__3EDC53F0] DEFAULT (0) FOR [ult_idbloq],
      CONSTRAINT [DF_tbVisiBai_ult_direc] DEFAULT (0) FOR [ult_direc],
      CONSTRAINT [DF__tbVisiBai__reini__2A164134] DEFAULT (0) FOR [reinic],
      CONSTRAINT [DF__tbVisiBai__provi__2B0A656D] DEFAULT (0) FOR [provisorio],
      CONSTRAINT [DF_tbVisiBai_contador] DEFAULT (0) FOR [contador],
      CONSTRAINT [DF_tbVisiBai_sequencia] DEFAULT (',') FOR [sequencia],
      CONSTRAINT [PK_tbVisiBai] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY] ;
   CREATE INDEX IX_tbVisiBai_Limpeza ON dbo.tbVisiBai (id_pass, id_empresa, ult_acess);
   CREATE  INDEX [IX_idempresa] ON [dbo].[tbVisiBai]([id_empresa]) ON [PRIMARY];
   --CREATE  INDEX [IX_idhorario] ON [dbo].[tbVisiBai]([id_horario]) ON [PRIMARY];
   --CREATE  INDEX [IX_iddepart] ON [dbo].[tbVisiBai]([id_depart]) ON [PRIMARY];
   --CREATE INDEX [IX_idsublocal] ON [dbo].[tbVisiBai]([id_sublocal]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVisiBai') and name = 'id_agrupamento')
BEGIN
   ALTER TABLE dbo.tbVisiBai ADD [id_agrupamento] int NULL;
   ALTER TABLE dbo.tbVisiBai ADD [id_custo] int NULL;
END
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbVisiBai') and name = 'nome' and length < 100)
BEGIN
   ALTER TABLE tbVisiBai ALTER COLUMN nome VARCHAR(100);
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbVisiBai') and name = 'IX_idhorario')
BEGIN
   EXEC('DROP INDEX tbVisiBai.IX_idhorario');
   EXEC('DROP INDEX tbVisiBai.IX_iddepart');
   EXEC('DROP INDEX tbVisiBai.IX_idsublocal');
END;
GO

/*
   Tabela de locais de acesso
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLocais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLocais] (
      [id_local] int NOT NULL,
      [id_empresa] int NOT NULL,
      [descricao] varchar(50) NOT NULL ,
      [altera] int NOT NULL,
      [acessos] int NOT NULL,
      [permanencia] int NOT NULL,
      [id_horario] int NOT NULL,
      [feriado] bit NULL,
      [vip] bit NULL,
      [g_bloq] varchar(255) NULL,
      [id_consist] int NULL,
      [ramal] varchar(5) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLocais] WITH NOCHECK ADD CONSTRAINT [PK_tbLocais] PRIMARY KEY CLUSTERED ([id_local]) ON [PRIMARY];
   CREATE INDEX [IX_tbLocais_id_empresa] ON [dbo].[tbLocais]([id_empresa]) ON [PRIMARY];
END
GO

/*
   Tabela de sub-locais de acesso
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSubLocais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbSubLocais] (
      [id_sublocal] int NOT NULL,
      [id_local] int NOT NULL,
      [descricao] varchar(50) NOT NULL ,
      [maximo_sub] int NOT NULL,
      [maximo_vis] int NOT NULL,
      [ramal] varchar(5) NULL,
      [id_paciente] integer NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbSubLocais] WITH NOCHECK ADD CONSTRAINT [PK_tbSubLocais] PRIMARY KEY CLUSTERED ([id_sublocal]) ON [PRIMARY];
   CREATE INDEX [IX_tbSubLocais_id_local] ON [dbo].[tbSubLocais]([id_local]) ON [PRIMARY];
END
GO

/*
   Tabela de tipos de movimento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHTMov') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHTMov] (
      [id_htmov] int NOT NULL,
      [descricao] varchar(20) NOT NULL, [status] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHTMov] WITH NOCHECK ADD CONSTRAINT [PK_tbHTMov] PRIMARY KEY CLUSTERED ([id_htmov]) ON [PRIMARY];
END
GO

/*
   Tabela de movimento de paciente
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHMov') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHMov] (
      [id_hmov] [bigint] NOT NULL,
      [id_paciente] int NOT NULL,
      [tipo_entrada] int NULL,
      [desc_entrada] varchar(50) NULL,
      [cabelos] int NULL,
      [pele] int NULL,
      [idade_apx] int NULL,
      [caract] varchar(250) NOT NULL ,
      [roupas] varchar(250) NOT NULL ,
      [pertences] varchar(250) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHMov] WITH NOCHECK ADD CONSTRAINT [PK_tbHMov] PRIMARY KEY CLUSTERED ([id_hmov]) ON [PRIMARY];
   CREATE INDEX [IX_tbHMov_id_paciente] ON [dbo].[tbHMov]([id_paciente]) ON [PRIMARY];
END
GO

/*
   Tabela de movimento de paciente
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHMovDet') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHMovDet] (
      [id_hmov] [bigint] NOT NULL,
      [id_paciente] int NOT NULL,
      [data] datetime NOT NULL,
      [id_htmov] int NOT NULL,
      [id_local] int NULL,
      [id_sublocal] int NULL,
     [obs] varchar(100) NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [IX_tbHMovDet] ON [dbo].[tbHMovDet]([id_hmov]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbHMovDetPaci] ON [dbo].[tbHMovDet]([id_hmov],[id_paciente],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbHMovDet_id_paciente] ON [dbo].[tbHMovDet]([id_paciente]) ON [PRIMARY];
END
GO

/*
   Tabela de convnios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbConvenio') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbConvenio] (
      [id_convenio] int NOT NULL,
      [ans] varchar(15) NOT NULL, [descricao] varchar(50) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbConvenio] WITH NOCHECK ADD CONSTRAINT [PK_tbConvenio] PRIMARY KEY CLUSTERED ([id_convenio]) ON [PRIMARY];
   CREATE INDEX [IX_tbConvenio_ans] ON [dbo].[tbConvenio]([ans]) ON [PRIMARY];
END
GO

/*
   Tabela de cidades
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCidade') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCidade] (
      [id_cidade] int NOT NULL,
      [descricao] varchar(50) NOT NULL, [uf] varchar(2) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCidade] WITH NOCHECK ADD CONSTRAINT [PK_tbCidade] PRIMARY KEY CLUSTERED ([id_cidade]) ON [PRIMARY];
   CREATE INDEX [IX_tbCidade] ON [dbo].[tbCidade]([descricao]) ON [PRIMARY];
END
GO

/*
   Tabela de pacientes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPacientes') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPacientes] (
      [id_paciente] int NOT NULL,
      [id_empresa] int NOT NULL,
      [codigo] varchar(15) NOT NULL ,
      [nome] varchar(100) NOT NULL ,
      [dtatualizacao] datetime NOT NULL,
      [id_local] int NULL,
      [id_sublocal] int NULL,
      [id_pass_ult] int NULL,
      [dtvis_ult] datetime NULL,
      [foto]        varchar(25) NULL,
      [doc_rg]      varchar(50) NULL,
      [doc_cpf]     varchar(50) NULL,
      [doc_outros]  varchar(50) NULL,
      [sem_ident]   bit NULL,
      [restricao]   int NULL,
      [apelido]     varchar(20) NULL,
      [sus]         varchar(15) NULL,
      [id_convenio] int NULL,
      [convenio]    varchar(20) NULL,
      [dt_nasc]     datetime NULL,
      [sexo]        tinyint NULL,
      [endereco]    varchar(70) NULL,
      [bairro]      varchar(30) NULL,
      [cidade]      varchar(50) NULL,
      [uf]          varchar(2) NULL,
      [cep]         varchar(10) NULL,
      [fone]        varchar(15) NULL,
      [celular]     varchar(15) NULL,
      [email]       varchar(30) NULL,
      [obs]         varchar(250) NULL,
      [nome_rsp]    varchar(50) NULL,
      [endereco_rsp] varchar(70) NULL,
      [bairro_rsp]  varchar(30) NULL,
      [cidade_rsp]  varchar(50) NULL,
      [uf_rsp]      varchar(2) NULL,
      [cep_rsp]     varchar(10) NULL,
      [fone_rsp]    varchar(15) NULL,
      [celular_rsp] varchar(15) NULL,
      [email_rsp]   varchar(30) NULL,
      [obs_rsp]     varchar(250) NULL,
      [ult_mov]     [float] NULL,
      [ult_status]  int NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbPacientes] WITH NOCHECK ADD CONSTRAINT [PK_tbPacientes] PRIMARY KEY CLUSTERED ([id_paciente]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbPacientes_codigo] ON [dbo].[tbPacientes]([id_empresa],[codigo]) ON [PRIMARY];
   CREATE INDEX [IX_tbPacientes_dtatualizacao] ON [dbo].[tbPacientes]([id_empresa],[dtatualizacao]) ON [PRIMARY];
   CREATE INDEX [IX_tbPacientes_nome] ON [dbo].[tbPacientes]([nome]) ON [PRIMARY];
   CREATE INDEX [IX_tbPacientes_idslocal] ON [dbo].[tbPacientes]([id_sublocal],[nome]) ON [PRIMARY];
   CREATE INDEX [IX_tbPacientes_cod] ON [dbo].[tbPacientes]([codigo]) ON [PRIMARY];
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPacientes') and name = 'IX_tbPacientes_cons')
BEGIN
   CREATE INDEX [IX_tbPacientes_cons] ON [dbo].[tbPacientes]([id_empresa],[dtatualizacao],[ult_status]) ON [PRIMARY];
END
GO

/*
  Aux de rel. de totais de refeitrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRelTotRefeitorio') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRelTotRefeitorio] (
      [id_relatorio]  [float] NOT NULL,
      [tipo_reg]    int NUll,        [id_empresa]  int NULL,
      [codempresa]  varchar(8) NULL, [desc_emp]    varchar(70) NULL,
      [id_depart]   int NULL,        [coddepart]   varchar(10) NULL,
      [desc_depto]  varchar(50) NULL, [id_pass]    int NULL,
      [nome]        varchar(100) NULL, [tipo]       [char](1) NULL,
      [cracha]      [float] NULL,       [codass]     varchar(15) NULL,
      [id_refeit]   int NULL,         [codrefeit]  varchar(5) NULL,
      [desc_refeit] varchar(20) NULL, [data]        datetime NULL,
      [qtd1] int NULL, [vlr1] [float] NULL, [qtd2] int NULL, [vlr2] [float] NULL,
      [qtd3] int NULL, [vlr3] [float] NULL, [qtd4] int NULL, [vlr4] [float] NULL,
      [qtd5] int NULL, [vlr5] [float] NULL, [qtd6] int NULL, [vlr6] [float] NULL,
      [qtd7] int NULL, [vlr7] [float] NULL, [qtd8] int NULL, [vlr8] [float] NULL,
      [qtd9] int NULL, [vlr9] [float] NULL,
      [desc_cargo] varchar(100) null,
      [cpf] varchar(15) null,
      [matricula] varchar(15) null
   ) ON [PRIMARY];
   CREATE INDEX [IX_tbRelTotRefeitorio] ON [dbo].[tbRelTotRefeitorio]([id_relatorio]) ON [PRIMARY];
end
GO
--Atualizao
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRelTotRefeitorio') and name = 'nome' and length < 100)
BEGIN
   ALTER TABLE tbRelTotRefeitorio ALTER COLUMN nome VARCHAR(100);
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRelTotRefeitorio') and name = 'coddepart' and length < 10)
BEGIN
   ALTER TABLE tbRelTotRefeitorio ALTER COLUMN coddepart VARCHAR(10);
END;
GO
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRelTotRefeitorio') and name = 'desc_depto' and length <> 50)
BEGIN
   ALTER TABLE [dbo].[tbRelTotRefeitorio] ALTER COLUMN desc_depto VARCHAR(50) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRelTotRefeitorio') and name = 'desc_cargo')
BEGIN
   ALTER TABLE [dbo].[tbRelTotRefeitorio] ADD [desc_cargo] varchar(100) null;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRelTotRefeitorio') and name = 'cpf')
BEGIN
   ALTER TABLE [dbo].[tbRelTotRefeitorio] ADD [cpf] varchar(15) null;
   ALTER TABLE [dbo].[tbRelTotRefeitorio] ADD [matricula] varchar(15) null;
END;
GO

/*
   Movimentao de acessos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMovim') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMovim] (
      [id_pass] int NOT NULL,
      [id_empresa] int NOT NULL,
      [cracha] [float] NOT NULL,
      [data] datetime NOT NULL,
      [hora] datetime NOT NULL,
      [relogio] smallint NOT NULL,
      [status] tinyint NOT NULL,
      [evento] tinyint NOT NULL,
      [funcao] tinyint NOT NULL,
      [id_eventvisi] int NOT NULL,
      [tipo] [char](1) NOT NULL ,
      [id_depart] int NULL,
      [id_local] int NULL,
      [id_sublocal] int NULL,
      [pass_visi] int NULL,
      [visitado] varchar(50) NULL,
      [paci_visi] int NULL,
      [id_auto] int NULL,
      [ponto] tinyint null,
      [id_movim] BIGINT NOT NULL IDENTITY(1,1)
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMovim] WITH NOCHECK ADD
      CONSTRAINT [DF_tbMovim_data] DEFAULT (getdate()) FOR [data],
      CONSTRAINT [DF_tbMovim_hora] DEFAULT (getdate()) FOR [hora],
      CONSTRAINT [DF_tbMovim_relogio] DEFAULT (0) FOR [relogio],
      CONSTRAINT [DF_tbMovim_status] DEFAULT (0) FOR [status],
      CONSTRAINT [DF_tbMovim_evento] DEFAULT (0) FOR [evento],
      CONSTRAINT [DF_tbMovim_funcao] DEFAULT (1) FOR [funcao],
      CONSTRAINT [DF_tbMovim_id_eventvisi] DEFAULT (0) FOR [id_eventvisi],
      CONSTRAINT [DF_tbMovim_tipo] DEFAULT ('') FOR [tipo],
      CONSTRAINT [DF_tbMovim_id_depart] DEFAULT (0) FOR [id_depart];
   CREATE INDEX IX_tbMovim_Limpeza ON dbo.tbMovim (id_pass, data);
   CREATE INDEX IX_tbMovim_Data ON dbo.tbMovim (data);
   CREATE INDEX IX_tbMovim_IdAuto ON dbo.tbMovim (id_auto);
   CREATE INDEX [IX_tbMovim_id_movim] ON [dbo].[tbMovim]([id_movim]);
   --CREATE INDEX IX_tbMovim_IdPass ON dbo.tbMovim (id_pass);
   --CREATE INDEX [IX_idsublocal] ON [dbo].[tbMovim]([id_sublocal]) ON [PRIMARY];
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbMovim') and name = 'ponto')
BEGIN
   ALTER TABLE [dbo].[tbMovim] ADD [ponto] tinyint null;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbMovim') and name = 'id_movim')
BEGIN
   ALTER TABLE dbo.tbMovim ADD [id_movim] BIGINT NOT NULL IDENTITY(1,1);
   CREATE INDEX [IX_tbMovim_id_movim] ON [dbo].[tbMovim]([id_movim]);
END
GO
IF EXISTS(SELECT TOP 1 evento FROM tbMovim WHERE evento=101)
BEGIN
   exec('UPDATE tbMovim SET evento=54 WHERE evento=101');
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbMovim') and name = 'IX_tbMovim_IdPass')
BEGIN
   EXEC('DROP INDEX tbMovim.IX_tbMovim_IdPass');
   EXEC('DROP INDEX tbMovim.IX_idsublocal');
END;
GO

/*
   Histrico de cadastramento de veculos x Movimento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMHAuto') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMHAuto] (
      [id_movim] BIGINT NOT NULL,
      [id_hauto] BIGINT NOT NULL,
      [id_testac] int NULL,
      [f_valor] numeric(9,2) NULL,
      [data_ent] datetime NULL,
      [m_tempo] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMHAuto] WITH NOCHECK ADD CONSTRAINT [PK_tbMHAuto] PRIMARY KEY ([id_movim],[id_hauto]) ON [PRIMARY];
   EXEC('INSERT INTO tbMHAuto SELECT DISTINCT m.id_movim, h.id_hauto FROM tbMovim m INNER JOIN tbHistAuto h ON m.id_auto = h.id_auto AND m.id_pass=h.id_pass AND m.data BETWEEN h.data_ini AND isnull(h.data_fim,m.data)');
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbMHAuto') and name = 'id_testac')
BEGIN
   ALTER TABLE [dbo].[tbMHAuto] ADD [id_testac] int NULL;
   ALTER TABLE [dbo].[tbMHAuto] ADD [f_valor] numeric(9,2) NULL;
   ALTER TABLE [dbo].[tbMHAuto] ADD [data_ent] datetime NULL;
   ALTER TABLE [dbo].[tbMHAuto] ADD [m_tempo] int NULL;
END
GO

/*
   Tabela de estacionamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTEstac') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTEstac] (
      [id_testac] int NOT NULL,
      [descricao] varchar(30) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTEstac] WITH NOCHECK ADD CONSTRAINT [PK_tbTEstac] PRIMARY KEY ([id_testac]) ON [PRIMARY];
end
GO

/*
   Tabela de estacionamento - tipos de passante
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTPEstac') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTPEstac] (
      [id_testac] int NOT NULL,
      [tipo] varchar(1) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTPEstac] WITH NOCHECK ADD CONSTRAINT [PK_tbTPEstac] PRIMARY KEY ([id_testac],[tipo]) ON [PRIMARY];
end
GO

/*
   Tabela de estacionamento - faixas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTFEstac') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTFEstac] (
      [id_testac] int NOT NULL,
      [faixa] int NOT NULL,
      [tempo] varchar(5) NOT NULL,
      [m_tempo] int NOT NULL,
      [valor] [varchar](6) NULL,
      [f_valor] numeric(5,2) NOT NULL,
      [por_hora] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTFEstac] WITH NOCHECK ADD CONSTRAINT [PK_tbTFEstac] PRIMARY KEY ([id_testac],[faixa]) ON [PRIMARY];
end
GO

/*
   vwMovim - Acesso e Refeitrio
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.vwMovim') AND (xtype='V' or xtype='U')) BEGIN DROP VIEW dbo.vwMovim; END;
GO
CREATE VIEW dbo.vwMovim AS
   SELECT id_pass, id_empresa, cracha, data, hora, relogio, status, evento, funcao, id_eventvisi, tipo,
          id_depart, id_local, id_sublocal, pass_visi, visitado, paci_visi, id_auto, ponto, id_movim
   FROM tbMovim WITH (NOLOCK)
   UNION ALL
   SELECT id_pass, id_empresa, cracha, data, hora, relogio, status, evento, funcao, 0 as id_eventvisi, tipo,
          id_depart, convert(int,0) as id_local, convert(int,0) as id_sublocal,
          convert(int,0) as pass_visi, convert(varchar(50),'') as visitado,
          convert(int,0) as paci_visi, convert(int,0) as id_auto, convert(bit,0) as ponto, id_mrefeit as id_movim
   FROM tbMRefeit WITH (NOLOCK)
GO

/*
   vwInfoBloq - Informaes de status do bloqueio
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.vwInfoBloq') AND (xtype='V' or xtype='U')) BEGIN DROP VIEW dbo.vwInfoBloq; END;
GO
CREATE VIEW dbo.vwInfoBloq AS
   SELECT x.id_bloq, x.ponto, x.acesso, (
   CASE WHEN x.temAlerta=1 AND x.situacao NOT IN (1,7,8) THEN 9
        ELSE x.situacao END
   ) as situacao
   FROM (
   SELECT b.id_bloq,
      (CASE WHEN b.id_modelo IN (7,8,14,16,22,24,28,30) THEN 1 ELSE 0 END) as ponto,
      (CASE WHEN b.id_modelo IN (4,5,11,12,13,15,17,18,20,21,23,25,26,27,32,33,34) THEN 1 ELSE 0 END) as acesso,
    isnull(i.valor,0) as situacao,
    (CASE WHEN
    EXISTS(SELECT TOP 1 alrt.id_bloq FROM tbInfoBloq alrt
    WHERE alrt.id_bloq = b.id_bloq AND (alrt.tipo_info=2 OR (alrt.tipo_info=3 AND alrt.descricao IN ('Falha','Erro')) )
      AND isnull(alrt.dt_validade, getdate()) >=getdate()) THEN 1 ELSE 0 END) AS temAlerta
   FROM tbBloq b
   LEFT JOIN tbInfoBloq i ON b.id_bloq = i.id_bloq AND i.tipo_info=0 AND isnull(i.dt_validade, getdate()) >=getdate()
   WHERE b.st_bloq IN (0, 2)
   GROUP BY b.id_bloq, isnull(i.valor,0), b.id_modelo) AS x
GO

/*
   Dias verficados
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoChkDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoChkDia] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL, [tipo_chk] tinyint NOT NULL, [obs_chk] varchar(30) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoChkDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoChkDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoChkDia') and name = 'obs_chk')
BEGIN
   ALTER TABLE [dbo].[tbPtoChkDia] ADD [obs_chk] varchar(30) NULL;
END;
GO

/*
   tbPtoCIDDia - Lanamentos dirios de Cdigo de CID
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoCIDDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoCIDDia] (
      [id_pass] int NOT NULL, [data] datetime NOT NULL, [cid] varchar(10) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoCIDDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoCIDDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoCIDDia] ON [dbo].[tbPtoCIDDia]([cid],[id_pass]) ON [PRIMARY];
end
GO

/*
   Ponto - Tabelas do dia
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoDia] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL, [tipodia] [char](1) NOT NULL,
      [tipohe] [char](1) NOT NULL,
      [trabalhado] bit NOT NULL, [flexivel] bit NOT NULL,
      [id_eveabo] int NULL,
      [horas_abono] varchar(7) NULL, [m_horas_abono] int NULL,
      [id_eveafa] int NULL, [folga] bit NOT NULL,
      [id_phorario] int NULL,   [id_arredonda] int NULL,
      [id_dsr] int NULL,        [id_he] int NULL,
      [id_adicional] int NULL,  [id_hnormais] int NULL,
      [desc_feriado] varchar(20) NULL ,
      [admissao] bit NOT NULL, [demissao] bit NOT NULL,
      [entrada1]    varchar(6) NOT NULL, [saida1]      varchar(6) NOT NULL,
      [entrada2]    varchar(6) NOT NULL, [saida2]      varchar(6) NOT NULL,
      [entrada3]    varchar(6) NOT NULL, [saida3]      varchar(6) NOT NULL,
      [entrada4]    varchar(6) NOT NULL, [saida4]      varchar(6) NOT NULL,
      [flex_ini]    varchar(6) NOT NULL, [flex_fim]    varchar(6) NOT NULL,
      [flex_tempo]  varchar(6) NOT NULL,
      [e1] int NOT NULL, [s1] int NOT NULL, [e2] int NOT NULL, [s2] int NOT NULL,
      [e3] int NOT NULL, [s3] int NOT NULL, [e4] int NOT NULL, [s4] int NOT NULL,
      [fxini] int NOT NULL, [fxfim] int NOT NULL, [fxtmp] int NOT NULL,
      [obs] varchar(30) NULL, [norm_ini] int NOT NULL, [norm_fim] int NOT NULL,
      [hrs_prev] varchar(7) NOT NULL, [m_hrs_prev] int NOT NULL,
      [afd_dia] bit null, [id_tolera] int null,
      [apontado] bit null, [id_tabbco] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoDia_apontado] ON [dbo].[tbPtoDia]([apontado],[data]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoDia') and name = 'afd_dia')
BEGIN
   ALTER TABLE [dbo].[tbPtoDia] ADD [afd_dia] BIT NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoDia') and name = 'id_tolera')
BEGIN
   ALTER TABLE [dbo].[tbPtoDia] ADD [id_tolera] INT NULL;
   EXEC('UPDATE tbPtoDia SET id_tolera=isnull((select f.id_tolera from tbFunc f where f.id_pass=tbPtoDia.id_pass),0)');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoDia') and name = 'apontado')
BEGIN
   ALTER TABLE [dbo].[tbPtoDia] ADD [apontado] bit null;
   exec('UPDATE tbPtoDia SET apontado=1');
   exec('CREATE INDEX [IX_tbPtoDia_apontado] ON [dbo].[tbPtoDia]([apontado],[data]) ON [PRIMARY]');
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoDia') and name = 'id_tabbco')
BEGIN
   ALTER TABLE [dbo].[tbPtoDia] ADD [id_tabbco] int NULL;
   exec('UPDATE tbPtoDia SET id_tabbco=1 WHERE EXISTS(SELECT f.id_pass FROM tbFunc f WHERE f.id_pass=tbPtoDia.id_pass AND f.banco=1)');
END
GO

/*
   Ponto - Tabela de estatsticas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoEstat') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoEstat] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [m_intjr] int NOT NULL,
      [m_atrasos] int NOT NULL,
      [m_he_dia] int NOT NULL,
      [m_he_intervalo] int NOT NULL,
      [m_faltas] int NOT NULL,
      [alerta_dia] bit NOT NULL,
      [dia_tipo] tinyint NOT NULL, --0: normal, 1:admisso, 2:incio afast., 3:fim afast, 4: demisso
      [dia_cid]  varchar(10) NULL,
      [dia_previsto]  bit NOT NULL,
      [dia_ausencia] bit NOT NULL,
      [dia_inativo] bit NOT NULL,
      [m_previsto] int NOT NULL,
      [m_ausencia] int NOT NULL,
      [m_inativo] int NOT NULL,
      [id_eveabo] int NOT NULL,
      [alrt_interjor] bit NOT NULL,
      [alrt_he_intv] bit NOT NULL,
      [alrt_he_dia] bit NOT NULL,
      [alrt_atraso_dia] bit NOT NULL,
      [alrt_falta_dia] bit NOT NULL,
      [m_acres_d] int NOT NULL,
      [m_acres_n] int NOT NULL,
      [m_acres_dp] int NOT NULL,
      [m_acres_np] int NOT NULL,
      [m_acres_b] int NOT NULL,
      [m_acres_bp] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoEstat] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoEstat] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoEstat_alerta] ON [dbo].[tbPtoEstat]([id_pass],[data],[alerta_dia]) ON [PRIMARY];
end;
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoEstat') and name = 'dia_contradado')
BEGIN
   ALTER TABLE tbPtoEstat DROP COLUMN admissao, demissao, dia_contradado, dia_parado, pabsenteismo, m_absenteismo, m_contratado;
   ALTER TABLE tbPtoEstat ADD dia_tipo tinyint NULL, dia_cid varchar(10) NULL, dia_previsto bit NULL, dia_ausencia bit NULL, dia_inativo bit NULL, m_previsto int NULL, m_ausencia int NULL, m_inativo int NULL, id_eveabo int NULL,alrt_interjor bit NULL,alrt_he_intv bit NULL,alrt_he_dia bit NULL,alrt_atraso_dia bit NULL,alrt_falta_dia bit NULL;
   EXEC('UPDATE tbPtoEstat SET m_intjr=0,m_atrasos=0,m_he_dia=0,m_he_intervalo=0,m_faltas=0,dia_tipo=0,dia_previsto=0,dia_ausencia=0,dia_inativo=0,m_previsto=0,m_ausencia=0,m_inativo=0,id_eveabo=0,alrt_interjor=0,alrt_he_intv=0,alrt_he_dia=0,alrt_atraso_dia=0,alrt_falta_dia=0');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_intjr int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_atrasos int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_he_dia int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_he_intervalo int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_faltas int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN dia_tipo tinyint NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN dia_previsto bit NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN dia_ausencia bit NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN dia_inativo bit NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_previsto int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_ausencia int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_inativo int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN id_eveabo int NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN alrt_interjor bit NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN alrt_he_intv bit NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN alrt_he_dia bit NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN alrt_atraso_dia bit NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN alrt_falta_dia bit NOT NULL');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoEstat') and name = 'm_acres_d')
BEGIN
   ALTER TABLE tbPtoEstat ADD m_acres_d INT NULL, m_acres_n INT NULL, m_acres_dp INT NULL, m_acres_np INT NULL, m_acres_b INT NULL, m_acres_bp INT NULL;
   EXEC('UPDATE tbPtoEstat SET m_acres_d=0, m_acres_n=0, m_acres_dp=0, m_acres_np=0, m_acres_b=0, m_acres_bp=0');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_acres_d INT NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_acres_n INT NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_acres_dp INT NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_acres_np INT NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_acres_b INT NOT NULL');
   EXEC('ALTER TABLE tbPtoEstat ALTER COLUMN m_acres_bp INT NOT NULL');
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoEstat') and name = 'IX_tbPtoEstat_alerta')
BEGIN
   EXEC('DROP INDEX tbPtoEstat.IX_tbPtoEstat_alerta');
END;
GO

/*
   Ponto - Apontamento do dia
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoApDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoApDia] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [falta] bit NOT NULL,
      [hrs_norm] varchar(7) NOT NULL, [m_hrs_norm] int NOT NULL,
      [hn_tot] varchar(7) NOT NULL, [m_hn_tot] int NOT NULL,
      [trab_tot] varchar(7) NOT NULL, [m_trab_tot] int NOT NULL,
      [m_hn_tmpdia] int NULL, [m_dhn_tmpdia] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoApDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoApDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoApDia') and name = 'm_hn_tmpdia')
BEGIN
   ALTER TABLE [dbo].[tbPtoApDia] ADD [m_hn_tmpdia] int NULL;
   ALTER TABLE [dbo].[tbPtoApDia] ADD [m_dhn_tmpdia] int NULL;
END;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoAboDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoAboDia] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_diverg] int NOT NULL,
      [id_eveabo] int NOT NULL,    [contadia] smallint NOT NULL,
      [gerado]  bit NOT NULL,
      [valor] varchar(7) NOT NULL, [m_valor] int NOT NULL,
      [id_usuario] int NULL,
      [cid] VARCHAR(10) NULL,
      [id_ptocp] BIGINT NULL,
      [obs] VARCHAR(30) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoAboDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoAboDia] PRIMARY KEY CLUSTERED ([id_pass],[data],[id_diverg],[id_eveabo]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbPtoAboDia] ON [dbo].[tbPtoAboDia]([id_pass],[data],[contadia]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoAboDia_id_div] ON [dbo].[tbPtoAboDia]([id_pass],[data],[id_diverg]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoAboDia_gerado] ON [dbo].[tbPtoAboDia]([id_pass],[data],[gerado]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoAboDia_idata] ON [dbo].[tbPtoAboDia]([id_pass],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoAboDia_id_usuario] ON [dbo].[tbPtoAboDia]([id_usuario]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoAboDia_id_ptocp] ON [dbo].[tbPtoAboDia]([id_ptocp]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoAboDia') and name = 'id_usuario')
BEGIN
   ALTER TABLE [dbo].[tbPtoAboDia] ADD [id_usuario] int NULL;
   exec('UPDATE tbPtoAboDia SET id_usuario=0');
   exec('CREATE INDEX [IX_tbPtoAboDia_id_usuario] ON [dbo].[tbPtoAboDia]([id_usuario]) ON [PRIMARY]');
END
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoAboDia') and name = 'IX_tbPtoAboDia_id_diverg')
BEGIN
   DROP INDEX dbo.tbPtoAboDia.IX_tbPtoAboDia_id_diverg;
   CREATE INDEX [IX_tbPtoAboDia_id_div] ON [dbo].[tbPtoAboDia]([id_pass],[data],[id_diverg]) ON [PRIMARY];
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoAboDia') and name = 'cid')
BEGIN
   ALTER TABLE dbo.tbPtoAboDia ADD [cid] VARCHAR(10) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoAboDia') and name = 'id_ptocp')
BEGIN
   ALTER TABLE dbo.tbPtoAboDia ADD [id_ptocp] BIGINT NULL;
   exec('CREATE INDEX [IX_tbPtoAboDia_id_ptocp] ON [dbo].[tbPtoAboDia]([id_ptocp]) ON [PRIMARY]');
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoAboDia') and name = 'IX_tbPtoAboDia_id_div')
BEGIN
   exec('DROP INDEX tbPtoAboDia.IX_tbPtoAboDia_id_div');
   exec('DROP INDEX tbPtoAboDia.IX_tbPtoAboDia_gerado');
   exec('DROP INDEX tbPtoAboDia.IX_tbPtoAboDia_idata');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoAboDia') and name = 'obs')
BEGIN
   ALTER TABLE dbo.tbPtoAboDia ADD [obs] VARCHAR(30) NULL;
END;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoDivsDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoDivsDia] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,      [lancado] bit NOT NULL,
      [id_diverg] int NOT NULL,      [contadia] smallint NOT NULL,
      [valor] varchar(7) NOT NULL,   [m_valor] int NOT NULL,
      [abonado] varchar(7) NOT NULL, [m_abonado] int NOT NULL,
      [id_associ] int NOT NULL, [m_ant_arred]  int NOT NULL,
      [monetario] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoDivsDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoDivsDia] PRIMARY KEY CLUSTERED ([id_pass],[data],[id_diverg]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbPtoDivsDia] ON [dbo].[tbPtoDivsDia]([id_pass],[data],[contadia]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoDivsDia_lancado] ON [dbo].[tbPtoDivsDia]([id_pass],[data],[lancado]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoDivsDia_idata] ON [dbo].[tbPtoDivsDia]([id_pass],[data]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoDivsDia_id_associ] ON [dbo].[tbPtoDivsDia]([id_pass],[data],[id_associ]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoDivsDia_divlancado] ON [dbo].[tbPtoDivsDia]([id_pass],[data],[id_diverg],[lancado]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoDivsDia') and name = 'monetario')
BEGIN
   ALTER TABLE [dbo].[tbPtoDivsDia] ADD [monetario] bit NULL;
   EXEC('UPDATE tbPtoDivsDia SET monetario=0');
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoDivsDia') and name = 'IX_tbPtoDivsDia_lancado')
BEGIN
   exec('DROP INDEX tbPtoDivsDia.IX_tbPtoDivsDia_lancado');
   exec('DROP INDEX tbPtoDivsDia.IX_tbPtoDivsDia_idata');
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoDivsDia') and name = 'IX_tbPtoDivsDia_id_assoc')
BEGIN
   exec('DROP INDEX tbPtoDivsDia.IX_tbPtoDivsDia_id_assoc');
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoDivsDia') and name = 'IX_tbPtoDivsDia_divlancado')
BEGIN
   exec('DROP INDEX tbPtoDivsDia.IX_tbPtoDivsDia_divlancado');
END;
GO

/*
   vwPtoAboDia - Abonos e afastamentos
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.vwPtoAboDia') AND (xtype='V' or xtype='U')) BEGIN DROP VIEW dbo.vwPtoAboDia; END;
GO
CREATE VIEW dbo.vwPtoAboDia AS
   SELECT
      a.id_pass, a.data, a.id_diverg,
      a.id_eveabo, a.gerado,
      (CASE WHEN a.m_valor = 599999 THEN isnull(d.valor,'  00:00') ELSE a.valor END) as valor,
      (CASE WHEN a.m_valor = 599999 THEN isnull(d.m_valor,0) ELSE a.m_valor END) as m_valor,
      a.id_usuario, a.cid, a.obs, a.id_ptocp
   FROM tbPtoAboDia a
   LEFT JOIN tbPtoDivsDia d ON d.id_pass = a.id_pass AND d.data=a.data AND d.id_diverg=a.id_diverg
GO

/*
   vwPtoPTAbo - Totais de abono do funcionrio
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.vwPtoPTAbo') AND (xtype='V' or xtype='U')) BEGIN DROP VIEW dbo.vwPtoPTAbo; END;
GO
CREATE VIEW dbo.vwPtoPTAbo AS
   SELECT
      a.id_pass, a.data, a.id_diverg,
      a.id_eveabo, a.gerado,
      (CASE WHEN a.m_valor = 599999 THEN isnull(d.valor,'  00:00') ELSE a.valor END) as valor,
      (CASE WHEN a.m_valor = 599999 THEN isnull(d.m_valor,0) ELSE a.m_valor END) as m_valor,
      a.id_usuario, a.cid, a.id_ptocp
   FROM tbPtoAboDia a
   LEFT JOIN tbPtoDivsDia d ON d.id_pass = a.id_pass AND d.data=a.data AND d.id_diverg=a.id_diverg
GO

/*
   Tabela de HE diria
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoHEDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoHEDia] (
      [id_pass] int NOT NULL, [data] datetime NOT NULL,
      [opcao] int NOT NULL, [periodo] int NOT NULL,
      [he_d] int NOT NULL, [he_d_fp] int NOT NULL,
      [he_n] int NOT NULL, [he_n_fp] int NOT NULL,
      [opcao_sg] int NOT NULL, [periodo_sg] int NOT NULL,
      [he_d_sg] int NOT NULL, [he_d_fp_sg] int NOT NULL,
      [he_n_sg] int NOT NULL, [he_n_fp_sg] int NOT NULL,
      [he_inicio] tinyint NULL,
      [abo_he_d] int NOT NULL, [abo_he_d_fp] int NOT NULL,
      [abo_he_n] int NOT NULL, [abo_he_n_fp] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoHEDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoHEDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoHEDia] ON [dbo].[tbPtoHEDia]([id_pass],[data],[opcao]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoHEDia2] ON [dbo].[tbPtoHEDia]([id_pass],[data],[opcao_sg]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoHEDia') and name = 'he_inicio')
BEGIN
   ALTER TABLE [dbo].[tbPtoHEDia] ADD [he_inicio] tinyint NULL;
   EXEC('UPDATE tbPtoHEDia SET he_inicio=0');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoHEDia') and name = 'abo_he_d')
BEGIN
   ALTER TABLE [dbo].[tbPtoHEDia] ADD [abo_he_d] int NULL, [abo_he_d_fp] int NULL, [abo_he_n] int NULL, [abo_he_n_fp] int NULL;
   EXEC('UPDATE tbPtoHEDia SET abo_he_d=0, abo_he_d_fp=0, abo_he_n=0, abo_he_n_fp=0');
   ALTER TABLE [dbo].[tbPtoHEDia] ALTER COLUMN [abo_he_d] int NOT NULL;
   ALTER TABLE [dbo].[tbPtoHEDia] ALTER COLUMN [abo_he_d_fp] int NOT NULL;
   ALTER TABLE [dbo].[tbPtoHEDia] ALTER COLUMN [abo_he_n] int NOT NULL;
   ALTER TABLE [dbo].[tbPtoHEDia] ALTER COLUMN [abo_he_n_fp] int NOT NULL;
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoHEDia') and name = 'IX_tbPtoHEDia')
BEGIN
   exec('DROP INDEX tbPtoHEDia.IX_tbPtoHEDia');
   exec('DROP INDEX tbPtoHEDia.IX_tbPtoHEDia2');
END;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoDscDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoDscDia] (
      [id_pass] int NOT NULL, [data] datetime NOT NULL,
      [soma] int NOT NULL, [tol_s] int NOT NULL, [tol_m] int NOT NULL,
      [flex] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoDscDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoDscDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoDscDia') and name = 'tol_s')
BEGIN
   ALTER TABLE [dbo].[tbPtoDscDia] ADD [tol_s] int NULL, [tol_m] int NULL;
   EXEC('UPDATE tbPtoDscDia SET tol_s=soma, tol_m=soma');
   EXEC('ALTER TABLE [dbo].[tbPtoDscDia] ALTER COLUMN [tol_s] int NOT NULL');
   EXEC('ALTER TABLE [dbo].[tbPtoDscDia] ALTER COLUMN [tol_m] int NOT NULL');
END;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoDscDia') and name = 'flex')
BEGIN
   ALTER TABLE [dbo].[tbPtoDscDia] ADD [flex] int NULL;
END;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoAcrDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoAcrDia] (
      [id_pass] int NOT NULL, [data] datetime NOT NULL,
      [soma] int NOT NULL, [tol_s] int NOT NULL, [tol_m] int NOT NULL,
      [flex] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoAcrDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoAcrDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoAcrDia') and name = 'flex')
BEGIN
   ALTER TABLE [dbo].[tbPtoAcrDia] ADD [flex] int NULL;
END;
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoDSRDia') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoDSRDia] (
      [id_pass] int NOT NULL, [data] datetime NOT NULL,
      [acres_dsr] int NOT NULL, [desc_dsr] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoDSRDia] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoDSRDia] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end
GO

/*
   Compensasao automtica
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoCp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoCp] (
      [id_ptocp] BIGINT NOT NULL IDENTITY(1,1),
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_diverg] int NOT NULL,
      [soma] bit NOT NULL,
      [id_eveabo_div] int NOT NULL,
      [id_eveabo_cmp] int NOT NULL,
      [dt_ini_cmp] datetime NOT NULL,
      [dt_fim_cmp] datetime NOT NULL,
      [dias_comp] varchar(10) NOT NULL,
      [min_comp_dia] varchar(8) NOT NULL,
      [m_min_comp_dia] int NOT NULL,
      [max_comp_dia] varchar(8) NOT NULL,
      [m_max_comp_dia] int NOT NULL,
      [hrs_tot] bit NOT NULL,
      [horas] varchar(8) NOT NULL,
      [m_horas] int NOT NULL,
      [compensado] varchar(8) NOT NULL,
      [m_compensado] int NOT NULL,
      [pagodesc] varchar(8) NOT NULL,
      [m_pagodesc] int NOT NULL,
      [saldo] varchar(8) NOT NULL,
      [m_saldo] int NOT NULL,
      [id_usuario] int NOT NULL,
      [gerado] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoCp] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoCp] PRIMARY KEY CLUSTERED ([id_ptocp]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbPtoCp] ON [dbo].[tbPtoCp]([id_pass],[data],[id_diverg]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoCp_sld] ON [dbo].[tbPtoCp]([soma],[id_pass],[data],[m_saldo]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCp_data] ON [dbo].[tbPtoCp]([id_pass],[data]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCp_div] ON [dbo].[tbPtoCp]([id_pass],[data],[id_diverg]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCp_abo] ON [dbo].[tbPtoCp]([id_pass],[data],[id_eveabo_div]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCp_soma] ON [dbo].[tbPtoCp]([soma],[id_pass],[data]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCp_gerado] ON [dbo].[tbPtoCp]([id_pass],[data],[gerado]) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoCp') and name = 'gerado')
BEGIN
   ALTER TABLE [dbo].[tbPtoCp] ADD [gerado] bit NULL;
   EXEC('CREATE INDEX [IX_tbPtoCp_gerado] ON [dbo].[tbPtoCp]([id_pass],[data],[gerado]) ON [PRIMARY]');
END;
GO
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoCp') and name = 'IX_tbPtoAboDia_id_div')
BEGIN
   exec('DROP INDEX tbPtoCp.IX_tbPtoCp_data');
   exec('DROP INDEX tbPtoCp.IX_tbPtoCp_div');
   exec('DROP INDEX tbPtoCp.IX_tbPtoCp_abo');
   exec('DROP INDEX tbPtoCp.IX_tbPtoCp_soma');
   exec('DROP INDEX tbPtoCp.IX_tbPtoCp_gerado');
END;
GO

/*
   Ocorrncias geradoras de 'Compensasao automtica' pelo CALENDRIO
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoCpCalend') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoCpCalend] (
      [id_empresa] int NOT NULL,
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_eveabo_div] int NOT NULL,
      [id_eveabo_cmp] int NOT NULL,
      [dt_ini_cmp] datetime NOT NULL,
      [dt_fim_cmp] datetime NOT NULL,
      [dias_comp] varchar(10) NOT NULL,
      [min_comp_dia] varchar(8) NOT NULL,
      [m_min_comp_dia] int NOT NULL,
      [max_comp_dia] varchar(8) NOT NULL,
      [m_max_comp_dia] int NOT NULL,
      [hrs_tot] bit NOT NULL,
      [horas] varchar(8) NOT NULL,
      [m_horas] int NOT NULL,
      [id_usuario] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoCpCalend] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoCpCalend] PRIMARY KEY CLUSTERED ([id_empresa],[id_pass],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoCpCalend_id_pass] ON [dbo].[tbPtoCpCalend]([id_pass],[data]) ON [PRIMARY];
end;
GO

/*
   Ocorrncias de 'Compensasao automtica'
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoCpCmp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoCpCmp] (
      [id_ptocp] BIGINT NOT NULL,
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_diverg] int NOT NULL,
      [id_eveabo_cmp] int NOT NULL,
      [soma] bit NOT NULL,
      [horas] varchar(8) NOT NULL,
      [m_horas] int NOT NULL,
      [compensado] varchar(8) NOT NULL,
      [m_compensado] int NOT NULL,
      [pagodesc] varchar(8) NOT NULL,
      [m_pagodesc] int NOT NULL,
      [saldo] varchar(8) NOT NULL,
      [m_saldo] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoCpCmp] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoCpCmp] PRIMARY KEY CLUSTERED ([id_ptocp],[id_pass],[data],[id_diverg]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoCpCmp_data] ON [dbo].[tbPtoCpCmp]([id_pass],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoCpCmp_data2] ON [dbo].[tbPtoCpCmp]([id_ptocp],[data]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoCpCmp_soma] ON [dbo].[tbPtoCpCmp]([soma],[id_pass],[data]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCpCmp] ON [dbo].[tbPtoCpCmp]([id_ptocp]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCpCmp_div] ON [dbo].[tbPtoCpCmp]([id_pass],[data],[id_diverg]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCpCmp_abo] ON [dbo].[tbPtoCpCmp]([id_pass],[data],[id_eveabo_cmp]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCpCmp_cmp] ON [dbo].[tbPtoCpCmp]([soma],[id_pass],[data],[m_compensado]) ON [PRIMARY];
   --CREATE INDEX [IX_tbPtoCpCmp_pgd] ON [dbo].[tbPtoCpCmp]([soma],[id_pass],[data],[m_pagodesc]) ON [PRIMARY];
end;
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbPtoCpCmp') and name = 'IX_tbPtoCpCmp')
BEGIN
   exec('DROP INDEX tbPtoCpCmp.IX_tbPtoCpCmp');
   exec('DROP INDEX tbPtoCpCmp.IX_tbPtoCpCmp_div');
   exec('DROP INDEX tbPtoCpCmp.IX_tbPtoCpCmp_abo');
   exec('DROP INDEX tbPtoCpCmp.IX_tbPtoCpCmp_cmp');
   exec('DROP INDEX tbPtoCpCmp.IX_tbPtoCpCmp_pgd');
END;
GO

/*
   vwPtoCp - Resumo da compensao de horas
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.vwPtoCp') AND (xtype='V' or xtype='U')) BEGIN DROP VIEW dbo.vwPtoCp; END;
GO
CREATE VIEW dbo.vwPtoCp
AS
   SELECT
      c.id_pass,
      c.data as data_ocor,  c.id_ptocp,  0 as tipo,
      (CASE WHEN d.id_diverg < 1000 THEN 'S ' ELSE 'A ' END)+(CASE WHEN c.soma=1 THEN '(+) ' ELSE '(-) ' END)+d.descricao as evento,
      c.horas,
      c.data as data_ori,
      '' as compensado,
      '' as pago,
      '' as descontado,
      c.saldo,
      c.dt_ini_cmp,
      c.dt_fim_cmp
   FROM tbPtoCp c INNER JOIN tbDivergencias d ON c.id_diverg = d.id_diverg
   UNION ALL
   SELECT
      cmp.id_pass,
      cmp.data as data_ocor,  cmp.id_ptocp,  1 as tipo,
      (CASE WHEN cmp.id_eveabo_cmp=0 THEN (CASE WHEN d.id_diverg < 1000 THEN 'S ' ELSE 'A ' END)+(CASE WHEN cmp.soma=1 THEN '(+) ' ELSE '(-) ' END)+d.descricao ELSE a.descricao END) as evento,
      cmp.horas,
      ori.data as data_ori,
      cmp.compensado,
      (CASE WHEN cmp.soma=1 and cmp.id_eveabo_cmp=0 THEN cmp.pagodesc ELSE '+  00:00' END) as pago,
      (CASE WHEN cmp.soma=0 and cmp.id_eveabo_cmp=0 THEN cmp.pagodesc ELSE '+  00:00' END) as descontado,
      cmp.saldo,
      ori.dt_ini_cmp,
      ori.dt_fim_cmp
   FROM tbPtoCpCmp cmp  LEFT JOIN tbDivergencias d ON cmp.id_diverg = d.id_diverg
   INNER JOIN tbPtoCp ori ON ori.id_ptocp=cmp.id_ptocp
   LEFT JOIN tbEvsAbono a ON cmp.id_eveabo_cmp = a.id_eveabo
GO

/*
   Ocorrncias dirias do banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBco') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBco] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [per_bco] int NOT NULL,
      [id_diverg] int NOT NULL,
      [horas] varchar(8) NOT NULL,
      [m_horas] int NOT NULL,
      [m_semabo] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBco] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBco] PRIMARY KEY CLUSTERED ([id_pass],[data],[id_diverg]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoBco] ON [dbo].[tbPtoBco]([id_pass],[per_bco]) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoBco') and name = 'm_semabo')
BEGIN
   ALTER TABLE tbPtoBco ADD [m_semabo] int null;
   EXEC('UPDATE tbPtoBco SET m_semabo = m_horas');
END;
GO

/*
   Tb. compensao de bco
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBcoCmp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBcoCmp] (
      [id_pass] int NOT NULL,
      [per_bco] int NOT NULL, [per_cmp] int NOT NULL,
      [tipo_cmp] tinyint NOT NULL,
      [horas] varchar(8) NOT NULL,
      [m_horas] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBcoCmp] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBcoCmp] PRIMARY KEY CLUSTERED ([id_pass],[per_bco],[per_cmp],[tipo_cmp]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoBcoCmp] ON [dbo].[tbPtoBcoCmp]([id_pass],[per_cmp]) ON [PRIMARY];
end;
GO

/*
   Saldos mensais do banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBcoSld') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBcoSld] (
      [id_pass] int NOT NULL,
      [per_bco] int NOT NULL,
      [antes] varchar(8) NOT NULL,
      [creditos] varchar(8) NOT NULL,
      [debitos] varchar(8) NOT NULL,
      [pago] varchar(8) NOT NULL,
      [descontado] varchar(8) NOT NULL,
      [acumulado] varchar(8) NOT NULL,
      [saldo] varchar(8) NOT NULL,
      [compensado] varchar(8) NOT NULL,
      [saldo_fim] varchar(8) NOT NULL,
      [m_antes] int NOT NULL,
      [m_creditos] int NOT NULL,
      [m_debitos] int NOT NULL,
      [m_pago] int NOT NULL,
      [m_descontado] int NOT NULL,
      [m_acumulado] int NOT NULL,
      [m_saldo] int NOT NULL,
      [m_compensado] int NOT NULL,
      [m_saldo_fim] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBcoSld] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBcoSld] PRIMARY KEY CLUSTERED ([id_pass],[per_bco]) ON [PRIMARY];
end;
GO

/*
   Saldos manuais do banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBcoSMes') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBcoSMes] (
      [id_pass] int NOT NULL,
      [per_bco] int NOT NULL,
      [antes] varchar(8) NOT NULL,
      [creditos] varchar(8) NOT NULL,
      [debitos] varchar(8) NOT NULL,
      [acumulado] varchar(8) NOT NULL,
      [m_antes] int NOT NULL,
      [m_creditos] int NOT NULL,
      [m_debitos] int NOT NULL,
      [m_acumulado] int NOT NULL,
      [id_usuario] int null,
      [data_ocor] datetime null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBcoSMes] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBcoSMes] PRIMARY KEY CLUSTERED ([id_pass],[per_bco]) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoBcoSMes') and name = 'id_usuario')
BEGIN
   ALTER TABLE tbPtoBcoSMes ADD [id_usuario] int null, [data_ocor] datetime null;
END;
GO

/*
   Perodos onde o usurio determinou a reinicializao do banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBcoZera') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBcoZera] (
      [id_pass] int NOT NULL, [per_bco] int NOT NULL, [acao] tinyint NOT NULL, [id_usuario] int NOT NULL, [data_ocor] datetime NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBcoZera] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBcoZera] PRIMARY KEY CLUSTERED ([id_pass],[per_bco],[acao]) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id=object_id(N'dbo.tbPtoBcoZera') and name = 'acao')
BEGIN
   ALTER TABLE tbPtoBcoZera ADD [acao] tinyint NULL, [id_usuario] int NULL, [data_ocor] datetime NULL;
   exec('update tbPtoBcoZera set acao=0, id_usuario=0, data_ocor=getdate()');
   exec('ALTER TABLE tbPtoBcoZera ALTER COLUMN [acao] tinyint NOT NULL');
   exec('ALTER TABLE tbPtoBcoZera ALTER COLUMN [id_usuario] int NOT NULL');
   exec('ALTER TABLE tbPtoBcoZera ALTER COLUMN [data_ocor] datetime NOT NULL');
   exec('ALTER TABLE [dbo].[tbPtoBcoZera] DROP CONSTRAINT [PK_tbPtoBcoZera]');
   exec('ALTER TABLE [dbo].[tbPtoBcoZera] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBcoZera] PRIMARY KEY CLUSTERED ([id_pass],[per_bco],[acao]) ON [PRIMARY]');
END;
GO

/*
   Perodos onde o usurio determinou o pagamento do banco de horas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBcoPgto') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBcoPgto] (
      [id_pass] int NOT NULL, [per_bco] int NOT NULL,
      [acao] tinyint NOT NULL,
      [id_usuario] int NOT NULL,
      [data_ocor] datetime NOT NULL,
      [creditos] varchar(8) NOT NULL,
      [debitos] varchar(8) NOT NULL,
      [m_creditos] int NOT NULL,
      [m_debitos] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBcoPgto] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBcoPgto] PRIMARY KEY CLUSTERED ([id_pass],[per_bco],[acao]) ON [PRIMARY];
end;
GO

/*
   Efetuado em H. Flex
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoHFlx') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoHFlx] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL, [efetuado] int NOT NULL, [normais] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoHFlx] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoHFlx] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoBcoDivs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoBcoDivs] (
      [id_pass] int NOT NULL, [data] datetime NOT NULL, [pagar] int NOT NULL, [descontar] int NOT NULL, [saldo_sinal] bit NULL, [saldo_vlr] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoBcoDivs] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoBcoDivs] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoBcoDivs') and name = 'saldo_sinal')
BEGIN
   ALTER TABLE tbPtoBcoDivs ADD [saldo_sinal] bit NULL, [saldo_vlr] int NULL;
END;
GO

/*
   Ponto - Marcaes Originais Enquadradas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoEnq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoEnq] (
      [id_pass] int NOT NULL,   [data] datetime NOT NULL,
      [original] bit NOT NULL,
      [contamc]  tinyint NOT NULL,
      [primeira] datetime NULL, [ultima] datetime NULL,
      [m_primeira] int NULL, [m_ultima] int NULL,
      [fmsaida] bit NOT NULL, [funcao_pri] tinyint NOT NULL,
      [ent01] varchar(5) NULL, [sai01] varchar(5) NULL,
      [ent02] varchar(5) NULL, [sai02] varchar(5) NULL,
      [ent03] varchar(5) NULL, [sai03] varchar(5) NULL,
      [ent04] varchar(5) NULL, [sai04] varchar(5) NULL,
      [ent05] varchar(5) NULL, [sai05] varchar(5) NULL,
      [ent06] varchar(5) NULL, [sai06] varchar(5) NULL,
      [ent07] varchar(5) NULL, [sai07] varchar(5) NULL,
      [ent08] varchar(5) NULL, [sai08] varchar(5) NULL,
      [m_ent01] int NOT NULL, [m_sai01] int NOT NULL,
      [m_ent02] int NOT NULL, [m_sai02] int NOT NULL,
      [m_ent03] int NOT NULL, [m_sai03] int NOT NULL,
      [m_ent04] int NOT NULL, [m_sai04] int NOT NULL,
      [m_ent05] int NOT NULL, [m_sai05] int NOT NULL,
      [m_ent06] int NOT NULL, [m_sai06] int NOT NULL,
      [m_ent07] int NOT NULL, [m_sai07] int NOT NULL,
      [m_ent08] int NOT NULL, [m_sai08] int NOT NULL,
      [fimper1] tinyint NOT NULL, [fimper2] tinyint NOT NULL,
      [fimper3] tinyint NOT NULL, [fimper4] tinyint NOT NULL,
      [iniflex] tinyint NOT NULL, [fimflex] tinyint NOT NULL,
      [hrs_trab] varchar(7) NOT NULL, [m_hrs_trab] int NOT NULL,
      [ult_he_ent] tinyint NULL, [pri_he_sai] tinyint NULL, [id_usuario] int NULL,
      [apontado] bit null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoEnq] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoEnq] PRIMARY KEY CLUSTERED ([id_pass],[data],[original]) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoEnq_apontado] ON [dbo].[tbPtoEnq]([apontado],[data]) ON [PRIMARY];
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoEnq') and name = 'ult_he_ent')
BEGIN
   ALTER TABLE [dbo].[tbPtoEnq] ADD [ult_he_ent] tinyint NULL, [pri_he_sai] tinyint NULL, [id_usuario] int NULL;
   exec('UPDATE tbPtoEnq SET ult_he_ent=0, pri_he_sai=0, id_usuario=0');
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoEnq') and name = 'apontado')
BEGIN
   ALTER TABLE [dbo].[tbPtoEnq] ADD [apontado] bit null;
   exec('UPDATE tbPtoEnq SET apontado=0');
   exec('CREATE INDEX [IX_tbPtoEnq_apontado] ON [dbo].[tbPtoEnq]([apontado],[data]) ON [PRIMARY]');
END
GO

/*
   Ponto - Marcaes de acesso para apontamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoAce') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoAce] (
      [id_pass] int NOT NULL,   [data] datetime NOT NULL,
      [original] bit NOT NULL,
      [primeira] datetime NULL, [ultima] datetime NULL,
      [m_primeira] int NULL,    [m_ultima] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoAce] WITH NOCHECK ADD CONSTRAINT [PK_tbPtoAce] PRIMARY KEY CLUSTERED ([id_pass],[data]) ON [PRIMARY];
END
GO

/*
   Dados da aplicao
*/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSets') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   drop table tbSets;
end;
GO
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSets') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbSets] (
      [id_usuario] int NOT NULL, [secao] varchar(50) NOT NULL ,
      [chave] varchar(50) NOT NULL, [valor] varchar(300) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbSets] WITH NOCHECK ADD CONSTRAINT [PK_tbSets] PRIMARY KEY CLUSTERED ([id_usuario],[secao],[chave]) ON [PRIMARY];
END
GO

/*
   Pr-parametrizao de refeitrio
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbPreRef') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbPreRef] (
    [id_empresa] int NOT NULL, [geral] bit NOT NULL, [tipopass] varchar(1) NOT NULL,
    [id_refeit] int NOT NULL, [limite_diario] int NULL, [creditos_iniciais] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPreRef] WITH NOCHECK ADD CONSTRAINT [PK_tbPreRef] PRIMARY KEY CLUSTERED ([id_empresa],[geral],[tipopass],[id_refeit])  ON [PRIMARY];
END
GO

/*
   Faixas de refeies autorizadas para os passantes
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbFaixasRefeitPass') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbFaixasRefeitPass] (
      [id_pass] int NOT NULL, [id_refeit] int NOT NULL, [limite_diario] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbFaixasRefeitPass] WITH NOCHECK ADD CONSTRAINT [PK_tbFaixasRefeitPass] PRIMARY KEY CLUSTERED ([id_pass],[id_refeit])  ON [PRIMARY];
END
GO

/*
   Tabela de crditos para consumo em refeitrio
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbCredRefeit') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbCredRefeit] (
      [id_pass] int NOT NULL,     [id_refeit] int NOT NULL,
      [id_empresa] int NOT NULL,  [dtlancado] datetime NOT NULL,
      [dtvalidade] datetime NULL, [quantidade] int NOT NULL,
      [saldo] int NOT NULL, [vlunitario] [float] NOT NULL, [cancelado] bit NOT NULL,
      [usuario_inc] int NOT NULL, [usuario_ext] int NULL, [origem] int NOT NULL,
      [id_cxcredref] int NULL, [ano_hcxcr] int NULL, [id_hcxcr] int NULL,
      [id_credref] BIGINT NOT NULL IDENTITY(1,1)
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCredRefeit] WITH NOCHECK ADD CONSTRAINT [PK_tbCredRefeit] PRIMARY KEY CLUSTERED ([id_credref]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbCredRefeit] ON [dbo].[tbCredRefeit]([id_pass],[id_refeit],[dtlancado]) ON [PRIMARY];
   CREATE INDEX [IX_tbCredRefeit_rels] ON [dbo].[tbCredRefeit]([id_empresa],[id_refeit]) ON [PRIMARY];
   CREATE INDEX [IX_tbCredRefeit_comm] ON [dbo].[tbCredRefeit]([id_pass],[id_refeit],[saldo],[dtvalidade]) ON [PRIMARY];
   CREATE INDEX [IX_tbCredRefeit_relat1] ON [dbo].[tbCredRefeit]([id_pass],[dtlancado],[quantidade]);
   CREATE INDEX [IX_tbCredRefeit_relat2] ON [dbo].[tbCredRefeit]([id_pass],[dtlancado],[id_refeit],[quantidade]);
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCredRefeit') and name = 'id_credref')
BEGIN
   ALTER TABLE dbo.tbCredRefeit ADD [id_credref] BIGINT NOT NULL IDENTITY(1,1);
   ALTER TABLE dbo.tbCredRefeit DROP PK_tbCredRefeit;
   ALTER TABLE [dbo].[tbCredRefeit] WITH NOCHECK ADD CONSTRAINT [PK_tbCredRefeit] PRIMARY KEY CLUSTERED ([id_credref]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbCredRefeit] ON [dbo].[tbCredRefeit]([id_pass],[id_refeit],[dtlancado]) ON [PRIMARY];
END
GO

/*
   Tabela de lanamento automtico de crditos
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbCredAut') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbCredAut] (
      [id_empresa] int NOT NULL, [id_pass] int NOT NULL,    [id_refeit] int NOT NULL,
      [minimo] int NOT NULL,     [quantidade] int NOT NULL, [dias_validade] int NULL,
      [id_usuario] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCredAut] WITH NOCHECK ADD CONSTRAINT [PK_tbCredAut] PRIMARY KEY CLUSTERED ([id_pass], [id_refeit]) ON [PRIMARY];
   CREATE INDEX [IX_tbCredAut] ON [dbo].[tbCredAut]([id_pass]) ON [PRIMARY];
END
GO

/*
   Cupom para Caixas de venda de crditos de refeitrio
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbCupomCR') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbCupomCR] (
      [id_cupomcr] int NOT NULL, [descricao] varchar(25) NOT NULL,
      [cabec] varchar(320) NOT NULL, [titulo] varchar(40) NOT NULL,
      [rodape] varchar(320) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCupomCR] WITH NOCHECK ADD CONSTRAINT [PK_tbCupomCR] PRIMARY KEY CLUSTERED ([id_cupomcr]) ON [PRIMARY];
END
GO

/*
   Caixas de venda de crditos de refeitrio
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbCxCredRef') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbCxCredRef] (
      [id_cxcredref] int NOT NULL, [descricao] varchar(25) NOT NULL,
      [id_cupomcr] int NULL, [obs] varchar(250) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCxCredRef] WITH NOCHECK ADD CONSTRAINT [PK_tbCxCredRef] PRIMARY KEY CLUSTERED ([id_cxcredref]) ON [PRIMARY];
END
GO

/*
   Endereo Mac dos caixas
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbMcCxCR') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbMcCxCR] (
    [mac] varchar(25) NOT NULL, [id_cxcredref] int NOT NULL,
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMcCxCR] WITH NOCHECK ADD CONSTRAINT [PK_tbMcCxCR] PRIMARY KEY CLUSTERED ([mac]) ON [PRIMARY];
END
GO

/*
   Caixas - Histrico de caixa
*/
IF NOT EXISTS(SELECT name FROM dbo.sysobjects WHERE id = object_id(N'dbo.tbHCxCR') AND objectproperty(id, N'IsUserTable') = 1)
BEGIN
   CREATE TABLE [dbo].[tbHCxCR] (
      [id_cxcredref] int NOT NULL,
      [ano_hcxcr]    int NOT NULL,  [id_hcxcr]     int NOT NULL,
      [id_usuario]   int NOT NULL,  [dtaberto]     datetime NOT NULL,
      [dtfechado]    datetime NULL, [imp_fecha]    bit NOT NULL,
      [abertura] float NOT NULL, [creditos] float NOT NULL, [estornos] float NOT NULL, [fechamento] float NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHCxCR] WITH NOCHECK ADD CONSTRAINT [PK_tbHCxCR] PRIMARY KEY CLUSTERED ([id_cxcredref],[ano_hcxcr],[id_hcxcr]) ON [PRIMARY];
END
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbHCxCR') and name = 'abertura')
BEGIN
   EXEC('DELETE FROM tbHCxCR');
   ALTER TABLE [dbo].[tbHCxCR] ADD [abertura] float NOT NULL;
   ALTER TABLE [dbo].[tbHCxCR] ADD [creditos] float NOT NULL;
   ALTER TABLE [dbo].[tbHCxCR] ADD [estornos] float NOT NULL;
   ALTER TABLE [dbo].[tbHCxCR] ADD [fechamento] float NOT NULL;
END;
GO

/*
   Layouts de cracha
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayCX') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayCX] (
   [id_laycx] int NOT NULL, [id_empresa] int NOT NULL,
    [geral] bit NOT NULL, [descricao] varchar(20) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayCX] WITH NOCHECK ADD CONSTRAINT [PK_tbLayCX] PRIMARY KEY CLUSTERED ([id_laycx])  ON [PRIMARY];
end
GO

/*
   Layouts de cracha - Tipos de passante
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayCXT') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayCXT] (
   [id_laycx] int NOT NULL, [tipo_pass] [char](1) NOT NULL,
   [id_papel] int NOT NULL, [tem_verso] bit NOT NULL,
   [largura]  int NULL, [altura] int null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayCXT] WITH NOCHECK ADD CONSTRAINT [PK_tbLayCXT] PRIMARY KEY CLUSTERED ([id_laycx],[tipo_pass])  ON [PRIMARY];
end
GO
--Atualizao
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbLayCXT') and name = 'largura')
BEGIN
   ALTER TABLE tbLayCXT ADD [largura] int NULL, [altura] int null;
END;
GO

/*
   Layouts de cracha - Campos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLayCXC') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLayCXC] (
    [id_laycx] int NOT NULL,  [tipo_pass] [char](1) NOT NULL,
    [frente]   bit NOT NULL,  [nome] varchar(20) NOT NULL,
    [indice] int NOT NULL, [tipo] int NOT NULL,
    [posicao] int NOT NULL,   [pleft] int NOT NULL,
    [ptop] int NOT NULL,   [twidth] int NOT NULL,
    [theight] int NOT NULL, [texto] varchar(255) NULL,
    [imagem] [image] NULL, [ajustar_img] bit NOT NULL,
    [cor] int NOT NULL, [fonte] varchar(30) NOT NULL ,
    [f_tam] int NOT NULL,  [f_neg] bit NOT NULL,   [f_ita] bit NOT NULL,
    [f_und] bit NOT NULL,  [f_str] bit NOT NULL,   [f_cor] int NOT NULL,
    [alinhamento] int NOT NULL, [recuo] bit NOT NULL, [borda] bit NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLayCXC] WITH NOCHECK ADD CONSTRAINT [PK_tbLayCXC] PRIMARY KEY CLUSTERED ([id_laycx], [tipo_pass], [frente], [nome], [indice])  ON [PRIMARY];
end
GO

/*
  Tabela de mdulos do sistema
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbModulos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbModulos] (
      [id_modulo] int NOT NULL,
      [descricao] varchar(200) NOT NULL,
      [visibilidade] varchar(1) NOT NULL
   ) ON [PRIMARY];
    ALTER TABLE [dbo].[tbModulos] WITH NOCHECK ADD
      CONSTRAINT [PK_tbModulos] PRIMARY KEY CLUSTERED ([id_modulo])  ON [PRIMARY];
end
GO
delete from tbModulos;
insert into tbModulos (id_modulo, descricao, visibilidade) values (102, 'Parmetros do sistema','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (103, 'Parmetros de passantes','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (104, 'Cadastro de usurios','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (106, 'Cadastro de crachs mestres','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (108, 'Cadastro de layout de crachs','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (109, 'Cadastro de eventos de abono (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (110, 'Cadastro de vnculo de cdigo de crachs','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (114, 'Cadastro de centros de custo (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (115, 'Cadastro de agrupamentos (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (116, 'Cadastro de vagas','E');
insert into tbModulos (id_modulo, descricao, visibilidade) values (201, 'Cadastro de empresas','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (202, 'Cadastro de horrios','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (203, 'Cadastro de bloqueios (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (204, 'Cadastro de grupos de bloqueios (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (205, 'Cadastro de departamentos','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (206, 'Cadastro de funcionrios','F');
insert into tbModulos (id_modulo, descricao, visibilidade) values (207, 'Cadastro de visitantes','V');
insert into tbModulos (id_modulo, descricao, visibilidade) values (208, 'Cadastro de terceiros','T');
insert into tbModulos (id_modulo, descricao, visibilidade) values (209, 'Cadastro de condminos','C');
insert into tbModulos (id_modulo, descricao, visibilidade) values (210, 'Cadastro de scios','S');
insert into tbModulos (id_modulo, descricao, visibilidade) values (211, 'Cadastro de pais','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (212, 'Cadastro de alunos','A');
insert into tbModulos (id_modulo, descricao, visibilidade) values (213, 'Cadastro de veculos','E');
insert into tbModulos (id_modulo, descricao, visibilidade) values (214, 'Cadastro de tabela de consistncias (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (215, 'Cadastro de tabelas de refeio','R');
insert into tbModulos (id_modulo, descricao, visibilidade) values (216, 'Cadastro de caixas','R');
insert into tbModulos (id_modulo, descricao, visibilidade) values (217, 'Processo de cadastramento de tabelas de refeio, em lote','R');
insert into tbModulos (id_modulo, descricao, visibilidade) values (218, 'Cadastro de afastamentos','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (220, 'Cadastro de eventos com ingressos','E');
insert into tbModulos (id_modulo, descricao, visibilidade) values (221, 'Cadastro de crachs provisrios','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (222, 'Cadastro de escalas','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (223, 'Cadastro de localizao de paciente','H');
insert into tbModulos (id_modulo, descricao, visibilidade) values (224, 'Cadastro de visita hospitalar','H');
insert into tbModulos (id_modulo, descricao, visibilidade) values (225, 'Parmetros de visita hospitalar','H');
insert into tbModulos (id_modulo, descricao, visibilidade) values (226, 'Cadastro de tipo de visita','V');
insert into tbModulos (id_modulo, descricao, visibilidade) values (227, 'Tabelas de integrao','A');
insert into tbModulos (id_modulo, descricao, visibilidade) values (228, 'Cadastro de cargos','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (229, 'Cadastro de distribuidores de ingressos','E');
insert into tbModulos (id_modulo, descricao, visibilidade) values (230, 'Cadastro de cursos','A');
insert into tbModulos (id_modulo, descricao, visibilidade) values (231, 'Tipos de movimento','H');
insert into tbModulos (id_modulo, descricao, visibilidade) values (232, 'Cadastro de pacientes','H');
insert into tbModulos (id_modulo, descricao, visibilidade) values (233, 'Cadastro de Tipos de Ocupao de Unidade','T');
insert into tbModulos (id_modulo, descricao, visibilidade) values (234, 'Cadastro de Unidades','T');
insert into tbModulos (id_modulo, descricao, visibilidade) values (235, 'Cadastro de Animais no Condomnio','T');
insert into tbModulos (id_modulo, descricao, visibilidade) values (236, 'Cadastro de Notificaes','T');
insert into tbModulos (id_modulo, descricao, visibilidade) values (237, 'Cadastro de Restrio de Acesso  Unidade','T');
insert into tbModulos (id_modulo, descricao, visibilidade) values (238, 'Cadastro de Categorias de Condmino','T');
insert into tbModulos (id_modulo, descricao, visibilidade) values (239, 'Cadastro de Locais de Presena','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (240, 'Cadastro de digitais','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (241, 'EPI - Cadastro de operadores','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (242, 'EPI - Cadastro de equipamentos','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (243, 'EPI - Cadastro de situao de devoluo','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (244, 'Cadastro de tabelas de estacionamento','E');
insert into tbModulos (id_modulo, descricao, visibilidade) values (301, 'Calendrio - Geral / em lote (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (302, 'Cadastro de mensagens','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (303, 'Processo de exportao de marcaes','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (304, 'Processo de exportao de cadastros','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (305, 'Processo de importao de dados cadastrais','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (306, 'Processo de reinicializao de status de crachs','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (307, 'Processo de importao de marcaes','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (308, 'Processo de limpeza','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (309, 'Processo de parametrizao, em lote','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (310, 'Processo de exportao de marcaes de refeitrio','R');
insert into tbModulos (id_modulo, descricao, visibilidade) values (311, 'Processo de importao de afastamentos','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (312, 'Calendrio - Individual (pwAcesso)','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (313, 'Bloqueio de visitante','V');
insert into tbModulos (id_modulo, descricao, visibilidade) values (314, 'Agendamento de visita','V');
insert into tbModulos (id_modulo, descricao, visibilidade) values (315, 'Gravao de carto mifare','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (316, 'Registro de acesso com carto mifare','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (317, 'Processo de importao de agendamento de visitas','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (318, 'Registro de refeio avulsa','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (501, 'Cadastro de layouts de exportao de cadastros','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (502, 'Cadastro de layouts de exportao de movimento','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (503, 'Cadastro de layouts de importao de dados cadastrais','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (504, 'Cadastro de layouts dos relgios','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (505, 'Processo de autorizao de acesso, em lote','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (507, 'Processo de reclassificao de refeitrio','R');
insert into tbModulos (id_modulo, descricao, visibilidade) values (508, 'Movimento de Refeitrio','R');
insert into tbModulos (id_modulo, descricao, visibilidade) values (509, 'Registro de integrao','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (510, 'Movimento de EPI','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (511, 'Impresso de crachs, em lote','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (990, 'Comunicao Real-Time','Z');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1002, 'Parmetros do sistema (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1003, 'Cadastro de usurios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1006, 'Cadastro de layout de crachs (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1101, 'Cadastro de empresas (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1102, 'Cadastro de horrios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1103, 'Cadastro de horrios flexveis (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1104, 'Cadastro de eventos de abono (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1105, 'Cadastro de divergncias - Internas (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1106, 'Cadastro de divergncias - Cd. Associado (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1107, 'Cadastro de arredondamentos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1108, 'Cadastro de tolerncias (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1109, 'Cadastro de adicionais Noturnos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1110, 'Cadastro de DSR (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1111, 'Cadastro de horas-extras (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1112, 'Cadastro de horas normais (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1113, 'Cadastro de cargos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1114, 'Cadastro de centros de custo (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1115, 'Cadastro de agrupamentos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1116, 'Cadastro de departamentos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1117, 'Cadastro de funcionrios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1118, 'Calendrio - Geral / em lote (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1119, 'Calendrio - Individual (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1120, 'Cadastro de cdigos de CID (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1121, 'Cadastro de escalas de revezamento (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1122, 'Cadastro de relgios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1123, 'Cadastro de grupos de relgios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1124, 'Cadastro de Justificativas de Tratamento (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1125, 'Tabelas de vale transporte (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1126, 'Tabelas de vale refeio (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1127, 'Tabelas de plano de sade (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1128, 'Cadastro de crachs provisrios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1129, 'Tabelas de Cesta Bsica (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1130, 'Tabelas de Benefcios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1131, 'Cadastro de tabelas de refeio (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1132, 'Cadastro de tabelas de integrao (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1133, 'Cadastro de tabelas de prmios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1134, 'Cadastro de tabelas de Banco de Horas (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1201, 'Processo de importao de marcaes (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1202, 'Reprocessamento de apontamentos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1203, 'Reinicializao de marcaes (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1204, 'Apontamentos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1205, 'Permisso de HE - Gerais (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1206, 'Permisso de HE - Individuais (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1207, 'Histrico de tabelas (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1208, 'Importao de arquivo AFD (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1209, 'Processo de gerao de intervalos (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1210, 'Gerao de apontamentos em lote (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1211, 'Processo de exp. de apontamentos para folha (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1212, 'Importao de dados cadastrais (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1213, 'Processo de encerramento (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1214, 'Processo de limpeza (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1215, 'Processo de parametrizao em lote (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1218, 'Processo de exportao de marcaes (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1219, 'Processo de manuteno de banco de horas (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1220, 'Processo de registro de integrao (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1221, 'Lanamento de apontamentos manuais (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1222, 'Manuteno de relgio: Configurao / Data e hora (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1223, 'Manuteno de relgio: Funcionrios / Digitais (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1225, 'Manuteno de relgio: Captura de marcaes (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1226, 'Manuteno de relgio: Limpeza / Reposicionamento (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1229, 'Manuteno de relgio: Pendrive (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1230, 'Histrico de advertncias (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1231, 'Histrico de atestados (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1301, 'Relatrio de Espelho de Ponto (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1401, 'Layouts de relgios (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1402, 'Layouts de importao de dados cadastrais (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1403, 'Layouts de exportao para Folha (pwPonto)','P');
insert into tbModulos (id_modulo, descricao, visibilidade) values (1405, 'Layouts de exportao de movimento (pwPonto)','P');
GO


/*
  Tabela de auditoria de crachs
*/

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbACrachas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbACrachas] (
      [id_usuario] int NOT NULL,
      [data] datetime NOT NULL,
      [usuario] varchar(20) NOT NULL, [nome_usuario] varchar(40) NOT NULL ,
      [cracha] [float] NOT NULL,   [via] tinyint NOT NULL,
      [provisorio] bit NOT NULL, [prov_ini] datetime NULL, [prov_fim] datetime NULL,
      [id_modulo] int NOT NULL, [acao] int NOT NULL,
      [id_pass] int NULL, [id_empresa] int NULL, [id_depart] int NULL,
      [tipo_pessoa] varchar(1) NOT NULL ,
      [nome_pessoa] varchar(100) NULL,
      [doc_pessoa] varchar(50) NULL,
      [cracha_antes] int NULL,[via_antes] tinyint NULL,
      [prov_ini_antes] datetime NULL, [prov_fim_antes] datetime NULL,
      [visitado] varchar(50) NULL, [empresa_visi] varchar(40) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbACrachas] WITH NOCHECK ADD
      CONSTRAINT [PK_tbACrachas] PRIMARY KEY CLUSTERED ([id_usuario],[data]) ON [PRIMARY];
    CREATE INDEX [IX_tbACrachas_cracha] ON [dbo].[tbACrachas]([cracha],[via]) ON [PRIMARY];
    CREATE INDEX [IX_tbACrachas_id_pessoa] ON [dbo].[tbACrachas]([id_pass]) ON [PRIMARY];
    CREATE INDEX [IX_tbACrachas_data] ON [dbo].[tbACrachas]([data]) ON [PRIMARY];
end
GO
--Atualizao
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbACrachas') and name = 'nome_pessoa' and length < 100)
BEGIN
   ALTER TABLE tbACrachas ALTER COLUMN nome_pessoa VARCHAR(100);
END;
GO


/*
  Tabela de Auditoria de Alteraes Cadastrais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbACadastros') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbACadastros] (
      [id_usuario] int NOT NULL,
      [data] datetime NOT NULL, [dataid] varchar(17) NOT NULL,
      [usuario] varchar(20) NOT NULL, [nome_usuario] varchar(40) NOT NULL ,
      [cracha] [float] NOT NULL, [via] tinyint NOT NULL,
      [id_modulo] int NOT NULL, [acao] int NOT NULL,
      [id_pass] int NULL, [id_empresa] int NULL,
      [id_depart] int NULL, [tipo_pessoa] varchar(1) NOT NULL ,
      [nome_pessoa] varchar(100) NULL, [doc_pessoa] varchar(50) NULL,
    [observacao] varchar(300) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbACadastros] WITH NOCHECK ADD
      CONSTRAINT [PK_tbACadastros] PRIMARY KEY CLUSTERED ([id_usuario],[data]) ON [PRIMARY];
    CREATE INDEX [IX_tbACadastros_cracha] ON [dbo].[tbACadastros]([cracha],[via]) ON [PRIMARY];
    CREATE INDEX [IX_tbACadastros_id_pessoa] ON [dbo].[tbACadastros]([id_pass]) ON [PRIMARY];
    CREATE INDEX [IX_tbACadastros_data] ON [dbo].[tbACadastros]([data]) ON [PRIMARY];
end
GO
--Atualizao
IF EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbACadastros') and name = 'nome_pessoa' and length < 100)
BEGIN
   ALTER TABLE tbACadastros ALTER COLUMN nome_pessoa VARCHAR(100);
END;
GO

/*
  Tabela de Campos Alterados da Auditoria de Alteraes Cadastrais
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbACampos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbACampos] (
      [id_usuario] int NOT NULL,
      [data] datetime NOT NULL, [dataid] varchar(17) NOT NULL,
         [desc_campo] varchar(50) NOT NULL,
         [chave] bit NOT NULL, [posicao] int NOT NULL,
      [valor_antes] varchar(50) NULL, [valor_atual] varchar(50) NULL
   ) ON [PRIMARY];
    CREATE CLUSTERED INDEX [IX_tbACampos] ON [dbo].[tbACampos]([dataid]) ON [PRIMARY];
    CREATE INDEX [IX_tbACampos_Consultas] ON [dbo].[tbACampos]([id_usuario],[data]) ON [PRIMARY];
end
GO

/*
   Histrico da auditoria
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAHist') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAHist] (
      [data] datetime NOT NULL,
      [id_usuario] int NOT NULL, [usuario] varchar(20) NOT NULL ,
    [nome_usuario] varchar(40) NOT NULL, [descricao] varchar(200) NOT NULL
   ) ON [PRIMARY];
end
GO

/*
   Toques de Sirene
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSirene') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbSirene] (
      [id_bloq] int NOT NULL, [horario] varchar(5) NOT NULL,
      [tempo]   int NOT NULL, [wdias]   varchar(7) NOT NULL,
         [rele] int NULL
   ) ON [PRIMARY];
   CREATE INDEX [IX_tbSirene] ON [dbo].[tbSirene]([id_bloq]) ON [PRIMARY];
end
GO

/*
   Cargos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCargos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCargos] (
      [id_cargo] int NOT NULL, [descricao] varchar(30) NOT NULL,
      [id_phorario] int NULL, [id_arredonda] int NULL,
      [id_dsr] int NULL, [id_he] int NULL,
      [id_adicional] int NULL, [id_hnormais] int NULL,
      [codigo] int NOT NULL, [id_tolera] int null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCargos] WITH NOCHECK ADD
   CONSTRAINT [PK_tbCargos] PRIMARY KEY CLUSTERED ([id_cargo]) ON [PRIMARY];
   CREATE INDEX [IX_tbCargos] ON [dbo].[tbCargos]([descricao]) ON [PRIMARY];
   CREATE INDEX [IX_tbCargos_codigo] ON [dbo].[tbCargos]([codigo]) ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCargos') and name = 'id_phorario')
BEGIN
   ALTER TABLE [dbo].[tbCargos] ADD id_phorario int NULL;
   ALTER TABLE [dbo].[tbCargos] ADD id_arredonda int NULL;
   ALTER TABLE [dbo].[tbCargos] ADD id_dsr int NULL;
   ALTER TABLE [dbo].[tbCargos] ADD id_he int NULL;
   ALTER TABLE [dbo].[tbCargos] ADD id_adicional int NULL;
   ALTER TABLE [dbo].[tbCargos] ADD id_hnormais int NULL;
END
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCargos') and name = 'codigo')
BEGIN
   ALTER TABLE [dbo].[tbCargos] ADD codigo int NULL;
   exec('UPDATE tbCargos SET codigo = id_cargo');
   exec('ALTER TABLE tbCargos ALTER COLUMN codigo INT NOT NULL');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbCargos') and name = 'id_tolera')
BEGIN
   ALTER TABLE [dbo].[tbCargos] ADD id_tolera int NULL;
END;
GO

/*
  Cadastro de Distribuidores
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDIngressos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDIngressos] (
      [id_dingressos] [float] NOT NULL,
      [nome] varchar(70) NOT NULL,
      [bloqueiar_novos] bit NOT NULL, [cnpj] varchar(20) NULL,
      [inscricao] varchar(20) NULL,   [endereco] varchar(70) NULL,
      [bairro] varchar(40) NULL,      [cidade] varchar(40) NULL,
      [cep] varchar(10) NULL,  [uf] varchar(2) NULL,
      [fone] varchar(16) NULL, [ramal] varchar(5) NULL,
      [fax] varchar(16) NULL,  [obs] varchar(1000) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbDIngressos] WITH NOCHECK ADD CONSTRAINT [PK_tbDIngressos] PRIMARY KEY CLUSTERED ([id_dingressos]) ON [PRIMARY];
end
GO

/*
  Cadastro de Eventos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCEvento') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCEvento] (
      [id_cevento] [float] NOT NULL,
      [descricao] varchar(50) NOT NULL,
      [data_ini] datetime NOT NULL, [data_fim] datetime NOT NULL,
      [saida] bit NOT NULL,
      [reentrada] bit NOT NULL, [resaida] bit NOT NULL,
      [unicoacesso] bit NOT NULL, [gravaimp] bit NOT NULL,
      [fx1] varchar(40) NULL, [fx2] varchar(40) NULL,
      [fx3] varchar(40) NULL, [fx4] varchar(40) NULL, [fx5] varchar(40) NULL,
      [fx6] varchar(40) NULL, [fx7] varchar(40) NULL, [fx8] varchar(40) NULL,
      [ent_mestre] [float] NULL, [sai_mestre] [float] NULL,
      [semfim] BIT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCEvento] WITH NOCHECK ADD CONSTRAINT [PK_tbCEvento] PRIMARY KEY CLUSTERED ([id_cevento]) ON [PRIMARY];
   CREATE INDEX [IX_tbCEvento] ON [dbo].[tbCEvento](data_ini, data_fim ) ON [PRIMARY];
end
GO

/*
   Tabela de ingressos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbIngressos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbIngressos] (
      [id_cevento]    [float] NOT NULL,
      [id_dingressos] [float] NOT NULL,
      [cracha_ini]    [float] NOT NULL, [cracha_fim] [float] NOT NULL,
      [status]        int   NOT NULL, [dtcad] datetime NOT NULL,
      [entradas]      [float] NOT NULL, [saidas] [float] NOT NULL,
      [utilizados]    [float] NOT NULL
   ) ON [PRIMARY];
   CREATE CLUSTERED INDEX [IX_tbIngressos] ON [dbo].[tbIngressos]([cracha_ini],[cracha_fim],[status]) ON [PRIMARY];
   CREATE INDEX [IX_tbIngressos_id_cevento] ON [dbo].[tbIngressos](id_cevento) ON [PRIMARY];
   CREATE INDEX [IX_tbIngressos_id_dingressos] ON [dbo].[tbIngressos](id_dingressos) ON [PRIMARY];
end
GO

/*
   Tabela de Ocorrncias de Bloqueio
*/
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbOcorCEvento') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   DROP TABLE [dbo].[tbOcorCEvento];
end
GO
CREATE TABLE [dbo].[tbOcorCEvento] (
   [id_ocor] int NOT NULL,
   [descricao] varchar(200) NOT NULL, [entsai] int NOT NULL,
    [flagimpedimento] bit NOT NULL, [mestre] bit NULL
) ON [PRIMARY];
ALTER TABLE [dbo].[tbOcorCEvento] WITH NOCHECK ADD CONSTRAINT [PK_tbOcorCEvento] PRIMARY KEY CLUSTERED ([id_ocor]) ON [PRIMARY];
 CREATE INDEX [IX_tbOcorCEvento] ON [dbo].[tbOcorCEvento](flagimpedimento) ON [PRIMARY];
 CREATE INDEX [IX_tbOcorCEvento2] ON [dbo].[tbOcorCEvento](entsai,flagimpedimento) ON [PRIMARY];
GO
--Registros padres
delete from tbOcorCEvento;
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (01, 'Entrada liberada - Primeiro acesso', 1, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (02, 'Entrada liberada', 1, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (03, 'Sada liberada', 0, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (04, 'Entrada liberada - Crach MESTRE', 1, 0, 1);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (05, 'Sada liberada - Crach MESTRE', 0, 0, 1);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (20, 'Entrada em BATCH. Primeiro acesso', 1, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (21, 'Entrada em BATCH', 1, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (22, 'Sada em BATCH', 0, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (23, 'Entrada em BATCH - Crach MESTRE', 1, 0, 1);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (24, 'Sada em BATCH - Crach MESTRE', 0, 0, 1);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (25, 'Entrada em BATCH - Ingresso fora da faixa', 1,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (26, 'Sada em BATCH - Ingresso fora da faixa', 0, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (27, 'Entrada em BATCH - Ingresso j utilizado', 1,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (28, 'Entrada em BATCH - Fora do horrio permitido', 1,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (29, 'Sada em BATCH - Fora do horrio permitido', 0, 0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (30, 'Entrada em BATCH - Fora do perodo do evento', 1,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (31, 'Sada em BATCH - Fora do perodo do evento', 0,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (32, 'Sada em BATCH - Sentido proibido', 0,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (33, 'Entrada em BATCH - Ingresso bloqueado', 1,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (34, 'Sada em BATCH - Ingresso bloqueado', 0,  0, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (40, 'Acesso Bloqueado: Ingresso no cadastrado', 2, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (41, 'Acesso Bloqueado: Ingresso j utilizado', 2, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (42, 'Acesso Bloqueado: Tentativa de dupla-entrada', 1, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (43, 'Acesso Bloqueado: Tentativa de dupla-sada', 0, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (44, 'Acesso Bloqueado: Tentativa de sada sem entrada', 0, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (45, 'Acesso Bloqueado: Fora da faixa horria', 2, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (46, 'Acesso Bloqueado: Fora do perodo do evento', 2, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (47, 'Acesso Bloqueado: Sentido probido', 0, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (48, 'Acesso Bloqueado: Impedido em espera', 2, 1, 0);
Insert tbOcorCEvento (id_ocor, descricao, entsai, flagimpedimento, mestre) Values (49, 'Acesso Bloqueado: Ingresso Bloqueado', 2, 1, 0);

/*
   Movimentao de acessos em evento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMCEvento') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMCEvento] (
      [id_cevento] [float] NOT NULL,
      [cracha] [float] NOT NULL,
      [datahora] datetime NOT NULL, [id_ocor] int NOT NULL,
      [relogio] smallint NOT NULL, [id_dingressos] [float] NOT NULL
   ) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento] ON [dbo].[tbMCEvento](id_cevento) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento2] ON [dbo].[tbMCEvento](id_cevento,cracha) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento3] ON [dbo].[tbMCEvento](id_cevento,datahora) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento4] ON [dbo].[tbMCEvento](id_cevento,id_ocor) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento5] ON [dbo].[tbMCEvento](id_cevento,cracha,datahora) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento6] ON [dbo].[tbMCEvento](id_cevento,cracha,id_ocor) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento7] ON [dbo].[tbMCEvento](id_dingressos, datahora) ON [PRIMARY];
    CREATE INDEX [IX_tbMCEvento8] ON [dbo].[tbMCEvento](cracha,id_ocor) ON [PRIMARY];
END
GO

/*
   Tabela de status dos crachs dos eventos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCrachaCEvento') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbCrachaCEvento] (
      [id_cevento]     [float]    NOT NULL,
      [cracha]         [float]    NOT NULL, [status] [char](1)  NOT NULL,
      [ultacesso_dt]   datetime NULL, [ultacesso_ocor] int      NULL,
      [ultacesso_bloq] smallint NULL, [reinic] bit NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbCrachaCEvento] WITH NOCHECK ADD CONSTRAINT [PK_tbCrachaCEvento] PRIMARY KEY CLUSTERED ([id_cevento],[cracha]) ON [PRIMARY];
end
GO

/*
   Tabela de settings
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSettings') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbSettings] (
      [id_usuario] int NOT NULL,
      [id_empresa] int NOT NULL,
      [secao] varchar(50) NOT NULL ,
      [chave] varchar(50) NOT NULL ,
      [valor] varchar(300) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbSettings] WITH NOCHECK ADD
      CONSTRAINT [PK_tbSettings] PRIMARY KEY CLUSTERED ([id_usuario],[id_empresa],[secao],[chave]) ON [PRIMARY];
end
GO

/*
   Agendamento de Visitas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAgVisi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAgVisi] (
      [id_agvisi] int NOT NULL,
      [id_pass] int NOT NULL,
      [id_visi] int NOT NULL,
      [permanente] bit NOT NULL ,
      [data_ini] datetime NOT NULL,
      [data_fim] datetime NOT NULL,
      [status] tinyint NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAgVisi] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAgVisi] PRIMARY KEY CLUSTERED ([id_agvisi]) ON [PRIMARY];
   CREATE INDEX [IX_tbAgVisi] ON [dbo].[tbAgVisi](id_pass,id_visi) ON [PRIMARY];
   CREATE INDEX [IX_tbAgVisi_id_pass] ON [dbo].[tbAgVisi](id_pass) ON [PRIMARY];
   CREATE INDEX [IX_tbAgVisi_id_visi] ON [dbo].[tbAgVisi](id_visi) ON [PRIMARY];
end
GO

/*
   Bloqueio de Visitantes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBVisi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBVisi] (
      [id_bvisi] int NOT NULL,
      [id_visi] int NOT NULL,
      [status] tinyint NOT NULL,
      [id_usuario] int NOT NULL,
      [data] datetime NOT NULL,
      [motivo] varchar(250) NOT NULL,
      [msg] varchar(150) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBVisi] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBVisi] PRIMARY KEY NONCLUSTERED ([id_bvisi]) ON [PRIMARY];
   CREATE CLUSTERED INDEX [IX_tbBVisi_id_visi] ON [dbo].[tbBVisi](id_visi) ON [PRIMARY];
end
GO

/*
   Digitais dos passantes
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDigitais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDigitais](
      [id_pass] int NOT NULL,
      [ordem]   tinyint NOT NULL,
      [digital] varchar(2500) NULL,
      [digital2] binary(1500) NULL,
      [formato] int NOT NULL,
      [codigo] int NULL,
      [digital_ex] varchar(2500) NULL,
      [qualidade] int NULL,
      [dedo] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbDigitais] WITH NOCHECK ADD
      CONSTRAINT [PK_tbDigitais] PRIMARY KEY NONCLUSTERED ([id_pass],[formato],[ordem]) ON [PRIMARY];
   CREATE INDEX [IX_tbDigitais_codigo] ON [dbo].[tbDigitais](codigo, formato) ON [PRIMARY];
end;
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDigitais') and name = 'digital2')
BEGIN
   ALTER TABLE [dbo].[tbDigitais] ADD [digital2] binary(1500) NULL;
   ALTER TABLE [dbo].[tbDigitais] ALTER COLUMN [digital] varchar(2500) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDigitais') and name = 'formato')
BEGIN
   ALTER TABLE [dbo].[tbDigitais] ADD [formato] int NULL;
   if exists(SELECT id_bloq FROM tbBloq WHERE id_modelo=7) begin
      exec('UPDATE tbDigitais SET formato=0');
   end else begin
      exec('UPDATE tbDigitais SET formato=1');
   end;
   exec('ALTER TABLE [dbo].[tbDigitais] DROP CONSTRAINT [PK_tbDigitais]');
   exec('ALTER TABLE [dbo].[tbDigitais] ALTER COLUMN [formato] int NOT NULL');
   exec('ALTER TABLE [dbo].[tbDigitais] WITH NOCHECK ADD CONSTRAINT [PK_tbDigitais] PRIMARY KEY NONCLUSTERED ([id_pass],[formato],[ordem]) ON [PRIMARY]');
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDigitais') and name = 'codigo')
BEGIN
   ALTER TABLE [dbo].[tbDigitais] ADD [codigo] int NULL;
   CREATE INDEX [IX_tbDigitais_codigo] ON [dbo].[tbDigitais](codigo, formato) ON [PRIMARY];
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDigitais') and name = 'digital_ex')
BEGIN
   ALTER TABLE [dbo].[tbDigitais] ADD [digital_ex] varchar(2500) NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDigitais') and name = 'qualidade')
BEGIN
   ALTER TABLE [dbo].[tbDigitais] ADD [qualidade] int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDigitais') and name = 'dedo')
BEGIN
   ALTER TABLE [dbo].[tbDigitais] ADD [dedo] int NULL;
END;
GO

/*
   Incluso de Digitais por Bloqueio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbIncDigi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbIncDigi](
      [id_bloq] int NOT NULL, [id_pass] int NOT NULL,
      [etapa] int NULL, [etapa_l2] int NULL,
      [data] datetime NOT NULL default GETDATE()
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbIncDigi] WITH NOCHECK ADD
      CONSTRAINT [PK_tbIncDigi] PRIMARY KEY ([id_bloq],[id_pass]) ON [PRIMARY];
end;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbIncDigi') and name = 'etapa')
BEGIN
   ALTER TABLE [dbo].[tbIncDigi] ADD [etapa] int NULL;
END;
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbIncDigi') and name = 'etapa_l2')
BEGIN
   ALTER TABLE [dbo].[tbIncDigi] ADD [etapa_l2] int NULL;
   ALTER TABLE [dbo].[tbIncDigi] ADD [data] datetime NOT NULL default GETDATE();
END;
GO

/*
   Excluso de Digitais por Bloqueio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbDelDigi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbDelDigi](
      [id_bloq] int NOT NULL, [codigo] float NOT NULL,
      [etapa] int NULL, [etapa_l2] int NULL,
      [data] datetime NOT NULL default GETDATE()
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbDelDigi] WITH NOCHECK ADD
      CONSTRAINT [PK_tbDelDigi] PRIMARY KEY ([id_bloq],[codigo]) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbDelDigi') and name = 'etapa')
BEGIN
   ALTER TABLE [dbo].[tbDelDigi] ADD [etapa] int NULL;
   ALTER TABLE [dbo].[tbDelDigi] ADD [etapa_l2] int NULL;
   ALTER TABLE [dbo].[tbDelDigi] ADD [data] datetime NOT NULL default GETDATE();
END;
GO

/*
   Digitais enviadas para o bloqueio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEnvDigi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEnvDigi](
      [id_bloq] int NOT NULL, [id_pass] int NOT NULL, [data] datetime NOT NULL, [tipo_envio] int null
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEnvDigi] WITH NOCHECK ADD
      CONSTRAINT [PK_tbEnvDigi] PRIMARY KEY ([id_bloq],[id_pass]) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEnvDigi') and name = 'tipo_envio')
BEGIN
   ALTER TABLE [dbo].[tbEnvDigi] ADD [tipo_envio] int null;
END;
GO


/*
   Faixas para relgios - digitais de ponto
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPFxRelogs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPFxRelogs](
      [id_pfxrelog] int NOT NULL, [faixas] char(70) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPFxRelogs] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPFxRelogs] PRIMARY KEY NONCLUSTERED ([id_pfxrelog]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbPFxRelogs_faixas] ON [dbo].[tbPFxRelogs](faixas) ON [PRIMARY];
end;
GO

/*
   Faixas para relgios - digitais de acesso
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFxRelogs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAFxRelogs](
      [id_afxrelog] int NOT NULL, [faixas] char(70) NOT NULL,
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAFxRelogs] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAFxRelogs] PRIMARY KEY NONCLUSTERED ([id_afxrelog]) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbAFxRelogs_faixas] ON [dbo].[tbAFxRelogs](faixas) ON [PRIMARY];
end;
GO

/*
   Relacional: faixas x horarios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRFxRelogs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRFxRelogs](
      [ponto] bit NOT NULL, [id_hor] int NOT NULL, [fxrelog] varchar(70) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbRFxRelogs] WITH NOCHECK ADD
      CONSTRAINT [PK_tbRFxRelogs] PRIMARY KEY NONCLUSTERED (ponto,id_hor) ON [PRIMARY];
end;
GO

/*
   Histrico de troca de crach
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbHistCracha') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbHistCracha](
      [id_pass] int NOT NULL,
      [cracha] bigint NOT NULL,
      [data_ini] datetime NOT NULL,
      [data_fim] datetime NULL,
      [id_usuario] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbHistCracha] WITH NOCHECK ADD
      CONSTRAINT [PK_tbHistCracha] PRIMARY KEY NONCLUSTERED (id_pass, cracha, data_ini) ON [PRIMARY];
   CREATE INDEX [IX_tbHistCracha] ON [dbo].[tbHistCracha](cracha) ON [PRIMARY];
   CREATE INDEX IX_tbHistCracha_consulta ON dbo.tbHistCracha(id_pass, cracha, data_fim);
   exec('INSERT INTO tbHistCracha (id_pass,cracha,data_ini) SELECT p.id_pass, p.cracha, p.data FROM tbPass p WHERE not p.data is null');
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbHistCracha') and name = 'IX_tbHistCracha_consulta')
BEGIN
   CREATE INDEX IX_tbHistCracha_consulta ON dbo.tbHistCracha(id_pass, cracha, data_fim);
END;
GO

/*
   Marcao X PIS
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMPIS') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbMPIS](
      [doc_pis] char(12) NOT NULL,
      [marc] datetime NOT NULL,
      [id_pass] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbMPIS] WITH NOCHECK ADD
      CONSTRAINT [PK_tbMPIS] PRIMARY KEY NONCLUSTERED (doc_pis, marc) ON [PRIMARY];
end;
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbJustJorn') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbJustJorn](
      [id_jstjrn] int NOT NULL,
      [descricao] varchar(30) NOT NULL,
      [ocor] tinyint NOT NULL,
      [sistema] bit NOT NULL,
      [padrao] bit NOT NULL,
      [obs] varchar(500) NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbJustJorn] WITH NOCHECK ADD CONSTRAINT [PK_tbJustJorn] PRIMARY KEY NONCLUSTERED (id_jstjrn) ON [PRIMARY];
   CREATE INDEX [IX_tbJustJorn] ON [dbo].[tbJustJorn](ocor,padrao) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.tbJustJorn)
begin
   INSERT INTO tbJustJorn (id_jstjrn, descricao, ocor, sistema, padrao) VALUES (1, 'Marc. mltipla',0,1,0);
   INSERT INTO tbJustJorn (id_jstjrn, descricao, ocor, sistema, padrao) VALUES (2, 'Fora do horrio',0,1,1);
   INSERT INTO tbJustJorn (id_jstjrn, descricao, ocor, sistema, padrao) VALUES (3, 'Marc. includa',1,1,1);
   INSERT INTO tbJustJorn (id_jstjrn, descricao, ocor, sistema, padrao) VALUES (5, 'Pr-assinalada',2,1,1);
   INSERT INTO tbJustJorn (id_jstjrn, descricao, ocor, sistema, padrao) VALUES (6, 'Importado sem AFD',1,1,0);
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbMcTrata') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbMcTrata (
      cnpj CHAR(14) NOT NULL,  pis CHAR(12) NOT NULL,  data DATETIME NOT NULL,
      marc DATETIME NOT NULL,  hora CHAR(5) NOT NULL,  id_jstjrn INT NOT NULL
   )
   CREATE INDEX [IX_tbMcTrata] ON [dbo].[tbMcTrata](cnpj, pis, data) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFD') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAFD (
      id_afd BIGINT NOT NULL,    perini DATETIME NOT NULL,  perfim DATETIME NOT NULL,
      marcini DATETIME NOT NULL, marcfim DATETIME NOT NULL,
      data   DATETIME NOT NULL,  afd01  CHAR(9) NOT NULL,   afd02  CHAR(1) NOT NULL,
      afd03  CHAR(1) NOT NULL,   afd04  CHAR(14) NOT NULL,  afd05  CHAR(12) NOT NULL,
      afd06  CHAR(150) NOT NULL, afd07  CHAR(17) NOT NULL,  afd08  CHAR(8) NOT NULL,
      afd09  CHAR(8) NOT NULL,   afd10  CHAR(8) NOT NULL,   afd11  CHAR(4) NOT NULL,
      tr01   CHAR(9) NOT NULL,   tr02   CHAR(9) NOT NULL,   tr03   CHAR(9) NOT NULL,
      tr04   CHAR(9) NOT NULL,   tr05   CHAR(9) NOT NULL,   tr06   CHAR(1) NOT NULL,
      cksum  CHAR(255) NOT NULL
   )
   ALTER TABLE [dbo].[tbAFD] WITH NOCHECK ADD CONSTRAINT [PK_tbAFD] PRIMARY KEY CLUSTERED ([id_afd]) ON [PRIMARY];
   CREATE INDEX [IX_tbAFD] ON [dbo].[tbAFD](afd07, afd08, afd09, afd10, afd11) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRAFD') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbRAFD (
      id_rafd BIGINT NOT NULL, data DATETIME NOT NULL, arquivo VARCHAR(200) NOT NULL,
      cnpj CHAR(14) NOT NULL, rep  CHAR(17) NOT NULL,
      id_empresa INT NULL,   id_afd  BIGINT   NULL,
      marcini DATETIME NULL, marcfim DATETIME NULL,
      regs_r2 INT NOT NULL, regs_r3 INT NOT NULL, regs_r4 INT NOT NULL, regs_r5 INT NOT NULL,
      falta_cad BIT NOT NULL, importado tinyint NOT NULL, layout varchar(40) NULL
   )
   ALTER TABLE [dbo].[tbRAFD] WITH NOCHECK ADD CONSTRAINT [PK_tbRAFD] PRIMARY KEY CLUSTERED ([id_rafd]) ON [PRIMARY];
   CREATE INDEX [IX_tbRAFD] ON [dbo].[tbRAFD](data) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRAFD') and name = 'layout')
BEGIN
   ALTER TABLE [dbo].[tbRAFD] ADD layout varchar(40) NULL;
   exec('UPDATE tbRAFD SET layout=''<Padro>''');
END;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRAFD_Alerta') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbRAFD_Alerta (
      id_rafd BIGINT NOT NULL, linha INT NOT NULL, data DATETIME NOT NULL,
      tipo_alerta TINYINT NOT NULL, falta_cad BIT NOT NULL, alerta VARCHAR(500) NULL
   )
   CREATE INDEX [IX_tbRAFD_Alerta] ON [dbo].[tbRAFD_Alerta](id_rafd) ON [PRIMARY];
   CREATE INDEX [IX_tbRAFD_Alerta_falta_cad] ON [dbo].[tbRAFD_Alerta](falta_cad) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbInfoCap') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbInfoCap (
      rep CHAR(17) NOT NULL,
      reg BIGINT NULL,
      nsr CHAR(9) NULL,
      data_ini datetime NULL
   )
   ALTER TABLE [dbo].[tbInfoCap] WITH NOCHECK ADD CONSTRAINT [PK_tbInfoCap] PRIMARY KEY CLUSTERED ([rep]) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFDR2') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAFDR2 (
      id_afd BIGINT NOT NULL,
      r201   CHAR(9) NOT NULL,  r202 CHAR(1) NOT NULL,  r203 CHAR(8) NOT NULL,  r204 CHAR(4) NOT NULL,
      r205   CHAR(1) NOT NULL,  r206 CHAR(14) NOT NULL, r207 CHAR(12) NOT NULL, r208 CHAR(150) NOT NULL,
      r209   CHAR(100) NOT NULL
   )
   ALTER TABLE [dbo].[tbAFDR2] WITH NOCHECK ADD CONSTRAINT [PK_tbAFDR2] PRIMARY KEY CLUSTERED ([id_afd], [r201]) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFDR3') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAFDR3 (
      id_afd BIGINT NOT NULL,   cnpj CHAR(14) NOT NULL,
      id_emp_r3 INT NOT NULL,   id_pass INT NOT NULL,   dtref DATETIME NOT NULL, ordem INT NOT NULL,
      rep    CHAR(17) NOT NULL, marc DATETIME NOT NULL,
      r301   CHAR(9) NOT NULL,  r302 CHAR(1) NOT NULL,  r303  CHAR(8) NOT NULL,
      r304   CHAR(4) NOT NULL,  r305 CHAR(12) NOT NULL, cksum CHAR(255) NOT NULL
   )
   ALTER TABLE [dbo].[tbAFDR3] WITH NOCHECK ADD CONSTRAINT [PK_tbAFDR3] PRIMARY KEY CLUSTERED ([rep],[r305],[marc],[r301]) ON [PRIMARY];
   CREATE INDEX [IX_tbAFDR3] ON [dbo].[tbAFDR3](id_pass, dtref) ON [PRIMARY];
   CREATE INDEX [IX_tbAFDR3_marc] ON [dbo].[tbAFDR3](id_pass, marc) ON [PRIMARY];
   CREATE INDEX [IX_tbAFDR3_id_emp_r3] ON [dbo].[tbAFDR3](id_emp_r3) ON [PRIMARY];
   --CREATE INDEX [IX_tbAFDR3_marcpis] ON [dbo].[tbAFDR3](id_pass, r305, marc) ON [PRIMARY];
   --CREATE INDEX [IX_tbAFDR3_id_afd] ON [dbo].[tbAFDR3](id_afd) ON [PRIMARY];
   --CREATE INDEX [IX_tbAFDR3_r305] ON [dbo].[tbAFDR3](r305) ON [PRIMARY];
   --CREATE INDEX [IX_tbAFDR3_cnpj] ON [dbo].[tbAFDR3](cnpj) ON [PRIMARY];
   --CREATE INDEX [IX_tbAFDR3_ppas] ON [dbo].[tbAFDR3](id_pass, r305) ON [PRIMARY];
end;
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbAFDR3') and name = 'IX_tbAFDR3_marcpis')
BEGIN
   EXEC('DROP INDEX tbAFDR3.IX_tbAFDR3_marcpis');
   EXEC('DROP INDEX tbAFDR3.IX_tbAFDR3_id_afd');
   EXEC('DROP INDEX tbAFDR3.IX_tbAFDR3_r305');
   EXEC('DROP INDEX tbAFDR3.IX_tbAFDR3_cnpj');
   EXEC('DROP INDEX tbAFDR3.IX_tbAFDR3_ppas');
END;
GO


if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFDImp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAFDImp (
      cnpj CHAR(14) NOT NULL, rep CHAR(17) NOT NULL, nsr CHAR(9) NOT NULL, pis CHAR(12) NOT NULL,
      marc DATETIME NOT NULL, situacao tinyint NOT NULL
   )
   ALTER TABLE [dbo].[tbAFDImp] WITH NOCHECK ADD CONSTRAINT [PK_tbAFDImp] PRIMARY KEY CLUSTERED (cnpj, rep, nsr, pis, marc) ON [PRIMARY];
   CREATE INDEX [IX_tbAFDImp_situacao] ON [dbo].[tbAFDImp](situacao) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFDR4') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAFDR4 (
      id_afd BIGINT NOT NULL,
      r401   CHAR(9) NOT NULL, r402 CHAR(1) NOT NULL, r403 CHAR(8) NOT NULL,
      r404   CHAR(4) NOT NULL, r405 CHAR(8) NOT NULL, r406 CHAR(4) NOT NULL
   )
   ALTER TABLE [dbo].[tbAFDR4] WITH NOCHECK ADD CONSTRAINT [PK_tbAFDR4] PRIMARY KEY CLUSTERED ([id_afd], [r401]) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFDR5') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAFDR5 (
      id_afd BIGINT NOT NULL,
      r501   CHAR(9) NOT NULL, r502 CHAR(1) NOT NULL,  r503 CHAR(8) NOT NULL, r504 CHAR(4) NOT NULL,
      r505   CHAR(1) NOT NULL, r506 CHAR(12) NOT NULL, r507 CHAR(52) NOT NULL
   )
   ALTER TABLE [dbo].[tbAFDR5] WITH NOCHECK ADD CONSTRAINT [PK_tbAFDR5] PRIMARY KEY CLUSTERED ([id_afd], [r501]) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAFDLog') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAFDLog (
      rep  CHAR(17) NOT NULL,
     nsr  CHAR(9) NOT NULL,
     data DATETIME NOT NULL,
     tipo int NOT NULL,
     acao int NOT NULL,
     info varchar(255),
     id_afdlog BIGINT IDENTITY (1, 1) NOT NULL
   )
   ALTER TABLE [dbo].[tbAFDLog] WITH NOCHECK ADD CONSTRAINT [PK_tbAFDLog] PRIMARY KEY CLUSTERED ([rep], [data], [tipo], [acao]) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAltJorn') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbAltJorn (
      id_pass INT NOT NULL, marc DATETIME NOT NULL, ordem INT NOT NULL,
      data DATETIME NOT NULL, acao TINYINT NOT NULL, id_jstjrn INT NOT NULL,
      data_alt DATETIME NOT NULL, id_usuario INT NOT NULL, afd BIT NOT NULL
   )
   ALTER TABLE [dbo].[tbAltJorn] WITH NOCHECK ADD CONSTRAINT [PK_tbAltJorn] PRIMARY KEY CLUSTERED (id_pass, marc, ordem) ON [PRIMARY];
   CREATE INDEX [IX_tbAltJorn] ON [dbo].[tbAltJorn](id_pass, data) ON [PRIMARY];
   CREATE INDEX [IX_tbAltJorn_afd] ON [dbo].[tbAltJorn](id_pass, data, afd) ON [PRIMARY];
   CREATE INDEX [IX_tbAltJorn_marc] ON [dbo].[tbAltJorn](id_pass, marc, acao, afd) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbCVinculado') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbCVinculado (
      [cracha] [float] NOT NULL, [vinculado] [float] NOT NULL
   )
   ALTER TABLE [dbo].[tbCVinculado] WITH NOCHECK ADD CONSTRAINT [PK_tbCVinculado2] PRIMARY KEY CLUSTERED (cracha, vinculado) ON [PRIMARY];
   CREATE UNIQUE INDEX [IX_tbCVinculado] ON [dbo].[tbCVinculado](vinculado) ON [PRIMARY];
end;
GO
--Atualizaes
IF EXISTS(SELECT name FROM dbo.sysindexes WHERE id = object_id(N'dbo.tbCVinculado') and name = 'PK_tbCVinculado')
BEGIN
   EXEC('ALTER TABLE dbo.tbCVinculado DROP CONSTRAINT PK_tbCVinculado');
   ALTER TABLE [dbo].[tbCVinculado] WITH NOCHECK ADD CONSTRAINT [PK_tbCVinculado2] PRIMARY KEY CLUSTERED (cracha, vinculado) ON [PRIMARY];
END;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEMedico') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbEMedico (
      [id_emedico] [int] NOT NULL,
      [descricao] [varchar](50) NOT NULL,
      [dtinicio] [datetime] NOT NULL,
      [ativo] [bit] NOT NULL,
      [tipo_exame] [tinyint] NOT NULL,
      [opt_per] [tinyint] NOT NULL,
      [meses] [tinyint] NOT NULL,
      [dia] [tinyint] NOT NULL,
      [mes] [tinyint] NOT NULL,
      [qtde_min] [tinyint] NOT NULL,
      [todos_cargos] bit NOT NULL,
      [id_empresa] [int] NOT NULL,
      [dias] [int] NOT NULL,
      [tpass] [varchar](30) NOT NULL
   )
   ALTER TABLE [dbo].[tbEMedico] WITH NOCHECK ADD CONSTRAINT [PK_tbEMedico] PRIMARY KEY CLUSTERED (id_emedico) ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEMedico') and name = 'id_empresa')
BEGIN
   ALTER TABLE [dbo].[tbEMedico] ADD [id_empresa] [int] NULL, [dias] [int] NULL, [tpass] [varchar](30) NULL;
   exec('UPDATE tbEMedico SET id_empresa=0, dias=0, tpass=''#F#''');
   exec('ALTER TABLE [dbo].[tbEMedico] ALTER COLUMN [id_empresa] [int] NOT NULL');
   exec('ALTER TABLE [dbo].[tbEMedico] ALTER COLUMN [dias] [int] NOT NULL');
   exec('ALTER TABLE [dbo].[tbEMedico] ALTER COLUMN [tpass] [varchar](30) NOT NULL');
   exec('UPDATE tbEMedico SET opt_per=opt_per+2');
END;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEMedicoCargos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbEMedicoCargos (
      [id_emedico] [int] NOT NULL, [id_cargo] [int] NOT NULL
   )
   ALTER TABLE [dbo].[tbEMedicoCargos] WITH NOCHECK ADD CONSTRAINT [PK_tbEMedicoCargos] PRIMARY KEY CLUSTERED (id_emedico, id_cargo) ON [PRIMARY];
   CREATE INDEX [IX_tbEMedicoCargos] ON [dbo].[tbEMedicoCargos](id_cargo) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEMedicoResp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbEMedicoResp (
      [id_emresp] [int] NOT NULL, [nome] [varchar](100) NOT NULL
   )
   ALTER TABLE [dbo].[tbEMedicoResp] WITH NOCHECK ADD CONSTRAINT [PK_tbEMedicoResp] PRIMARY KEY CLUSTERED (id_emresp) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEMedicoHist') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbEMedicoHist (
      [id_emhist] [bigint] NOT NULL IDENTITY(1,1),
      [id_pass] [INT] NOT NULL,
      [data] [datetime] NOT NULL,
      [id_emedico] [INT] NOT NULL,
      [id_emresp] [INT] NOT NULL,
      [avaliacao] [tinyint] NOT NULL,
      [obs] [varchar](250) NOT NULL,
      [id_usuario] INT NOT NULL
   )
   ALTER TABLE [dbo].[tbEMedicoHist] WITH NOCHECK ADD CONSTRAINT [PK_tbEMedicoHist] PRIMARY KEY CLUSTERED (id_emhist) ON [PRIMARY];
   CREATE INDEX [IX_tbEMedicoHist_id_pass] ON [dbo].[tbEMedicoHist](id_pass) ON [PRIMARY];
   CREATE INDEX [IX_tbEMedicoHist_data] ON [dbo].[tbEMedicoHist](data) ON [PRIMARY];
   CREATE INDEX [IX_tbEMedicoHist_id_emedico] ON [dbo].[tbEMedicoHist](id_emedico) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTreina') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbTreina (
      [id_empresa] [int] NOT NULL,
      [id_treina] [int] NOT NULL,
      [descricao] [varchar](50) NOT NULL,
      [dtinicio] [datetime] NOT NULL,
      [ativo] [bit] NOT NULL,
      [opt_per] [tinyint] NOT NULL,
      [meses] [tinyint] NOT NULL,
      [dia] [tinyint] NOT NULL,
      [mes] [tinyint] NOT NULL,
      [todos_cargos] bit NOT NULL,
      [dias] [int] NOT NULL,
      [tpass] [varchar](30) NOT NULL
   )
   ALTER TABLE [dbo].[tbTreina] WITH NOCHECK ADD CONSTRAINT [PK_tbTreina] PRIMARY KEY CLUSTERED (id_treina) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTreinaCargos') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbTreinaCargos (
      [id_treina] [int] NOT NULL, [id_cargo] [int] NOT NULL
   )
   ALTER TABLE [dbo].[tbTreinaCargos] WITH NOCHECK ADD CONSTRAINT [PK_tbTreinaCargos] PRIMARY KEY CLUSTERED (id_treina, id_cargo) ON [PRIMARY];
   CREATE INDEX [IX_tbTreinaCargos] ON [dbo].[tbTreinaCargos](id_cargo) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTreinaResp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbTreinaResp (
      [id_tresp] [int] NOT NULL, [nome] [varchar](100) NOT NULL
   )
   ALTER TABLE [dbo].[tbTreinaResp] WITH NOCHECK ADD CONSTRAINT [PK_tbTreinaResp] PRIMARY KEY CLUSTERED (id_tresp) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTreinaHist') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbTreinaHist (
      [id_thist] [bigint] NOT NULL IDENTITY(1,1),
      [id_pass] [INT] NOT NULL,
      [data] [datetime] NOT NULL,
      [id_treina] [INT] NOT NULL,
      [id_tresp] [INT] NOT NULL,
      [avaliacao] [tinyint] NOT NULL,
      [obs] [varchar](250) NOT NULL,
      [id_usuario] INT NOT NULL
   )
   ALTER TABLE [dbo].[tbTreinaHist] WITH NOCHECK ADD CONSTRAINT [PK_tbTreinaHist] PRIMARY KEY CLUSTERED (id_thist) ON [PRIMARY];
   CREATE INDEX [IX_tbTreinaHist_id_pass] ON [dbo].[tbTreinaHist](id_pass) ON [PRIMARY];
   CREATE INDEX [IX_tbTreinaHist_data] ON [dbo].[tbTreinaHist](data) ON [PRIMARY];
   CREATE INDEX [IX_tbTreinaHist_id_treina] ON [dbo].[tbTreinaHist](id_treina) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRIntegra') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbRIntegra (
      [id_rintegra] [int] NOT NULL,
      [descricao] [varchar](50) NOT NULL,
      [tbloq] bit NOT NULL,
      [ttreina] bit NOT NULL,
      [ntreina] bit NOT NULL,
      [texame] bit NOT NULL,
      [nexame] bit NOT NULL
   )
   ALTER TABLE [dbo].[tbRIntegra] WITH NOCHECK ADD CONSTRAINT [PK_tbRIntegra] PRIMARY KEY CLUSTERED (id_rintegra) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRIntegraBloq') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbRIntegraBloq (
      [id_rintegra] [int] NOT NULL, [id_bloq] [int] NOT NULL
   )
   ALTER TABLE [dbo].[tbRIntegraBloq] WITH NOCHECK ADD CONSTRAINT [PK_tbRIntegraBloq] PRIMARY KEY CLUSTERED (id_rintegra, id_bloq) ON [PRIMARY];
   CREATE INDEX [IX_tbRIntegraBloq] ON [dbo].[tbRIntegraBloq](id_bloq) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRIntegraTreina') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbRIntegraTreina (
      [id_rintegra] [int] NOT NULL, [id_treina] [int] NOT NULL
   )
   ALTER TABLE [dbo].[tbRIntegraTreina] WITH NOCHECK ADD CONSTRAINT [PK_tbRIntegraTreina] PRIMARY KEY CLUSTERED (id_rintegra, id_treina) ON [PRIMARY];
   CREATE INDEX [IX_tbRIntegraTreina] ON [dbo].[tbRIntegraTreina](id_treina) ON [PRIMARY];
end;
GO

if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRIntegraExame') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE tbRIntegraExame (
      [id_rintegra] [int] NOT NULL, [id_emedico] [int] NOT NULL
   )
   ALTER TABLE [dbo].[tbRIntegraExame] WITH NOCHECK ADD CONSTRAINT [PK_tbRIntegraExame] PRIMARY KEY CLUSTERED (id_rintegra, id_emedico) ON [PRIMARY];
   CREATE INDEX [IX_tbRIntegraExame] ON [dbo].[tbRIntegraExame](id_emedico) ON [PRIMARY];
end;
GO

/*
   Tabela de relatrio da monitorao de acessos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRMonitAce') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRMonitAce] (
      [id_sisexec] BIGINT NOT NULL,
      [ordem] integer NOT NULL,
      [campo] VARCHAR(100) NOT NULL,
      [informacao] VARCHAR(2000) NOT NULL,
      [imagem] IMAGE NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbRMonitAce] WITH NOCHECK ADD
      CONSTRAINT [PK_tbRMonitAce] PRIMARY KEY CLUSTERED ([id_sisexec],[ordem])  ON [PRIMARY];
end;
GO

/*
   Tabela de alertas do monitor de acesso
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbAlertMAce') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbAlertMAce] (
      [id_usuario] int NOT NULL,
      [cracha] float NOT NULL,
      [som] VARCHAR(30) NOT NULL,
      [entrada] BIT NOT NULL,
      [saida]   BIT NOT NULL,
      [voz_nome] BIT NOT NULL,
      [id_movim] BIGINT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbAlertMAce] WITH NOCHECK ADD
      CONSTRAINT [PK_tbAlertMAce] PRIMARY KEY CLUSTERED ([id_usuario],[cracha])  ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbAlertMAce') and name = 'entrada')
BEGIN
   ALTER TABLE [dbo].[tbAlertMAce] ADD [entrada] BIT NULL, [saida] BIT NULL, [voz_nome] BIT NULL, [id_movim] bigint;
   exec('UPDATE tbAlertMAce SET entrada=1, saida=1, voz_nome=0');
   exec('ALTER TABLE [dbo].[tbAlertMAce] ALTER COLUMN [entrada] BIT NOT NULL');
   exec('ALTER TABLE [dbo].[tbAlertMAce] ALTER COLUMN [saida]   BIT NOT NULL');
   exec('ALTER TABLE [dbo].[tbAlertMAce] ALTER COLUMN [voz_nome] BIT NOT NULL');
END;
GO

/*
   Tabela de prmios
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoPremio') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoPremio] (
      [id_premio] int NOT NULL,
      [data_ini] datetime NOT NULL,
      [data_fim] datetime NOT NULL,
      [periodo] tinyint NOT NULL,
      [descricao] VARCHAR(30) NOT NULL,
      [c_dias] VARCHAR(15) NOT NULL, [c_normal] bit NOT NULL,
      [c_amin] varchar(7) NOT NULL, [m_c_amin] int NOT NULL, [c_aqtd] int NOT NULL,
      [c_emin] varchar(7) NOT NULL, [m_c_emin] int NOT NULL, [c_eqtd] int NOT NULL,
      [p_dias] VARCHAR(15) NOT NULL, [p_normal] bit NOT NULL,
      [p_amin] varchar(7) NOT NULL, [m_p_amin] int NOT NULL, [p_aqtd] int NOT NULL,
      [p_emin] varchar(7) NOT NULL, [m_p_emin] int NOT NULL, [p_eqtd] int NOT NULL,
      [c_ferias] bit NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoPremio] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoPremio] PRIMARY KEY CLUSTERED ([id_premio])  ON [PRIMARY];
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbPtoPremio') and name = 'c_ferias')
BEGIN
   ALTER TABLE [dbo].[tbPtoPremio] ADD [c_ferias] bit NULL;
END;
GO

/*
   Tabela de datas avulsas de prmio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoPremioDatas') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoPremioDatas] (
      [id_premio] int NOT NULL, [data] datetime NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoPremioDatas] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoPremioDatas] PRIMARY KEY CLUSTERED ([id_premio],[data])  ON [PRIMARY];
end;
GO

/*
   Divergncias de prmio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoPremioDivs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoPremioDivs] (
      [id_premio] int NOT NULL,
      [concede] bit NOT NULL,
      [id_diverg] int NOT NULL,
      [s_min] varchar(7) NOT NULL, [m_s_min] int NOT NULL, [somar] bit NOT NULL,
      [abono] bit NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoPremioDivs] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoPremioDivs] PRIMARY KEY CLUSTERED ([id_premio],[concede],[id_diverg])  ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioDivs_concede] ON [dbo].[tbPtoPremioDivs](id_premio, concede) ON [PRIMARY];
end;
GO

/*
   Eventos de prmio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoPremioEvs') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoPremioEvs] (
      [id_premio] int NOT NULL,
      [concede] bit NOT NULL,
      [id_eveabo] int NOT NULL,
      [s_min] varchar(7) NOT NULL, [m_s_min] int NOT NULL, [somar] bit NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoPremioEvs] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoPremioEvs] PRIMARY KEY CLUSTERED ([id_premio],[concede],[id_eveabo])  ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioEvs_concede] ON [dbo].[tbPtoPremioEvs](id_premio, concede) ON [PRIMARY];
end;
GO

/*
   Tabela de prmios por funcionrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoPremioPass') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoPremioPass] (
      [id_pass] int NOT NULL,
      [id_premio] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoPremioPass] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoPremioPass] PRIMARY KEY CLUSTERED ([id_pass],[id_premio])  ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioPass_id_pass] ON [dbo].[tbPtoPremioPass](id_pass) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioPass_id_premio] ON [dbo].[tbPtoPremioPass](id_premio) ON [PRIMARY];
end;
GO

/*
   Tabela de premiao
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoPremioConcede') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoPremioConcede] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_premio] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoPremioConcede] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoPremioConcede] PRIMARY KEY CLUSTERED ([id_pass],[data],[id_premio])  ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioConcede_id_pass] ON [dbo].[tbPtoPremioConcede](id_pass, data) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioConcede_id_premio] ON [dbo].[tbPtoPremioConcede](id_premio, data) ON [PRIMARY];
end;
GO

/*
   Tabela de perda de premiao
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPtoPremioPerde') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPtoPremioPerde] (
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_premio] int NOT NULL,
      [perde_data] datetime NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPtoPremioPerde] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPtoPremioPerde] PRIMARY KEY CLUSTERED ([id_pass],[data],[id_premio])  ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioPerde_id_pass] ON [dbo].[tbPtoPremioPerde](id_pass, data) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioPerde_perde_data] ON [dbo].[tbPtoPremioPerde](id_pass, perde_data) ON [PRIMARY];
   CREATE INDEX [IX_tbPtoPremioPerde_id_premio] ON [dbo].[tbPtoPremioPerde](id_premio, data) ON [PRIMARY];
end;
GO

/*
   Tabela de locais de presena
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPLocais') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPLocais] (
      [id_plocal] int NOT NULL,
      [descricao] varchar(30) NOT NULL,
      [ordem] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPLocais] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPLocais] PRIMARY KEY CLUSTERED ([id_plocal])  ON [PRIMARY];
end;
GO

/*
   Locais de presena - Vinculo por empresa
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPLocaisEmp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPLocaisEmp] (
      [id_plocal] int NOT NULL,
      [id_empresa] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPLocaisEmp] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPLocaisEmp] PRIMARY KEY CLUSTERED ([id_plocal],[id_empresa])  ON [PRIMARY];
end;
GO

/*
   Locais de presena - Vinculo por departamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPLocaisDep') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPLocaisDep] (
      [id_plocal] int NOT NULL,
      [id_depart] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPLocaisDep] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPLocaisDep] PRIMARY KEY CLUSTERED ([id_plocal],[id_depart])  ON [PRIMARY];
end;
GO

/*
   Locais de presena - Vinculo por C.Custo
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPLocaisCust') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPLocaisCust] (
      [id_plocal] int NOT NULL,
      [id_custo] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPLocaisCust] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPLocaisCust] PRIMARY KEY CLUSTERED ([id_plocal],[id_custo])  ON [PRIMARY];
end;
GO

/*
   Locais de presena - Vinculo por agrupamento
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbPLocaisGrup') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbPLocaisGrup] (
      [id_plocal] int NOT NULL,
      [id_agrupamento] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbPLocaisGrup] WITH NOCHECK ADD
      CONSTRAINT [PK_tbPLocaisGrup] PRIMARY KEY CLUSTERED ([id_plocal],[id_agrupamento])  ON [PRIMARY];
end;
GO

/*
   Temporria para gerao de nmeros de crach
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbSys10') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbSys10] (
      [tipo] varchar(1) NOT NULL,
      [cracha] float NOT NULL,
      [data] datetime NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbSys10] WITH NOCHECK ADD
      CONSTRAINT [PK_tbSys10] PRIMARY KEY CLUSTERED ([tipo],[cracha])  ON [PRIMARY];
end;
GO

/*
   Tipos de Equipamentos de Trabalho
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbTEPI') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbTEPI] (
      [id_tepi] int NOT NULL,
      [descricao] varchar(30) NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbTEPI] WITH NOCHECK ADD
      CONSTRAINT [PK_tbTEPI] PRIMARY KEY CLUSTERED ([id_tepi])  ON [PRIMARY];
end;
GO

/*
   Equipamentos de Trabalho
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEPI') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEPI] (
     [id_epi] int NOT NULL,
      [id_tepi] int NOT NULL,
      [codigo] float NOT NULL,
      [descricao] varchar(60) NOT NULL,
      [ref] varchar(40) NULL,
      [unidade] varchar(5) NOT NULL,
      [valor] float NOT NULL,
      [existente] float NOT NULL,
      [disponivel] float NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEPI] WITH NOCHECK ADD
      CONSTRAINT [PK_tbEPI] PRIMARY KEY CLUSTERED ([id_epi])  ON [PRIMARY];
   CREATE UNIQUE INDEX IX_tbEPI ON dbo.tbEPI(codigo);
end;
GO

/*
   EPI - Operadores
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEPIPass') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEPIPass] (
      [id_pass] int NOT NULL,
      [nivel] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEPIPass] WITH NOCHECK ADD
      CONSTRAINT [PK_tbEPIPass] PRIMARY KEY CLUSTERED ([id_pass])  ON [PRIMARY];
end;
GO

/*
   Situao de devoluo - EPI
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEPISD') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEPISD] (
     [id_episd] int NOT NULL,
      [descricao] varchar(30) NOT NULL,
      [devolucao] int NOT NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEPISD] WITH NOCHECK ADD
      CONSTRAINT [PK_tbEPISD] PRIMARY KEY CLUSTERED ([id_episd])  ON [PRIMARY];
end;
GO


/*
   EPI - Parmetros
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEPIPar') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEPIPar] (
      [serv_bio] varchar(255) NOT NULL,
      [port_bio] int NOT NULL,
      [id_lbio] int NULL, --1: (500) Outros, 2: (505) Testech/Bio-I, 3: (512) Digital Persona, 4: (620) NK-FP3/FP4
      [formato] int NULL
   ) ON [PRIMARY];
end
GO
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEPIPar') and name = 'formato')
BEGIN
   ALTER TABLE [dbo].[tbEPIPar] ADD [formato] int NULL;
   exec('UPDATE tbEPIPar SET formato = 6');
END;
GO

/*
   Movimento de EPI
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEPIMov') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbEPIMov] (
     [id_epimov] BIGINT NOT NULL IDENTITY(1,1),
     [id_empresa] int NOT NULL,
     [id_pass] int NOT NULL,
     [id_custo] int NOT NULL,
     [id_depart] int NOT NULL,
     [id_agrupamento] int NOT NULL,
     [cracha] [float] NOT NULL,
     [tipo] [char](1) NOT NULL,
     [data] datetime NOT NULL,
     [id_epi] int NOT NULL,
     [id_usuario] int NOT NULL,
     [id_oper] int NOT NULL,
     [id_conf] int NOT NULL,
      [quantidade] float NOT NULL,
      [situac] int NOT NULL,
      [id_episd] int NOT NULL,
      [id_epiori] BIGINT NOT NULL,
      [patrimonio] varchar(10) NULL
    ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbEPIMov] WITH NOCHECK ADD
      CONSTRAINT [PK_tbEPIMov] PRIMARY KEY CLUSTERED ([id_epimov])  ON [PRIMARY];
   CREATE INDEX IX_tbEPIMov_id_pass ON dbo.tbEPIMov(id_pass);
   CREATE INDEX IX_tbEPIMov_id_epiori ON dbo.tbEPIMov(id_epiori);
end;
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbEPIMov') and name = 'patrimonio')
BEGIN
   ALTER TABLE [dbo].[tbEPIMov] ADD [patrimonio] varchar(10) NULL;
END;
GO

/*
   Filtros de relatrio
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFiltro') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFiltro] (
      [id_filtro] int NOT NULL,
      [id_usuario] int NOT NULL,
      [descricao] varchar(20) NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbFiltro] WITH NOCHECK ADD
      CONSTRAINT [PK_tbFiltro] PRIMARY KEY CLUSTERED ([id_filtro])  ON [PRIMARY];
   CREATE INDEX IX_tbFiltro ON dbo.tbFiltro([id_usuario],[id_filtro]);
end
GO

/*
   Filtros de relatrio - tabelas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFiltroTab') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbFiltroTab] (
      [id_filtro] int NOT NULL,
      [tabela] int NOT NULL, --1:departamento, 2:centro de custo, 3:cargo, 4:horrio pto, 5:horrio ace, 6:agrupamento, 7:categoria, 8:banco
      [id_tabela] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbFiltroTab] WITH NOCHECK ADD
      CONSTRAINT [PK_tbFiltroTab] PRIMARY KEY CLUSTERED ([id_filtro],[tabela],[id_tabela])  ON [PRIMARY];
end
GO


/*
   Refeies avulsas
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbRefAvulsa') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbRefAvulsa] (
      [id_refavulso] BIGINT NOT NULL IDENTITY(1,1),
      [id_pass] int NOT NULL,
      [data] datetime NOT NULL,
      [id_refeit] int NOT NULL,
      [valor] float NOT NULL,
      [id_usuario] int NOT NULL,
      [id_cxcredref] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbRefAvulsa] WITH NOCHECK ADD
      CONSTRAINT [PK_tbRefAvulsa] PRIMARY KEY CLUSTERED ([id_refavulso])  ON [PRIMARY];
   CREATE INDEX [IX_tbRefAvulsa] ON dbo.tbRefAvulsa(id_pass);
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbRefAvulsa') and name = 'id_cxcredref')
BEGIN
   ALTER TABLE [dbo].[tbRefAvulsa] ADD [id_cxcredref] int NULL
END;
GO

/*
   Backup de digitais, por CPF
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBkpBmp') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBkpBmp] (
      [doc_cpf] varchar(12) NOT NULL,
      [ordem]   tinyint NOT NULL,
      [bmp]     VARBINARY(MAX) NOT NULL,
      [width]   int NOT NULL,
      [height]  int NOT NULL,
      [data]    datetime NOT NULL,
      [id_pass] int NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBkpBmp] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBkpBmp] PRIMARY KEY ([doc_cpf],[ordem])  ON [PRIMARY];
end
GO

/*
   Backup de templates, por CPF
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbBkpDigi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbBkpDigi] (
      [doc_cpf]   varchar(12) NOT NULL,
      [formato]   int NOT NULL,
      [ordem]     tinyint NOT NULL,
      [digital]   varchar(2500) NULL,
      [digital_ex] varchar(2500) NULL,
      [id_pass]   int NOT NULL,
      [data]      datetime NOT NULL,
      [qualidade] int NULL,
      [dedo] int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbBkpDigi] WITH NOCHECK ADD
      CONSTRAINT [PK_tbBkpDigi] PRIMARY KEY ([doc_cpf], [formato], [ordem])  ON [PRIMARY];
end
GO
--Atualizaes
IF NOT EXISTS(SELECT name FROM dbo.syscolumns WHERE id = object_id(N'dbo.tbBkpDigi') and name = 'dedo')
BEGIN
   ALTER TABLE [dbo].[tbBkpDigi] ADD [dedo] int NULL;
END;
GO

/*
   Auditoria de biometria
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbADigi') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbADigi] (
      [id_pass]    int NOT NULL,
      [formato]    int NOT NULL,
      [data]       datetime NOT NULL,
      [id_usuario] int NOT NULL,
      [acao]       int NULL, -- 1: Capturou digitais, 1: Falha ao capturar, 2: Excluiu digitais
      [qualidade]  int NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbADigi] WITH NOCHECK ADD
      CONSTRAINT [PK_tbADigi] PRIMARY KEY ([id_pass], [formato], [data])  ON [PRIMARY];
end
GO

/*
   vwPLocaisPass
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.vwPLocaisPass') AND xtype = 'V') BEGIN DROP VIEW dbo.vwPLocaisPass; END;
GO
CREATE VIEW dbo.vwPLocaisPass
AS
   SELECT  p.id_pass, l.ordem, l.id_plocal
   FROM tbPass p
   INNER JOIN tbPLocais l ON l.id_plocal IN (
      select emp.id_plocal from tbPLocaisEmp emp where emp.id_empresa=p.id_empresa
      union
      select dep.id_plocal from tbPLocaisDep dep where dep.id_depart=p.id_depart
      union
      select cust.id_plocal from tbPLocaisCust cust where cust.id_custo=p.id_custo
      union
      select grup.id_plocal from tbPLocaisGrup grup where grup.id_agrupamento=p.id_agrupamento
      )
   AND l.ordem = isnull((
      select MAX(l2.ordem) from tbPLocais l2 WHERE l2.id_plocal IN (
         select emp.id_plocal from tbPLocaisEmp emp where emp.id_empresa=p.id_empresa
         union
         select dep.id_plocal from tbPLocaisDep dep where dep.id_depart=p.id_depart
         union
         select cust.id_plocal from tbPLocaisCust cust where cust.id_custo=p.id_custo
         union
         select grup.id_plocal from tbPLocaisGrup grup where grup.id_agrupamento=p.id_agrupamento
         )), l.ordem)
   GROUP BY p.id_pass, l.ordem, l.id_plocal
GO

/*
   Lista de crachs em equipamento id_modelo = 32
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLstM32') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLstM32] (
      [id_bloq]   int NOT NULL,
      [cracha]    bigint NOT NULL,
      [matricula] bigint NOT NULL, --Mestre: 10000000000000 + cracha, Provisrio: 20000000000000 + id_pass
      [id_evento] int NOT NULL,
      [status]    int NOT NULL, --1:a validar, 2:validado, 3:enviar, 4:excluir, 5:falha ao enviar, 6: falha ao excluir, 7:enviado, 8:excluido
      [memoria]   bit NOT NULL,
      [data]      datetime NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLstM32] WITH NOCHECK ADD
      CONSTRAINT [PK_tbLstM32] PRIMARY KEY ([id_bloq],[cracha])  ON [PRIMARY];
   CREATE INDEX [IX_tbLstM32] ON dbo.tbLstM32([id_bloq],[status]);
   CREATE INDEX [IX_tbLstM32_matricula] ON dbo.tbLstM32([id_bloq],[matricula]);
end
GO

/*
   Lista de crachs em equipamento id_modelo = 34
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLstM34') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLstM34] (
      [id_bloq]   int NOT NULL,
      [pin]       bigint NOT NULL, --Passante: id_pass * 10, Mestre: cracha * 10 + 1
      [cracha]    bigint NOT NULL,
      [senha]     int NOT NULL,
      [id_pass]   int NOT NULL,
      [status]    int NOT NULL, --0:validar (tbIncDigi), 1: validar (comum), 2: enviar, 3: excluir, 4: enviado
      [enviado]   bit NOT NULL,
      [data]      datetime NOT NULL
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLstM34] WITH NOCHECK ADD
      CONSTRAINT [PK_tbLstM34] PRIMARY KEY ([id_bloq],[pin])  ON [PRIMARY];
   CREATE INDEX [IX_tbLstM34_status] ON dbo.tbLstM34([id_bloq],[status]);
   CREATE INDEX [IX_tbLstM34_id_pass] ON dbo.tbLstM34([id_bloq],[id_pass]);
end
GO

/*
   Liberao remota de acesso
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLibRemoto') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
   CREATE TABLE [dbo].[tbLibRemoto](
      [id_bloq] int NOT NULL,
      [id_pass] int NOT NULL,
      [entsai] int NOT NULL,
      [data] datetime NOT NULL default GETDATE()
   ) ON [PRIMARY];
   ALTER TABLE [dbo].[tbLibRemoto] WITH NOCHECK ADD
      CONSTRAINT [PK_tbLibRemoto] PRIMARY KEY ([id_bloq]) ON [PRIMARY];
end
GO

/*
-------------------------------------
 PASSO 2: CRIAR/ATUALIZAR PROCEDURES
-------------------------------------
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_SYS01') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.P_SYS01; END;
GO
CREATE PROCEDURE dbo.P_SYS01(@opt int, @id_ret int = -1 output) WITH ENCRYPTION AS
BEGIN
declare @ult_id_pass int, @mxP int, @mxV int, @mxB int;
SET NOCOUNT ON;
SELECT TOP 1 @ult_id_pass=isnull(ult_id_pass,0) FROM tbParSist;
if @ult_id_pass<=0 OR
exists(SELECT id_pass FROM tbPass WHERE id_pass=@ult_id_pass+1) OR
exists(SELECT id_pass FROM tbVisiBai WHERE id_pass=@ult_id_pass+1) OR
exists(SELECT id_pass FROM tbCrachasBatch WHERE id_pass=@ult_id_pass+1) begin
SELECT @mxP=MAX(id_pass) FROM tbPass;
SELECT @mxV=MAX(id_pass) FROM tbVisiBai;
SELECT @mxB=MAX(id_pass) FROM tbCrachasBatch;
if isnull(@mxV,0) > isnull(@mxP,0) begin
SELECT @mxP=@mxV;
end;
if isnull(@mxB,0) > isnull(@mxP,0) begin
SELECT @mxP=@mxB;
end;
UPDATE tbParSist SET ult_id_pass=isnull(@mxP,0);
end;
SELECT TOP 1 @ult_id_pass=isnull(ult_id_pass,0)+1 FROM tbParSist;
if @opt=101 begin
UPDATE tbParSist SET ult_id_pass=@ult_id_pass;
end;
if isnull(@id_ret,-1)=0
select @id_ret=@ult_id_pass
else
select @ult_id_pass as id_pass;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_SYS10') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.P_SYS10; END;
GO
CREATE PROCEDURE dbo.P_SYS10(@id_empresa int, @tipo varchar(1), @opt int) WITH ENCRYPTION AS
BEGIN
declare @cracha FLOAT, @anterior FLOAT, @fxini FLOAT, @mxC FLOAT;
declare @achou bit;
SET NOCOUNT ON;
if @tipo='F' begin
SELECT @fxini=isnull(func_ini,1) FROM tbEmpresas WHERE id_empresa=@id_empresa;
end else if @tipo='T' begin
SELECT @fxini=isnull(terc_ini,1) FROM tbEmpresas WHERE id_empresa=@id_empresa;
end else begin
SELECT @fxini=isnull(visi_ini,1) FROM tbEmpresas WHERE id_empresa=@id_empresa;
end;
if @fxini<=0 begin select @fxini=1; end;
select @cracha=@fxini, @anterior=@fxini-1;
select @achou=0;
while @achou=0 begin
SELECT @cracha=MIN(cracha) FROM tbPass WHERE cracha>@anterior;
select @cracha=isnull(@cracha,0);
if @anterior=0 or @cracha=0 or (@cracha-@anterior) > 1 begin
select @cracha=@anterior+1;
end;
select @anterior=@cracha;
if NOT EXISTS(SELECT TOP 1 cracha FROM tbPass WHERE cracha=@cracha)
AND NOT EXISTS(SELECT cracha FROM tbCMestre WHERE cracha=@cracha)
AND NOT EXISTS(SELECT TOP 1 cracha FROM tbProvisorios WHERE cracha=@cracha)
AND NOT EXISTS(SELECT cracha FROM tbSys10 WHERE tipo=@tipo AND cracha=@cracha) begin
select @achou=1;
end;
end;
if @opt=101 begin
INSERT INTO tbSys10 (tipo, cracha, data) VALUES (@tipo, @cracha, getdate());
DELETE FROM tbSys10 WHERE data < dateadd(d,-1,getdate());
DELETE FROM tbSys10 WHERE data > dateadd(d,1,getdate());
end;
select @cracha as cracha;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO001') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO001 END
GO
CREATE PROCEDURE dbo.AP_PTO001(@DATA datetime, @RET INT output) WITH ENCRYPTION AS
BEGIN
select @RET = 0;
if not @DATA is null begin select @RET = (datepart(hh,@DATA)*60)+datepart(mi,@DATA) end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO002') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO002; END;
GO
CREATE PROCEDURE dbo.AP_PTO002(@m_marc int, @24h bit, @marc char(5) output) WITH ENCRYPTION AS
BEGIN
declare @hor int;
declare @min int;
select @marc = '__:__', @hor = 0, @min = 0;
if @m_marc < 60 begin
if @m_marc >= 0 begin
select @min = @m_marc;
select @marc = '00:' + right('00'+ltrim(str(@min)),2);
end;
end else begin
select @hor = @m_marc / 60;
select @min = @m_marc - (@hor * 60);
if @24h=0 begin select @hor = @hor % 24; end;
select @marc = right('00'+ltrim(str(@hor)),2) + ':' + right('00'+ltrim(str(@min)),2);
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO003') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO003; END;
GO
CREATE PROCEDURE dbo.AP_PTO003(@m_marc int, @marc char(7) output) WITH ENCRYPTION AS
BEGIN
declare @hor int;
declare @min int;
select @marc = '  00:00', @hor = 0, @min = 0;
if @m_marc < 0 begin select @m_marc=0; end;
if @m_marc < 60 begin
if @m_marc >= 0 begin
select @min = @m_marc;
select @marc = '  00:' + right('00'+ltrim(str(@min)),2);
end;
end else begin
select @hor = @m_marc / 60;
select @min = @m_marc - (@hor * 60);
select @marc = right('0000'+ltrim(str(@hor)),4) + ':' + right('00'+ltrim(str(@min)),2);
if left(@marc,2) = '00' begin select @marc = '  ' + right(@marc,5) end;
if left(@marc,1) = '0' begin select @marc = ' ' + right(@marc,6) end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO004') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO004; END;
GO
CREATE PROCEDURE dbo.AP_PTO004(@m_marc int, @marc char(8) output) WITH ENCRYPTION AS
BEGIN
declare @hor int;
declare @min int;
declare @neg bit;
select @marc = '+  00:00', @hor = 0, @min = 0, @neg=0;
if @m_marc < 0 begin select @m_marc=abs(@m_marc), @neg=1; end;
if @m_marc < 60 begin
if @m_marc >= 0 begin
select @min = @m_marc;
select @marc = '+  00:' + right('00'+ltrim(str(@min)),2);
end;
end else begin
select @hor = @m_marc / 60;
select @min = @m_marc - (@hor * 60);
select @marc = '+'+right('0000'+ltrim(str(@hor)),4) + ':' + right('00'+ltrim(str(@min)),2);
IF left(@marc,3) = '+00' begin select @marc = '+  ' + right(@marc,5) end;
IF left(@marc,2) = '+0' begin select @marc = '+ ' + right(@marc,6) end;
end;
if @neg=1 begin select @marc='-'+right(@marc,7); end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTHALT') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTHALT; END;
GO
CREATE PROCEDURE dbo.AP_PTHALT(@data datetime, @id_pass int, @id_phalt1 int, @id_phalt2 int, @id_phalt3 int, @id_phorario int OUTPUT, @m_nova_marc int = null) WITH ENCRYPTION AS
BEGIN
declare @id_phalt0 int; declare @data_ant as datetime; declare @wdia int; declare @wdia_ant int;
declare @id_phorario_ant int; declare @flexivel_ant bit; declare @trabalhado_ant bit;
declare @e1 int; declare @s1 int; declare @eOLD int; declare @sOLD int;
declare @eALT0 int; declare @sALT0 int; declare @eALT1 int; declare @sALT1 int;
declare @eALT2 int; declare @sALT2 int; declare @eALT3 int; declare @sALT3 int;
declare @m_primeira int; declare @dif0 int; declare @dif1 int; declare @dif2 int; declare @dif3 int;
select @id_phalt0 = @id_phorario;
select @data_ant = dateadd(d,-1,@data);
select @wdia = DATEPART(dw,@data);
select @wdia_ant = DATEPART(dw,@data_ant);
select @eOLD=0, @sOLD=0;
select @eALT0=0, @sALT0=0, @eALT1=0, @sALT1=0, @eALT2=0, @sALT2=0, @eALT3=0, @sALT3=0;
if isnull(@id_phalt0,0) > 0 begin
select @e1=0, @s1=0;
SELECT @e1=m_entrada1, @s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3 WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1 ELSE -1 END)
FROM tbFxPHorarios WHERE id_phorario = @id_phalt0 AND wdia=@wdia;
if isnull(@e1,-1) < 0 begin select @e1=0; end; if isnull(@s1,-1) < 0 begin select @s1=0; end;
select @eALT0=@e1;
select @sALT0=(@s1 + 1); if (@e1 > @s1) begin select @sALT0=@sALT0+1440; end;
end;
if isnull(@id_phalt1,0) > 0 begin
select @e1=0, @s1=0;
SELECT @e1=m_entrada1, @s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3 WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1 ELSE -1 END)
FROM tbFxPHorarios WHERE id_phorario = @id_phalt1 AND wdia=@wdia;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
if isnull(@s1,-1) < 0 begin select @s1=0; end;
select @eALT1=@e1;
select @sALT1=(@s1 + 1); if (@e1 > @s1) begin select @sALT1=@sALT1+1440; end;
end;
if isnull(@id_phalt2,0) > 0 begin
select @e1=0, @s1=0;
SELECT @e1=m_entrada1, @s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3 WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1 ELSE -1 END)
FROM tbFxPHorarios WHERE id_phorario = @id_phalt2 AND wdia=@wdia;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
if isnull(@s1,-1) < 0 begin select @s1=0; end;
select @eALT2=@e1;
select @sALT2=(@s1 + 1); if (@e1 > @s1) begin select @sALT2=@sALT2+1440; end;
end;
if isnull(@id_phalt3,0) > 0 begin
select @e1=0, @s1=0;
SELECT @e1=m_entrada1, @s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3 WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1 ELSE -1 END)
FROM tbFxPHorarios WHERE id_phorario = @id_phalt3 AND wdia=@wdia;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
if isnull(@s1,-1) < 0 begin select @s1=0; end;
select @eALT3=@e1;
select @sALT3=(@s1 + 1); if (@e1 > @s1) begin select @sALT3=@sALT3+1440; end;
end;
if (@eALT0<=0) begin
if (@sALT3>0 AND @sALT3<1440) begin select @id_phalt3=0; end;
if (@sALT3>0 AND @sALT2<1440) begin select @id_phalt2=0; end;
if (@sALT3>0 AND @sALT1<1440) begin select @id_phalt1=0; end;
end;
if (ISNULL(@id_phalt1,0)>0 OR ISNULL(@id_phalt2,0)>0 OR ISNULL(@id_phalt3,0)>0) begin
select @id_phorario_ant=0, @flexivel_ant=0, @trabalhado_ant=0;
SELECT @id_phorario_ant=isnull(id_phorario,0),@flexivel_ant=isnull(flexivel,0),@trabalhado_ant=isnull(trabalhado,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data_ant;
if @flexivel_ant=0 and @trabalhado_ant=1 and isnull(@id_phorario_ant,0) > 0
begin
select @e1=0, @s1=0;
SELECT @e1=m_entrada1, @s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3 WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1 ELSE -1 END)
FROM tbFxPHorarios WHERE id_phorario = @id_phorario_ant AND wdia=@wdia_ant;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
if isnull(@s1,-1) < 0 begin select @s1=0; end;
select @eOLD=@e1;
select @sOLD=@s1; if (@e1 > @s1) begin select @sOLD = @sOLD + 1440; end;
select @sOLD=@sOLD+240;
if (@sOLD>1440) begin
if (@eALT3>0 AND (@eALT3+1441)<@sOLD) begin select @id_phalt3=0; end;
if (@eALT2>0 AND (@eALT2+1441)<@sOLD) begin select @id_phalt2=0; end;
if (@eALT1>0 AND (@eALT1+1441)<@sOLD) begin select @id_phalt1=0; end;
if (@eALT0>0 AND (@eALT0+1441)<@sOLD) begin select @id_phalt0=0; end;
end;
end;
end;
if (ISNULL(@id_phalt1,0)>0 OR ISNULL(@id_phalt2,0)>0 OR ISNULL(@id_phalt3,0)>0) begin
select @m_primeira=-1;
SELECT TOP 1 @m_primeira=isnull(m_primeira,-1) FROM tbPtoEnq
WHERE id_pass=@id_pass AND data=@data ORDER BY original;
if (isnull(@m_primeira,-1)<0) begin
select @m_primeira=@m_nova_marc;
end;
if (isnull(@m_primeira,0)>0) begin
if (@m_primeira>1440) begin select @m_primeira=@m_primeira-1440; end;
select @dif0=2880, @dif1=2880, @dif2=2880, @dif3=2880;
if (@eALT0>0 and ISNULL(@id_phalt0,0)>0) begin
select @dif0=ABS(@m_primeira-@eALT0);
end;
if (@eALT1>0 and ISNULL(@id_phalt1,0)>0) begin
select @dif1=ABS(@m_primeira-@eALT1);
end;
if (@eALT2>0 and ISNULL(@id_phalt2,0)>0) begin
select @dif2=ABS(@m_primeira-@eALT2);
end;
if (@eALT3>0 and ISNULL(@id_phalt3,0)>0) begin
select @dif3=ABS(@m_primeira-@eALT3);
end;
if (@dif0<=@dif1 and @dif0<=@dif2 and @dif0<=@dif3) begin
select @id_phalt1=0, @id_phalt2=0, @id_phalt3=0;
end else if (@dif1<=@dif0 and @dif1<=@dif2 and @dif1<=@dif3) begin
select @id_phalt0=0, @id_phalt2=0, @id_phalt3=0;
end else if (@dif2<=@dif0 and @dif2<=@dif1 and @dif2<=@dif3) begin
select @id_phalt0=0, @id_phalt1=0, @id_phalt3=0;
end else if (@dif3<=@dif0 and @dif3<=@dif1 and @dif3<=@dif2) begin
select @id_phalt0=0, @id_phalt1=0, @id_phalt2=0;
end;
end;
end;
/* Retorno */
if (ISNULL(@id_phalt0,0)>0) begin
select @id_phorario = @id_phalt0;
end else if (ISNULL(@id_phalt1,0)>0) begin
select @id_phorario = @id_phalt1;
end else if (ISNULL(@id_phalt2,0)>0) begin
select @id_phorario = @id_phalt2;
end else if (ISNULL(@id_phalt3,0)>0) begin
select @id_phorario = @id_phalt3;
end;
end;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO005') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO005 END;
GO
CREATE PROCEDURE dbo.AP_PTO005(@data datetime, @id_empresa int, @id_pass int,
@TipoDia char(1) output,      @TrocaHor Bit output,   @TipoHE char(1) output, @id_eveabo int output,
@id_phorario int output,      @id_horario int output, @descFeriado varchar(20) output, @descEveAbo varchar(30) output,
@horAbono varchar(7) output, @m_horAbono int output, @folga bit output, @m_nova_marc int = null) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_aux int; declare @achou bit; declare @id_phalt1 int; declare @id_phalt2 int; declare @id_phalt3 int
select @TipoDia = 'N';   select @TrocaHor = 0;     select @TipoHE = 'N';
select @id_eveabo = 0;   select @id_phorario = 0;  select @id_horario = 0;
select @descFeriado = ''; select @descEveAbo = ''
select @horAbono = '';  select @m_horAbono = 0;
select @id_phalt1=0, @id_phalt2=0, @id_phalt3=0;
if exists(select top 1 * from tbCalendario where (id_empresa = @id_empresa or id_empresa = 0) and id_pass = 0 and data = @data) begin
SELECT top 1 @TipoDia=isnull(tipo,'N'),
@id_eveabo=isnull(id_eveabo,0),
@horAbono=isnull(horas_abono,'____:__'), @m_horAbono=isnull(m_horas_abono,0),
@descFeriado=isnull(desc_feriado,'') FROM tbCalendario
WHERE (id_empresa = @id_empresa OR id_empresa = 0) AND id_pass = 0 AND data = @data and tipo <> 'T';
SELECT top 1 @TrocaHor = 1, @id_horario=isnull(id_horario,0), @id_phorario=isnull(id_phorario,0) FROM tbCalendario
WHERE (id_empresa = @id_empresa OR id_empresa = 0) AND id_pass = 0 AND data = @data and tipo = 'T';
end;
if @id_pass > 0 and exists(select top 1 * from tbCalendario where id_pass = @id_pass and data = @data) begin
SELECT top 1 @TipoDia=isnull(tipo,'N'),
@id_eveabo=isnull(id_eveabo,0),
@horAbono=isnull(horas_abono,'____:__'), @m_horAbono=isnull(m_horas_abono,0),
@descFeriado=isnull(desc_feriado,'') FROM tbCalendario
WHERE id_pass = @id_pass AND data = @data and tipo <> 'T';
SELECT top 1 @TrocaHor = 1, @id_horario=isnull(id_horario,0), @id_phorario=isnull(id_phorario,0) FROM tbCalendario
WHERE id_pass = @id_pass AND data = @data and tipo = 'T';
end;
if exists(select top 1 * from tbPerHE where (id_empresa = @id_empresa or id_empresa = 0) and id_pass = 0 and data = @data) begin
SELECT top 1 @TipoHE=isnull(tipo,'N') FROM tbPerHE
WHERE (id_empresa = @id_empresa OR id_empresa = 0) AND id_pass = 0 AND data = @data;
end;
if exists(select top 1 * from tbPerHE where id_pass = @id_pass and data = @data) begin
SELECT top 1 @TipoHE=isnull(tipo,'N') FROM tbPerHE
WHERE id_pass = @id_pass AND data = @data;
end;
if @id_eveabo > 0 begin
select @descEveAbo = isnull(descricao,'No cadastrado') from tbEvsAbono
where id_eveabo = @id_eveabo;
end;
select @folga = 0;
if @TipoDia = 'F' begin select @folga = 1; end;
if @TrocaHor=0 or isnull(@id_horario,0) = 0 begin
select @id_horario = id_horario from tbPass where id_pass = @id_pass;
end;
if @TrocaHor=0 or isnull(@id_phorario,0) = 0 begin
select @id_phorario=id_phorario, @id_phalt1=isnull(id_phalt1,0), @id_phalt2=isnull(id_phalt2,0), @id_phalt3=isnull(id_phalt3,0) from tbPass where id_pass = @id_pass;
--Histrico de tabelas
select @achou=0, @id_aux=0;
SELECT top 1 @achou=1, @id_aux=id_tab FROM tbHistTab
WHERE id_pass = @id_pass and data >= @data and tabela=0
ORDER BY data asc;
if @achou=1 and isnull(@id_aux,0) > 0 begin select @id_phorario=@id_aux; end;
if (isnull(@id_phorario,0)>0 and isnull(@id_phalt1,0)+isnull(@id_phalt2,0)+isnull(@id_phalt3,0) > 0) begin
if exists(SELECT tipo from tbPGHorarios where id_phorario = @id_phorario and tipo = 'N') begin
exec AP_PTHALT @data, @id_pass, @id_phalt1, @id_phalt2, @id_phalt3, @id_phorario OUTPUT, @m_nova_marc;
end;
end;
end;
if isnull(@id_phorario,0) > 0 begin
if exists(SELECT tipo from tbPGHorarios where id_phorario = @id_phorario and tipo = 'E') begin
select @achou=0, @id_aux=0;
SELECT @achou = 1, @id_aux = (case when folga = 1 then -1 else id_phorario end) FROM tbPEscalasHorarios WHERE id_pescala = @id_phorario and data = @data;
if DATEPART(dw,@data)=1 begin
if exists(SELECT id_pass FROM tbPEscFDom WHERE id_pass=@id_pass AND data=@data) begin
SELECT @achou=1, @id_aux=-1;
end;
end;
if @achou = 1 and @id_aux = -1 begin
select @folga = 1;
end;
if @achou = 0 or @folga = 1 begin
select @achou = 0;
select @achou = 1, @id_aux = id_phorario from tbPEscalas where id_pescala = @id_phorario;
if @achou = 0 begin
select @folga = 1;
select @id_phorario=0;
end;
end;
if @id_aux > 0 begin select @id_phorario=@id_aux; end else begin select @id_phorario=0;end;
end;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO006') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO006 END;
GO
CREATE PROCEDURE dbo.AP_PTO006(@data datetime, @id_empresa int, @id_pass int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @TipoDia char(1); declare @TrocaHor Bit;     declare @TipoHE char(1)
declare @id_eveabo int;   declare @id_phorario int;  declare @id_horario int;
declare @descFeriado varchar(20);
declare @horAbono varchar(7);     declare @m_horAbono int;
declare @descHorPto varchar(100);   declare @descHorAce varchar(50);
declare @descEveAbo varchar(30);   declare @folga bit;
EXEC AP_PTO005 @data, @id_empresa, @id_pass, @TipoDia out, @TrocaHor out, @TipoHE out, @id_eveabo out, @id_phorario out, @id_horario out, @descFeriado out, @descEveAbo out, @horAbono out, @m_horAbono out, @folga out;
select @descHorPto = '';
if @id_phorario > 0 begin
select @descHorPto = isnull(descricao,'No cadastrado') from tbPGHorarios
where id_phorario = @id_phorario;
end;
select @descHorAce = '';
if @id_horario > 0 begin
select @descHorAce = isnull(descricao,'No cadastrado') from tbGHorarios
where id_horario = @id_horario;
end;
select @TipoDia as tipodia, @TrocaHor as trocahor, @TipoHE as tipohe,
@id_eveabo as id_eveabo, @id_phorario as id_phorario, @id_horario as id_horario,
@descFeriado as descferiado, @horAbono as horAbono, @m_horAbono as m_horAbono,
@descHorPto as deschorpto, @descHorAce as deschorace, @descEveAbo as desceveabo;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO007') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO007; END;
GO
CREATE PROCEDURE dbo.AP_PTO007(@id_phorario int, @wdia tinyint, @norm_ini int, @norm_fim int,
@e1 int output, @s1 int output,@e2 int output, @s2 int output,@e3 int output, @s3 int output,
@e4 int output, @s4 int output,@fxini int output, @fxfim int output,@fxtmp int output,
@entrada1 varchar(6) output, @saida1 varchar(6) output, @entrada2 varchar(6) output, @saida2 varchar(6) output,
@entrada3 varchar(6) output, @saida3 varchar(6) output, @entrada4 varchar(6) output, @saida4 varchar(6) output,
@flex_ini varchar(6) output, @flex_fim varchar(6) output, @flex_tempo varchar(6) output,
@hrs_prev varchar(7) output, @m_hrs_prev int output
) WITH ENCRYPTION AS
BEGIN
declare @achou bit;
select @entrada1='__:__',@saida1='__:__',@entrada2='__:__',@saida2='__:__';
select @entrada3='__:__',@saida3='__:__',@entrada4='__:__',@saida4='__:__';
select @flex_ini='__:__',@flex_fim='__:__',@flex_tempo='__:__';
select @e1=-1,@s1=-1,@e2=-1,@s2=-1,@e3=-1,@s3=-1,@e4=-1,@s4=-1;
select @fxini=-1,@fxfim=-1,@fxtmp=0,@m_hrs_prev=0, @hrs_prev='  00:00';
select @achou=0;
if @norm_ini>-1 and @norm_fim>-1 begin
SELECT top 1 @achou=1,
@entrada1=entrada1,@saida1=saida1,@entrada2=entrada2,@saida2=saida2,
@entrada3=entrada3,@saida3=saida3,@entrada4=entrada4,@saida4=saida4,
@flex_ini=flex_ini,@flex_fim=flex_fim,@flex_tempo=flex_tempo,
@e1=m_entrada1,@s1=m_saida1,@e2=m_entrada2,@s2=m_saida2,
@e3=m_entrada3,@s3=m_saida3,@e4=m_entrada4,@s4=m_saida4,
@fxini=m_flex_ini, @fxfim=m_flex_fim, @fxtmp=m_flex_tempo
FROM tbFxPHorarios WHERE id_phorario = @id_phorario and wdia = @wdia;
end;
if @achou=1 begin
if @e1>-1 begin select @e1=@e1+1440; end; if @s1>-1 begin select @s1=@s1+1440; end;
if @e2>-1 begin select @e2=@e2+1440; end; if @s2>-1 begin select @s2=@s2+1440; end;
if @e3>-1 begin select @e3=@e3+1440; end; if @s3>-1 begin select @s3=@s3+1440; end;
if @e4>-1 begin select @e4=@e4+1440; end; if @s4>-1 begin select @s4=@s4+1440; end;
if @fxini>-1 begin select @fxini=@fxini+1440; end;
if @fxfim>-1 begin select @fxfim=@fxfim+1440; end;
if @s1>-1 and @e1>@s1 begin
if @fxini>=1440 and @fxini <=@s1 begin select @fxini=@fxini+1440; select @fxfim=@fxfim+1440; end;
if @fxfim>=1440 and @fxfim <=@s1 begin select @fxfim=@fxfim+1440; end;
select @s1=@s1+1440;
end;
if @e2>-1 and @s1>@e2 begin select @e2=@e2+1440; end;
if @s2>-1 and @e2>@s2 begin
if @fxini>=1440 and @fxini <=@s2 begin select @fxini=@fxini+1440; select @fxfim=@fxfim+1440; end;
if @fxfim>=1440 and @fxfim <=@s2 begin select @fxfim=@fxfim+1440; end;
select @s2=@s2+1440;
end;
if @e3>-1 and @s2>@e3 begin select @e3=@e3+1440; end;
if @s3>-1 and @e3>@s3 begin
if @fxini>=1440 and @fxini <=@s3 begin select @fxini=@fxini+1440; select @fxfim=@fxfim+1440; end;
if @fxfim>=1440 and @fxfim <=@s3 begin select @fxfim=@fxfim+1440; end;
select @s3=@s3+1440;
end;
if @e4>-1 and @s3>@e4 begin select @e4=@e4+1440; end;
if @s4>-1 and @e4>@s4 begin
if @fxini>=1440 and @fxini <=@s4 begin select @fxini=@fxini+1440; select @fxfim=@fxfim+1440; end;
if @fxfim>=1440 and @fxfim <=@s4 begin select @fxfim=@fxfim+1440; end;
select @s4=@s4+1440;
end;
if @s4>-1 and @s4 < @norm_ini begin select @e1=-1,@s1=-1, @e2=-1,@s2=-1, @e3=-1,@s3=-1, @e4=-1,@s4=-1;
end else begin if @e4>-1 and @e4 < @norm_ini begin select @e1=-1,@s1=-1, @e2=-1,@s2=-1, @e3=-1,@s3=-1, @e4=@norm_ini;
end else begin if @s3>-1 and @s3 < @norm_ini begin select @e1=-1,@s1=-1, @e2=-1,@s2=-1, @e3=-1,@s3=-1;
end else begin if @e3>-1 and @e3 < @norm_ini begin select @e1=-1,@s1=-1, @e2=-1,@s2=-1, @e3=@norm_ini;
end else begin if @s2>-1 and @s2 < @norm_ini begin select @e1=-1,@s1=-1, @e2=-1,@s2=-1;
end else begin if @e2>-1 and @e2 < @norm_ini begin select @e1=-1,@s1=-1, @e2=@norm_ini;
end else begin if @s1>-1 and @s1 < @norm_ini begin select @e1=-1,@s1=-1;
end else begin if @e1>-1 and @e1 < @norm_ini begin select @e1=@norm_ini;
end; end; end; end; end; end; end; end;
if @e1>-1 and @e1 > @norm_fim begin select @e1=-1,@s1=-1, @e2=-1,@s2=-1, @e3=-1,@s3=-1, @e4=-1,@s4=-1;
end else begin if @s1>-1 and @s1 > @norm_fim begin select @s1=@norm_fim, @e2=-1,@s2=-1, @e3=-1,@s3=-1, @e4=-1,@s4=-1;
end else begin if @e2>-1 and @e2 > @norm_fim begin select @e2=-1,@s2=-1, @e3=-1,@s3=-1, @e4=-1,@s4=-1;
end else begin if @s2>-1 and @s2 > @norm_fim begin select @s2=@norm_fim, @e3=-1,@s3=-1, @e4=-1,@s4=-1;
end else begin if @e3>-1 and @e3 > @norm_fim begin select @e3=-1,@s3=-1, @e4=-1,@s4=-1;
end else begin if @s3>-1 and @s3 > @norm_fim begin select @s3=@norm_fim, @e4=-1,@s4=-1;
end else begin if @e4>-1 and @e4 > @norm_fim begin select @e4=-1,@s4=-1;
end else begin if @s4>-1 and @s4 > @norm_fim begin select @s4=@norm_fim;
end; end; end; end; end; end; end; end;
if (@fxfim>-1 and @fxfim < @norm_ini) or (@fxini>-1 and @fxini > @norm_fim) or
(@fxfim>-1 and @fxfim > @norm_fim) or (@fxini>-1 and @fxini < @norm_ini) begin
select @fxini=-1,@fxfim=-1,@fxtmp=0;
end;
EXEC AP_PTO002 @e1, 0, @entrada1 output; EXEC AP_PTO002 @s1, 0, @saida1 output;
EXEC AP_PTO002 @e2, 0, @entrada2 output; EXEC AP_PTO002 @s2, 0, @saida2 output;
EXEC AP_PTO002 @e3, 0, @entrada3 output; EXEC AP_PTO002 @s3, 0, @saida3 output;
EXEC AP_PTO002 @e4, 0, @entrada4 output; EXEC AP_PTO002 @s4, 0, @saida4 output;
EXEC AP_PTO002 @fxini, 0, @flex_ini output; EXEC AP_PTO002 @fxfim, 0, @flex_fim output;
EXEC AP_PTO002 @fxtmp, 0, @flex_tempo output;
if @e1>-1 and @s1>-1 begin select @m_hrs_prev=@m_hrs_prev+(@s1-@e1); end;
if @e2>-1 and @s2>-1 begin select @m_hrs_prev=@m_hrs_prev+(@s2-@e2); end;
if @e3>-1 and @s3>-1 begin select @m_hrs_prev=@m_hrs_prev+(@s3-@e3); end;
if @e4>-1 and @s4>-1 begin select @m_hrs_prev=@m_hrs_prev+(@s4-@e4); end;
if @fxfim>-1 and @fxfim>-1 and @fxtmp>0 begin select @m_hrs_prev=@m_hrs_prev-@fxtmp; end;
if @m_hrs_prev>0 begin EXEC AP_PTO003 @m_hrs_prev, @hrs_prev output; end;
end;
end;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO008') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO008; END
GO
CREATE PROCEDURE dbo.AP_PTO008(@id_pass int output, @data datetime output, @m_nova_marc int = null) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_empresa int;
declare @TrocaHor Bit;   declare @TipoHE char(1);
declare @id_horario int; declare @descFeriado varchar(20);
declare @descEveAbo varchar(30);
declare @descHorPto varchar(100); declare @descHorAce varchar(50);
declare @achou bit; declare @wdia tinyint;
declare @tipodia char(1); declare @id_eveabo int; declare @id_tolera int;
declare @horas_abono varchar(7); declare @m_horas_abono int;
declare @id_eveafa int; declare @folga int; declare @id_phorario int;
declare @descAfast varchar(30);
declare @id_arredonda int; declare @id_dsr int;
declare @id_he int; declare @id_adicional int;
declare @id_hnormais int; declare @flexivel bit;  declare @trabalhado bit;
declare @id_tabbco int;
declare @admissao bit; declare @demissao bit;
declare @entrada1 varchar(6); declare @saida1 varchar(6);
declare @entrada2 varchar(6); declare @saida2 varchar(6);
declare @entrada3 varchar(6); declare @saida3 varchar(6);
declare @entrada4 varchar(6); declare @saida4 varchar(6);
declare @flex_ini varchar(6); declare @flex_fim varchar(6);
declare @flex_tempo varchar(6);
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int;
declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int;
declare @fxini int; declare @fxfim int; declare @fxtmp int;
declare @obs varchar(30); declare @hrs_prev varchar(7); declare @m_hrs_prev int;
declare @norm_ini int; declare @norm_fim int;
declare @dtseguinte datetime; declare @trab_seg bit; declare @categoria tinyint;
declare @cod_cid varchar(10), @cod_cid_a varchar(10);
select top 1 @id_empresa=id_empresa from tbPass where id_pass = @id_pass;
select @wdia = DATEPART(dw,@data);
select @cod_cid='', @cod_cid_a='';
EXEC AP_PTO005 @data, @id_empresa, @id_pass, @tipodia out, @TrocaHor out, @TipoHE out, @id_eveabo out, @id_phorario out, @id_horario out, @descFeriado out, @descEveAbo out, @horas_abono out, @m_horas_abono out, @folga out, @m_nova_marc;
select @flexivel = 0;
SELECT top 1 @flexivel = 1 from tbPGHorarios where id_phorario = @id_phorario and tipo = 'F';
select @id_eveafa = 0, @descAfast='';
SELECT top 1 @id_eveafa = id_eveabo, @cod_cid_a=cid FROM tbAfast
WHERE id_pass = @id_pass
AND @data BETWEEN convert(datetime,convert(varchar,isnull(dataini,'00:00:00'),101))
AND convert(datetime,convert(varchar,isnull(datafim,'00:00:00'),101));
if @id_eveafa>0 begin
select @descAfast='Afastado';
SELECT @descAfast=descricao FROM tbEvsAbono WHERE id_eveabo=@id_eveafa;
end;
select @categoria=0;
SELECT top 1 @id_arredonda=isnull(id_arredonda,0),
@id_dsr=isnull(id_dsr,0),
@id_he=isnull(id_he,0),
@id_adicional=isnull(id_adicional,0),
@id_hnormais=isnull(id_hnormais,0),
@id_tolera=isnull(id_tolera,0),
@categoria=isnull(categoria,0),
@id_tabbco=isnull((CASE WHEN banco=1 THEN id_tabbco ELSE 0 END),0)
FROM tbFunc WHERE id_pass=@id_pass;
SELECT top 1 @id_he=id_tab FROM tbHistTab WHERE id_pass = @id_pass and data >= @data and tabela=1 ORDER BY data asc;
SELECT top 1 @id_dsr=id_tab FROM tbHistTab WHERE id_pass = @id_pass and data >= @data and tabela=2 ORDER BY data asc;
SELECT top 1 @id_adicional=id_tab FROM tbHistTab WHERE id_pass = @id_pass and data >= @data and tabela=3 ORDER BY data asc;
SELECT top 1 @id_hnormais=id_tab FROM tbHistTab WHERE id_pass = @id_pass and data >= @data and tabela=4 ORDER BY data asc;
SELECT top 1 @id_arredonda=id_tab FROM tbHistTab WHERE id_pass = @id_pass and data >= @data and tabela=5 ORDER BY data asc;
SELECT top 1 @id_tolera=id_tab FROM tbHistTab WHERE id_pass = @id_pass and data >= @data and tabela=6 ORDER BY data asc;
SELECT top 1 @id_tabbco=id_tab FROM tbHistTab WHERE id_pass = @id_pass and data >= @data and tabela=7 ORDER BY data asc;
select @trabalhado = 0;
if @folga=0 and @id_eveafa=0 and (@tipodia='N' or @tipodia='A' or @tipodia='C' or @tipodia='V' or @tipodia='P') and isnull(@id_phorario,0) > 0 begin
select @trabalhado = 1;
if @flexivel = 0 begin
if not exists(SELECT m_entrada1 FROM tbFxPHorarios WHERE id_phorario=@id_phorario AND wdia=@wdia AND m_entrada1 > -1) begin select @trabalhado = 0; end;
if @tipodia = 'V' or @tipodia = 'P' begin
if not exists(SELECT feriado_normal FROM tbPHorarios WHERE id_phorario=@id_phorario AND feriado_normal=1) begin
if not exists(SELECT feriado_normal FROM tbFunc WHERE id_pass=@id_pass AND isnull(feriado_normal,0)=1 AND categoria=1 ) begin
select @trabalhado = 0;
end;
end;
end;
end else begin
if (@tipodia = 'V' or @tipodia = 'P') and not exists(SELECT feriado_normal FROM tbFunc WHERE id_pass=@id_pass AND isnull(feriado_normal,0)=1 AND categoria=1 ) begin
if not exists(SELECT id_pflex FROM tbPHorFlex WHERE id_pflex = @id_phorario AND SUBSTRING(dias_normais,8,1) = '1') begin
select @trabalhado = 0;
end;
end else begin
if not exists(SELECT id_pflex FROM tbPHorFlex WHERE id_pflex = @id_phorario AND SUBSTRING(dias_normais,@wdia,1) = '1') begin
select @trabalhado = 0;
end;
end;
end;
end;
select @admissao = 0, @demissao = 0;
SELECT @admissao = 1 FROM tbFunc WHERE id_pass = @id_pass and admissao > @data;
SELECT @demissao = 1 FROM tbFunc WHERE id_pass = @id_pass and dtdemissao <= @data;
if @admissao=1 or @demissao=1 begin select @trabalhado = 0; end;
select @norm_ini=0, @norm_fim=4320;
if @trabalhado=0 begin select @norm_ini=-1, @norm_fim=-1; end;
select @entrada1='__:__',@saida1='__:__',@entrada2='__:__',@saida2='__:__';
select @entrada3='__:__',@saida3='__:__',@entrada4='__:__',@saida4='__:__';
select @flex_ini='__:__',@flex_fim='__:__',@flex_tempo='__:__';
select @e1=-1,@s1=-1,@e2=-1,@s2=-1,@e3=-1,@s3=-1,@e4=-1,@s4=-1;
select @fxini=-1,@fxfim=-1,@fxtmp=0;
select @m_hrs_prev=0, @hrs_prev='  00:00';
EXEC AP_PTO007 @id_phorario, @wdia, @norm_ini, @norm_fim,
@e1 output, @s1 output, @e2 output, @s2 output, @e3 output,@s3 output,
@e4 output, @s4 output, @fxini output, @fxfim output, @fxtmp output,
@entrada1 output, @saida1 output, @entrada2 output, @saida2 output,
@entrada3 output, @saida3 output, @entrada4 output, @saida4 output,
@flex_ini output, @flex_fim output, @flex_tempo output, @hrs_prev output, @m_hrs_prev output;
if @flexivel = 1 begin
select @m_hrs_prev=0, @hrs_prev='  00:00';
if @trabalhado = 1 begin
SELECT TOP 1 @m_hrs_prev=(CASE WHEN @wdia=1 THEN m_diario_dm WHEN @wdia=3 THEN m_diario_tr
WHEN @wdia=4 THEN m_diario_qa WHEN @wdia=5 THEN m_diario_qi WHEN @wdia=6 THEN m_diario_sx
WHEN @wdia=7 THEN m_diario_sb ELSE m_diario_sg END) FROM tbPHorFlex
WHERE id_pflex = @id_phorario AND apura_tipo = 0;
if @m_hrs_prev>0 begin EXEC AP_PTO003 @m_hrs_prev, @hrs_prev output; end;
end;
end;
select @obs='';
If @admissao=1 begin
select @obs = 'ADMISSO';
end else if @demissao=1 begin
select @obs = 'DEMISSO';
end else if isnull(@id_eveafa,0)>0 begin
select @obs = @descAfast;
end else if @tipodia = 'V' begin
select @obs = 'Feriado: ' + lTrim(@descFeriado);
end else if @tipodia = 'F' Or @tipodia = 'A' begin
select @obs = lTrim(@descEveAbo)
end else if @tipodia = 'P' begin
select @obs = 'Ponte';
end else if @folga=1 or (@categoria=1 and @trabalhado=0) begin
select @obs = 'Folga';
end else if @trabalhado=0 begin
If @wdia = 1 begin
select @obs = 'Domingo';
end else if @wdia = 7 begin
select @obs = 'Sbado';
end else begin
select @obs = 'Folga';
end;
end else if @tipodia = 'C' begin
select @obs = 'Compensar';
end;
if len(isnull(@cod_cid_a,'')) > 0 begin
select @cod_cid=@cod_cid_a;
end else begin
SELECT TOP 1 @cod_cid=isnull(cid,'') FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data ORDER BY cid DESC;
if len(isnull(@cod_cid,'')) = 0 begin
SELECT TOP 1 @cod_cid=isnull(cid,'') FROM tbCalendario WHERE id_pass=@id_pass AND data=@data;
end;
end;
if len(isnull(@cod_cid,''))>0 begin
IF NOT EXISTS(SELECT id_pass FROM tbPtoCIDDia WHERE id_pass=@id_pass AND data=@data) begin
INSERT INTO tbPtoCIDDia (id_pass,data,cid) VALUES (@id_pass, @data, @cod_cid);
end else begin
UPDATE tbPtoCIDDia SET cid=@cod_cid WHERE id_pass=@id_pass AND data=@data;
end;
end else begin
UPDATE tbPtoCIDDia SET cid='' WHERE id_pass=@id_pass AND data=@data;
end;
if not exists(SELECT id_pass FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoDia (id_pass,data,tipodia,tipohe,trabalhado,id_eveabo,horas_abono,m_horas_abono,id_eveafa,folga,id_phorario,id_arredonda,id_dsr,id_he,id_adicional,id_hnormais,flexivel,desc_feriado, admissao, demissao,
entrada1,saida1,entrada2,saida2,entrada3,saida3,entrada4,saida4,
flex_ini,flex_fim,flex_tempo,e1,s1,e2,s2,e3,s3,e4,s4,fxini,fxfim,fxtmp,m_hrs_prev,hrs_prev,obs, norm_ini, norm_fim, id_tolera, apontado, id_tabbco
)
VALUES (@id_pass,@data,@tipodia,@TipoHE,@trabalhado,@id_eveabo,@horas_abono,@m_horas_abono,@id_eveafa,@folga,@id_phorario,@id_arredonda,@id_dsr,@id_he,@id_adicional,@id_hnormais,@flexivel,@descFeriado, @admissao, @demissao,
@entrada1,@saida1,@entrada2,@saida2, @entrada3,@saida3,@entrada4,@saida4,
@flex_ini,@flex_fim,@flex_tempo, @e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@fxini,@fxfim,@fxtmp,@m_hrs_prev,@hrs_prev,@obs,@norm_ini,@norm_fim,@id_tolera,0, @id_tabbco
);
end else begin
UPDATE tbPtoDia SET tipodia=@tipodia,tipohe=@TipoHE,trabalhado=@trabalhado,id_eveabo=@id_eveabo,horas_abono=@horas_abono,m_horas_abono=@m_horas_abono,
id_eveafa=@id_eveafa,folga=@folga,id_phorario=@id_phorario,id_arredonda=@id_arredonda,id_dsr=@id_dsr,id_he=@id_he,
id_adicional=@id_adicional,id_hnormais=@id_hnormais,flexivel=@flexivel,desc_feriado=@descFeriado, admissao=@admissao, demissao=@demissao,
entrada1=@entrada1,saida1=@saida1,entrada2=@entrada2,saida2=@saida2,entrada3=@entrada3,saida3=@saida3,entrada4=@entrada4,saida4=@saida4,
flex_ini=@flex_ini,flex_fim=@flex_fim,flex_tempo=@flex_tempo,e1=@e1,s1=@s1,e2=@e2,s2=@s2,e3=@e3,s3=@s3,e4=@e4,s4=@s4,fxini=@fxini,fxfim=@fxfim,fxtmp=@fxtmp,
m_hrs_prev=@m_hrs_prev,hrs_prev=@hrs_prev,obs=@obs,norm_ini=@norm_ini,norm_fim=@norm_fim,id_tolera=@id_tolera,id_tabbco=@id_tabbco
WHERE id_pass = @id_pass AND data = @data;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO009') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO009; END;
GO
CREATE PROCEDURE dbo.AP_PTO009(@id_pass int output, @data datetime output, @reproc bit, @m_nova_marc int = null) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
if not @id_pass is null and not @data is null begin
if @reproc=1 OR NOT EXISTS(SELECT id_pass FROM tbPtoDia WHERE id_pass=@id_pass AND data=@data) begin
EXEC AP_PTO008 @id_pass output, @data output, @m_nova_marc;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO010') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO010; END;
GO
CREATE PROCEDURE dbo.AP_PTO010(@m_ent01 int output, @m_sai01 int output, @m_ent02 int output, @m_sai02 int output,
@m_ent03 int output, @m_sai03 int output, @m_ent04 int output, @m_sai04 int output,
@m_ent05 int output, @m_sai05 int output, @m_ent06 int output, @m_sai06 int output,
@m_ent07 int output, @m_sai07 int output, @m_ent08 int output, @m_sai08 int output
) WITH ENCRYPTION AS
BEGIN
declare @i tinyint;
select @i=0;
while (@i<7) begin
if @m_ent01=-1 begin select @m_ent01 = @m_sai01; select @m_sai01=-1; end;
if @m_sai01=-1 begin select @m_sai01 = @m_ent02; select @m_ent02=-1; end;
if @m_ent02=-1 begin select @m_ent02 = @m_sai02; select @m_sai02=-1; end;
if @m_sai02=-1 begin select @m_sai02 = @m_ent03; select @m_ent03=-1; end;
if @m_ent03=-1 begin select @m_ent03 = @m_sai03; select @m_sai03=-1; end;
if @m_sai03=-1 begin select @m_sai03 = @m_ent04; select @m_ent04=-1; end;
if @m_ent04=-1 begin select @m_ent04 = @m_sai04; select @m_sai04=-1; end;
if @m_sai04=-1 begin select @m_sai04 = @m_ent05; select @m_ent05=-1; end;
if @m_ent05=-1 begin select @m_ent05 = @m_sai05; select @m_sai05=-1; end;
if @m_sai05=-1 begin select @m_sai05 = @m_ent06; select @m_ent06=-1; end;
if @m_ent06=-1 begin select @m_ent06 = @m_sai06; select @m_sai06=-1; end;
if @m_sai06=-1 begin select @m_sai06 = @m_ent07; select @m_ent07=-1; end;
if @m_ent08=-1 begin select @m_ent08 = @m_sai08; select @m_sai08=-1; end;
select @i=@i+1;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO011') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO011; END;
GO
CREATE PROCEDURE dbo.AP_PTO011(@data datetime, @m_marc int, @marc datetime output) WITH ENCRYPTION AS
BEGIN
select @m_marc = isnull(@m_marc,-1);
if @m_marc < 0 begin
select @marc = null;
end else begin
select @marc = dateadd(n,@m_marc-1440,@data);
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO012') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO012; END;
GO
CREATE PROCEDURE dbo.AP_PTO012(@id_pass int output, @data datetime output, @m_marc int,
@m_ent01 int output, @m_sai01 int output, @m_ent02 int output, @m_sai02 int output,
@m_ent03 int output, @m_sai03 int output, @m_ent04 int output, @m_sai04 int output,
@m_ent05 int output, @m_sai05 int output, @m_ent06 int output, @m_sai06 int output,
@m_ent07 int output, @m_sai07 int output, @m_ent08 int output, @m_sai08 int output,
@temmult bit output, @ver_multiplas bit) WITH ENCRYPTION AS
BEGIN
declare @batidas_multiplas tinyint;
select @temmult=0, @batidas_multiplas=0;
if @ver_multiplas=1 begin
SELECT @batidas_multiplas=e.batidas_multiplas FROM tbEmpresas e INNER JOIN tbPass p ON p.id_empresa = e.id_empresa AND p.id_pass = @id_pass;
if isnull(@batidas_multiplas,0) > 0 begin
if (@m_ent01 > -1 and abs(@m_ent01 - @m_marc) < @batidas_multiplas) or
(@m_sai01 > -1 and abs(@m_sai01 - @m_marc) < @batidas_multiplas) or
(@m_ent02 > -1 and abs(@m_ent02 - @m_marc) < @batidas_multiplas) or
(@m_sai02 > -1 and abs(@m_sai02 - @m_marc) < @batidas_multiplas) or
(@m_ent03 > -1 and abs(@m_ent03 - @m_marc) < @batidas_multiplas) or
(@m_sai03 > -1 and abs(@m_sai03 - @m_marc) < @batidas_multiplas) or
(@m_ent04 > -1 and abs(@m_ent04 - @m_marc) < @batidas_multiplas) or
(@m_sai04 > -1 and abs(@m_sai04 - @m_marc) < @batidas_multiplas) or
(@m_ent05 > -1 and abs(@m_ent05 - @m_marc) < @batidas_multiplas) or
(@m_sai05 > -1 and abs(@m_sai05 - @m_marc) < @batidas_multiplas) or
(@m_ent06 > -1 and abs(@m_ent06 - @m_marc) < @batidas_multiplas) or
(@m_sai06 > -1 and abs(@m_sai06 - @m_marc) < @batidas_multiplas) or
(@m_ent07 > -1 and abs(@m_ent07 - @m_marc) < @batidas_multiplas) or
(@m_sai07 > -1 and abs(@m_sai07 - @m_marc) < @batidas_multiplas) or
(@m_ent08 > -1 and abs(@m_ent08 - @m_marc) < @batidas_multiplas) or
(@m_sai08 > -1 and abs(@m_sai08 - @m_marc) < @batidas_multiplas) begin
select @temmult = 1;
end;
end;
end;
if @temmult = 0 begin
if @m_ent01 = -1 or @m_ent01 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_ent04; select @m_ent04=@m_sai03; select @m_sai03=@m_ent03; select @m_ent03=@m_sai02;
select @m_sai02 = @m_ent02; select @m_ent02=@m_sai01; select @m_sai01=@m_ent01; select @m_ent01=@m_marc;
end else begin if @m_sai01 = -1 or @m_sai01 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_ent04; select @m_ent04=@m_sai03; select @m_sai03=@m_ent03; select @m_ent03=@m_sai02;
select @m_sai02 = @m_ent02; select @m_ent02=@m_sai01; select @m_sai01=@m_marc;
end else begin if @m_ent02 = -1 or @m_ent02 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_ent04; select @m_ent04=@m_sai03; select @m_sai03=@m_ent03; select @m_ent03=@m_sai02;
select @m_sai02 = @m_ent02; select @m_ent02=@m_marc;
end else begin if @m_sai02 = -1 or @m_sai02 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_ent04; select @m_ent04=@m_sai03; select @m_sai03=@m_ent03; select @m_ent03=@m_sai02;
select @m_sai02 = @m_marc;
end else begin if @m_ent03 = -1 or @m_ent03 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_ent04; select @m_ent04=@m_sai03; select @m_sai03=@m_ent03; select @m_ent03=@m_marc;
end else begin if @m_sai03 = -1 or @m_sai03 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_ent04; select @m_ent04=@m_sai03; select @m_sai03=@m_marc;
end else begin if @m_ent04 = -1 or @m_ent04 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_ent04; select @m_ent04=@m_marc;
end else begin if @m_sai04 = -1 or @m_sai04 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_sai04;
select @m_sai04 = @m_marc;
end else begin if @m_ent05 = -1 or @m_ent05 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_ent05; select @m_ent05=@m_marc;
end else begin if @m_sai05 = -1 or @m_sai05 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_sai05; select @m_sai05=@m_marc;
end else begin if @m_ent06 = -1 or @m_ent06 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_ent06; select @m_ent06=@m_marc;
end else begin if @m_sai06 = -1 or @m_sai06 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_sai06;
select @m_sai06 = @m_marc;
end else begin if @m_ent07 = -1 or @m_ent07 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_ent07; select @m_ent07=@m_marc;
end else begin if @m_sai07 = -1 or @m_sai07 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_sai07; select @m_sai07=@m_marc;
end else begin if @m_ent08 = -1 or @m_ent08 >= @m_marc begin
select @m_sai08 = @m_ent08; select @m_ent08=@m_marc;
end else begin
select @m_sai08=@m_marc;
end;end;end;end;end;end;end;end;end;end;end;end;end;end;end;
end;
END;
GO
IF EXISTS(SELECT xtype FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO013') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO013; END;
GO
CREATE PROCEDURE dbo.AP_PTO013(@mc int,@e1 int, @s1 int, @e2 int, @s2 int, @e3 int, @s3 int, @e4 int, @s4 int, @e5 int, @s5 int, @psi tinyint output) WITH ENCRYPTION AS
BEGIN
declare @dif int
select @psi=99;
if @mc>-1 and @e1>-1 begin
select @psi=1; select @dif = abs(@mc-@e1);
if @s1>-1 and @dif > abs(@mc-@s1) begin select @psi=2; select @dif = abs(@mc-@s1); end;
if @e2>-1 and @dif > abs(@mc-@e2) begin select @psi=3; select @dif = abs(@mc-@e2); end;
if @s2>-1 and @dif > abs(@mc-@s2) begin select @psi=4; select @dif = abs(@mc-@s2); end;
if @e3>-1 and @dif > abs(@mc-@e3) begin select @psi=5; select @dif = abs(@mc-@e3); end;
if @s3>-1 and @dif > abs(@mc-@s3) begin select @psi=6; select @dif = abs(@mc-@s3); end;
if @e4>-1 and @dif > abs(@mc-@e4) begin select @psi=7; select @dif = abs(@mc-@e4); end;
if @s4>-1 and @dif > abs(@mc-@s4) begin select @psi=8; select @dif = abs(@mc-@s4); end;
if @e5>-1 and @dif > abs(@mc-@e5) begin select @psi=9; select @dif = abs(@mc-@e5); end;
if @s5>-1 and @dif > abs(@mc-@s5) begin select @psi=10; select @dif = abs(@mc-@s5); end;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO014') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO014; END;
GO
CREATE PROCEDURE dbo.AP_PTO014(@qtdeMov int, @psiIni int,
@m_ent01 int output,@m_sai01 int output,@m_ent02 int output,@m_sai02 int output,
@m_ent03 int output,@m_sai03 int output,@m_ent04 int output,@m_sai04 int output,
@m_ent05 int output,@m_sai05 int output,@m_ent06 int output,@m_sai06 int output,
@m_ent07 int output,@m_sai07 int output,@m_ent08 int output,@m_sai08 int output
) WITH ENCRYPTION AS
BEGIN
declare @i tinyint;
if @psiIni >0 and @qtdeMov > 0 begin
select @i=0;
while (@i<@qtdeMov) begin
if @psiIni<16 begin select @m_sai08=@m_ent08; end else begin if @psiIni=16 begin select @m_sai08=-1; end; end;
if @psiIni<15 begin select @m_ent08=@m_sai07; end else begin if @psiIni=15 begin select @m_ent08=-1; end; end;
if @psiIni<14 begin select @m_sai07=@m_ent07; end else begin if @psiIni=14 begin select @m_sai07=-1; end; end;
if @psiIni<13 begin select @m_ent07=@m_sai06; end else begin if @psiIni=13 begin select @m_ent07=-1; end; end;
if @psiIni<12 begin select @m_sai06=@m_ent06; end else begin if @psiIni=12 begin select @m_sai06=-1; end; end;
if @psiIni<11 begin select @m_ent06=@m_sai05; end else begin if @psiIni=11 begin select @m_ent06=-1; end; end;
if @psiIni<10 begin select @m_sai05=@m_ent05; end else begin if @psiIni=10 begin select @m_sai05=-1; end; end;
if @psiIni<9 begin select @m_ent05=@m_sai04; end else begin if @psiIni=9 begin select @m_ent05=-1; end; end;
if @psiIni<8 begin select @m_sai04=@m_ent04; end else begin if @psiIni=8 begin select @m_sai04=-1; end; end;
if @psiIni<7 begin select @m_ent04=@m_sai03; end else begin if @psiIni=7 begin select @m_ent04=-1; end; end;
if @psiIni<6 begin select @m_sai03=@m_ent03; end else begin if @psiIni=6 begin select @m_sai03=-1; end; end;
if @psiIni<5 begin select @m_ent03=@m_sai02; end else begin if @psiIni=5 begin select @m_ent03=-1; end; end;
if @psiIni<4 begin select @m_sai02=@m_ent02; end else begin if @psiIni=4 begin select @m_sai02=-1; end; end;
if @psiIni<3 begin select @m_ent02=@m_sai01; end else begin if @psiIni=3 begin select @m_ent02=-1; end; end;
if @psiIni<2 begin select @m_sai01=@m_ent01; end else begin if @psiIni=2 begin select @m_sai01=-1; end; end;
if @psiIni<=1 begin select @m_ent01=-1; end;
select @i=@i+1;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO015') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO015; END;
GO
CREATE PROCEDURE dbo.AP_PTO015(@id_pass int output, @data datetime output,@marc datetime,@funcao tinyint, @ponto tinyint, @original bit = 1, @id_usuario int = null) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @contamc tinyint; declare @primeira datetime; declare @ultima datetime; declare @fmsaida bit;
declare @m_primeira int; declare @m_ultima int; declare @funcao_pri tinyint;
declare @m_ent01 int; declare @m_sai01 int; declare @m_ent02 int; declare @m_sai02 int;
declare @m_ent03 int; declare @m_sai03 int; declare @m_ent04 int; declare @m_sai04 int;
declare @m_ent05 int; declare @m_sai05 int; declare @m_ent06 int; declare @m_sai06 int;
declare @m_ent07 int; declare @m_sai07 int; declare @m_ent08 int; declare @m_sai08 int;
declare @ent01 varchar(5); declare @sai01 varchar(5); declare @ent02 varchar(5); declare @sai02 varchar(5);
declare @ent03 varchar(5); declare @sai03 varchar(5); declare @ent04 varchar(5); declare @sai04 varchar(5);
declare @ent05 varchar(5); declare @sai05 varchar(5); declare @ent06 varchar(5); declare @sai06 varchar(5);
declare @ent07 varchar(5); declare @sai07 varchar(5); declare @ent08 varchar(5); declare @sai08 varchar(5);
declare @temmult bit; declare @TipoHE char(1); declare @hrs_trab varchar(7); declare @m_hrs_trab int;
declare @achou as bit;
declare @id_phorario int; declare @flexivel bit; declare @trabalhado bit;
declare @m_marc int; declare @dtmc datetime;
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int;
declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int;
declare @e5 int; declare @s5 int; declare @psifx tinyint;
declare @fxini int; declare @fxfim int; declare @fxtmp int;
declare @psi1 tinyint; declare @psi2 tinyint; declare @mc int;
declare @pula int;
declare @tipo_enquadra int; declare @m_enquadra_limite int;
declare @m_enquadra_antes int; declare @m_enquadra_depois int;
declare @enquadra_funcao int;
declare @fxi int; declare @fxf int;
declare @ult_he_ent tinyint; declare @pri_he_sai tinyint;
select @dtmc = convert(datetime,convert(varchar,@marc,101));
EXEC AP_PTO001 @marc, @m_marc output;
SELECT @m_marc = @m_marc + (1440 * (datediff(d,@data,@dtmc) + 1));
if @original=1 begin
DELETE FROM tbPtoEnq WHERE id_pass = @id_pass AND data = @data AND original = 0;
end;
select @achou = 0 ;
SELECT top 1 @achou=1, @contamc=contamc, @primeira=primeira,
@ultima=ultima, @fmsaida=fmsaida, @m_primeira=m_primeira,
@m_ultima=m_ultima, @funcao_pri=funcao_pri,
@ent01=ent01,@sai01=sai01,@ent02=ent02,
@sai02=sai02,@ent03=ent03,@sai03=sai03,
@ent04=ent04,@sai04=sai04,@ent05=ent05,
@sai05=sai05,@ent06=ent06,@sai06=sai06,
@ent07=ent07,@sai07=sai07,@ent08=ent08,
@sai08=sai08,
@m_ent01=m_ent01,@m_sai01=m_sai01,@m_ent02=m_ent02,
@m_sai02=m_sai02,@m_ent03=m_ent03,@m_sai03=m_sai03,
@m_ent04=m_ent04,@m_sai04=m_sai04,@m_ent05=m_ent05,
@m_sai05=m_sai05,@m_ent06=m_ent06,@m_sai06=m_sai06,
@m_ent07=m_ent07,@m_sai07=m_sai07,@m_ent08=m_ent08,
@m_sai08=m_sai08,
@hrs_trab=hrs_trab, @m_hrs_trab=m_hrs_trab,
@ult_he_ent=ult_he_ent, @pri_he_sai=pri_he_sai
FROM tbPtoEnq WHERE id_pass = @id_pass AND data = @data AND original=@original;
if @achou = 0 begin
select @contamc = 0; select @fmsaida = 0;
select @m_ent01=-1; select @m_sai01=-1; select @m_ent02=-1; select @m_sai02=-1;
select @m_ent03=-1; select @m_sai03=-1; select @m_ent04=-1; select @m_sai04=-1;
select @m_ent05=-1; select @m_sai05=-1; select @m_ent06=-1; select @m_sai06=-1;
select @m_ent07=-1; select @m_sai07=-1; select @m_ent08=-1; select @m_sai08=-1;
select @m_primeira = -1; select @m_ultima=-1; select @funcao_pri=0;
select @hrs_trab='  00:00', @m_hrs_trab=0;
select @ult_he_ent=0, @pri_he_sai=0;
INSERT INTO tbPtoEnq(id_pass,data,contamc,m_primeira,m_ultima,primeira,ultima,fmsaida,
m_ent01,m_sai01,m_ent02,m_sai02,m_ent03,m_sai03,
m_ent04,m_sai04,m_ent05,m_sai05,m_ent06,m_sai06,m_ent07,m_sai07,m_ent08,
m_sai08,funcao_pri,hrs_trab,m_hrs_trab,original,fimper1,fimper2,fimper3,fimper4,iniflex,fimflex,
ult_he_ent, pri_he_sai, id_usuario, apontado)
VALUES (@id_pass, @data, @contamc, @m_primeira, @m_ultima, @primeira, @ultima, @fmsaida,
@m_ent01,@m_sai01,@m_ent02,@m_sai02,@m_ent03,@m_sai03,
@m_ent04,@m_sai04,@m_ent05,@m_sai05,@m_ent06,@m_sai06,
@m_ent07,@m_sai07,@m_ent08,@m_sai08,@funcao_pri,@hrs_trab,@m_hrs_trab,@original,0,0,0,0,0,0,
@ult_he_ent, @pri_he_sai, @id_usuario, 0);
end;
EXEC AP_PTO010 @m_ent01 output, @m_sai01 output, @m_ent02 output, @m_sai02 output,@m_ent03 output, @m_sai03 output, @m_ent04 output, @m_sai04 output,
@m_ent05 output, @m_sai05 output, @m_ent06 output, @m_sai06 output,@m_ent07 output, @m_sai07 output, @m_ent08 output, @m_sai08 output
EXEC AP_PTO012 @id_pass output, @data output, @m_marc,
@m_ent01 output, @m_sai01 output, @m_ent02 output, @m_sai02 output,@m_ent03 output, @m_sai03 output, @m_ent04 output, @m_sai04 output,
@m_ent05 output, @m_sai05 output, @m_ent06 output, @m_sai06 output,@m_ent07 output, @m_sai07 output, @m_ent08 output, @m_sai08 output, @temmult out, 1;
if @m_ent01 = @m_marc begin select @funcao_pri = @funcao; end;
select @m_primeira=@m_ent01; select @m_ultima=@m_primeira;
select @achou = 0;
SELECT top 1 @achou = 1, @id_phorario=id_phorario,@flexivel=flexivel,@trabalhado=trabalhado,@TipoHE=tipohe,
@e1=e1,@s1=s1,@e2=e2,@s2=s2,@e3=e3,@s3=s3,@e4=e4,@s4=s4,@fxini=fxini,@fxfim=fxfim,@fxtmp=fxtmp
FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data;
select @e5=-1,@s5=-1,@psifx=0;
if @achou = 1 begin
if @fxini>-1 begin
select @fxi=@fxini+((@fxfim-@fxini)/4);
select @fxf=@fxfim-(@fxi-@fxini);
if @s1>@fxf begin
select @psifx=1;
select @s5=@s4; select @e5=@e4;
select @s4=@s3; select @e4=@e3;
select @s3=@s2; select @e3=@e2;
select @s2=@s1;
select @s1=@fxi; select @e2=@fxf;
end else begin
if @s2>@fxf begin
select @psifx=2;
select @s5=@s4; select @e5=@e4;
select @s4=@s3; select @e4=@e3;
select @s3=@s2;
select @s2=@fxi; select @e3=@fxf;
end else begin
if @s3>@fxf begin
select @psifx=3;
select @s5=@s4; select @e5=@e4;
select @s4=@s3;
select @s3=@fxi; select @e4=@fxf;
end else begin
select @psifx=4; select @s5=@s4;
select @s4=@fxi; select @e5=@fxf;
end;
end;
end;
end;
end;
if @m_ent01 > -1 begin
if @flexivel = 0 begin
EXEC AP_PTO013 @m_ent01,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi1 output;
EXEC AP_PTO013 @m_sai01,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi2 output;
select @mc=1;
if @psi1<>99 begin
select @pula=0;
if @psi1 % 2 = 0 begin
if @psi1 < @mc begin select @psi1 = @mc; end;
if @psi2=@psi1 begin
if @psi2<>2 or @fxini<0 or (@m_ent01=-1 or @m_ent01<@fxini) or (@m_ent02>-1 and @m_ent02<=@fxfim)  begin
if @psi1-@mc>0 begin select @psi1=@psi1-1; end;
end else begin
select @pula=1;
end;
end;
if @psi2=99 or @psi2>@psi1 begin select @pula=@psi1-@mc; end;
if @pula<0 begin select @mc=@mc+1; if @psi2=99 begin select @pula=1; end else begin select @pula=@psi2-2; end; end;
end else begin
if @psi1>@mc begin
select @pula=@psi1-@mc;
if @pula=2 and @fxini>-1 and @fxfim>-1 and @m_sai01>=@fxini and @m_sai01<=@fxfim begin
select @pula=1;
end;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
select @mc=@mc+@pula+1; select @pula=0;
end else begin
select @mc=@mc+1;
end;
if @psi2<>99 and @psi2-@psi1>1 begin
select @pula=1;
if @fxini>-1 and @fxfim>-1 and @m_sai01>=@fxini and @m_sai01<=@fxfim begin
select @pula=0;
end;
end;
end;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
end;
EXEC AP_PTO013 @m_ent02,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi1 output;
EXEC AP_PTO013 @m_sai02,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi2 output;
select @mc=3;
if @psi1<>99 begin
select @pula=0;
if @psi1 % 2 = 0 begin
if @psi1 < @mc begin select @psi1 = @mc; end;
if @psi2=@psi1 and @psi1-@mc>0 begin select @psi1=@psi1-1; end;
if @psi2=99 or @psi2>@psi1 begin select @pula=@psi1-@mc; end;
if @pula<0 begin select @mc=@mc+1; if @psi2=99 begin select @pula=1; end else begin select @pula=@psi2-2; end; end;
end else begin
if @psi1>@mc begin
select @pula=@psi1-@mc;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
select @mc=@mc+@pula+1; select @pula=0;
end else begin
select @mc=@mc+1;
end;
if @psi2<>99 and @psi2-@psi1>1 begin
select @pula=1;
if @fxini>-1 and @fxfim>-1 and ((@m_sai02>=@fxini and @m_sai02<=@fxfim) or (@m_ent02>=@fxini and @m_ent02<=@fxfim)) begin
select @pula=0;
end;
end;
end;
if @pula=0 and @m_ent01>-1 and @m_sai01=-1 and @m_ent02>-1 and @m_ent02<@s2 and ((@fxfim=-1 and @m_ent02<=@e2) or (@fxfim>-1 and @m_ent02<=@fxfim))  begin
if @m_sai02=-1 or (@fxfim=-1 and @m_sai02<=@e2) or (@fxfim>-1 and @m_sai02<=@fxfim) begin
select @m_sai01=@m_ent02,@m_ent02=@m_sai02,@m_sai02=@m_ent03,@m_ent03=@m_sai03,
@m_sai03=@m_ent04,@m_ent04=@m_sai04,@m_sai04=@m_ent05,@m_ent05=@m_sai05,
@m_sai05=@m_ent06,@m_ent06=@m_sai06,@m_sai06=@m_ent07,@m_ent07=@m_sai07,
@m_sai07=@m_ent08,@m_ent08=@m_sai08,@m_sai08=-1;
end else begin
select @m_sai01=@m_ent02,@m_ent02=-1;
end;
end;
if @pula=0 begin
if @m_sai01>-1 and @m_ent02=-1 and @m_sai02>-1 begin
if @fxfim>-1 begin
if @m_sai01>@fxini+((@fxfim-@fxini)/2) and @m_sai01<=@fxfim begin select @m_ent02=@m_sai01, @m_sai01=-1 end;
end else if @e2>-1 begin
if @m_sai01>@s1+((@e2-@s1)/2) and @m_sai01<=@e2 begin select @m_ent02=@m_sai01, @m_sai01=-1 end;
end;
end;
end else if @pula=1 begin
if @m_sai01>-1 and @m_ent02>-1 and @m_sai02=-1 begin
if @fxfim>-1 begin
if @m_sai01>@fxini+((@fxfim-@fxini)/2) and @m_sai01<=@fxfim begin select @m_sai02=@m_ent02, @m_ent02=@m_sai01, @m_sai01=-1, @pula=0 end;
end else if @e2>-1 begin
if @m_sai01>@s1+((@e2-@s1)/2) and @m_sai01<=@e2 begin select @m_sai02=@m_ent02, @m_ent02=@m_sai01, @m_sai01=-1, @pula=0 end;
end;
end;
end;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
end;
EXEC AP_PTO013 @m_ent03,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi1 output;
EXEC AP_PTO013 @m_sai03,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi2 output;
select @mc=5;
if @psi1<>99 begin
select @pula=0;
if @psi1 % 2 = 0 begin
if @psi1 < @mc begin select @psi1 = @mc; end;
if @psi2=@psi1 and @psi1-@mc>0 begin select @psi1=@psi1-1; end;
if @psi2=99 or @psi2>@psi1 begin select @pula=@psi1-@mc; end;
if @pula<0 begin select @mc=@mc+1; if @psi2=99 begin select @pula=1; end else begin select @pula=@psi2-2; end; end;
end else begin
if @psi1>@mc begin
select @pula=@psi1-@mc;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
select @mc=@mc+@pula+1; select @pula=0;
end else begin
select @mc=@mc+1;
end;
if @psi2<>99 and @psi2-@psi1>1 begin
select @pula=1;
end;
end;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
end;
EXEC AP_PTO013 @m_ent04,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi1 output;
EXEC AP_PTO013 @m_sai04,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi2 output;
select @mc=7;
if @psi1<>99 begin
select @pula=0;
if @psi1 % 2 = 0 begin
if @psi1 < @mc begin select @psi1 = @mc; end;
if @psi2=@psi1 and @psi1-@mc>0 begin select @psi1=@psi1-1; end;
if @psi2=99 or @psi2>@psi1 begin select @pula=@psi1-@mc; end;
if @pula<0 begin select @mc=@mc+1; if @psi2=99 begin select @pula=1; end else begin select @pula=@psi2-2; end; end;
end else begin
if @psi1>@mc begin
select @pula=@psi1-@mc;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
select @mc=@mc+@pula+1; select @pula=0;
end else begin
select @mc=@mc+1;
end;
if @psi2<>99 and @psi2-@psi1>1 begin
select @pula=1;
end;
end;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
end;
EXEC AP_PTO013 @m_ent05,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi1 output;
EXEC AP_PTO013 @m_sai05,@e1,@s1,@e2,@s2,@e3,@s3,@e4,@s4,@e5,@s5,@psi2 output;
select @mc=9;
if @psi1<>99 begin
select @pula=0;
if @psi1 % 2 = 0 begin
if @psi1 < @mc begin select @psi1 = @mc; end;
if @psi2=@psi1 and @psi1-@mc>0 begin select @psi1=@psi1-1; end;
if @psi2=99 or @psi2>@psi1 begin select @pula=@psi1-@mc; end;
if @pula<0 begin select @mc=@mc+1; if @psi2=99 begin select @pula=1; end else begin select @pula=@psi2-2; end; end;
end else begin
if @psi1>@mc begin
select @pula=@psi1-@mc;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
select @mc=@mc+@pula+1; select @pula=0;
end else begin
select @mc=@mc+1;
end;
if @psi2<>99 and @psi2-@psi1>1 begin select @pula=1; end;
end;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
end;
end else begin
if @m_ent01 > - 1 begin
select @mc=1; select @pula=0;
select @tipo_enquadra=-1; select @m_enquadra_limite = -1; select @m_enquadra_antes=-1; select @m_enquadra_depois=-1; select @enquadra_funcao=-99;
SELECT @tipo_enquadra=tipo_enquadra, @m_enquadra_limite=m_enquadra_limite,
@m_enquadra_antes=m_enquadra_antes, @m_enquadra_depois=m_enquadra_depois,
@enquadra_funcao=enquadra_funcao
FROM tbPHorFlex WHERE id_pflex = @id_phorario;
select @tipo_enquadra=isnull(@tipo_enquadra,-1);
if @tipo_enquadra > -1 begin
if @tipo_enquadra=1 begin
--Fx Entra
select @m_enquadra_antes=@m_enquadra_antes+1440;
select @m_enquadra_depois=@m_enquadra_depois+1440;
if @m_enquadra_antes>@m_enquadra_depois begin select @m_enquadra_depois=@m_enquadra_depois+1440 end;
if @m_enquadra_antes >= 0 and not (@m_ent01 >= @m_enquadra_antes and @m_ent01 <= @m_enquadra_depois) begin
select @pula=1;
end;
end else begin if @tipo_enquadra=2 begin
if @funcao_pri <> @enquadra_funcao begin
--Fx Entra alternativa
if @m_enquadra_antes<=0 and @m_enquadra_depois<=0 begin
select @pula=1;
end else begin
select @m_enquadra_antes=@m_enquadra_antes+1440;
select @m_enquadra_depois=@m_enquadra_depois+1440;
if @m_enquadra_antes>@m_enquadra_depois begin select @m_enquadra_depois=@m_enquadra_depois+1440 end;
if @m_enquadra_antes >= 0 and not (@m_ent01 >= @m_enquadra_antes and @m_ent01 <= @m_enquadra_depois) begin
select @pula=1;
end;
end;
end;
end; end;
end;
EXEC AP_PTO014 @pula, @mc, @m_ent01 output,@m_sai01 output,@m_ent02 output,@m_sai02 output, @m_ent03 output,@m_sai03 output,@m_ent04 output,@m_sai04 output,
@m_ent05 output,@m_sai05 output,@m_ent06 output,@m_sai06 output,@m_ent07 output,@m_sai07 output,@m_ent08 output,@m_sai08 output;
end;
end;
end;
select @contamc = 0; select @fmsaida = 0;
if @m_ent01 > -1 begin select @contamc=2; select @m_ultima=@m_ent01; select @fmsaida = 1; end;
if @m_sai01 > -1 begin select @contamc=2; select @m_ultima=@m_sai01; select @fmsaida = 0; end;
if @m_ent02 > -1 begin select @contamc=4; select @m_ultima=@m_ent02; select @fmsaida = 1; end;
if @m_sai02 > -1 begin select @contamc=4; select @m_ultima=@m_sai02; select @fmsaida = 0; end;
if @m_ent03 > -1 begin select @contamc=6; select @m_ultima=@m_ent03; select @fmsaida = 1; end;
if @m_sai03 > -1 begin select @contamc=6; select @m_ultima=@m_sai03; select @fmsaida = 0; end;
if @m_ent04 > -1 begin select @contamc=8; select @m_ultima=@m_ent04; select @fmsaida = 1; end;
if @m_sai04 > -1 begin select @contamc=8; select @m_ultima=@m_sai04; select @fmsaida = 0; end;
if @m_ent05 > -1 begin select @contamc=10; select @m_ultima=@m_ent05; select @fmsaida = 1; end;
if @m_sai05 > -1 begin select @contamc=10; select @m_ultima=@m_sai05; select @fmsaida = 0; end;
if @m_ent06 > -1 begin select @contamc=12; select @m_ultima=@m_ent06; select @fmsaida = 1; end;
if @m_sai06 > -1 begin select @contamc=12; select @m_ultima=@m_sai06; select @fmsaida = 0; end;
if @m_ent07 > -1 begin select @contamc=14; select @m_ultima=@m_ent07; select @fmsaida = 1; end;
if @m_sai07 > -1 begin select @contamc=14; select @m_ultima=@m_sai07; select @fmsaida = 0; end;
if @m_ent08 > -1 begin select @contamc=16; select @m_ultima=@m_ent08; select @fmsaida = 1; end;
if @m_sai08 > -1 begin select @contamc=16; select @m_ultima=@m_sai08; select @fmsaida = 0; end;
EXEC AP_PTO011 @data, @m_primeira, @primeira output;
EXEC AP_PTO011 @data, @m_ultima, @ultima output;
if not @ultima is null begin select @ultima = dateadd(s,59,@ultima); end;
select @ent01=null, @sai01=null,@ent02=null, @sai02=null,@ent03=null, @sai03=null,@ent04=null, @sai04=null;
select @ent05=null, @sai05=null,@ent06=null, @sai06=null,@ent07=null, @sai07=null,@ent08=null, @sai08=null;
if @m_ent01>-1 or @m_sai01>-1 or @contamc>0 begin EXEC AP_PTO002 @m_ent01, 0, @ent01 output; EXEC AP_PTO002 @m_sai01, 0, @sai01 output; end;
if @m_ent02>-1 or @m_sai02>-1 or @contamc>2 begin EXEC AP_PTO002 @m_ent02, 0, @ent02 output; EXEC AP_PTO002 @m_sai02, 0, @sai02 output; end;
if @m_ent03>-1 or @m_sai03>-1 or @contamc>4 begin EXEC AP_PTO002 @m_ent03, 0, @ent03 output; EXEC AP_PTO002 @m_sai03, 0, @sai03 output; end;
if @m_ent04>-1 or @m_sai04>-1 or @contamc>6 begin EXEC AP_PTO002 @m_ent04, 0, @ent04 output; EXEC AP_PTO002 @m_sai04, 0, @sai04 output; end;
if @m_ent05>-1 or @m_sai05>-1 or @contamc>8 begin EXEC AP_PTO002 @m_ent05, 0, @ent05 output; EXEC AP_PTO002 @m_sai05, 0, @sai05 output; end;
if @m_ent06>-1 or @m_sai06>-1 or @contamc>10 begin EXEC AP_PTO002 @m_ent06, 0, @ent06 output; EXEC AP_PTO002 @m_sai06, 0, @sai06 output; end;
if @m_ent07>-1 or @m_sai07>-1 or @contamc>12 begin EXEC AP_PTO002 @m_ent07, 0, @ent07 output; EXEC AP_PTO002 @m_sai07, 0, @sai07 output; end;
if @m_ent08>-1 or @m_sai08>-1 or @contamc>14 begin EXEC AP_PTO002 @m_ent08, 0, @ent08 output; EXEC AP_PTO002 @m_sai08, 0, @sai08 output; end;
select @m_hrs_trab=0, @hrs_trab='  00:00';
if @m_ent01>-1 and @m_sai01>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai01-@m_ent01); end;
if @m_ent02>-1 and @m_sai02>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai02-@m_ent02); end;
if @m_ent03>-1 and @m_sai03>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai03-@m_ent03); end;
if @m_ent04>-1 and @m_sai04>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai04-@m_ent04); end;
if @m_ent05>-1 and @m_sai05>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai05-@m_ent05); end;
if @m_ent06>-1 and @m_sai06>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai06-@m_ent06); end;
if @m_ent07>-1 and @m_sai07>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai07-@m_ent07); end;
if @m_ent08>-1 and @m_sai08>-1 begin select @m_hrs_trab=@m_hrs_trab+(@m_sai08-@m_ent08); end;
EXEC AP_PTO003 @m_hrs_trab, @hrs_trab output;
UPDATE tbPtoEnq SET contamc=@contamc, primeira=@primeira,
ultima=@ultima, m_primeira=@m_primeira,
m_ultima=@m_ultima, fmsaida=@fmsaida,funcao_pri=@funcao_pri,
ent01=@ent01,sai01=@sai01,ent02=@ent02,
sai02=@sai02,ent03=@ent03,sai03=@sai03,
ent04=@ent04,sai04=@sai04,ent05=@ent05,
sai05=@sai05,ent06=@ent06,sai06=@sai06,
ent07=@ent07,sai07=@sai07,ent08=@ent08,
sai08=@sai08,
m_ent01=@m_ent01,m_sai01=@m_sai01,m_ent02=@m_ent02,
m_sai02=@m_sai02,m_ent03=@m_ent03,m_sai03=@m_sai03,
m_ent04=@m_ent04,m_sai04=@m_sai04,m_ent05=@m_ent05,
m_sai05=@m_sai05,m_ent06=@m_ent06,m_sai06=@m_sai06,
m_ent07=@m_ent07,m_sai07=@m_sai07,m_ent08=@m_ent08,
m_sai08=@m_sai08,
hrs_trab=@hrs_trab,m_hrs_trab=@m_hrs_trab,
ult_he_ent=@ult_he_ent, pri_he_sai=@pri_he_sai, id_usuario=@id_usuario,
apontado=0
WHERE id_pass = @id_pass AND data = @data AND original=@original;
UPDATE tbPtoDia SET afd_dia=0 WHERE id_pass=@id_pass AND data=@data;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO040') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO040; END;
GO
CREATE PROCEDURE dbo.AP_PTO040(@id_pass int output, @data datetime output,@marc datetime, @consulta tinyint output) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @m_ent01 int; declare @m_sai01 int; declare @m_ent02 int; declare @m_sai02 int;
declare @m_ent03 int; declare @m_sai03 int; declare @m_ent04 int; declare @m_sai04 int;
declare @m_ent05 int; declare @m_sai05 int; declare @m_ent06 int; declare @m_sai06 int;
declare @m_ent07 int; declare @m_sai07 int; declare @m_ent08 int; declare @m_sai08 int;
declare @temmult bit; declare @TipoHE char(1); declare @norm_ini int; declare @norm_fim int;
declare @achou as bit;
declare @id_phorario int; declare @flexivel bit;
declare @m_marc int; declare @dtmc datetime;
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int;
declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int;
declare @fxini int; declare @fxfim int; declare @fxtmp int;
declare @na_faixa int;
select @dtmc = convert(datetime,convert(varchar,@marc,101));
EXEC AP_PTO001 @marc, @m_marc output;
SELECT @m_marc = @m_marc + (1440 * (datediff(d,@data,@dtmc) + 1));
select @achou = 0 ;
SELECT top 1 @achou=1,
@m_ent01=m_ent01,@m_sai01=m_sai01,@m_ent02=m_ent02,@m_sai02=m_sai02,@m_ent03=m_ent03,@m_sai03=m_sai03,
@m_ent04=m_ent04,@m_sai04=m_sai04,@m_ent05=m_ent05,@m_sai05=m_sai05,@m_ent06=m_ent06,@m_sai06=m_sai06,
@m_ent07=m_ent07,@m_sai07=m_sai07,@m_ent08=m_ent08,@m_sai08=m_sai08
FROM tbPtoEnq WHERE id_pass = @id_pass AND data = @data AND original=1;
if @achou = 0 begin
select @m_ent01=-1, @m_sai01=-1, @m_ent02=-1, @m_sai02=-1, @m_ent03=-1, @m_sai03=-1, @m_ent04=-1, @m_sai04=-1;
select @m_ent05=-1, @m_sai05=-1, @m_ent06=-1, @m_sai06=-1, @m_ent07=-1, @m_sai07=-1, @m_ent08=-1, @m_sai08=-1;
end;
EXEC AP_PTO010 @m_ent01 output, @m_sai01 output, @m_ent02 output, @m_sai02 output,@m_ent03 output, @m_sai03 output, @m_ent04 output, @m_sai04 output,
@m_ent05 output, @m_sai05 output, @m_ent06 output, @m_sai06 output,@m_ent07 output, @m_sai07 output, @m_ent08 output, @m_sai08 output
EXEC AP_PTO012 @id_pass output, @data output, @m_marc,
@m_ent01 output, @m_sai01 output, @m_ent02 output, @m_sai02 output,@m_ent03 output, @m_sai03 output, @m_ent04 output, @m_sai04 output,
@m_ent05 output, @m_sai05 output, @m_ent06 output, @m_sai06 output,@m_ent07 output, @m_sai07 output, @m_ent08 output, @m_sai08 output, @temmult out, 1;
select @achou = 0;
SELECT top 1 @achou = 1, @id_phorario=id_phorario,@flexivel=flexivel,@TipoHE=isnull(tipohe,'N'),
@e1=e1,@s1=s1,@e2=e2,@s2=s2,@e3=e3,@s3=s3,@e4=e4,@s4=s4,@fxini=fxini,@fxfim=fxfim,@fxtmp=fxtmp,@norm_ini=norm_ini,@norm_fim=norm_fim
FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data;
select @na_faixa = 1;
if isnull(@temmult,0) = 1 begin
select @na_faixa = 5;
end else begin if ((@m_marc<@norm_ini and @norm_ini>-1) or (@m_marc>@norm_fim and @norm_fim>-1) or (@flexivel=0 and @e1=-1)) begin
if @TipoHE<>'P' begin select @na_faixa=2; end;
end; end;
if @na_faixa = 1 and @data<@dtmc begin
select @na_faixa = 3;
end;
select @consulta = @na_faixa;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO016') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO016; END
GO
CREATE PROCEDURE dbo.AP_PTO016(@id_pass int,  @marc datetime, @funcao tinyint, @ponto tinyint, @consulta tinyint output) WITH ENCRYPTION AS
BEGIN
declare @wdia tinyint;  declare @trabalhado bit;
declare @id_phorario int; declare @data datetime;
declare @flexivel bit;    declare @proximidade int;
declare @wdia_ant tinyint; declare @trabalhado_ant bit;
declare @id_phorario_ant int; declare @data_ant datetime;
declare @flexivel_ant bit; declare @proximidade_ant int; declare @fm_ant bit;
declare @wdia_dep tinyint; declare @trabalhado_dep bit;
declare @id_phorario_dep int; declare @data_dep datetime;
declare @flexivel_dep bit; declare @proximidade_dep int;
declare @EnqDia tinyint; declare @antes int; declare @depois int;
declare @e1 int;    declare @s1 int; declare @e2 int;    declare @s2 int;
declare @m_marc int; declare @tipo_enquadra int; declare @m_enquadra_limite int;
declare @m_enquadra_antes int; declare @m_enquadra_depois int;
declare @enquadra_funcao int;
declare @dif int, @mold_s1 int, @mold_e2 int, @mold_s2 int, @mold_e3 int;
declare @achou bit;
select @data = convert(datetime,convert(varchar,@marc,101));
select @data_ant = dateadd(d,-1,@data);
select @data_dep = dateadd(d,1,@data);
EXEC AP_PTO001 @marc, @m_marc output;
select @wdia = DATEPART(dw,@data);
select @wdia_ant = DATEPART(dw,@data_ant);
select @wdia_dep = DATEPART(dw,@data_ant);
select @EnqDia = 0;
SELECT top 1 @EnqDia = isnull((CASE WHEN data = @data_ant THEN 1 WHEN data = @data THEN 2 ELSE 3 END),0)
FROM tbPtoEnq WHERE id_pass = @id_pass
AND data BETWEEN @data_ant AND @data_dep AND @marc BETWEEN primeira AND ultima AND original = 1
ORDER BY data;
if @EnqDia = 0 begin
if exists(SELECT data FROM tbPtoEnq WHERE id_pass = @id_pass AND data = @data_ant AND @marc <= ultima AND original = 1) begin select @EnqDia = 1; end;
end;
if @EnqDia = 1 begin
EXEC AP_PTO009 @id_pass output, @data_ant output, 0;
SELECT @id_phorario_ant=isnull(id_phorario,0),@flexivel_ant=isnull(flexivel,0),@trabalhado_ant=isnull(trabalhado,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data_ant;
end;
if @EnqDia = 2 begin
EXEC AP_PTO009 @id_pass output, @data output, 0;
SELECT @id_phorario=isnull(id_phorario,0),@flexivel=isnull(flexivel,0),@trabalhado=isnull(trabalhado,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data;
end;
if @EnqDia = 3 begin
EXEC AP_PTO009 @id_pass output, @data_dep output, 0;
SELECT @id_phorario_dep=isnull(id_phorario,0),@flexivel_dep=isnull(flexivel,0),@trabalhado_dep=isnull(trabalhado,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data_dep;
end;
if @EnqDia = 0 begin
select @proximidade_ant = 99999, @fm_ant=0, @proximidade = 99999, @proximidade_dep = 99999;
if not exists(SELECT data FROM tbPtoEnq WHERE id_pass = @id_pass AND data = @data AND @marc > primeira AND original = 1) begin
EXEC AP_PTO009 @id_pass output, @data_ant output, 0;
SELECT @id_phorario_ant=isnull(id_phorario,0),@flexivel_ant=isnull(flexivel,0),@trabalhado_ant=isnull(trabalhado,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data_ant;
if @flexivel_ant = 0 and isnull(@id_phorario_ant,0) > 0 begin
select @depois=0; select @e1=0; select @s1=0
SELECT @depois=isnull(m_enquadra_depois,0) FROM tbPHorarios WHERE id_phorario = @id_phorario_ant;
SELECT @e1=m_entrada1,@s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3
WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1
ELSE -1 END) FROM tbFxPHorarios WHERE id_phorario = @id_phorario_ant AND wdia=@wdia_ant;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
if isnull(@s1,-1) < 0 begin select @s1=0; end;
if (@e1=0 and @s1=0) begin
SELECT TOP 1 @e1=m_entrada1,@s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3
WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1
ELSE -1 END) FROM tbFxPHorarios WHERE id_phorario = @id_phorario_ant;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
if isnull(@s1,-1) < 0 begin select @s1=0; end;
end;
select @s2=(@s1 + @depois); if @s2 > 1440 begin select @s2 = @s2 - 1440; end;
if (@e1 > @s2) and (@m_marc <= @s2) begin
select @proximidade_ant = 0;
end else begin
if @e1 > @s1 begin
select @proximidade_ant = @m_marc-@s1;
end else begin
select @proximidade_ant = @m_marc+1440-@s1;
end;
end;
--FM anterior
select @achou=0, @dif=0;
SELECT @achou=1, @dif=abs((@m_marc+2880)-m_ultima)
FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data_ant AND m_ultima>-1 AND original=1 AND fmsaida=1;
if (@achou=1 AND @dif>0 AND @dif<720) begin
select @fm_ant=1, @proximidade_ant = 0;
end;
end else begin
if @flexivel_ant = 1
begin
select @tipo_enquadra=-1; select @m_enquadra_limite = -1; select @m_enquadra_antes=-1; select @m_enquadra_depois=-1; select @enquadra_funcao=-99;
SELECT @tipo_enquadra=tipo_enquadra, @m_enquadra_limite=m_enquadra_limite,
@m_enquadra_antes=m_enquadra_antes, @m_enquadra_depois=m_enquadra_depois,
@enquadra_funcao=enquadra_funcao
FROM tbPHorFlex WHERE id_pflex = @id_phorario_ant;
select @tipo_enquadra=isnull(@tipo_enquadra,-1);
if @tipo_enquadra > -1 begin
if @tipo_enquadra=0 begin
select @achou=0;
SELECT @achou=1, @dif=abs((@m_marc+2880)-m_ultima), @mold_s1=m_sai01, @mold_e2=m_ent02, @mold_s2=m_sai02, @mold_e3=m_ent03
FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data_ant AND m_ultima>-1 AND original=1;
if @achou=1 and @dif>-1 and @dif <= @m_enquadra_limite begin
if @dif<240 or (@mold_s1=-1 and @mold_e2=-1 and @mold_s2=-1) begin
select @proximidade_ant = 0;
end else if (@mold_e2>-1 and @mold_s2=-1) or (@mold_e3>-1) begin
select @proximidade_ant = 0;
end;
end;
end else begin if @tipo_enquadra=1 begin
select @m_enquadra_antes=@m_enquadra_antes+1440;
select @m_enquadra_depois=@m_enquadra_depois+1440;
if @m_enquadra_antes>@m_enquadra_depois begin select @m_enquadra_depois=@m_enquadra_depois+1440 end;
if @proximidade_ant>0 or @m_enquadra_antes<0 or (@m_marc+1440 >= @m_enquadra_antes and @m_marc+1440 <= @m_enquadra_depois) begin
select @proximidade = 0;
end;
end else begin if @tipo_enquadra=2 begin
if @funcao <> @enquadra_funcao begin
--if exists(SELECT id_pass FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data_ant AND m_primeira > - 1 AND abs((@m_marc+2880)-m_primeira) <= 2160 AND original = 1) begin
select @proximidade_ant = 0;
--end;
end;
end; end; end;
end;
end;
end;
end;
if @fm_ant=0 AND not exists(SELECT data FROM tbPtoEnq WHERE id_pass = @id_pass AND data = @data_dep AND @marc > primeira AND original = 1) begin
EXEC AP_PTO009 @id_pass output, @data output, 1, @m_marc;
SELECT @id_phorario=isnull(id_phorario,0),@flexivel=isnull(flexivel,0),@trabalhado=isnull(trabalhado,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data;
if @flexivel = 0 and isnull(@id_phorario,0) > 0 begin
select @antes=0; select @depois=0; select @e1=0; select @s1=0
SELECT @antes=isnull(m_enquadra_antes,0), @depois=isnull(m_enquadra_depois,0) FROM tbPHorarios WHERE id_phorario = @id_phorario;
SELECT TOP 1 @e1=m_entrada1, @s1=(CASE WHEN isnull(m_saida4,-1) >= 0 THEN m_saida4
WHEN isnull(m_saida3,-1) >= 0 THEN m_saida3
WHEN isnull(m_saida2,-1) >= 0 THEN m_saida2
WHEN isnull(m_saida1,-1) >= 0 THEN m_saida1
ELSE -1 END) FROM tbFxPHorarios WHERE id_phorario = @id_phorario;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
if isnull(@s1,-1) < 0 begin select @s1=0; end;
select @e2=(@e1 - @antes); if @e2 < 0 begin select @e2 = 0; end;
select @s2=(@s1 + @depois); if (@e1 > @s1) or (@s2>1440) begin select @s2 = 1440; end;
if @m_marc >= @e2 and @m_marc <= @s2 begin
select @proximidade = 0;
end else begin
if @m_marc < @e2 begin
select @proximidade = @m_marc - @e1;
end else begin
if @e1 <= @s1 begin select @proximidade = @m_marc - @s1; end;
end;
end;
end else begin
if @flexivel = 1
begin
select @tipo_enquadra=-1; select @m_enquadra_limite = -1; select @m_enquadra_antes=-1; select @m_enquadra_depois=-1; select @enquadra_funcao=-99;
SELECT @tipo_enquadra=tipo_enquadra, @m_enquadra_limite=m_enquadra_limite,
@m_enquadra_antes=m_enquadra_antes, @m_enquadra_depois=m_enquadra_depois,
@enquadra_funcao=enquadra_funcao
FROM tbPHorFlex WHERE id_pflex = @id_phorario;
select @tipo_enquadra=isnull(@tipo_enquadra,-1);
if @tipo_enquadra > -1 begin
if @tipo_enquadra=0 begin
if @proximidade_ant>0 and not exists(SELECT id_pass FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data AND m_ultima > - 1 AND abs((@m_marc+1440)-m_ultima) > @m_enquadra_limite AND original = 1) begin
select @proximidade = 0;
end;
end else begin if @tipo_enquadra=1 begin
select @m_enquadra_antes=@m_enquadra_antes+1440;
select @m_enquadra_depois=@m_enquadra_depois+1440;
if @m_enquadra_antes>@m_enquadra_depois begin select @m_enquadra_depois=@m_enquadra_depois+1440 end;
if @proximidade_ant>0 or @m_enquadra_antes<0 or (@m_marc+1440 >= @m_enquadra_antes and @m_marc+1440 <= @m_enquadra_depois) begin
select @proximidade = 0;
end;
end else begin if @tipo_enquadra=2 begin
if @proximidade_ant>0 or @funcao = @enquadra_funcao begin
select @proximidade = 0;
end else begin
if @m_enquadra_antes>0 and @m_enquadra_depois>0 begin
select @m_enquadra_antes=@m_enquadra_antes+1440;
select @m_enquadra_depois=@m_enquadra_depois+1440;
if @m_enquadra_antes>@m_enquadra_depois begin select @m_enquadra_depois=@m_enquadra_depois+1440 end;
if @m_marc+1440 > (@m_enquadra_depois+240) begin
select @proximidade = 0;
end;
end;
end;
end; end; end;
end;
end;
end;
end;
if @proximidade_ant > 0 and @proximidade > 300 begin
EXEC AP_PTO009 @id_pass output, @data_dep output, 0;
SELECT @id_phorario_dep=isnull(id_phorario,0),@flexivel_dep=isnull(flexivel,0),@trabalhado_dep=isnull(trabalhado,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data_dep;
if @flexivel_dep = 0 and isnull(@id_phorario_dep,0) > 0 begin
/* Horrio Fixo */
select @antes=0; select @e1=0;
SELECT @antes=isnull(m_enquadra_antes,0) FROM tbPHorarios WHERE id_phorario = @id_phorario_dep;
SELECT @e1=m_entrada1 FROM tbFxPHorarios WHERE id_phorario = @id_phorario_dep;
if isnull(@e1,-1) < 0 begin select @e1=0; end;
select @e2=(@e1 - @antes);
if @e2 < 0 begin
if @m_marc > 1440+@e2 begin
select @proximidade_dep = 0
end else begin
select @proximidade_dep = @e1+1440-@m_marc;
end;
end else begin
select @proximidade_dep = @m_marc-@e1;
end;
end;
end;
if @proximidade_ant=0 and @proximidade<>0 begin
if @trabalhado_ant=1 or @flexivel_ant=1 begin
select @EnqDia = 1;
end else begin
if @proximidade < -600 or exists(SELECT fmsaida FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data_ant AND fmsaida=1 AND original = 1) begin
select @EnqDia = 1;
end else begin
select @EnqDia = 2;
end;
end;
end else begin
if @proximidade_ant>=0 and @proximidade=0 and (@proximidade_dep<>0 or @proximidade_ant=0 or @trabalhado_dep=0) begin
if @trabalhado = 1 or @trabalhado_ant = 0 or @flexivel=1 begin
select @EnqDia = 2;
end else begin
if @proximidade_ant<600 OR (@trabalhado=1 AND exists(SELECT fmsaida FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data_ant AND fmsaida=1 AND original = 1)) begin
select @EnqDia = 1;
end else begin
select @EnqDia = 2;
end;
end;
end else begin
if @flexivel=0 and (@proximidade>300 and @proximidade_dep=0) begin
select @EnqDia = 3;
end else begin
select @EnqDia = 2;
end;
end;
end;
end;
if @EnqDia = 0 begin select @EnqDia = 2; end;
if @EnqDia = 1 begin
select @data = @data_ant; select @wdia = @wdia_ant;
select @trabalhado = @trabalhado_ant;
select @id_phorario = @id_phorario_ant;
select @flexivel = @flexivel_ant;
end;
if @EnqDia = 3 begin
select @data = @data_dep; select @wdia = @wdia_dep;
select @trabalhado = @trabalhado_dep;
select @id_phorario = @id_phorario_dep;
select @flexivel = @flexivel_dep;
end;
if isnull(@consulta,0) = 0 begin
EXEC AP_PTO015 @id_pass output, @data output, @marc, @funcao, @ponto;
if @EnqDia = 1 begin
EXEC AP_PTO009 @id_pass output, @data_ant output, 1;
end;
end else begin
EXEC AP_PTO040 @id_pass output, @data output, @marc, @consulta out;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO017') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO017; END;
GO
CREATE PROCEDURE dbo.AP_PTO017(@id_pass int output, @data datetime output, @id_diverg int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @m_totabo int; declare @totabo varchar(7); declare @m_totdiv int;
if not @id_pass is null and not @data is null begin
SELECT @m_totdiv=SUM(m_valor) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg;
select @m_totdiv=ISNULL(@m_totdiv,0);
SELECT @m_totabo=SUM(m_valor) FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND id_diverg = @id_diverg;
select @m_totabo=ISNULL(@m_totabo,0);
if @m_totabo > @m_totdiv begin select @m_totabo = @m_totdiv; end;
EXEC AP_PTO003 @m_totabo, @totabo output;
UPDATE tbPtoDivsDia SET abonado = @totabo, m_abonado = @m_totabo WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO018') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO018; END;
GO
CREATE PROCEDURE dbo.AP_PTO018(@id_pass int output, @data datetime output, @id_diverg int, @m_valor int, @somar bit = 0, @lancado bit = 0, @monetario bit=0) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @valor varchar(7); declare @m_vlr_antes int; declare @contadia smallint;
declare @achou bit; declare @reg_lancado bit;
if not @id_pass is null and not @data is null begin
select @achou=0;
SELECT @achou=1, @m_vlr_antes=m_valor, @reg_lancado=lancado FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg
if @monetario=0 begin
EXEC AP_PTO003 @m_valor, @valor output;
end else begin
select @valor=replace(convert(varchar(7),convert(NUMERIC(10,2),(convert(float,@m_valor) / 100.0))),'.',',');
select @valor=right(space(7)+rtrim(@valor),7);
end;
if @achou=1 begin
if @lancado=1 or @monetario=1 begin
UPDATE tbPtoDivsDia SET m_valor = @m_valor, valor=@valor, lancado=1, m_ant_arred = @m_valor, monetario=@monetario
WHERE id_pass=@id_pass AND data=@data AND id_diverg = @id_diverg;
end else begin if @somar=1 and @reg_lancado=0 begin
select @m_valor=@m_valor+@m_vlr_antes;
EXEC AP_PTO003 @m_valor, @valor output;
UPDATE tbPtoDivsDia SET m_valor = @m_valor, valor=@valor, m_ant_arred = @m_valor, monetario=0
WHERE id_pass=@id_pass AND data=@data AND id_diverg = @id_diverg;
end; end;
end else begin
SELECT @contadia=0;
SELECT @contadia=isnull(MAX(contadia),0) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data
SELECT @contadia=@contadia+1;
INSERT INTO tbPtoDivsDia (id_pass, data, id_diverg, contadia, valor, m_valor, abonado, m_abonado, lancado, id_associ, m_ant_arred, monetario)
VALUES (@id_pass, @data, @id_diverg, @contadia, @valor, @m_valor, '  00:00', 0, @lancado, 0, @m_valor, @monetario);
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO041') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO041; END;
GO
CREATE PROCEDURE dbo.AP_PTO041(@id_empresa int output, @id_pass int output, @data datetime output, @id_diverg int,  @id_eveabo int, @m_valor int, @id_ptocp bigint, @gerado bit) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @valor varchar(7); declare @contadia smallint; declare @achou bit;
declare @id_usuario int, @vlr1 int;
select @id_usuario=0;
if @id_ptocp=0 begin
SELECT @id_usuario=id_usuario FROM tbCalendario WHERE id_pass=@id_pass AND data=@data AND id_eveabo>0;
if isnull(@id_usuario,0)=0 begin
SELECT @id_usuario=id_usuario FROM tbCalendario
WHERE (id_empresa = @id_empresa OR id_empresa = 0) AND id_pass=0 AND data=@data AND id_eveabo>0;
end;
select @id_usuario=isnull(@id_usuario,0);
end else begin
SELECT @id_usuario=id_usuario FROM tbPtoCp WHERE id_ptocp=@id_ptocp;
select @id_usuario=isnull(@id_usuario,0);
end;
select @achou=0, @vlr1=0;
SELECT @achou=1, @vlr1=isnull(m_valor,0) FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg AND id_eveabo=@id_eveabo
if @vlr1>0 and @id_ptocp>0 begin
select @m_valor=@m_valor+@vlr1;
end;
if EXISTS(SELECT calculo FROM tbEvsAbono WHERE id_eveabo = @id_eveabo AND calculo=0) begin
select @m_valor=0;
end;
EXEC AP_PTO003 @m_valor, @valor output;
if @achou=1 begin
UPDATE tbPtoAboDia SET m_valor = @m_valor, valor=@valor, id_usuario=@id_usuario, gerado=@gerado, id_ptocp=@id_ptocp
WHERE id_pass=@id_pass AND data=@data AND id_diverg = @id_diverg AND id_eveabo = @id_eveabo;
end else begin
SELECT @contadia=0;
SELECT @contadia=isnull(MAX(contadia),0) FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data
SELECT @contadia=@contadia+1;
INSERT INTO tbPtoAboDia (id_pass, data, id_diverg, id_eveabo, contadia, gerado, valor, m_valor, id_usuario, id_ptocp)
VALUES (@id_pass, @data, @id_diverg, @id_eveabo, @contadia, @gerado, @valor, @m_valor, @id_usuario, @id_ptocp);
end;
EXEC AP_PTO017 @id_pass output, @data output, @id_diverg;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO045') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO045; END;
GO
CREATE PROCEDURE dbo.AP_PTO045(@id_pass int output, @data datetime output, @mes_fec int, @ano_fec int, @fechamento_ini datetime, @fechamento_fim datetime, @trabalhado bit, @falta bit, @m_hrs_trab int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_tabbenf int, @vr BIT, @vr_dia_livre BIT, @vr_falta BIT,
@vt BIT, @vt_dia_livre BIT, @vt_falta BIT,
@ps BIT, @cesta BIT,
@m_acm_dia_hrs INT, @m_acm_per_hrs INT, @acm_per_qtd INT;
declare @dt_ini datetime, @dt_fim datetime, @dt_atu datetime, @trab BIT, @id_eveabo INT;
declare @prx_mes_ini datetime, @prx_mes_fim datetime, @prx_mes_qtde int, @dias_normais TINYINT;
declare @achou BIT, @m_valor INT, @m_valor2 INT;
declare @conta INT, @i INT, @id_diverg INT, @tolera TINYINT, @m_dia_hrs INT, @m_per_hrs INT, @per_qtd INT;
declare @ano INT, @mes TINYINT, @cred_vr TINYINT, @deb_vr TINYINT, @tot_vr TINYINT;
declare @cred_vt TINYINT, @deb_vt TINYINT, @tot_vt TINYINT;
declare @cred_cesta BIT, @tot_desc varchar(7), @m_tot_desc INT, @qtd_desc INT;
select @achou=0;
if not exists(SELECT id_pass FROM tbPass WHERE id_pass=@id_pass AND inativo=1)
and not exists(SELECT admissao FROM tbFunc WHERE id_pass=@id_pass AND NOT admissao IS NULL AND admissao>=@data)
and not exists(SELECT dtdemissao FROM tbFunc WHERE id_pass=@id_pass AND NOT dtdemissao IS NULL AND dtdemissao<@data) begin
SELECT @id_tabbenf=f.id_tabbenf,
@vr=b.vr, @vr_dia_livre=b.vr_dia_livre, @vr_falta=b.vr_falta,
@vt=b.vt, @vt_dia_livre=b.vt_dia_livre, @vt_falta=b.vt_falta,
@ps=b.ps, @cesta=b.cesta,
@m_acm_dia_hrs=b.m_acm_dia_hrs, @m_acm_per_hrs=b.m_acm_per_hrs, @acm_per_qtd=b.acm_per_qtd
FROM tbFunc f INNER JOIN tbTabBenf b ON f.id_tabbenf = b.id_tabbenf WHERE id_pass=@id_pass;
if isnull(@id_tabbenf,0) > 0
select @achou=1;
end;
if @achou=1 begin
select @prx_mes_ini=dateadd(m,1,CONVERT(datetime,right('00'+ltrim(str(@mes_fec)),2)+'/01/'+ltrim(str(@ano_fec))));
select @prx_mes_fim=dateadd(d,-1,dateadd(m,1,@prx_mes_ini));
select @prx_mes_qtde=datediff(d,@prx_mes_ini,@prx_mes_fim)+1;
select @ano=year(@prx_mes_ini), @mes=month(@prx_mes_ini);
select @cred_vr=0, @deb_vr=0,@tot_vr=0,@cred_vt=0,@deb_vt=0,@tot_vt=0,@cred_cesta=0,@tot_desc='____:__', @m_tot_desc=0, @qtd_desc=0;
select @dias_normais=0;
if @data=@fechamento_fim and (@vr=1 or @vt=1) begin
select @dt_ini=@prx_mes_ini, @dt_fim=@prx_mes_fim;
select @dt_atu=@dt_ini;
while @dt_atu<=@dt_fim
begin
if @dt_atu>@fechamento_fim or not EXISTS(SELECT id_pass FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dt_atu) begin
EXEC AP_PTO009 @id_pass output, @dt_atu output, 0;
end;
select @trab=0, @id_eveabo=0;
SELECT @trab=isnull(trabalhado,0), @id_eveabo=isnull(id_eveabo,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dt_atu;
if @trab=1 and @id_eveabo not in (SELECT id_eveabo FROM tbEvsAbono WHERE afasta=1) begin
select @dias_normais=@dias_normais+1;
end;
select @dt_atu=@dt_atu+1;
end;
end;
if @vr=1 begin
if @vr_falta=1 and @falta=1 begin
select @m_valor=60;
exec AP_PTO018 @id_pass output, @data output, 54, @m_valor;
EXEC AP_PTO017 @id_pass output, @data output, 54;
end;
if @vr_dia_livre=1 and @trabalhado=0 and @m_hrs_trab>0 begin
select @m_valor=60;
exec AP_PTO018 @id_pass output, @data output, 55, @m_valor;
EXEC AP_PTO017 @id_pass output, @data output, 55;
end;
if @data=@fechamento_fim begin
select @m_valor=@dias_normais;
select @deb_vr=0;
SELECT @deb_vr=count(data) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=54 AND (m_valor-m_abonado)>0;
select @deb_vr=isnull(@deb_vr,0);
select @m_valor=@m_valor-@deb_vr;
select @cred_vr=0;
SELECT @cred_vr=count(data) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=55 AND (m_valor-m_abonado)>0;
select @cred_vr=isnull(@cred_vr,0);
select @m_valor=@m_valor+@cred_vr;
if @m_valor>0 begin
select @tot_vr=@m_valor;
select @m_valor=@m_valor*60;
exec AP_PTO018 @id_pass output,@data output, 58, @m_valor
EXEC AP_PTO017 @id_pass output,@data output, 58;
end;
end;
end;
if @vt=1 begin
if @vt_falta=1 and @falta=1 begin
select @m_valor=60;
exec AP_PTO018 @id_pass output, @data output, 56, @m_valor;
EXEC AP_PTO017 @id_pass output, @data output, 56;
end;
if @vt_dia_livre=1 and @trabalhado=0 and @m_hrs_trab>0 begin
select @m_valor=60;
exec AP_PTO018 @id_pass output, @data output, 57, @m_valor;
EXEC AP_PTO017 @id_pass output, @data output, 57;
end;
if @data=@fechamento_fim begin
select @m_valor=@dias_normais;
select @deb_vt=0;
SELECT @deb_vt=count(data) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=56 AND (m_valor-m_abonado)>0;
select @deb_vt=isnull(@deb_vt,0);
select @m_valor=@m_valor-@deb_vt;
select @cred_vt=0;
SELECT @cred_vt=count(data) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=57 AND (m_valor-m_abonado)>0;
select @cred_vt=isnull(@cred_vt,0);
select @m_valor=@m_valor+@cred_vt;
if @m_valor>0 begin
select @tot_vt=@m_valor;
select @m_valor=@m_valor*60;
exec AP_PTO018 @id_pass output,@data output, 59, @m_valor
EXEC AP_PTO017 @id_pass output,@data output, 59;
end;
end;
end;
if @cesta=1 and @data=@fechamento_fim begin
select @cred_cesta=1;
select @conta=0, @i=1;
SELECT @conta=COUNT(id_diverg) FROM tbDivsCesta WHERE id_tabbenf=@id_tabbenf AND tolera<>1;
select @id_diverg=0;
while @i<=isnull(@conta,0) begin
select @achou=0;
SELECT TOP 1 @achou=1, @id_diverg=id_diverg, @tolera=tolera, @m_dia_hrs=m_dia_hrs, @m_per_hrs=m_per_hrs, @per_qtd=per_qtd FROM tbDivsCesta
WHERE id_tabbenf=@id_tabbenf AND tolera<>1 AND id_diverg>@id_diverg ORDER BY id_diverg;
if @achou=1 begin
if @tolera=0 begin
if exists(SELECT TOP 1 id_pass FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=@id_diverg AND (m_valor-m_abonado)>0)
select @cred_cesta=0;
end else begin if @tolera=2 begin
if @m_dia_hrs>0 begin
if exists(SELECT TOP 1 id_pass FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=@id_diverg AND (m_valor-m_abonado)>@m_dia_hrs)
select @cred_cesta=0;
end;
if @cred_cesta=1 and @m_per_hrs>0 begin
select @m_valor=0;
SELECT @m_valor=sum((m_valor-m_abonado)) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=@id_diverg AND (m_valor-m_abonado)>0;
if isnull(@m_valor,0)>@m_per_hrs
select @cred_cesta=0;
end;
if @cred_cesta=1 and @per_qtd>0 begin
select @m_valor=0;
SELECT @m_valor=count(data) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg=@id_diverg AND (m_valor-m_abonado)>0;
if isnull(@m_valor,0)>@per_qtd
select @cred_cesta=0;
end;
end; end;
end;
if @cred_cesta=0
select @i=@conta;
select @i=@i+1;
end; --while
if @cred_cesta=1 begin
if @m_acm_dia_hrs>0 begin
if exists(SELECT TOP 1 data FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg IN (SELECT c.id_diverg FROM tbDivsCesta c WHERE c.id_tabbenf=@id_tabbenf AND c.tolera=1 ) AND (m_valor-m_abonado)>0 GROUP BY data HAVING SUM((m_valor-m_abonado)) > @m_acm_dia_hrs)
select @cred_cesta=0;
end;
if @cred_cesta=1 and @m_acm_per_hrs>0 begin
select @m_valor=0;
SELECT @m_valor=sum((m_valor-m_abonado)) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg IN (SELECT c.id_diverg FROM tbDivsCesta c WHERE c.id_tabbenf=@id_tabbenf AND c.tolera=1 ) AND (m_valor-m_abonado)>0;
if isnull(@m_valor,0)>@m_acm_per_hrs
select @cred_cesta=0;
end;
if @cred_cesta=1 and @acm_per_qtd>0 begin
select @m_valor=0;
SELECT @m_valor=count(data) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg IN (SELECT c.id_diverg FROM tbDivsCesta c WHERE c.id_tabbenf=@id_tabbenf AND c.tolera=1 ) AND (m_valor-m_abonado)>0;
if isnull(@m_valor,0)>@acm_per_qtd
select @cred_cesta=0;
end;
end;
select @m_valor=60;
if @cred_cesta=0 begin
exec AP_PTO018 @id_pass output,@data output, 70, @m_valor
EXEC AP_PTO017 @id_pass output,@data output, 70;
end else begin
exec AP_PTO018 @id_pass output,@data output, 71, @m_valor
EXEC AP_PTO017 @id_pass output,@data output, 71;
end;
end;
if @data=@fechamento_fim begin
if @cesta=1 begin
select @m_valor=0;
SELECT @m_valor=sum((m_valor-m_abonado)) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg IN (SELECT c.id_diverg FROM tbDivsCesta c WHERE c.id_tabbenf=@id_tabbenf) AND (m_valor-m_abonado)>0;
select @m_tot_desc=isnull(@m_valor,0);
EXEC AP_PTO003 @m_tot_desc, @tot_desc output;
select @m_valor=0;
SELECT @m_valor=count(data) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim AND id_diverg IN (SELECT c.id_diverg FROM tbDivsCesta c WHERE c.id_tabbenf=@id_tabbenf) AND (m_valor-m_abonado)>0;
select @qtd_desc=isnull(@m_valor,0);
end;
if not exists(SELECT id_pass FROM tbPtoBenf WHERE id_pass=@id_pass AND ano=@ano AND mes=@mes) begin
INSERT INTO tbPtoBenf (id_pass,ano,mes,data,dias_mes,cred_vr,deb_vr,tot_vr,
cred_vt,deb_vt,tot_vt,cesta,tot_desc,m_tot_desc,qtd_desc)
VALUES (@id_pass,@ano,@mes,@data,@dias_normais,@cred_vr,@deb_vr,@tot_vr,
@cred_vt,@deb_vt,@tot_vt,@cred_cesta,@tot_desc,@m_tot_desc,@qtd_desc);
end else begin
UPDATE tbPtoBenf SET data=@data,dias_mes=@dias_normais,cred_vr=@cred_vr,deb_vr=@deb_vr,tot_vr=@tot_vr,
cred_vt=@cred_vt,deb_vt=@deb_vt,tot_vt=@tot_vt,cesta=@cred_cesta,
tot_desc=@tot_desc,m_tot_desc=@m_tot_desc,qtd_desc=@qtd_desc
WHERE id_pass=@id_pass AND ano=@ano AND mes=@mes;
end;
end;
end; --@achou
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO046') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO046; END;
GO
CREATE PROCEDURE dbo.AP_PTO046(@id_pass int,  @data_ini datetime, @data_fim datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_diverg int;
declare @id_diverg_atu int;
declare @achou bit;
declare @vlr int;
if EXISTS(SELECT top 1 id_diverg FROM tbRefeit WHERE isnull(id_diverg,0) > 0)
begin
select @id_diverg_atu=0, @achou=1;
WHILE @achou=1 begin
select @achou=0;
SELECT TOP 1 @achou=1, @id_diverg=id_diverg FROM tbRefeit WHERE isnull(id_diverg,0) > @id_diverg_atu ORDER BY id_diverg;
if @achou=1 begin
select @id_diverg_atu=@id_diverg;
select @vlr=0;
SELECT @vlr=isnull(sum(isnull(valor_refeit,0))*100,0) FROM tbMRefeit WITH (NOLOCK)
WHERE id_pass=@id_pass AND
convert(datetime,convert(varchar,data,101)) between @data_ini and @data_fim AND
id_refeit IN (SELECT r.id_refeit FROM tbRefeit r WHERE r.id_diverg=@id_diverg) AND
status=0 AND
evento IN (select id_evento from tbEventoSist where flagimpedimento=0)
if @vlr>0 begin
exec AP_PTO018 @id_pass output, @data_fim output, @id_diverg, @vlr, 0, 0, 1;
end;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO049') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO049; END;
GO
CREATE PROCEDURE dbo.AP_PTO049(@id_empresa int output, @id_pass int output, @data datetime output, @wdia int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @achou bit;
declare @id_ptocp bigint, @id_diverg int;
declare @data_cp datetime, @dt_ini_cmp datetime, @dt_fim_cmp datetime;
declare @hrs_tot bit, @m_min_comp_dia int, @m_max_comp_dia int, @dias_comp varchar(10);
declare @horas varchar(8), @compensado varchar(8), @pagodesc varchar(8), @saldo varchar(8);
declare @m_horas int, @m_compensado int, @m_pagodesc int, @m_saldo int, @m_valor int;
declare @m_totcmpdia int, @m_compensado_ant int;
declare @id_eveabo_cmp int, @soma bit, @soma_cmp bit;
declare @id_diverg_cmp int;
select @id_ptocp=0, @achou=1, @id_diverg_cmp=0, @data_cp='01/01/2000';
while @achou=1 begin
select @achou=0;
SELECT TOP 1 @achou=1, @id_ptocp=id_ptocp, @data_cp=data, @soma=soma,@id_diverg=id_diverg, @dt_ini_cmp=dt_ini_cmp, @dt_fim_cmp=dt_fim_cmp,
@m_horas=m_horas, @horas=horas, @id_eveabo_cmp=id_eveabo_cmp,
@hrs_tot=hrs_tot,@m_min_comp_dia=m_min_comp_dia, @m_max_comp_dia=m_max_comp_dia, @dias_comp=dias_comp
FROM tbPtoCp p
WHERE p.id_pass=@id_pass AND @data BETWEEN p.dt_ini_cmp AND p.dt_fim_cmp AND data<>@data AND (data>@data_cp OR (data=@data_cp AND id_ptocp>@id_ptocp))
ORDER BY p.data, p.id_ptocp;
if @achou=1 begin
if @soma=0 begin
select @soma_cmp=1;
end else begin
select @soma_cmp=0;
end;
if @hrs_tot=1 begin
select @m_valor=@m_horas;
SELECT TOP 1 @m_valor=isnull(m_valor,@m_horas) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data_cp AND id_diverg=@id_diverg;
if @m_valor>0 AND @m_valor<>@m_horas begin
select @m_horas=@m_valor;
if @soma=0 begin
select @m_horas=@m_horas*(-1);
end;
exec AP_PTO004 @m_horas, @horas output;
select @m_horas=abs(@m_horas);
UPDATE tbPtoCp SET m_horas=@m_horas, horas=@horas WHERE id_ptocp=@id_ptocp;
end;
end;
select @m_saldo=0, @m_totcmpdia=0, @m_compensado_ant=0, @m_compensado=0, @m_pagodesc=0;
SELECT @m_compensado_ant=sum(c.m_compensado) FROM tbPtoCpCmp c WHERE c.id_ptocp = @id_ptocp and c.data >= @dt_ini_cmp AND c.data < @data;
select @m_compensado_ant=isnull(@m_compensado_ant,0);
select @m_saldo=@m_horas-@m_compensado_ant;
if @m_saldo<0 begin select @m_saldo=0 end;
select @m_horas=@m_saldo;
if @m_saldo>0 begin
if substring(@dias_comp,@wdia+1,1) = '1' begin
select @achou=0, @m_valor=0;
SELECT TOP 1 @achou=1, @m_valor=sum(d.m_valor-d.m_abonado) FROM tbPtoDivsDia d
INNER JOIN tbDivergencias p ON d.id_diverg=p.id_diverg AND p.soma <> @soma AND p.cp_auto=1 AND p.ativada=1
WHERE d.id_pass=@id_pass AND d.data=@data AND d.id_diverg NOT IN (SELECT ass.id_diverg FROM tbDivAssoc ass)
select @m_valor=isnull(@m_valor,0);
if @achou=1 and @m_valor>0 begin
if @m_valor >= @m_min_comp_dia or @m_saldo < @m_min_comp_dia begin
/* Lanar compensao nas divergncias do dia */
select @achou=1,@id_diverg_cmp=0;
while (@achou=1 and @m_saldo>0)
begin
select @achou=0;
SELECT TOP 1 @achou=1, @m_valor=(d.m_valor-d.m_abonado), @id_diverg_cmp=d.id_diverg FROM tbPtoDivsDia d
INNER JOIN tbDivergencias p ON d.id_diverg=p.id_diverg AND p.soma <> @soma AND p.cp_auto=1 AND p.ativada=1
WHERE d.id_pass=@id_pass AND d.data=@data AND d.id_diverg NOT IN (SELECT ass.id_diverg FROM tbDivAssoc ass)
AND d.id_diverg > @id_diverg_cmp ORDER BY d.id_diverg;
select @m_valor=isnull(@m_valor,0);
if (@achou=1 and @m_saldo>0)
begin
if @m_max_comp_dia>0 and @m_max_comp_dia<(@m_totcmpdia+@m_valor) begin
if @m_max_comp_dia>@m_totcmpdia begin
select @m_valor=@m_max_comp_dia-@m_totcmpdia;
end else begin
select @m_valor=0;
end;
end;
if @m_valor>0 begin
if @m_valor>@m_saldo begin
select @m_compensado=@m_saldo, @m_saldo=0;
end else begin
select @m_compensado=@m_valor, @m_saldo=@m_saldo-@m_valor;
end;
select @m_totcmpdia=@m_totcmpdia+@m_compensado;
if @soma=0 begin
select @m_horas=@m_horas*(-1),@m_saldo=@m_saldo*(-1);
end else begin
select @m_compensado=@m_compensado*(-1);
end;
exec AP_PTO004 @m_horas, @horas output;
exec AP_PTO004 @m_compensado, @compensado output;
exec AP_PTO004 0, @pagodesc output;
exec AP_PTO004 @m_saldo, @saldo output;
select @m_horas=abs(@m_horas),@m_compensado=abs(@m_compensado), @m_saldo=abs(@m_saldo);
DELETE FROM tbPtoCpCmp WHERE id_ptocp=@id_ptocp AND id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg_cmp;
INSERT INTO tbPtoCpCmp (id_ptocp,id_pass,data,id_diverg,id_eveabo_cmp,soma,horas,m_horas,compensado,m_compensado,
pagodesc,m_pagodesc,saldo,m_saldo)
VALUES (@id_ptocp,@id_pass,@data,@id_diverg_cmp,@id_eveabo_cmp,@soma_cmp,@horas,@m_horas,@compensado,@m_compensado,
'+  00:00',0,@saldo,@m_saldo);
exec AP_PTO041 @id_empresa output, @id_pass output,  @data output, @id_diverg_cmp,  @id_eveabo_cmp, @m_compensado, @id_ptocp, 1;
select @m_horas=@m_saldo;
end;
end;
end;
end;
end;
end;
end else begin
select @m_saldo=0
end;
if @data=@dt_fim_cmp AND @m_saldo>0 begin
exec AP_PTO018 @id_pass output, @data output, 101, @m_saldo, 1;
select @m_pagodesc=@m_saldo, @m_saldo=0;
select @soma_cmp=@soma, @id_diverg_cmp=101, @id_eveabo_cmp=0;
if @soma=0 begin
select @m_horas=@m_horas*(-1),@m_pagodesc=@m_pagodesc*-1;
end;
exec AP_PTO004 @m_horas, @horas output;
exec AP_PTO004 @m_compensado, @compensado output;
exec AP_PTO004 @m_pagodesc, @pagodesc output;
exec AP_PTO004 @m_saldo, @saldo output;
select @m_horas=abs(@m_horas),@m_pagodesc=abs(@m_pagodesc);
DELETE FROM tbPtoCpCmp WHERE id_ptocp=@id_ptocp AND id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg_cmp;
INSERT INTO tbPtoCpCmp (id_ptocp,id_pass,data,id_diverg,id_eveabo_cmp,soma,horas,m_horas,compensado,m_compensado,
pagodesc,m_pagodesc,saldo,m_saldo)
VALUES (@id_ptocp,@id_pass,@data,@id_diverg_cmp,@id_eveabo_cmp,@soma_cmp,@horas,@m_horas,'+  00:00',0,
@pagodesc,@m_pagodesc,'+  00:00',0);
end;
select @m_compensado=@m_compensado_ant+@m_totcmpdia;
if @soma=0 begin
select @m_horas=abs(@m_horas)*(-1),@m_saldo=abs(@m_saldo)*(-1),@m_pagodesc=abs(@m_pagodesc)*-1;
end else begin
select @m_compensado=abs(@m_compensado)*(-1);
end;
exec AP_PTO004 @m_horas, @horas output;
exec AP_PTO004 @m_compensado, @compensado output;
exec AP_PTO004 @m_pagodesc, @pagodesc output;
exec AP_PTO004 @m_saldo, @saldo output;
select @m_horas=abs(@m_horas),@m_compensado=abs(@m_compensado), @m_pagodesc=abs(@m_pagodesc), @m_saldo=abs(@m_saldo);
UPDATE tbPtoCp SET m_saldo=@m_saldo, saldo=@saldo, m_compensado=@m_compensado, compensado=@compensado,
m_pagodesc=@m_pagodesc, pagodesc=@pagodesc
WHERE id_ptocp=@id_ptocp;
UPDATE tbPtoDia SET apontado=0 WHERE id_pass=@id_pass AND data>@data AND data<=@dt_fim_cmp;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO058') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO058; END;
GO
CREATE PROCEDURE dbo.AP_PTO058(@id_empresa int output, @id_pass int output, @data datetime output, @tipodia char(1)) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @apagarCP bit, @achou bit;
declare @id_eveabo_div int, @id_eveabo_cmp int, @dt_ini_cmp datetime, @dt_fim_cmp datetime;
declare @dias_comp varchar(10), @min_comp_dia varchar(8), @m_min_comp_dia int, @max_comp_dia varchar(8);
declare @m_max_comp_dia int, @hrs_tot bit, @horas varchar(8), @m_horas int, @id_usuario int;
declare @id_diverg int, @id_ptocp bigint;
select @apagarCP=1;
if @tipodia='C' begin
select @achou=0;
SELECT @achou=1, @id_eveabo_div=id_eveabo_div, @id_eveabo_cmp=id_eveabo_cmp,
@dt_ini_cmp=dt_ini_cmp, @dt_fim_cmp=dt_fim_cmp, @dias_comp=dias_comp, @min_comp_dia=min_comp_dia,
@m_min_comp_dia=m_min_comp_dia, @max_comp_dia=max_comp_dia,
@m_max_comp_dia=m_max_comp_dia, @hrs_tot=hrs_tot, @horas=horas, @m_horas=m_horas, @id_usuario=id_usuario
FROM tbPtoCpCalend WHERE id_empresa=@id_empresa AND id_pass=@id_pass AND data=@data;
if @achou=0 begin
SELECT @achou=1, @id_eveabo_div=id_eveabo_div, @id_eveabo_cmp=id_eveabo_cmp,
@dt_ini_cmp=dt_ini_cmp, @dt_fim_cmp=dt_fim_cmp, @dias_comp=dias_comp, @min_comp_dia=min_comp_dia,
@m_min_comp_dia=m_min_comp_dia, @max_comp_dia=max_comp_dia,
@m_max_comp_dia=m_max_comp_dia, @hrs_tot=hrs_tot, @horas=horas, @m_horas=m_horas, @id_usuario=id_usuario
FROM tbPtoCpCalend WHERE id_empresa=@id_empresa AND id_pass=0 AND data=@data;
end;
if @achou=0 begin
SELECT @achou=1, @id_eveabo_div=id_eveabo_div, @id_eveabo_cmp=id_eveabo_cmp,
@dt_ini_cmp=dt_ini_cmp, @dt_fim_cmp=dt_fim_cmp, @dias_comp=dias_comp, @min_comp_dia=min_comp_dia,
@m_min_comp_dia=m_min_comp_dia, @max_comp_dia=max_comp_dia,
@m_max_comp_dia=m_max_comp_dia, @hrs_tot=hrs_tot, @horas=horas, @m_horas=m_horas, @id_usuario=id_usuario
FROM tbPtoCpCalend WHERE id_empresa=0 AND id_pass=0 AND data=@data;
end;
if @achou=1 begin
select @achou=0
SELECT TOP 1 @achou=1 FROM tbPtoDivsDia d
INNER JOIN tbDivergencias p ON d.id_diverg=p.id_diverg AND p.soma=0 AND p.cp_auto=1 AND p.ativada=1
WHERE d.id_pass=@id_pass AND d.data=@data
AND d.id_diverg NOT IN (SELECT ass.id_diverg FROM tbDivAssoc ass)
AND d.m_abonado = 0;
if @achou=1 begin
select @apagarCP=0;
select @achou=1, @id_diverg=0;
while (@achou=1) begin
select @achou=0;
SELECT TOP 1 @achou=1, @id_diverg=d.id_diverg, @horas=d.valor, @m_horas=d.m_valor FROM tbPtoDivsDia d
INNER JOIN tbDivergencias p ON d.id_diverg=p.id_diverg AND p.soma=0 AND p.cp_auto=1 AND p.ativada=1
WHERE d.id_pass=@id_pass AND d.data=@data
AND d.id_diverg NOT IN (SELECT ass.id_diverg FROM tbDivAssoc ass)
AND d.m_abonado = 0 AND d.id_diverg>@id_diverg
ORDER BY d.id_diverg;
if @achou=1 AND @id_diverg>0 begin
select @horas='+'+@horas;
SELECT @id_ptocp=0;
SELECT @id_ptocp=id_ptocp FROM tbPtoCp WHERE id_pass = @id_pass AND data = @data AND gerado=1 AND id_diverg=@id_diverg;
if @id_ptocp=0 begin
INSERT INTO tbPtoCp (id_pass,data,id_diverg,soma,id_eveabo_div,id_eveabo_cmp,dt_ini_cmp,dt_fim_cmp,dias_comp,min_comp_dia,m_min_comp_dia,max_comp_dia,
m_max_comp_dia,hrs_tot,horas,m_horas,compensado,m_compensado,pagodesc,m_pagodesc,saldo,m_saldo,id_usuario,gerado)
VALUES (
@id_pass,@data,@id_diverg,0,@id_eveabo_div,@id_eveabo_cmp,@dt_ini_cmp,@dt_fim_cmp, @dias_comp,@min_comp_dia,@m_min_comp_dia,@max_comp_dia,
@m_max_comp_dia, 1, @horas, @m_horas,'+  00:00',0,'+  00:00',0,@horas, @m_horas,@id_usuario,1
);
SELECT @id_ptocp=@@IDENTITY;
end else begin
UPDATE tbPtoCp SET id_pass=@id_pass, data=@data, id_diverg=@id_diverg, soma=0,
id_eveabo_div=@id_eveabo_div, id_eveabo_cmp=@id_eveabo_cmp,
dt_ini_cmp=@dt_ini_cmp, dt_fim_cmp=@dt_fim_cmp, dias_comp=@dias_comp,
min_comp_dia=@min_comp_dia, m_min_comp_dia=@m_min_comp_dia,
max_comp_dia=@max_comp_dia, m_max_comp_dia=@m_max_comp_dia,
hrs_tot=1, horas=@horas, m_horas=@m_horas,
compensado='+  00:00', m_compensado=0,pagodesc='+  00:00', m_pagodesc=0,
saldo=@horas, m_saldo=@m_horas, id_usuario=@id_usuario
WHERE id_ptocp=@id_ptocp;
end;
exec AP_PTO041 @id_empresa output, @id_pass output,  @data output, @id_diverg,  @id_eveabo_cmp, 599999, @id_ptocp, 1;
end;
end; --while (@achou=1) begin
end; --@achou=1
DELETE FROM tbPtoCp WHERE id_pass = @id_pass AND data = @data AND gerado=1
AND id_diverg NOT IN (
SELECT d.id_diverg FROM tbPtoDivsDia d
INNER JOIN tbDivergencias p ON d.id_diverg=p.id_diverg AND p.soma=0 AND p.cp_auto=1 AND p.ativada=1
WHERE d.id_pass=@id_pass AND d.data=@data
AND d.id_diverg NOT IN (SELECT ass.id_diverg FROM tbDivAssoc ass)
);
end;
end;
if @apagarCP=1 begin
DELETE FROM tbPtoCp WHERE id_pass = @id_pass AND data = @data AND gerado=1;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO019') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO019; END;
GO
CREATE PROCEDURE dbo.AP_PTO019(@contamc tinyint,
@m_ent01 int, @m_sai01 int, @m_ent02 int, @m_sai02 int, @m_ent03 int, @m_sai03 int, @m_ent04 int, @m_sai04 int,
@m_ent05 int, @m_sai05 int, @m_ent06 int, @m_sai06 int, @m_ent07 int, @m_sai07 int, @m_ent08 int, @m_sai08 int,
@e1 int, @s1 int, @e2 int, @s2 int, @e3 int,@s3 int, @e4 int, @s4 int, @fxini int, @fxfim int, @fxtmp int,
@fimper1 tinyint output, @fimper2 tinyint output, @fimper3 tinyint output, @fimper4 tinyint output,
@iniflex tinyint output, @fimflex tinyint output
) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @peri tinyint; declare @psi tinyint; declare @sai int; declare @entP int; declare @i int;
select @peri=0, @fimper1=1,@fimper2=0,@fimper3=0,@fimper4=0;
select @psi=1;
while (@peri<4 and @e1>-1) begin
select @peri=@peri+1;
if @peri=1 begin
select @sai=@s1, @entP=@e2;
end else begin if @peri=2 begin
select @sai=@s2, @entP=@e3;
end else begin if @peri=3 begin
select @sai=@s3, @entP=@e4;
end else begin
select @sai=@s4, @entP=99999;
end; end; end;
select @i=2;
while ((@i*2)<=@contamc and @sai>-1) begin
if @i=2 and (@psi+1)=@i begin
if ( (@m_ent02>-1) and
(
(@m_ent02<=@sai and (@m_sai02=-1 OR @entP=-1 OR @m_sai02<=@entP)) OR
(@entP=-1 and @fxini>-1 and @fxfim>-1 and @fxtmp > 0) OR
(
(@m_ent02<@entP and abs(@m_ent02-@sai) < abs(@m_ent02-@entP)) and (@e2=-1 or @m_sai01=-1 or @m_sai01<@e1)
)
)
) or (@m_ent02=-1 and (@m_sai02<@sai or abs(@m_sai02-@sai) < abs(@m_sai02-@entP)))
begin
select @psi=@i;
end;
end;
if @i=3 and (@psi+1)=@i begin
if (@m_ent03>-1 and (@m_ent03<=@sai or (@m_ent03<@entP and abs(@m_ent03-@sai) < abs(@m_ent03-@entP)))) or
(@m_ent03=-1 and (@m_sai03<@sai or abs(@m_sai03-@sai) < abs(@m_sai03-@entP))) begin
select @psi=@i; end;
end;
if @i=4 and (@psi+1)=@i begin
if (@m_ent04>-1 and (@m_ent04<=@sai or (@m_ent04<@entP and abs(@m_ent04-@sai) < abs(@m_ent04-@entP)))) or
(@m_ent04=-1 and (@m_sai04<@sai or abs(@m_sai04-@sai) < abs(@m_sai04-@entP))) begin
select @psi=@i; end;
end;
if @i=5 and (@psi+1)=@i begin
if (@m_ent05>-1 and (@m_ent05<=@sai or (@m_ent05<@entP and abs(@m_ent05-@sai) < abs(@m_ent05-@entP)))) or
(@m_ent05=-1 and (@m_sai05<@sai or abs(@m_sai05-@sai) < abs(@m_sai05-@entP))) begin
select @psi=@i; end;
end;
if @i=6 and (@psi+1)=@i begin
if (@m_ent06>-1 and (@m_ent06<=@sai or (@m_ent06<@entP and abs(@m_ent06-@sai) < abs(@m_ent06-@entP)))) or
(@m_ent06=-1 and (@m_sai06<@sai or abs(@m_sai06-@sai) < abs(@m_sai06-@entP))) begin
select @psi=@i; end;
end;
if @i=7 and (@psi+1)=@i begin
if (@m_ent07>-1 and (@m_ent07<=@sai or (@m_ent07<@entP and abs(@m_ent07-@sai) < abs(@m_ent07-@entP)))) or
(@m_ent07=-1 and (@m_sai07<@sai or abs(@m_sai07-@sai) < abs(@m_sai07-@entP))) begin
select @psi=@i; end;
end;
if @i=8 and (@psi+1)=@i begin
if (@m_ent08>-1 and (@m_ent08<=@sai or (@m_ent08<@entP and abs(@m_ent08-@sai) < abs(@m_ent08-@entP)))) or
(@m_ent08=-1 and (@m_sai08<@sai or abs(@m_sai08-@sai) < abs(@m_sai08-@entP))) begin
select @psi=@i; end;
end;
select @i=@i+1;
end;
if @peri=1 begin
select @fimper1=@psi, @fimper2=@psi+1;
end else begin if @peri=2 begin
select @fimper2=@psi, @fimper3=@psi+1;
end else begin if @peri=3 begin
select @fimper3=@psi, @fimper4=@psi+1;
end else begin
select @fimper4=@psi;
end; end; end;
end;
select @iniflex=0,@fimflex=0;
if @fxini>-1 and @fxfim>-1 and @fxtmp > 0 begin
if @contamc > 0 and ((@m_sai01>=@fxini and @m_sai01<=@fxfim) or (@m_ent02>@fxini and (@m_ent02<=@fxfim or @m_sai01<=@fxini))) begin
select @iniflex=1, @fimflex=2;
if @contamc > 2 and ((@m_sai02>=@fxini and @m_sai02<=@fxfim) or (@m_ent03>@fxini and (@m_ent03<=@fxfim or (@m_sai02>-1 and @m_sai02<=@fxini)))) begin select @fimflex=3; end;
if @contamc > 4 and ((@m_sai03>=@fxini and @m_sai03<=@fxfim) or (@m_ent04>@fxini and (@m_ent04<=@fxfim or (@m_sai03>-1 and @m_sai03<=@fxini)))) begin select @fimflex=4; end;
if @contamc > 6 and ((@m_sai04>=@fxini and @m_sai04<=@fxfim) or (@m_ent05>@fxini and (@m_ent05<=@fxfim or (@m_sai04>-1 and @m_sai04<=@fxini)))) begin select @fimflex=5; end;
if @contamc > 8 and ((@m_sai05>=@fxini and @m_sai05<=@fxfim) or (@m_ent06>@fxini and (@m_ent06<=@fxfim or (@m_sai05>-1 and @m_sai05<=@fxini)))) begin select @fimflex=6; end;
if @contamc > 10 and ((@m_sai06>=@fxini and @m_sai06<=@fxfim) or (@m_ent07>@fxini and (@m_ent07<=@fxfim or (@m_sai06>-1 and @m_sai06<=@fxini)))) begin select @fimflex=7; end;
if @contamc > 12 and ((@m_sai07>=@fxini and @m_sai07<=@fxfim) or (@m_ent08>@fxini and (@m_ent08<=@fxfim or (@m_sai07>-1 and @m_sai07<=@fxini)))) begin select @fimflex=8; end;
if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin select @fimflex=9; end;
end else begin if @contamc > 2 and ((@m_sai02>=@fxini and @m_sai02<=@fxfim) or (@m_ent03>@fxini and (@m_ent03<=@fxfim or @m_sai02<=@fxini))) begin
select @iniflex=2, @fimflex=3;
if @contamc > 4 and ((@m_sai03>=@fxini and @m_sai03<=@fxfim) or (@m_ent04>@fxini and (@m_ent04<=@fxfim or @m_sai03<=@fxini))) begin select @fimflex=4; end;
if @contamc > 6 and ((@m_sai04>=@fxini and @m_sai04<=@fxfim) or (@m_ent05>@fxini and (@m_ent05<=@fxfim or @m_sai04<=@fxini))) begin select @fimflex=5; end;
if @contamc > 8 and ((@m_sai05>=@fxini and @m_sai05<=@fxfim) or (@m_ent06>@fxini and (@m_ent06<=@fxfim or @m_sai05<=@fxini))) begin select @fimflex=6; end;
if @contamc > 10 and ((@m_sai06>=@fxini and @m_sai06<=@fxfim) or (@m_ent07>@fxini and (@m_ent07<=@fxfim or @m_sai06<=@fxini))) begin select @fimflex=7; end;
if @contamc > 12 and ((@m_sai07>=@fxini and @m_sai07<=@fxfim) or (@m_ent08>@fxini and (@m_ent08<=@fxfim or @m_sai07<=@fxini))) begin select @fimflex=8; end;
if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin select @fimflex=9; end;
end else begin if @contamc > 4 and ((@m_sai03>=@fxini and @m_sai03<=@fxfim) or (@m_ent04>@fxini and (@m_ent04<=@fxfim or @m_sai03<=@fxini))) begin
select @iniflex=3, @fimflex=4;
if @contamc > 6 and ((@m_sai04>=@fxini and @m_sai04<=@fxfim) or (@m_ent05>@fxini and (@m_ent05<=@fxfim or @m_sai04<=@fxini))) begin select @fimflex=5; end;
if @contamc > 8 and ((@m_sai05>=@fxini and @m_sai05<=@fxfim) or (@m_ent06>@fxini and (@m_ent06<=@fxfim or @m_sai05<=@fxini))) begin select @fimflex=6; end;
if @contamc > 10 and ((@m_sai06>=@fxini and @m_sai06<=@fxfim) or (@m_ent07>@fxini and (@m_ent07<=@fxfim or @m_sai07<=@fxini))) begin select @fimflex=7; end;
if @contamc > 12 and ((@m_sai07>=@fxini and @m_sai07<=@fxfim) or (@m_ent08>@fxini and (@m_ent08<=@fxfim or @m_sai07<=@fxini))) begin select @fimflex=8; end;
if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin select @fimflex=9; end;
end else begin if @contamc > 6 and ((@m_sai04>=@fxini and @m_sai04<=@fxfim) or (@m_ent05>@fxini and (@m_ent05<=@fxfim or @m_sai04<=@fxini))) begin
select @iniflex=4, @fimflex=5;
if @contamc > 8 and ((@m_sai05>=@fxini and @m_sai05<=@fxfim) or (@m_ent06>@fxini and (@m_ent06<=@fxfim or @m_sai05<=@fxini))) begin select @fimflex=6; end;
if @contamc > 10 and ((@m_sai06>=@fxini and @m_sai06<=@fxfim) or (@m_ent07>@fxini and (@m_ent07<=@fxfim or @m_sai06<=@fxini))) begin select @fimflex=7; end;
if @contamc > 12 and ((@m_sai07>=@fxini and @m_sai07<=@fxfim) or (@m_ent08>@fxini and (@m_ent08<=@fxfim or @m_sai07<=@fxini))) begin select @fimflex=8; end;
if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin select @fimflex=9; end;
end else begin if @contamc > 8 and ((@m_sai05>=@fxini and @m_sai05<=@fxfim) or (@m_ent06>@fxini and (@m_ent06<=@fxfim or @m_sai05<=@fxini))) begin
select @iniflex=5, @fimflex=6;
if @contamc > 10 and ((@m_sai06>=@fxini and @m_sai06<=@fxfim) or (@m_ent07>@fxini and (@m_ent07<=@fxfim or @m_sai06<=@fxini))) begin select @fimflex=7; end;
if @contamc > 12 and ((@m_sai07>=@fxini and @m_sai07<=@fxfim) or (@m_ent08>@fxini and (@m_ent08<=@fxfim or @m_sai07<=@fxini))) begin select @fimflex=8; end;
if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin select @fimflex=9; end;
end else begin if @contamc > 10 and ((@m_sai06>=@fxini and @m_sai06<=@fxfim) or (@m_ent07>@fxini and (@m_ent07<=@fxfim or @m_sai06<=@fxini))) begin
select @iniflex=6, @fimflex=7;
if @contamc > 12 and ((@m_sai07>=@fxini and @m_sai07<=@fxfim) or (@m_ent08>@fxini and (@m_ent08<=@fxfim or @m_sai07>=@fxini))) begin select @fimflex=8; end;
if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin select @fimflex=9; end;
end else begin if @contamc > 12 and ((@m_sai07>=@fxini and @m_sai07<=@fxfim) or (@m_ent08>@fxini and (@m_ent08<=@fxfim or @m_sai07<=@fxini))) begin
select @iniflex=7, @fimflex=8;
if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin select @fimflex=9; end;
end else begin if @contamc > 14 and @m_sai08>=@fxini and @m_sai08<=@fxfim begin
select @iniflex=8, @fimflex=9;
end; end;end; end; end; end; end; end;
if @iniflex=0 and @fimflex=0 begin
if @contamc>2 and @m_sai01=-1 and @m_ent02=-1 and @m_ent01 < @fxfim and @m_sai02 > @fxini begin
select @iniflex=1, @fimflex=2;
end else begin if @contamc>4 and @m_sai02=-1 and @m_ent03=-1 and @m_ent02 < @fxfim and @m_sai03 > @fxini begin
select @iniflex=2, @fimflex=3;
end else begin if @contamc>6 and @m_sai03=-1 and @m_ent04=-1 and @m_ent03 < @fxfim and @m_sai04 > @fxini begin
select @iniflex=3, @fimflex=4;
end else begin if @contamc>8 and @m_sai04=-1 and @m_ent05=-1 and @m_ent04 < @fxfim and @m_sai05 > @fxini begin
select @iniflex=4, @fimflex=5;
end else begin if @contamc>10 and @m_sai05=-1 and @m_ent06=-1 and @m_ent05 < @fxfim and @m_sai06 > @fxini begin
select @iniflex=5, @fimflex=6;
end else begin if @contamc>12 and @m_sai06=-1 and @m_ent07=-1 and @m_ent06 < @fxfim and @m_sai07 > @fxini begin
select @iniflex=6, @fimflex=7;
end else begin if @contamc>14 and @m_sai07=-1 and @m_ent08=-1 and @m_ent07 < @fxfim and @m_sai08 > @fxini begin
select @iniflex=7, @fimflex=8;
end; end; end; end; end; end; end;
end;
end;
if @e1=-1 begin select @fimper1=0 end; if @e2=-1 begin select @fimper2=0 end;
if @e3=-1 begin select @fimper3=0 end; if @e4=-1 begin select @fimper4=0 end;
if @fimper1>=@fimper2 begin select @fimper2=0 end; if @fimper1>=@fimper3 begin select @fimper3=0 end;
if @fimper1>=@fimper4 begin select @fimper4=0 end; if @fimper2>=@fimper3 begin select @fimper3=0 end;
if @fimper2>=@fimper4 begin select @fimper4=0 end; if @fimper3>=@fimper4 begin select @fimper4=0 end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO020') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO020; END;
GO
CREATE PROCEDURE dbo.AP_PTO020(@id_pass int output, @data datetime output, @id_phorario int, @id_tolera int, @trabalhado bit, @contamc tinyint, @m_hrs_prev int,
@m_ent01 int, @m_sai01 int, @m_ent02 int, @m_sai02 int, @m_ent03 int, @m_sai03 int, @m_ent04 int, @m_sai04 int,
@m_ent05 int, @m_sai05 int, @m_ent06 int, @m_sai06 int, @m_ent07 int, @m_sai07 int, @m_ent08 int, @m_sai08 int,
@fimper1 tinyint, @fimper2 tinyint, @fimper3 tinyint, @fimper4 tinyint, @iniflex tinyint, @fimflex tinyint,
@e1 int, @s1 int, @e2 int, @s2 int, @e3 int, @s3 int, @e4 int, @s4 int, @fxini int, @fxfim int, @fxtmp int,
@falta bit output, @falta_aux bit output, @obs varchar(30) output
) WITH ENCRYPTION AS
BEGIN
declare @temfm bit; declare @vlr int, @vlr2 int;
declare @fm_fora_hor bit; declare @permc tinyint; declare @intvflex bit;
declare @fmE bit; declare @fmS bit;
declare @fmE1 bit; declare @fmS1 bit; declare @fmE2 bit; declare @fmS2 bit;
declare @fmE3 bit; declare @fmS3 bit; declare @fmE4 bit; declare @fmS4 bit;
declare @fmE5 bit; declare @fmS5 bit;
declare @falt1 bit; declare @falt2 bit; declare @falt3 bit; declare @falt4 bit;
declare @fmFE bit; declare @fmFS bit; declare @faltF bit;
declare @hent int; declare @hsai int; declare @iniper tinyint; declare @fimper tinyint;
declare @i int; declare @ment int; declare @msai int; declare @msai_ant int; declare @ment_prox int;
declare @msai_prox int;
declare @difitv int; declare @diffmFE int; declare @diffmFS int;
declare @trab1 int; declare @trab2 int; declare @trab3 int; declare @trab4 int; declare @trab int;
declare @m_desc_ent1 int, @m_desc_sai1 int, @m_desc_ent2 int, @m_desc_sai2 int;
declare @m_acre_ent1 int, @m_acre_sai1 int, @m_acre_ent2 int, @m_acre_sai2 int;
declare @pto_obrig bit; declare @dtHoje datetime;
select @falta=0, @falta_aux=0, @temfm=0, @fm_fora_hor=0, @difitv=@fxtmp, @trab1=0,@trab2=0,@trab3=0,@trab4=0, @trab=0,@diffmFS=0,@diffmFE=0;
select @pto_obrig=1;
SELECT @pto_obrig=isnull(pto_obrig,1) FROM tbFunc WHERE id_pass=@id_pass;
if @contamc=0 begin
if @m_hrs_prev > 0 begin
select @falta_aux=1;
select @dtHoje = convert(datetime,convert(varchar,getdate(),101));
if @pto_obrig=1 and (@data < @dtHoje or
(@data=@dtHoje and (isnull(@e1,0)=0 or dateadd(n,@e1-1430,@data)<=getdate())))
begin
select @falta=1;
if ltrim(@obs)='' begin UPDATE tbPtoDia SET obs='Falta' WHERE id_pass=@id_pass AND data = @data; end;
exec AP_PTO018 @id_pass output, @data output, 29, @m_hrs_prev;
UPDATE tbPtoEstat SET m_faltas=@m_hrs_prev WHERE id_pass=@id_pass AND data=@data;
end;
end;
end else begin
if @m_hrs_prev > 0 begin
select @m_desc_ent1=-1,@m_desc_sai1=-1,@m_desc_ent2=-1,@m_desc_sai2=-1;
select @m_acre_ent1=-1,@m_acre_sai1=-1,@m_acre_ent2=-1,@m_acre_sai2=-1;
SELECT TOP 1 @m_acre_ent1=m_acre_ent1_dia, @m_acre_sai1=m_acre_sai1_dia,
@m_acre_ent2=m_acre_ent2_dia, @m_acre_sai2=m_acre_sai2_dia,
@m_desc_ent1=m_desc_ent1_dia, @m_desc_sai1=m_desc_sai1_dia, @m_desc_ent2=m_desc_ent2_dia,
@m_desc_sai2=m_desc_sai2_dia
FROM tbTolera WHERE id_tolera = isnull(@id_tolera,0);
select @fmE1=0,@fmS1=0,@fmE2=0,@fmS2=0,@fmE3=0,@fmS3=0,@fmE4=0,@fmS4=0;
select @fmE5=0,@fmS5=0,@fmFE=0,@fmFS=0,@falt1=1,@falt2=1,@falt3=1,@falt4=1,@faltF=1;
select @i=0;
while (@i<8) begin
select @i=@i+1;
select @ment=@m_ent01, @msai_ant=-1, @msai=@m_sai01, @ment_prox=@m_ent02, @msai_prox=@m_sai02;
if @i=2 begin select @ment=@m_ent02, @msai_ant=@m_sai01, @msai=@m_sai02, @ment_prox=@m_ent03, @msai_prox=@m_sai03; end;
if @i=3 begin select @ment=@m_ent03, @msai_ant=@m_sai02, @msai=@m_sai03, @ment_prox=@m_ent04, @msai_prox=@m_sai04; end;
if @i=4 begin select @ment=@m_ent04, @msai_ant=@m_sai03, @msai=@m_sai04, @ment_prox=@m_ent05, @msai_prox=@m_sai05; end;
if @i=5 begin select @ment=@m_ent05, @msai_ant=@m_sai04, @msai=@m_sai05, @ment_prox=@m_ent06, @msai_prox=@m_sai06; end;
if @i=6 begin select @ment=@m_ent06, @msai_ant=@m_sai05, @msai=@m_sai06, @ment_prox=@m_ent07, @msai_prox=@m_sai07; end;
if @i=7 begin select @ment=@m_ent07, @msai_ant=@m_sai06, @msai=@m_sai07, @ment_prox=@m_ent08, @msai_prox=@m_sai08; end;
if @i=8 begin select @ment=@m_ent08, @msai_ant=@m_sai07, @msai=@m_sai08, @ment_prox=-1, @msai_prox=-1; end;
if @contamc>=(@i*2) begin
select @permc=0, @hent=-1, @hsai=-1, @fimper=0, @iniper=0;
if @fimper1 >=@i begin select @permc=1, @hent=@e1, @hsai=@s1, @iniper=1, @fimper=@fimper1, @fmE=@fmE1, @fmS=@fmS1,@trab=@trab1;
end else begin if @fimper2 >=@i begin select @permc=2, @hent=@e2, @hsai=@s2, @iniper=@fimper1+1, @fimper=@fimper2, @fmE=@fmE2, @fmS=@fmS2,@trab=@trab2;
end else begin if @fimper3 >=@i begin select @permc=3, @hent=@e3, @hsai=@s3, @iniper=(CASE WHEN @fimper2>0 THEN @fimper2+1 ELSE @fimper1+1 END), @fimper=@fimper3, @fmE=@fmE3, @fmS=@fmS3,@trab=@trab3;
end else begin if @fimper4 >=@i begin select @permc=4, @hent=@e4, @hsai=@s4, @iniper=(CASE WHEN @fimper3>0 THEN @fimper3+1 WHEN @fimper2>0 THEN @fimper2+1 ELSE @fimper1+1 END), @fimper=@fimper4, @fmE=@fmE4, @fmS=@fmS4,@trab=@trab4;
end; end; end; end;
if @ment=-1 begin if @permc>0 and @iniper=@i begin select @fmE=1; end else begin if @iniflex=0 or @i<=@iniflex or  @i>@fimflex begin select @fm_fora_hor=1; end; end; end;
if @msai=-1 begin if @permc>0 and @fimper=@i begin select @fmS=1; end else begin if @iniflex=0 or @i<@iniflex or  @i>=@fimflex begin select @fm_fora_hor=1; end; end; end;
if @permc>0 begin
if @ment>-1 and @msai>-1 and @msai>@hent begin
if @ment>=@hent and not (@m_desc_ent1>=0 and @m_desc_ent1 >= (@ment-@hent)) begin
if @msai<=@hsai and not (@m_desc_sai2>=0 and @m_desc_sai2 >= (@hsai-@msai))
select @trab=@trab+(@msai-@ment);
else
select @trab=@trab+(@hsai-@ment);
end else begin
if @msai<=@hsai and not (@m_desc_sai2>=0 and @m_desc_sai2 >= (@hsai-@msai))
select @trab=@trab+(@msai-@hent);
else
select @trab=@trab+(@hsai-@hent);
end;
end else begin
if @ment>-1 and @msai=-1 and @ment_prox=-1 and @msai_prox>-1 and @msai_prox>@hent
begin
if @ment>=@hent and not (@m_desc_ent1>=0 and @m_desc_ent1 >= (@hent-@ment)) begin
if @msai_prox<=@hsai and not (@m_desc_sai2>=0 and @m_desc_sai2 >= (@hsai-@msai_prox))
select @trab=@trab+(@msai_prox-@ment);
else
select @trab=@trab+(@hsai-@ment);
end else begin
if @msai_prox<=@hsai and not (@m_desc_sai2>=0 and @m_desc_sai2 >= (@hsai-@msai_prox))
select @trab=@trab+(@msai_prox-@hent);
else
select @trab=@trab+(@hsai-@hent);
end;
if @iniflex<=@i and @fimflex>=@i and @fxtmp>0 begin
select @trab=@trab-@fxtmp;
if @trab<0
select @trab=0;
end;
end;
end;
end;
if @permc=1 begin select @fmE1=@fmE,@fmS1=@fmS,@falt1=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt1 END),@trab1=@trab;
end else begin if @permc=2 begin select @fmE2=@fmE,@fmS2=@fmS,@falt2=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt2 END),@trab2=@trab;
end else begin if @permc=3 begin select @fmE3=@fmE,@fmS3=@fmS,@falt3=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt3 END),@trab3=@trab;
end else begin if @permc=4 begin select @fmE4=@fmE,@fmS4=@fmS,@falt4=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt4 END),@trab4=@trab;
end; end; end; end;
if @iniflex<=@i and @fimflex>=@i begin
if @iniflex=@i and @msai=-1 begin
select @fmFS=1;
if @ment_prox=-1 or @ment_prox<@fxini+@fxtmp begin
if @hent>-1 and @hent<@fxini begin
if @ment=-1 or @ment<@hent begin select @diffmFS=(@fxini-@hent); end else begin select @diffmFS=(@fxini-@ment); end;
end;
end else begin
if @hent>-1 and @hent<=@ment_prox begin
if @ment=-1 or @ment<@hent begin select @diffmFS=@ment_prox-(@hent+@fxtmp); end else begin select @diffmFS=@ment_prox-(@ment+@fxtmp); end;
end;
end;
end else begin if @fimflex=@i and @ment=-1 begin
select @fmFE=1;
if @msai_ant=-1 or @msai_ant>@fxfim-@difitv begin
if @hsai>-1 and @hsai>@fxfim begin
if @msai=-1 or @msai>=@hsai begin select @diffmFE=@diffmFE+(@hsai-@fxfim); end else begin select @diffmFS=@diffmFS+(@msai-@fxfim); end;
end;
end else begin
if @hsai>-1 and @hsai>=@msai_ant begin
if @msai=-1 or @msai>@hsai begin select @diffmFE=@hsai-(@msai_ant+@difitv); end else begin select @diffmFE=@msai-(@msai_ant+@difitv); end;
end;
end;
end else begin
if @fmFS=0 and @fmFE=0 and @iniflex<@i and @fimflex>@i and (@ment=-1 or @msai=-1)  begin
select @fm_fora_hor=1;
end;
end; end;
if @difitv>0 and (@msai>-1 and @msai<@fxfim) or (@ment_prox>-1 and @ment_prox>@iniflex) begin
select @vlr=0;
if @msai>-1 and @ment_prox>-1 begin
select @vlr=(case when @ment_prox>@fxfim then @fxfim else @ment_prox end);
select @vlr=@vlr-(case when @msai<@fxini then @fxini else @msai end);
end else begin if @msai=-1 begin
if @iniflex=@i begin
select @vlr=(case when @ment_prox>@fxfim then @fxfim else @ment_prox end);
select @vlr=@vlr-@fxini;
end;
end else begin
if @fimflex=@i begin
select @vlr=@fxfim;
select @vlr=@vlr-(case when @msai<@fxini then @fxini else @msai end);
end;
end; end;
if @vlr>0 begin select @difitv=@difitv-@vlr; end;
if @difitv<0 begin select @difitv=0; end;
if (@iniflex<>@i and @ment>-1) or (@fimflex<>@i and @msai>-1) begin select @faltF = 0; end;
end;
end;
end; -- @contamc>=(@i*2)
end;
end else begin
if (@contamc > 0 and (@m_ent01=-1 or @m_sai01=-1)) or (@contamc > 2 and (@m_ent02=-1 or @m_sai02=-1)) or
(@contamc > 4 and (@m_ent03=-1 or @m_sai03=-1)) or (@contamc > 6 and (@m_ent04=-1 or @m_sai04=-1)) or
(@contamc > 8 and (@m_ent05=-1 or @m_sai05=-1)) or (@contamc > 10 and (@m_ent06=-1 or @m_sai06=-1)) or
(@contamc > 12 and (@m_ent07=-1 or @m_sai07=-1)) or (@contamc > 14 and (@m_ent08=-1 or @m_sai08=-1)) begin
select @fm_fora_hor=1;
end;
end;
if @fxtmp>0 and @contamc=2 begin
if @m_ent01=-1 or @m_sai01=-1 or @m_ent01>@fxini or @m_sai01<=(@fxfim-@fxtmp) or @m_sai01-@m_ent01<=@fxtmp  begin
select @faltF=0, @fmFE=0, @fmFS=0;
end;
end else begin
if @fxtmp>0 and @contamc=4 and @fimper1=2
select @faltF=0
end;
/* Tratar 'Falta no 1 perodo' e 'Falta no 2 perodo' quando se utiliza intervalo flexvel*/
select @i=0;
if @fxtmp>0 begin
if @contamc=2 and (@m_ent01>-1 or @m_sai01>-1) begin
if (@m_sai01>-1 and @m_sai01<@fxini) or (@m_ent01<@fxini and (@m_sai01=-1 or (@m_sai01>=@fxini and @m_sai01<=@fxfim))) begin
select @i=2;
end else begin
if ((@m_ent01=-1 or (@m_ent01>=@fxini and @m_ent01<=@fxfim)) and (@m_sai01=-1 or @m_sai01>@fxfim)) or
((@m_ent01=-1 or @m_ent01>@fxfim) and (@m_sai01=-1 or @m_sai01>@fxfim)) begin
select @i=1;
end; end;
end else begin
if @contamc=4 and @m_ent01=-1 and @m_sai01=-1 and (@m_ent02>-1 or @m_sai02>-1) begin
if (@m_ent02=-1 or @m_ent02>=@fxini) and (@m_sai02=-1 or @m_sai02>@fxfim) begin select @i=1; end;
end;
end;
end;
if @i>0 begin
if @trab1=0 begin
if @m_sai01>-1 and @m_sai01<=@e1 begin
select @vlr=(@s1-@e1)-@fxtmp;
end else begin
select @vlr=((@s1-@e1)-@fxtmp)/2;
end;
end else begin
select @vlr=(@s1-@e1)-(@trab1+@fxtmp);
if @m_ent01>-1 and @m_ent01>@e1 and @m_ent01<(@e1+240) begin
select @vlr=@vlr-(@m_ent01-@e1);
if @vlr<0 begin select @vlr=0; end;
end;
end;
if @i=1 begin
--if @trab1=0 begin exec AP_PTO018 @id_pass output, @data output, 64, @vlr; end;
exec AP_PTO018 @id_pass output, @data output, 1, @vlr;
end else begin
if @trab1=0 and @fxtmp>0 and @m_ent01>-1 and @m_sai01=-1 and @m_ent02=-1 and @m_sai02=-1 begin
if @m_ent01 <= @e1 begin
exec AP_PTO018 @id_pass output, @data output, 65, @vlr;
end else if @m_ent01<(@e1+@vlr) begin
select @vlr2=(@e1+@vlr)-@m_ent01;
exec AP_PTO018 @id_pass output, @data output, 65, @vlr2;
end;
end;
exec AP_PTO018 @id_pass output, @data output, 2, @vlr;
end;
select @faltF=0, @fmFE=0, @fmFS=0;
end else begin
if @e1>-1 and (@falt1=1 or @fmE1=1 or @fmS1=1) begin
if @e1<=@fxfim and @s1>=@fxini and @fxtmp>0  begin
select @vlr=(@s1-@e1)-(@trab1+@fxtmp);
--select @faltF=0, @fmFE=0, @fmFS=0;
select @faltF=0;
end else begin
select @vlr=(@s1-@e1)-@trab1;
end;
if @vlr < 0 begin select @vlr=0; end;
if @falt1=1 begin
exec AP_PTO018 @id_pass output, @data output, 1, @vlr;
end else begin
if @fmE1=1 begin
if @m_ent01=-1 and @m_sai01>=@e1 begin
if @m_sai01<=@s1 begin
select @vlr=@m_sai01-@e1;
end else begin
select @vlr=@s1-@e1;
end;
end;
exec AP_PTO018 @id_pass output, @data output, 5, @vlr;
end;
if @fmS1=1 begin
if @fimper1<=1 begin
if @m_sai01=-1 and @m_ent01>-1 and @m_ent01<=@s1 begin
select @vlr=@s1-@m_ent01;
end;
end else if @fimper1<=2 begin
if @m_sai02=-1 and @m_ent02>-1 and @m_ent02<=@s1 begin
select @vlr=@s1-@m_ent02;
end;
end else if @fimper1<=3 begin
if @m_sai03=-1 and @m_ent03>-1 and @m_ent03<=@s1 begin
select @vlr=@s1-@m_ent03;
end;
end
exec AP_PTO018 @id_pass output, @data output, 9, @vlr;
end;
select @temfm=1;
end;
end;
end;
if @e2>-1 and (@falt2=1 or @fmE2=1 or @fmS2=1) begin
if @e2<=@fxfim and @s2>=@fxini and @fxtmp>0  begin
select @vlr=(@s2-@e2)-(@trab2+@fxtmp);
select @faltF=0, @fmFE=0, @fmFS=0;
end else begin
select @vlr=(@s2-@e2)-@trab2;
end;
if @vlr < 0 begin select @vlr=0; end;
if @falt2=1 begin
exec AP_PTO018 @id_pass output, @data output, 2, @vlr;
end else begin
if @fmE2=1 begin exec AP_PTO018 @id_pass output, @data output, 6, @vlr; end;
if @fmS2=1 begin exec AP_PTO018 @id_pass output, @data output, 10, @vlr; end;
select @temfm=1;
end;
end;
if @e3>-1 and (@falt3=1 or @fmE3=1 or @fmS3=1) begin
if @e3<=@fxfim and @s3>=@fxini and @fxtmp>0  begin
select @vlr=(@s3-@e3)-(@trab3+@fxtmp);
select @faltF=0, @fmFE=0, @fmFS=0;
end else begin
select @vlr=(@s3-@e3)-@trab3;
end;
if @vlr < 0 begin select @vlr=0; end;
if @falt3=1 begin
exec AP_PTO018 @id_pass output, @data output, 3, @vlr;
end else begin
if @fmE3=1 begin exec AP_PTO018 @id_pass output, @data output, 7, @vlr; end;
if @fmS3=1 begin exec AP_PTO018 @id_pass output, @data output, 11, @vlr; end;
select @temfm=1;
end;
end;
if @e4>-1 and (@falt4=1 or @fmE4=1 or @fmS4=1) begin
if @e4<=@fxfim and @s4>=@fxini and @fxtmp>0  begin
select @vlr=(@s4-@e4)-(@trab4+@fxtmp);
select @faltF=0, @fmFE=0, @fmFS=0;
end else begin
select @vlr=(@s4-@e4)-@trab4;
end;
if @vlr < 0 begin select @vlr=0; end;
if @falt4=1 begin
exec AP_PTO018 @id_pass output, @data output, 4, @vlr;
end else begin
if @fmE4=1 begin exec AP_PTO018 @id_pass output, @data output, 8, @vlr; end;
if @fmS4=1 begin exec AP_PTO018 @id_pass output, @data output, 12, @vlr; end;
select @temfm=1;
end;
end;
if @fxini>-1 and (@faltF=1 or @fmFE=1 or @fmFS=1) begin
if (@faltF=1 and @fmFE=0 and @fmFS=0) or (@fmFE=1 and @fmFS=1 and @difitv=@fxtmp) begin
if exists(select acresce_falta from tbPHorarios where id_phorario=@id_phorario and isnull(acresce_falta,0)=0) begin
select @vlr=0
if @trab1>0 begin
select @vlr=@trab1/2
exec AP_PTO018 @id_pass output, @data output, 64, @vlr;
select @vlr=@trab1-@vlr;
exec AP_PTO018 @id_pass output, @data output, 65, @vlr;
end;
end else begin
exec AP_PTO018 @id_pass output, @data output, 30, @fxtmp;
end;
select @temfm=1;
end else begin
if @fmFE=1 or @fmFS=1 begin
if exists(select acresce_falta from tbPHorarios where id_phorario=@id_phorario and isnull(acresce_falta,0)=0) begin
if @fmFE=1 begin
if @diffmFE<0 begin select @diffmFE=0; end;
exec AP_PTO018 @id_pass output, @data output, 64, @diffmFE;
end;
if @fmFS=1 begin
if @diffmFS<0 begin select @diffmFS=0; end;
exec AP_PTO018 @id_pass output, @data output, 65, @diffmFS;
end;
end else begin
exec AP_PTO018 @id_pass output, @data output, 30, @fxtmp;
end;
select @temfm=1;
end;
end;
end;
if @fm_fora_hor=1 begin
select @temfm=1;
end;
if @temfm=1 and (ltrim(@obs)='' or ltrim(@obs)='Domingo') begin
UPDATE tbPtoDia SET obs='F.M.' WHERE id_pass = @id_pass AND data = @data;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO021') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO021; END;
GO
CREATE PROCEDURE dbo.AP_PTO021(@id_pass int output, @data datetime output, @trabalhado bit, @id_phorario int, @contamc tinyint,
@m_ent01 int, @m_sai01 int, @m_ent02 int, @m_sai02 int, @m_ent03 int, @m_sai03 int, @m_ent04 int, @m_sai04 int,
@m_ent05 int, @m_sai05 int, @m_ent06 int, @m_sai06 int, @m_ent07 int, @m_sai07 int, @m_ent08 int, @m_sai08 int,
@falta bit output, @falta_aux bit output, @obs varchar(30) output) WITH ENCRYPTION AS
BEGIN
declare @temfm bit; declare @temfmItv int; declare @temfmES int;
declare @i int; declare @ment int; declare @msai int;
declare @m_intervalo int, @fm_intervalo bit, @apura_tipo int;
declare @pto_obrig bit; declare @dtHoje datetime;
select @m_intervalo=0, @fm_intervalo=1, @apura_tipo=0;
SELECT @m_intervalo=m_intervalo, @fm_intervalo=fm_intervalo, @apura_tipo=apura_tipo FROM tbPHorFlex WHERE id_pflex=@id_phorario;
select @falta=0, @falta_aux=0, @temfmItv=0, @temfmES=0;
select @pto_obrig=1;
SELECT @pto_obrig=isnull(pto_obrig,1) FROM tbFunc WHERE id_pass=@id_pass;
if @contamc=0 begin
if @trabalhado=1 begin
select @falta_aux=1;
select @dtHoje = convert(datetime,convert(varchar,getdate(),101));
if @pto_obrig=1 and @data <= @dtHoje and @apura_tipo=0 begin
select @falta=1;
if ltrim(@obs)='' begin UPDATE tbPtoDia SET obs='Falta' WHERE id_pass = @id_pass AND data = @data; end;
end;
end;
end else begin
select @i=0;
while (@i<8) begin
select @i=@i+1;
select @ment=@m_ent01, @msai=@m_sai01;
if @i=2 begin select @ment=@m_ent02, @msai=@m_sai02; end;
if @i=3 begin select @ment=@m_ent03, @msai=@m_sai03; end;
if @i=4 begin select @ment=@m_ent04, @msai=@m_sai04; end;
if @i=5 begin select @ment=@m_ent05, @msai=@m_sai05; end;
if @i=6 begin select @ment=@m_ent06, @msai=@m_sai06; end;
if @i=7 begin select @ment=@m_ent07, @msai=@m_sai07; end;
if @i=8 begin select @ment=@m_ent08, @msai=@m_sai08; end;
if @contamc>=(@i*2) begin
if @ment=-1 begin
if @i=1 begin select @temfmES=1; end else begin select @temfmItv=1; end;
end;
if @msai=-1 begin
if @contamc=(@i*2) begin select @temfmES=1; end else begin select @temfmItv=1; end;
end;
end;
end;
if @contamc=2 and @fm_intervalo=1 begin select @temfmItv=1; end;
select @temfm=0;
if @temfmItv=1 and @m_intervalo>-1 begin
if @trabalhado=1 begin
exec AP_PTO018 @id_pass output, @data output, 30, @m_intervalo;
end else begin
exec AP_PTO018 @id_pass output, @data output, 30, 0;
end;
select @temfm=1;
end;
if @temfmES=1 begin
select @temfm=1;
end;
if @temfm=1 and (ltrim(@obs)='' or ltrim(@obs)='Domingo') begin
UPDATE tbPtoDia SET obs='F.M.' WHERE id_pass = @id_pass AND data = @data;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO022') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO022; END;
GO
CREATE PROCEDURE dbo.AP_PTO022(@mini int, @mfim int, @noti int, @notf int, @m_ultima int, @pnot int output) WITH ENCRYPTION AS
BEGIN
declare @ni int; declare @nf int;
if @mini>-1 and @mfim>-1 AND @noti>-1 AND @notf>-1 begin
if @mini < @notf and @mfim > @noti begin
select @ni=@noti,@nf=@notf;
if @m_ultima<>-1 and @m_ultima>@nf and @m_ultima < (@noti+1440) begin select @nf=@m_ultima; end;
if @mini < @ni begin
if @mfim > @nf begin select @pnot=@pnot+(@nf-@ni);
end else begin select @pnot=@pnot+(@mfim-@ni); end;
end else begin
if @mfim > @nf begin select @pnot=@pnot+(@nf-@mini);
end else begin select @pnot=@pnot+(@mfim-@mini); end;
end;
end;
if @mini < (@notf+1440) and @mfim > (@noti+1440) begin
select @ni=(@noti+1440),@nf=(@notf+1440);
if @m_ultima>@nf and @m_ultima < (@noti+2880) begin select @nf=@m_ultima; end;
if @mini < @ni begin
if @mfim > @nf begin select @pnot=@pnot+(@nf-@ni);
end else begin select @pnot=@pnot+(@mfim-@ni); end;
end else begin
if @mfim > @nf begin select @pnot=@pnot+(@nf-@mini);
end else begin select @pnot=@pnot+(@mfim-@mini); end;
end;
end;
if @mini < (@notf+2880) and @mfim > (@noti+2880) begin
select @ni=(@noti+2880),@nf=(@notf+2880);
if @m_ultima>@nf begin select @nf=@m_ultima; end;
if @mini < @ni begin
if @mfim > @nf begin select @pnot=@pnot+(@nf-@ni);
end else begin select @pnot=@pnot+(@mfim-@ni); end;
end else begin
if @mfim > @nf begin select @pnot=@pnot+(@nf-@mini);
end else begin select @pnot=@pnot+(@mfim-@mini); end;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO023') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO023; END;
GO
CREATE PROCEDURE dbo.AP_PTO023(@ini int, @fim int, @noti int, @notf int, @he_d int output, @he_n int output, @he_d_sg int output, @he_n_sg int output) WITH ENCRYPTION AS
BEGIN
declare @he_aux_d int; declare @he_aux_n int;
if @fim<2880 begin
select @he_aux_d=@fim-@ini, @he_aux_n=0;
if @noti>-1 and @notf > -1 and @noti < @notf begin EXEC AP_PTO022 @ini,@fim,@noti,@notf,-1,@he_aux_n output; end;
select @he_d=@he_d+(@he_aux_d-@he_aux_n), @he_n=@he_n+@he_aux_n;
end else begin if @ini<2880 begin
select @he_aux_d=2880-@ini, @he_aux_n=0;
if @noti>-1 and @notf > -1 and @noti < @notf begin EXEC AP_PTO022 @ini,2880,@noti,@notf,-1,@he_aux_n output; end;
select @he_d=@he_d+(@he_aux_d-@he_aux_n), @he_n=@he_n+@he_aux_n;
select @he_aux_d=@fim-2880, @he_aux_n=0;
if @noti>-1 and @notf > -1 and @noti < @notf begin EXEC AP_PTO022 2880,@fim,@noti,@notf,-1,@he_aux_n output; end;
select @he_d_sg=@he_d_sg+(@he_aux_d-@he_aux_n), @he_n_sg=@he_n_sg+@he_aux_n;
end else begin
select @he_aux_d=@fim-@ini, @he_aux_n=0;
if @noti>-1 and @notf > -1 and @noti < @notf begin EXEC AP_PTO022 @ini,@fim,@noti,@notf,-1,@he_aux_n output; end;
select @he_d_sg=@he_d_sg+(@he_aux_d-@he_aux_n), @he_n_sg=@he_n_sg+@he_aux_n;
end; end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO024') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO024; END
GO
CREATE PROCEDURE dbo.AP_PTO024(@id_pass int output, @data datetime output, @trabalhado bit, @id_adicional int,
@dom_data datetime, @sab_data datetime, @tolerancia_ini datetime, @tolerancia_fim datetime,
@contamc tinyint, @id_phorario int, @id_arredonda int, @id_tolera int, @id_he int, @tipohe char(1), @m_hrs_prev int, @m_hrs_norm int output,
@m_ent01 int, @m_sai01 int, @m_ent02 int, @m_sai02 int, @m_ent03 int, @m_sai03 int, @m_ent04 int, @m_sai04 int,
@m_ent05 int, @m_sai05 int, @m_ent06 int, @m_sai06 int, @m_ent07 int, @m_sai07 int, @m_ent08 int, @m_sai08 int,
@wdiapto tinyint, @wdiapto_sg tinyint, @fimper1 tinyint, @fimper2 tinyint, @fimper3 tinyint, @fimper4 tinyint, @iniflex tinyint, @fimflex tinyint,
@e1 int, @s1 int, @e2 int, @s2 int, @e3 int, @s3 int, @e4 int, @s4 int, @fxini int, @fxfim int, @fxtmp int,
@ult_he_ent int output, @pri_he_sai int output) WITH ENCRYPTION AS
BEGIN
declare @ent_dia int; declare @sai_dia int;
declare @atr_1 int; declare @atr_2 int; declare @atr_3 int; declare @atr_4 int; declare @atr int;
declare @itv_1 int; declare @itv_2 int; declare @itv_3 int; declare @itv_4 int; declare @itv int;
declare @atc_1 int; declare @atc_2 int; declare @atc_3 int; declare @atc_4 int; declare @atc int;
declare @atr_f int; declare @atc_f int; declare @ant_1 int; declare @ant_2 int;
declare @ant_3 int; declare @ant_4 int; declare @ant int;
declare @dep_1 int; declare @dep_2 int; declare @dep_3 int; declare @dep_4 int; declare @dep int;
declare @dlivre int; declare @itv_antc int;
declare @oatr_1 int, @oatr_2 int, @oatr_3 int, @oatr_4 int, @oatc_1 int, @oatc_2 int, @oatc_3 int, @oatc_4 int, @oatc_f int, @oatr_f int;
declare @he_e1_d int; declare @he_e1_d_fp int; declare @he_e1_n int; declare @he_e1_n_fp int;
declare @he_s1_d int; declare @he_s1_d_fp int; declare @he_s1_n int; declare @he_s1_n_fp int;
declare @he_e2_d int; declare @he_e2_d_fp int; declare @he_e2_n int; declare @he_e2_n_fp int;
declare @he_s2_d int; declare @he_s2_d_fp int; declare @he_s2_n int; declare @he_s2_n_fp int;
declare @he_e1_d_sg int; declare @he_e1_d_fp_sg int; declare @he_e1_n_sg int; declare @he_e1_n_fp_sg int;
declare @he_s1_d_sg int; declare @he_s1_d_fp_sg int; declare @he_s1_n_sg int; declare @he_s1_n_fp_sg int;
declare @he_e2_d_sg int; declare @he_e2_d_fp_sg int; declare @he_e2_n_sg int; declare @he_e2_n_fp_sg int;
declare @he_s2_d_sg int; declare @he_s2_d_fp_sg int; declare @he_s2_n_sg int; declare @he_s2_n_fp_sg int;
declare @i int; declare @ment int; declare @msai int; declare @permc tinyint; declare @ultpermc tinyint;
declare @hent int; declare @hsai int; declare @hent_prox int; declare @hsai_prox int; declare @msai_ant int;
declare @fimper tinyint; declare @iniper tinyint; declare @vlr1 int; declare @vlr2 int, @vlr_itv int;
declare @intv_feito int; declare @ment_prox int; declare @msai_prox int;
declare @adc_ext_per int; declare @adc_min int; declare @adc_minhe int; declare @adc_intv bit; declare @adc_somar bit;
declare @adic_tolera bit;
declare @adc_w_hn char(10); declare @adc_w_he char(10); declare @redhen bit; declare @reduzida bit;
declare @adic_not int; declare @adic_nothe int; declare @adc_fator float; declare @adc_fator_pad bit; declare @noti int; declare @notf int;
declare @reduz_normal int; declare @reduz_he int;
declare @m_primeira int; declare @m_ultima int; declare @m_ultadc int;
declare @m_acre_ent1 int, @m_acre_sai1 int, @m_acre_ent2 int, @m_acre_sai2 int, @m_acre_soma int;
declare @m_desc_ent1 int, @m_desc_sai1 int, @m_desc_ent2 int, @m_desc_sai2 int, @m_desc_soma int;
declare @m_min_comp_dia int, @min_comp_dia_qsem int, @min_comp_dia_itv bit;
declare @m_min2_comp_dia int, @min2_comp_dia_qsem int;
declare @acre_ent1 int, @acre_ent2 int, @acre_sai1 int, @acre_sai2 int, @tolsma bit, @tolsemana bit, @tolmes bit;
declare @he_opcao int; declare @he_periodo int; declare @he_opcao_sg int; declare @he_periodo_sg int;
declare @he_d int; declare @he_d_fp int; declare @he_n int; declare @he_n_fp int;
declare @he_d_sg int; declare @he_d_fp_sg int; declare @he_n_sg int; declare @he_n_fp_sg int;
declare @m_abater_ht int; declare @m_abater_vl int;
declare @he_itv bit; declare @folga_dia bit; declare @achou bit;
declare @m_desc_soma_mes int, @desc_soma_qmes int, @m_desc_soma_sem int, @desc_soma_qsem int;
declare @m_acre_soma_mes int, @acre_soma_qmes int, @m_acre_soma_sem int, @acre_soma_qsem int;
declare @desc_exc tinyint, @acre_exc tinyint;
declare @tot_acre_exc int, @tot_desc_exc int;
declare @tot_desc_dia int, @tot_acre_dia int, @tot_acre_old int, @total_s int, @total_m int;
declare @ult_periodo tinyint; declare @vlr int; declare @wdiafaixa tinyint; declare @excede_flex bit;
declare @opstols1 bit, @opstols2 bit, @opstols3 bit, @opstols4 bit, @opstolm1 bit, @opstolm2 bit, @opstolm3 bit, @opstolm4 bit;
declare @opstols1a bit, @opstols2a bit, @opstols3a bit, @opstols4a bit, @opstolm1a bit, @opstolm2a bit, @opstolm3a bit, @opstolm4a bit;
declare @he_inicio tinyint;
declare @contafx int; declare @m_faixa_fim int; declare @id_divadc int;
declare @he_ace bit, @div_102 bit, @div_103 bit, @ptoace_p int, @ptoace_u int;
declare @ent_compensar int, @itv_comp int, @sai_comp_tolerado int;
select @ult_periodo=0;
if @fimper1>0 begin select @ult_periodo=1; end;
if @fimper2>0 begin select @ult_periodo=2; end;
if @fimper3>0 begin select @ult_periodo=3; end;
if @fimper4>0 begin select @ult_periodo=4; end;
select @intv_feito=0;
select @atr_1=-1,@atr_2=-1,@atr_3=-1,@atr_4=-1,@atr=-1, @itv_1=0, @itv_2=0, @itv_3=0, @itv_4=0, @itv=0,
@atc_1=0, @atc_2=0, @atc_3=0, @atc_4=0, @atc=0, @atc_f=0, @atr_f=0;
select @ant_1=0, @ant_2=0, @ant_3=0, @ant_4=0, @ant=0, @dep_1=0, @dep_2=0, @dep_3=0, @dep_4=0, @dep=0, @dlivre=0;
select @m_hrs_norm=0;
select @he_e1_d=0,@he_e1_d_fp=0,@he_e1_n=0,@he_e1_n_fp=0,@he_s1_d=0,@he_s1_d_fp=0,@he_s1_n=0,@he_s1_n_fp=0,@he_e2_d=0,@he_e2_d_fp=0,@he_e2_n=0,@he_e2_n_fp=0,@he_s2_d=0,@he_s2_d_fp=0,@he_s2_n=0,@he_s2_n_fp=0;
select @he_e1_d_sg=0,@he_e1_d_fp_sg=0,@he_e1_n_sg=0,@he_e1_n_fp_sg=0,@he_s1_d_sg=0,@he_s1_d_fp_sg=0,@he_s1_n_sg=0,@he_s1_n_fp_sg=0,@he_e2_d_sg=0,@he_e2_d_fp_sg=0,@he_e2_n_sg=0,@he_e2_n_fp_sg=0,@he_s2_d_sg=0,@he_s2_d_fp_sg=0,@he_s2_n_sg=0,@he_s2_n_fp_sg=0;
select @ult_he_ent=0,@pri_he_sai=0;
select @ultpermc=0;
if @fimper1>0 begin select @ultpermc=1; end; if @fimper2>0 begin select @ultpermc=2; end;
if @fimper3>0 begin select @ultpermc=3; end; if @fimper4>0 begin select @ultpermc=4; end;
select @sai_comp_tolerado=0;
select @m_desc_ent1=-1,@m_desc_sai1=-1,@m_desc_ent2=-1,@m_desc_sai2=-1,@m_desc_soma=-1;
select @m_min_comp_dia=-1, @min_comp_dia_qsem=0, @min_comp_dia_itv=0;
select @m_min2_comp_dia=-1, @min2_comp_dia_qsem=0;
select @m_acre_ent1=-1,@m_acre_sai1=-1,@m_acre_ent2=-1,@m_acre_sai2=-1,@m_acre_soma=-1;
select @m_desc_soma_mes=-1, @desc_soma_qmes=0, @m_desc_soma_sem=0, @desc_soma_qsem=0;
select @m_acre_soma_mes=-1, @acre_soma_qmes=0, @m_acre_soma_sem=0, @acre_soma_qsem=0;
select @desc_exc=0, @acre_exc=0;
select @opstols1=0,@opstols2=0,@opstols3=0,@opstols4=0,@opstolm1=0,@opstolm2=0,@opstolm3=0,@opstolm4=0;
select @opstols1a=0,@opstols2a=0,@opstols3a=0,@opstols4a=0,@opstolm1a=0,@opstolm2a=0,@opstolm3a=0,@opstolm4a=0;
SELECT TOP 1 @m_acre_ent1=m_acre_ent1_dia, @m_acre_sai1=m_acre_sai1_dia,
@m_acre_ent2=m_acre_ent2_dia, @m_acre_sai2=m_acre_sai2_dia, @m_acre_soma=m_acre_soma_dia,
@m_desc_ent1=m_desc_ent1_dia, @m_desc_sai1=m_desc_sai1_dia, @m_desc_ent2=m_desc_ent2_dia,
@m_min_comp_dia=isnull(m_min_comp_dia,-1), @min_comp_dia_qsem=isnull(min_comp_dia_qsem,0), @min_comp_dia_itv=isnull(min_comp_dia_itv,0),
@m_min2_comp_dia=isnull(m_min2_comp_dia,-1), @min2_comp_dia_qsem=isnull(min2_comp_dia_qsem,0),
@m_desc_sai2=m_desc_sai2_dia, @m_desc_soma=m_desc_soma_dia,
@m_desc_soma_mes=m_desc_soma_mes, @desc_soma_qmes=desc_soma_qmes,
@m_desc_soma_sem=m_desc_soma_sem, @desc_soma_qsem=desc_soma_qsem,
@m_acre_soma_mes=isnull(m_acre_soma_mes,0), @acre_soma_qmes=isnull(acre_soma_qmes,0),
@m_acre_soma_sem=isnull(m_acre_soma_sem,0), @acre_soma_qsem=isnull(acre_soma_qsem,0),
@desc_exc=isnull(desc_exc,0), @acre_exc=isnull(acre_exc,0),
@opstols1=opstols1,@opstols2=opstols2,@opstols3=opstols3,@opstols4=opstols4,
@opstolm1=opstolm1,@opstolm2=opstolm2,@opstolm3=opstolm3,@opstolm4=opstolm4,
@opstols1a=isnull(opstols1a,0),@opstols2a=isnull(opstols2a,0),@opstols3a=isnull(opstols3a,0),@opstols4a=isnull(opstols4a,0),
@opstolm1a=isnull(opstolm1a,0),@opstolm2a=isnull(opstolm2a,0),@opstolm3a=isnull(opstolm3a,0),@opstolm4a=isnull(opstolm4a,0)
FROM tbTolera WHERE id_tolera = isnull(@id_tolera,0);
select @m_abater_ht=-1, @m_abater_vl=-1, @he_itv=1, @folga_dia=0, @he_ace=0;
SELECT @m_abater_ht=isnull(m_abater_ht,-1), @m_abater_vl=isnull(m_abater_vl,-1),
@he_itv=isnull(he_itv,1), @folga_dia=isnull(folga_dia,0), @he_ace=isnull(he_ace,0)
FROM tbHE WHERE id_he=@id_he;
select @div_102=0;
if exists(SELECT id_diverg FROM tbDivergencias WHERE id_diverg=102 and ativada=1) begin
select @div_102=1;
end;
select @div_103=0;
if exists(SELECT id_diverg FROM tbDivergencias WHERE id_diverg=103 and ativada=1) begin
select @div_103=1;
end;
select @ent_dia=-1, @sai_dia=-1;
if @m_hrs_prev>0 begin
select @ent_dia=@e1, @sai_dia=(CASE WHEN @s4>-1 THEN @s4 WHEN @s3>-1 THEN @s3 WHEN @s2>-1 THEN @s2 ELSE @s1 END);
end;
select @m_primeira=-1, @m_ultima=-1, @m_ultadc=-1;
if @contamc>0 begin
select @m_primeira=@m_ent01;
if @contamc>2 and @m_primeira=-1  begin select @m_primeira=@m_ent02; end; if @contamc>4 and @m_primeira=-1  begin select @m_primeira=@m_ent03; end;
if @contamc>6 and @m_primeira=-1  begin select @m_primeira=@m_ent04; end; if @contamc>8 and @m_primeira=-1  begin select @m_primeira=@m_ent05; end;
if @contamc>10 and @m_primeira=-1 begin select @m_primeira=@m_ent06; end; if @contamc>12 and @m_primeira=-1 begin select @m_primeira=@m_ent07; end;
if @contamc>14 and @m_primeira=-1 begin select @m_primeira=@m_ent08; end; if @contamc>14 and @m_ultima=-1   begin select @m_ultima=@m_sai08;   end;
if @contamc>12 and @m_ultima=-1   begin select @m_ultima=@m_sai07;   end; if @contamc>10 and @m_ultima=-1   begin select @m_ultima=@m_sai06;   end;
if @contamc>8 and @m_ultima=-1    begin select @m_ultima=@m_sai05;   end; if @contamc>6 and @m_ultima=-1    begin select @m_ultima=@m_sai04;   end;
if @contamc>4 and @m_ultima=-1    begin select @m_ultima=@m_sai03;   end; if @contamc>2 and @m_ultima=-1    begin select @m_ultima=@m_sai02;   end;
if @m_ultima=-1 begin select @m_ultima=@m_sai01; end;
if @div_102=1 and @m_ultima>-1 begin
select @ptoace_p=-1, @ptoace_u=-1;
SELECT TOP 1 @ptoace_p=isnull(m_primeira,-1), @ptoace_u=isnull(m_ultima,-1) FROM tbPtoAce WHERE id_pass=@id_pass AND data=@data;
if @sai_dia>-1 and @m_ultima<(@sai_dia-15) begin
if @ptoace_p=-1 or (@ptoace_p=@ptoace_u and @ptoace_u>=@sai_dia) or @ptoace_p < @sai_dia+60  begin select @ptoace_p=@sai_dia; end;
end else begin
if @ptoace_p=-1 or (@ptoace_p=@ptoace_u and @ptoace_u>=@m_ultima) or @ptoace_p < @m_ultima+60  begin select @ptoace_p=@m_ultima; end;
end;
if @ptoace_p>-1 and @ptoace_u>-1 and @ptoace_p<@ptoace_u and @ptoace_u>@m_ultima begin
select @vlr1=(@ptoace_u-@ptoace_p);
if @sai_dia>-1 and @m_ultima<(@sai_dia-15) begin
select @ptoace_u=@sai_dia+@vlr1;
select @ptoace_p=@sai_dia;
end else begin
select @ptoace_u=@m_ultima+@vlr1;
select @ptoace_p=@m_ultima;
end;
if @vlr1>0 and @id_arredonda>0 begin
select @achou=0,@vlr2=0;
SELECT TOP 1 @achou=1,@vlr2=m_arredonda FROM tbArredFxs
WHERE id_arredonda=@id_arredonda AND id_diverg=102 AND @vlr1 BETWEEN m_faixa_ini AND m_faixa_fim;
if @achou=1 begin
select @vlr1=@vlr2;
end else begin
select @achou=0,@vlr=@vlr1%60,@vlr2=0;
SELECT TOP 1 @achou=1,@vlr2=m_arredonda FROM tbArredFxs
WHERE id_arredonda=@id_arredonda AND id_diverg=102 AND minutos=1 AND @vlr BETWEEN m_faixa_ini AND m_faixa_fim;
if @achou=1 begin
select @vlr2 = @vlr2+(@vlr1-@vlr);
select @vlr1 = @vlr2;
end;
end;
if @sai_dia>-1 and @m_ultima<(@sai_dia-15) begin
select @ptoace_u=@sai_dia+@vlr1;
end else begin
select @ptoace_u=@m_ultima+@vlr1;
end;
if @ptoace_u < @ptoace_p begin
select @ptoace_p=-1, @ptoace_u=-1, @vlr1=0;
end;
end;
if @vlr1>5 and @ptoace_p>-1 and @ptoace_u>-1 begin
if @div_102=1 begin exec AP_PTO018 @id_pass output, @data output, 102, @vlr1; end;
if @he_ace=1 begin
select @m_ultima=-1;
if @contamc>14 and @m_ultima=-1 begin select @m_sai08=@ptoace_u, @m_ultima=@ptoace_u; end;
if @contamc>12 and @m_ultima=-1 begin select @m_sai07=@ptoace_u, @m_ultima=@ptoace_u; end;
if @contamc>10 and @m_ultima=-1 begin select @m_sai06=@ptoace_u, @m_ultima=@ptoace_u; end;
if @contamc>8  and @m_ultima=-1 begin select @m_sai05=@ptoace_u, @m_ultima=@ptoace_u; end;
if @contamc>6  and @m_ultima=-1 begin select @m_sai04=@ptoace_u, @m_ultima=@ptoace_u; end;
if @contamc>4  and @m_ultima=-1 begin select @m_sai03=@ptoace_u, @m_ultima=@ptoace_u; end;
if @contamc>2  and @m_ultima=-1 begin select @m_sai02=@ptoace_u, @m_ultima=@ptoace_u; end;
if @m_ultima=-1 begin select @m_sai01=@ptoace_u, @m_ultima=@ptoace_u; end;
end;
end;
end;
end;
end;
if @div_103=1 and @m_hrs_prev=0 and @contamc=0 begin
select @ptoace_p=-1, @ptoace_u=-1;
SELECT TOP 1 @ptoace_p=isnull(m_primeira,-1), @ptoace_u=isnull(m_ultima,-1) FROM tbPtoAce WHERE id_pass=@id_pass AND data=@data;
if @ptoace_p>-1 and @ptoace_u>-1 and @ptoace_p<@ptoace_u begin
select @vlr1=@ptoace_u-@ptoace_p;
if @vlr1>0 and @id_arredonda>0 begin
select @achou=0,@vlr2=0;
SELECT TOP 1 @achou=1,@vlr2=m_arredonda FROM tbArredFxs
WHERE id_arredonda=@id_arredonda AND id_diverg=103 AND @vlr1 BETWEEN m_faixa_ini AND m_faixa_fim;
if @achou=1 begin
select @vlr1=@vlr2;
end else begin
select @achou=0,@vlr=@vlr1%60,@vlr2=0;
SELECT TOP 1 @achou=1,@vlr2=m_arredonda FROM tbArredFxs
WHERE id_arredonda=@id_arredonda AND id_diverg=103 AND minutos=1 AND @vlr BETWEEN m_faixa_ini AND m_faixa_fim;
if @achou=1 begin
select @vlr2 = @vlr2+(@vlr1-@vlr);
select @vlr1=@vlr2;
end;
end;
select @ptoace_u=@ptoace_p + @vlr1;
if @ptoace_u < @ptoace_p begin
select @ptoace_p=-1, @ptoace_u=-1, @vlr1=0;
end;
end;
if @vlr1>60 begin
SELECT TOP 1 @vlr1=@vlr1-isnull(h.m_abater_vl,0) FROM tbFunc f
INNER JOIN tbHE h ON h.id_he = f.id_he AND h.m_abater_ht>-1 AND @vlr1 > h.m_abater_ht
WHERE f.id_pass = @id_pass;
end;
if @vlr1>5 and @ptoace_p>-1 and @ptoace_u>-1 begin
if @div_103=1 begin
exec AP_PTO018 @id_pass output, @data output, 103, @vlr1;
end;
if @he_ace=1 begin
select @m_ent01=@ptoace_p, @m_primeira=@ptoace_p;
select @m_sai01=@ptoace_u, @m_ultima=@ptoace_u;
select @contamc=2;
end;
end;
end;
end;
if (@m_min_comp_dia<1 and @m_min2_comp_dia<1) begin
if @m_ultima>-1 and @sai_dia>-1 and (
(@m_desc_sai2>0 and @m_ultima<@sai_dia and (@sai_dia-@m_ultima)<=@m_desc_sai2) or
(@m_acre_sai2>0 and @m_ultima>@sai_dia and (@m_ultima-@sai_dia)<=@m_acre_sai2)
) begin
select @m_ultima=@sai_dia;
end;
end else if @m_primeira>-1 and @m_ultima>-1 begin
select @achou=0;
if @m_min_comp_dia>0 and @ent_dia>-1 and @m_primeira>-1 and @m_primeira>@ent_dia begin
select @ent_compensar=(@m_primeira-@ent_dia);
if (@ent_compensar>@m_min_comp_dia)  begin
select @ent_compensar=0; --estourou a compensao
end;
if @m_desc_ent1>0 AND @m_desc_ent1>=@ent_compensar begin
select @ent_compensar=0; --dentro dos minutos de tolerncia da entrada
end;
if @ent_compensar>0 AND @min_comp_dia_qsem>0 and @data>@dom_data begin
select @vlr1=0;
SELECT @vlr1=COUNT(0) FROM tbPtoDscDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND dateadd(d,-1,@data) AND isnull(flex,0)>0;
if @vlr1>=@min_comp_dia_qsem begin
select @ent_compensar=0; --atingiu o limite da semanal
end;
end;
if @ent_compensar>0 begin
select @vlr1=0;
select @itv_comp=0;
if @ent_compensar>0 AND @min_comp_dia_itv=1 AND @contamc=4 AND @m_sai01>-1 and @m_ent02>-1 begin
select @vlr_itv=0;
if (@e2>-1)  begin
if @m_sai01<=@e2 and @m_ent02>=@s1 begin
select @vlr_itv=(@m_ent02-@m_sai01);
select @vlr_itv=(@e2-@s1)-@vlr_itv;
end;
end else if (@fxtmp>0) begin
if @m_sai01<=@fxfim and @m_ent02>=@fxini begin
select @vlr_itv=(@m_ent02-@m_sai01);
select @vlr_itv=@fxtmp-@vlr_itv;
end;
end;
if @vlr_itv<0 begin select @vlr_itv=0; end;
if @vlr_itv>0 begin
if @vlr_itv>@m_acre_ent2 and @m_acre_ent2>0 begin
select @m_acre_ent2=0; --Cancela tolerncia do intervalo se o excedente era menor antes da compensao
end;
select @vlr2=@ent_compensar;
if @vlr_itv<@ent_compensar begin
select @vlr2=@vlr_itv, @ent_compensar=@ent_compensar-@vlr_itv;
end else begin
select @ent_compensar=0;
end;
if (@e2>-1) begin
if (@e2-@s1)>@vlr2 begin
if @m_sai01>@s1 and @m_sai01-@s1 >= @vlr2 begin
select @s1=@s1+@vlr2;
end else begin
select @e2=@e2-@vlr2;
end;
select @achou=1, @itv_comp=@vlr2, @vlr1=@vlr1+@vlr2;
end;
end else if (@fxtmp>0) and (@fxtmp>@vlr2) begin
select @fxtmp=@fxtmp-@vlr2;
select @achou=1, @itv_comp=@vlr2, @vlr1=@vlr1+@vlr2;
end;
end;
end;
if @ent_compensar>0 AND (@m_ultima>@sai_dia) begin
if (@m_ultima-@sai_dia)>@m_acre_sai2 and @m_acre_sai2>0 begin
select @m_acre_sai2=0; --Cancela tolerncia da sada se o excedente era maior antes da compensao
end;
if (@m_ultima-@sai_dia)>@m_acre_sai2 or @m_acre_sai2<=0 begin
select @achou=1;
select @vlr2=(@m_ultima-@sai_dia);
select @vlr1=@vlr1+@vlr2;
if @vlr1>@ent_compensar begin select @vlr1=@ent_compensar; end;
select @ent_compensar=0;
end else if @achou=1 begin
select @sai_comp_tolerado=(@m_ultima-@sai_dia);
end;
end;
if @achou=1 begin
select @sai_dia=(@sai_dia+(@m_primeira-@ent_dia)-(@itv_comp-@sai_comp_tolerado));
select @ent_dia=@m_primeira;
end;
if @achou=1 begin
if NOT EXISTS(SELECT id_pass FROM tbPtoDscDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoDscDia (id_pass, data, soma, tol_s, tol_m, flex) VALUES (@id_pass, @data, 0, 0, 0, @vlr1);
end else begin
UPDATE tbPtoDscDia SET flex=@vlr1 WHERE id_pass=@id_pass AND data=@data;
end;
end;
end; --if @ent_compensar>0 begin
end else if @m_min2_comp_dia>0 and @ent_dia>-1 and @m_primeira>-1 and @m_primeira<@ent_dia begin
select @ent_compensar=(@ent_dia-@m_primeira);
if (@ent_compensar>@m_min2_comp_dia) begin
select @ent_compensar=0; --estourou a compensao
end;
if @m_acre_ent1>0 AND @m_acre_ent1>=@ent_compensar begin
select @ent_compensar=0; --dentro dos minutos de tolerncia da entrada
end;
if @ent_compensar>0 AND @min2_comp_dia_qsem>0 AND @data>@dom_data begin
select @vlr1=0;
SELECT @vlr1=COUNT(0) FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND dateadd(d,-1,@data) AND isnull(flex,0)>0;
if @vlr1>=@min2_comp_dia_qsem begin
select @ent_compensar=0; --atingiu o limite da semanal
end;
end;
if @ent_compensar>0 begin
select @vlr1=0;
/* Compensar com sada antecipada */
if (@m_ultima<@sai_dia) begin
if (@sai_dia-@m_ultima)>=@m_desc_sai2 and @m_desc_sai2>0 begin
select @m_desc_sai2=0; --Cancela tolerncia da sada se o excedente era maior antes da compensao
end;
select @achou=1;
select @vlr1=(@sai_dia-@m_ultima);
if @vlr1>@ent_compensar begin select @vlr1=@ent_compensar; end;
select @ent_compensar=0;
select @sai_dia=@sai_dia-(@ent_dia-@m_primeira);
select @ent_dia=@m_primeira;
end;
if @achou=1 begin
if NOT EXISTS(SELECT id_pass FROM tbPtoAcrDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoAcrDia (id_pass, data, soma, tol_s, tol_m, flex) VALUES (@id_pass, @data, 0, 0, 0, @vlr1);
end else begin
UPDATE tbPtoAcrDia SET flex=@vlr1 WHERE id_pass=@id_pass AND data=@data;
end;
end;
end;
end;
if @achou=1 begin
if @ent_dia<0 begin select @ent_dia=-1; end;
select @e1=@ent_dia;
if @sai_dia<0 begin select @sai_dia=-1; end;
if @s4>-1 begin
select @s4=@sai_dia;
end else if @s3>-1 begin
select @s3=@sai_dia;
end else if @s2>-1 begin
select @s2=@sai_dia;
end else begin
select @s1=@sai_dia;
end;
end;
end;
select @excede_flex=0;
SELECT @excede_flex=isnull(excede_flex,0) FROM tbPHorarios WHERE id_phorario=@id_phorario;
select @noti=1320, @notf=1740, @adic_not=0, @adic_nothe=0, @reduz_normal=0, @reduz_he=0;
select @adc_ext_per=0,@adc_min=0,@adic_tolera=0,@adc_minhe=0,@adc_intv=1,@adc_somar=0,@adc_w_hn='0000000000',@adc_w_he='0000000000',@reduzida=1,@redhen=0,@adc_fator=0,@adc_fator_pad=1;
if @id_adicional>0 begin
SELECT TOP 1 @noti=isnull(m_periodo_ini,1320), @notf=isnull(m_periodo_fim,300),
@adc_min=m_minimo_entrada,@adc_minhe=m_minimo_saida,@adc_intv=intervalo,@adc_somar=somar_reduzida,
@adic_tolera=isnull(tolera,0),@adc_w_hn=w_hn,@adc_w_he=w_he, @reduzida=isnull(reduzida,1), @redhen=isnull(redhen,0), @adc_ext_per=extender_periodo, @adc_fator=fator
FROM tbAdicNot WHERE id_adicional=@id_adicional;
if @noti > @notf begin select @notf=@notf+1440; end;
if @trabalhado=0 begin select @adc_intv=0; end; --No considerar intervalo em dia livre
if isnull(@m_ultima,-1) > -1 and @m_ultima < (@notf+1440) begin
select @adc_ext_per=0
end;
if @adc_ext_per=1 begin
if @adc_minhe>0 and @m_ultima>-1 and @sai_dia>-1 and @m_ultima>@sai_dia and (@m_ultima-@sai_dia)<=@adc_minhe begin
select @m_ultima=@sai_dia;
end;
select @m_ultadc=@m_ultima;
if (@m_ultadc-1440)>@notf and ((@m_ultadc-1440)-@notf) < 240 begin select @notf = (@m_ultadc-1440); end;
end;
if @adc_intv=1 begin
if @m_primeira>-1 and @m_ultima>-1 and @m_primeira<>@m_ultima and @m_primeira<=@m_ultima begin
if (@ent_dia>@m_ultima) or (@sai_dia<@m_primeira) BEGIN
if @adc_ext_per=0 begin
EXEC AP_PTO022 @m_primeira,@m_ultima,@noti,@notf,@m_ultadc,@adic_nothe output;
end else begin
EXEC AP_PTO022 @m_primeira,@m_ultima,@noti,@notf,@m_ultadc,@adic_not output;
end;
end else begin
if @ent_dia>@m_primeira begin
EXEC AP_PTO022 @m_primeira,@ent_dia,@noti,@notf,@m_ultadc,@adic_nothe output;
if @sai_dia<@m_ultima AND @adc_ext_per=0 begin
EXEC AP_PTO022 @sai_dia,@m_ultima,@noti,@notf,@m_ultadc,@adic_nothe output;
EXEC AP_PTO022 @ent_dia,@sai_dia,@noti,@notf,@m_ultadc,@adic_not output;
end else begin
EXEC AP_PTO022 @ent_dia,@m_ultima,@noti,@notf,@m_ultadc,@adic_not output;
end;
end else begin
if @sai_dia<@m_ultima AND @adc_ext_per=0 begin
EXEC AP_PTO022 @sai_dia,@m_ultima,@noti,@notf,@m_ultadc,@adic_nothe output;
EXEC AP_PTO022 @m_primeira,@sai_dia,@noti,@notf,@m_ultadc,@adic_not output;
end else begin
EXEC AP_PTO022 @m_primeira,@m_ultima,@noti,@notf,@m_ultadc,@adic_not output;
end;
end;
end;
end;
end;
end;
select @permc=0, @i=0;
while (@i<8) begin
select @i=@i+1;
select @ment=@m_ent01, @msai_ant=-1, @msai=@m_sai01, @ment_prox=@m_ent02, @msai_prox=@m_sai02;
if @i=2 begin select @ment=@m_ent02, @msai_ant=@m_sai01, @msai=@m_sai02, @ment_prox=@m_ent03, @msai_prox=@m_sai03; end;
if @i=3 begin select @ment=@m_ent03, @msai_ant=@m_sai02, @msai=@m_sai03, @ment_prox=@m_ent04, @msai_prox=@m_sai04; end;
if @i=4 begin select @ment=@m_ent04, @msai_ant=@m_sai03, @msai=@m_sai04, @ment_prox=@m_ent05, @msai_prox=@m_sai05; end;
if @i=5 begin select @ment=@m_ent05, @msai_ant=@m_sai04, @msai=@m_sai05, @ment_prox=@m_ent06, @msai_prox=@m_sai06; end;
if @i=6 begin select @ment=@m_ent06, @msai_ant=@m_sai05, @msai=@m_sai06, @ment_prox=@m_ent07, @msai_prox=@m_sai07; end;
if @i=7 begin select @ment=@m_ent07, @msai_ant=@m_sai06, @msai=@m_sai07, @ment_prox=@m_ent08, @msai_prox=@m_sai08; end;
if @i=8 begin select @ment=@m_ent08, @msai_ant=@m_sai07, @msai=@m_sai08, @ment_prox=-1, @msai_prox=-1; end;
if @contamc>=(@i*2) begin
select @hent=-1, @hsai=-1, @hent_prox=-1, @hsai_prox=-1, @fimper=0, @iniper=0;
if @fimper1 >=@i begin
select @permc=1, @hent=@e1, @hsai=@s1, @hent_prox=@e2, @hsai_prox=@s2, @iniper=1, @fimper=@fimper1, @atr=@atr_1, @itv=@itv_1, @atc=@atc_1;
select @ant=@ant_1, @dep=@dep_1;
--Tratar entrada de extra fora do perodo quando h intervalo flexvel
if @ment>-1 and @msai>-1 and @hsai>-1 and @ment>@hsai and @msai_ant<=@hsai and @e2=-1 and @fxini>-1 and @fxfim>-1 and @fxtmp>0 begin
select @ment=@hsai;
end;
end else begin if @fimper2 >=@i begin
select @permc=2, @hent=@e2, @hsai=@s2, @hent_prox=@e3, @hsai_prox=@s3, @iniper=@fimper1+1, @fimper=@fimper2, @atr=@atr_2, @itv=@itv_2, @atc=@atc_2;
select @ant=@ant_2, @dep=@dep_2;
end else begin if @fimper3 >=@i begin
select @permc=3, @hent=@e3, @hsai=@s3, @hent_prox=@e4, @hsai_prox=@s4, @iniper=(CASE WHEN @fimper2>0 THEN @fimper2+1 ELSE @fimper1+1 END), @fimper=@fimper3, @atr=@atr_3, @itv=@itv_3, @atc=@atc_3;
select @ant=@ant_3, @dep=@dep_3;
end else begin if @fimper4 >=@i begin
select @permc=4, @hent=@e4, @hsai=@s4, @hent_prox=-1, @hsai_prox=-1, @iniper=(CASE WHEN @fimper3>0 THEN @fimper3+1 WHEN @fimper2>0 THEN @fimper2+1 ELSE @fimper1+1 END), @fimper=@fimper4, @atr=@atr_4, @itv=@itv_4, @atc=@atc_4;
select @ant=@ant_4, @dep=@dep_4;
end; end; end; end;
if @permc=0 begin
if @ment>-1 and @msai>-1 begin
select @dlivre = @dlivre + (@msai - @ment);
EXEC AP_PTO023 @ment, @msai, @noti, @notf, @he_s2_d_fp out, @he_s2_n_fp out, @he_s2_d_fp_sg out, @he_s2_n_fp_sg out;
end else begin
if @ment>-1 and @msai_prox>-1 begin
select @dlivre = @dlivre + (@msai_prox - @ment);
EXEC AP_PTO023 @ment, @msai_prox, @noti, @notf, @he_s2_d_fp out, @he_s2_n_fp out, @he_s2_d_fp_sg out, @he_s2_n_fp_sg out;
end;
end;
if @pri_he_sai=0 begin select @pri_he_sai=((@i*2)-1); end;
end else begin
if @atr=-1 begin
if @ment>=@hent or @msai >= @hent begin
select @atr=0;
if @ment>-1 and @hent>-1 and @ment>@hent begin
if @i=1 or @fxtmp<=0 or @hent>=@fxini or @ment<=@fxini begin
--@i=1, no estava calc. atraso com 1 entrada dentro do flexvel
select @atr=@ment-@hent;
end else begin
if @fxtmp<=0 or @ment<@fxini begin
select @atr=@fxini-@hent;
if @i=@contamc/2 and @ment>@fxini+@fxtmp begin
select @atr=@atr+(@ment-(@fxini+@fxtmp));
end;
end;
end;
if @atr<0 begin select @atr=0; end;
end;
end;
end;
if @msai>-1 and @msai<@hsai  begin
if @fxtmp<=0 or @hsai<=@fxfim or @msai>=@fxfim begin
select @atc=@hsai-@msai;
end else begin
if @msai<@fxini begin
select @atc=@hsai-(@msai+@fxtmp);
end else begin
select @atc=@hsai-@fxfim;
--if @i=@contamc/2 and @msai<(@fxfim-@fxtmp) begin --no estava calculando S.Ant. com sada dentro do int. flex
if @i=@contamc/2 begin
if @msai>=@fxini+@fxtmp begin
if @ment>-1 and @ment<=@fxini begin
select @atc=@atc+@fxfim-(@msai+@fxtmp);
end else begin if (@msai_ant=-1 or @msai_ant<=@fxini) and @ment>-1 and @ment<(@fxini+@fxtmp) begin
select @atc=@atc+((@fxfim-@msai)-((@fxini+@fxtmp)-@ment));
end else begin
select @atc=@atc+(@fxfim-@msai);
end; end;
end else begin
select @atc=@atc+(@fxfim-(@fxini+@fxtmp));
end;
end;
end;
end;
if @atc<0 begin select @atc=0; end;
end;
if @msai=-1 or (@msai >= @hsai and @ment <= @hsai) begin select @atc=0; end;
if @ment>-1 and @ment < @hent begin
if @msai=-1 or @msai >= @hent begin
select @ant=@ant+(@hent-@ment);
if @ant>0 and @fimper1>=@i begin select @ult_he_ent=((@i*2)-1); end;
if @permc=1 begin
EXEC AP_PTO023 @ment, @hent, @noti, @notf, @he_e1_d out, @he_e1_n out, @he_e1_d_sg out, @he_e1_n_sg out;
end else begin
EXEC AP_PTO023 @ment, @hent, @noti, @notf, @he_e2_d out, @he_e2_n out, @he_e2_d_sg out, @he_e2_n_sg out;
end;
end else begin
select @ant=@ant+(@msai-@ment);
if @ant>0 and @fimper1>=@i begin select @ult_he_ent=(@i*2); end;
if @permc=1 begin
EXEC AP_PTO023 @ment, @msai, @noti, @notf, @he_e1_d_fp out, @he_e1_n_fp out, @he_e1_d_fp_sg out, @he_e1_n_fp_sg out;
end else begin
EXEC AP_PTO023 @ment, @msai, @noti, @notf, @he_e2_d_fp out, @he_e2_n_fp out, @he_e2_d_fp_sg out, @he_e2_n_fp_sg out;
end;
end;
end;
if @msai>-1 and @msai > @hsai begin
if @ment=-1 or @ment <= @hsai begin
select @dep=@dep+(@msai-@hsai);
if @dep>0 and @ult_periodo=@permc and @pri_he_sai=0 begin select @pri_he_sai=(@i*2); end;
if @permc=@ultpermc and not (@msai>-1 and @hsai>-1 and @hent_prox >-1 and @msai>@hsai and @msai < @hent_prox) begin
EXEC AP_PTO023 @hsai, @msai, @noti, @notf, @he_s2_d out, @he_s2_n out, @he_s2_d_sg out, @he_s2_n_sg out;
end else begin
EXEC AP_PTO023 @hsai, @msai, @noti, @notf, @he_s1_d out, @he_s1_n out, @he_s1_d_sg out, @he_s1_n_sg out;
end;
end else begin
select @dep=@dep+(@msai-@ment);
if @dep>0 and @ult_periodo=@permc and @pri_he_sai=0 begin select @pri_he_sai=((@i*2)-1); end;
if @permc=@ultpermc begin
EXEC AP_PTO023 @ment, @msai, @noti, @notf, @he_s2_d_fp out, @he_s2_n_fp out, @he_s2_d_fp_sg out, @he_s2_n_fp_sg out;
end else begin
EXEC AP_PTO023 @ment, @msai, @noti, @notf, @he_s1_d_fp out, @he_s1_n_fp out, @he_s1_d_fp_sg out, @he_s1_n_fp_sg out;
end;
end;
end;
if @i>=@iniper and @msai>-1 and @ment_prox>-1 begin
if @intv_feito>@fxtmp or @iniflex=0 or @iniflex>@i or @fimflex<=@i begin
if @msai>=@hent and @msai<=@hsai and @ment_prox>=@hent and @ment_prox<=@hsai begin
select @vlr=@ment_prox-@msai;
if @vlr<0 begin select @vlr=0; end;
if not (@fxtmp=-1 and @msai<@hsai and @i=1 and @fimper1=1 and @fimper2=2) begin
select @itv=@itv+@vlr;
end;
end;
end;
end;
if (@iniflex<=@i and @fimflex>=@i) or (@iniflex=0 and @i=1 and @ment>-1 and @ment>=@fxini) begin
if @iniflex=@i begin
if @msai>-1 and @msai<@fxini begin
if @excede_flex=0 begin
select @atc_f=@fxini-@msai;
end else begin
select @fxini=@msai;
end;
end;
end;
if @fimflex=@i+1 and @intv_feito<@fxtmp begin
if @ment_prox>-1 and @ment_prox>@fxfim begin
if @excede_flex=0 begin
select @atr_f=@atr_f+(@ment_prox-@fxfim);
end else begin
select @fxfim=@ment_prox;
end;
end;
end;
if @fxtmp>0 begin --and @intv_feito<@fxtmp begin
select @vlr=0;
if (@msai>-1 and @msai<@fxfim) or (@ment_prox>-1 and @ment_prox>@fxini) begin
if @msai>-1 and @ment_prox>-1 begin
select @vlr=@ment_prox-@msai;
if @ment_prox>@msai and @msai>@fxfim begin select @vlr=@vlr-(@ment_prox-@msai); end;
--if @ment_prox>@fxfim+120 begin select @vlr=@vlr-(@ment_prox-@fxfim); end;
--if @msai<@fxini begin
--select @vlr=@vlr-(@fxini-@msai);
--if @vlr>@fxtmp begin select @vlr=@fxtmp; end;
--end;
end else begin if @msai=-1 begin
if @iniflex=@i begin
select @vlr=@ment_prox-@fxini;
if @vlr>@fxtmp begin select @vlr=@fxtmp; end;
end;
end else begin
if @fimflex=@i or @fimflex=@i+1 begin
select @vlr=@fxfim-@msai;
if @contamc=2 begin
if @ment>-1 and @ment>@fxini begin select @vlr=@vlr+(@ment-@fxini); end;
end else if @contamc=4 begin
if @msai>-1 and @msai=@m_sai02 begin select @vlr=0; end; -- tem 4 marcaes, considerar apenas as 2 do meio como intervalo
end;
if (@intv_feito+@vlr)>@fxtmp begin
if @intv_feito<@fxtmp begin
select @vlr=@fxtmp-@intv_feito;
end else begin
select @vlr=0;
end;
end;
end;
end; end;
end else begin if @contamc=2 and @msai>-1 and @ment>-1 and @ment>@fxini and @msai>@fxini begin
if @ment>@fxini+@fxtmp begin
select @vlr=@fxtmp;
end else begin
select @vlr=@ment-@fxini;
end;
end; end;
if @vlr>0 begin select @intv_feito=@intv_feito+@vlr; end;
if @intv_feito>@fxtmp and @atr_f<(@intv_feito-@fxtmp) begin
select @atr_f=(@intv_feito-@fxtmp);
end;
end;
end else begin if @iniflex=0 and @contamc=(@i+1) and @msai>-1 and @msai<@fxini begin
select @intv_feito=@fxtmp;
end; end; -- @iniflex<=@i and @fimflex>=@i
end;
if @ment>-1 and @msai=-1 and @ment_prox=-1 and @msai_prox > - 1 begin
select @msai=@msai_prox;
if @hsai_prox>-1 begin select @hsai=@hsai_prox; end;
end;
if @ment>-1 and @msai>-1 begin
if @hent=-1 begin
if @adc_intv=0 begin EXEC AP_PTO022 @ment,@msai,@noti,@notf,@m_ultadc,@adic_nothe output; end;
end else begin
if @hent>@ment begin
if @hent>@msai begin
if @adc_intv=0 begin EXEC AP_PTO022 @ment,@msai,@noti,@notf,@m_ultadc,@adic_nothe output; end;
end else begin
if @hsai<@msai begin
select @m_hrs_norm = @m_hrs_norm + (@hsai-@hent);
if @adc_intv=0 begin
EXEC AP_PTO022 @hent,@hsai,@noti,@notf,@m_ultadc,@adic_not output;
EXEC AP_PTO022 @ment,@hent,@noti,@notf,@m_ultadc,@adic_nothe output;
EXEC AP_PTO022 @hsai,@msai,@noti,@notf,@m_ultadc,@adic_nothe output;
end;
end else begin
select @m_hrs_norm = @m_hrs_norm + (@msai-@hent);
if @adc_intv=0 begin
EXEC AP_PTO022 @hent,@msai,@noti,@notf,@m_ultadc,@adic_not output;
EXEC AP_PTO022 @ment,@hent,@noti,@notf,@m_ultadc,@adic_nothe output;
end;
end;
end;
end else begin
if @hsai<@ment begin
if @adc_intv=0 begin EXEC AP_PTO022 @ment,@msai,@noti,@notf,@m_ultadc,@adic_nothe output; end;
end else begin
if @hsai<@msai begin
select @m_hrs_norm = @m_hrs_norm + (@hsai-@ment);
if @adc_intv=0 begin
if @adc_ext_per=0 begin
EXEC AP_PTO022 @ment,@hsai,@noti,@notf,@m_ultadc,@adic_not output;
EXEC AP_PTO022 @hsai,@msai,@noti,@notf,@m_ultadc,@adic_nothe output;
end else begin
EXEC AP_PTO022 @ment,@msai,@noti,@notf,@m_ultadc,@adic_not output;
end;
end;
end else begin
select @m_hrs_norm = @m_hrs_norm + (@msai-@ment);
if @adc_intv=0 begin EXEC AP_PTO022 @ment,@msai,@noti,@notf,@m_ultadc,@adic_not output; end;
end;
end;
end;
end;
end;
if @permc=1 begin select @atr_1=@atr, @itv_1=@itv, @atc_1=@atc, @ant_1=@ant, @dep_1=@dep;
end else begin if @permc=2 begin select @atr_2=@atr, @itv_2=@itv, @atc_2=@atc, @ant_2=@ant, @dep_2=@dep;
end else begin if @permc=3 begin select @atr_3=@atr, @itv_3=@itv, @atc_3=@atc, @ant_3=@ant, @dep_3=@dep;
end else begin if @permc=4 begin select @atr_4=@atr, @itv_4=@itv, @atc_4=@atc, @ant_4=@ant, @dep_4=@dep;
end; end; end; end;
end;
end;
if @atr_1 < 0 begin select @atr_1=0; end; if @atr_2 < 0 begin select @atr_2=0; end;
if @atr_3 < 0 begin select @atr_3=0; end; if @atr_4 < 0 begin select @atr_4=0; end;
select @itv_antc=0;
if @fxtmp>0 and @intv_feito<@fxtmp begin
select @itv_antc=@fxtmp-@intv_feito;
if @atr_f>0 begin --abater trmino de intervalo com atraso
select @itv_antc=@itv_antc-@atr_f;
if @itv_antc<0 begin select @itv_antc=0 end;
end;
select @m_hrs_norm = @m_hrs_norm - @itv_antc;
if @m_hrs_norm <= 0 begin select @m_hrs_norm=0, @itv_antc=0; end;
end;
UPDATE tbPtoEstat SET m_atrasos=((@atr_1+@atr_2+@atr_3+@atr_4)+@atc_f+@atr_f+(@atc_1+@atc_2+@atc_3+@atc_4)),
m_he_intervalo=(case when @itv_antc>0 then @itv_antc else m_he_intervalo end),
m_he_dia=(@he_e1_d + @he_e1_d_fp + @he_e1_n + @he_e1_n_fp + @he_e1_d_sg + @he_e1_d_fp_sg + @he_e1_n_sg + @he_e1_n_fp_sg)+
(@he_s1_d + @he_s1_d_fp + @he_s1_n + @he_s1_n_fp + @he_s1_d_sg + @he_s1_d_fp_sg + @he_s1_n_sg + @he_s1_n_fp_sg)+
(@he_e2_d + @he_e2_d_fp + @he_e2_n + @he_e2_n_fp + @he_e2_d_sg + @he_e2_d_fp_sg + @he_e2_n_sg + @he_e2_n_fp_sg)+
(@he_s2_d + @he_s2_d_fp + @he_s2_n + @he_s2_n_fp + @he_s2_d_sg + @he_s2_d_fp_sg + @he_s2_n_sg + @he_s2_n_fp_sg)
WHERE id_pass=@id_pass AND data=@data;
if @fxtmp > @intv_feito begin
select @vlr1=0, @vlr2 = @fxtmp-@intv_feito;
if @atr_f>0 begin --abater trmino de intervalo com atraso
select @vlr2=@vlr2-@atr_f;
if @vlr2<0 begin select @vlr2=0 end;
end;
EXEC AP_PTO022 @fxini,@fxfim,@noti,@notf,-1,@vlr1 output;
if @fxini < 2880 begin
if @vlr1>0 begin
select @he_e2_n=@he_e2_n+@vlr2;
end else begin
select @he_e2_d=@he_e2_d+@vlr2;
end;
end else begin
if @vlr1>0 begin
select @he_e2_n_sg=@he_e2_n_sg+@vlr2;
end else begin
select @he_e2_d_sg=@he_e2_d_sg+@vlr2;
end;
end;
end;
select @acre_ent1=@he_e1_d + @he_e1_d_fp + @he_e1_n + @he_e1_n_fp + @he_e1_d_sg + @he_e1_d_fp_sg + @he_e1_n_sg + @he_e1_n_fp_sg;
select @acre_sai1=@he_s1_d + @he_s1_d_fp + @he_s1_n + @he_s1_n_fp + @he_s1_d_sg + @he_s1_d_fp_sg + @he_s1_n_sg + @he_s1_n_fp_sg;
select @acre_ent2=@he_e2_d + @he_e2_d_fp + @he_e2_n + @he_e2_n_fp + @he_e2_d_sg + @he_e2_d_fp_sg + @he_e2_n_sg + @he_e2_n_fp_sg;
select @acre_sai2=@he_s2_d + @he_s2_d_fp + @he_s2_n + @he_s2_n_fp + @he_s2_d_sg + @he_s2_d_fp_sg + @he_s2_n_sg + @he_s2_n_fp_sg;
select @tot_acre_old=@acre_ent1+@acre_sai1+@acre_ent2+@acre_sai2;
if (@tipohe='X' or @id_he=0 or @he_itv=0) begin
if @fxtmp>0 begin
if @itv_antc>0 and (@m_acre_ent2<=0 or @m_acre_ent2<@itv_antc) begin
select @tot_acre_old=@tot_acre_old-@itv_antc;
end;
end else if @ant_2>0 and (@m_acre_ent2<=0 or @m_acre_ent2<@ant_2) begin
select @tot_acre_old=@tot_acre_old-@ant_2;
end;
if @tot_acre_old<0 begin select @tot_acre_old=0; end;
end;
if @tipohe='E' begin
select @adic_nothe=@adic_nothe-(@he_s2_n+@he_s2_n_fp+@he_s2_n_sg+@he_s2_n_fp_sg);
select @he_s2_d=0, @he_s2_d_fp=0, @he_s2_n=0, @he_s2_n_fp=0, @he_s2_d_sg=0, @he_s2_d_fp_sg=0, @he_s2_n_sg=0, @he_s2_n_fp_sg=0;
if @e2=-1 begin select @dep_1=0; end; if @e3=-1 begin select @dep_2=0; end;
if @e4=-1 begin select @dep_3=0; end; if @e4>-1 begin select @dep_4=0; end;
end;
if @he_itv=0 or @tipohe='E' or @tipohe='S' begin
select @he_s1_d=0, @he_s1_d_fp=0, @he_s1_n=0, @he_s1_n_fp=0, @he_s1_d_sg=0, @he_s1_d_fp_sg=0, @he_s1_n_sg=0, @he_s1_n_fp_sg=0;
if @he_itv=1 or (@m_acre_sai1>-1 and @m_acre_sai1>=@dep_1) begin
if @e2>-1 begin select @dep_1=0; end;
end;
if @e3>-1 begin select @dep_2=0; end; if @e4>-1 begin select @dep_3=0; end;
select @he_e2_d=0, @he_e2_d_fp=0, @he_e2_n=0, @he_e2_n_fp=0, @he_e2_d_sg=0, @he_e2_d_fp_sg=0, @he_e2_n_sg=0, @he_e2_n_fp_sg=0;
if @he_itv=1 or (@m_acre_ent2>-1 and @m_acre_ent2>=@ant_2) begin
if @e2>-1 begin select @ant_2=0; end;
end;
if @e3>-1 begin select @ant_3=0; end; if @e4>-1 begin select @ant_4=0; end;
end;
if @tipohe='S' begin
select @adic_nothe=@adic_nothe-(@he_e1_n+@he_e1_n_fp+@he_e1_n_sg+@he_e1_n_fp_sg);
select @he_e1_d=0, @he_e1_d_fp=0, @he_e1_n=0, @he_e1_n_fp=0, @he_e1_d_sg=0, @he_e1_d_fp_sg=0, @he_e1_n_sg=0, @he_e1_n_fp_sg=0;
select @ant_1=0, @ult_he_ent=0;
end;
if @m_abater_ht>-1 and @m_abater_vl>-1 and @dlivre > 0 and @dlivre > @m_abater_vl and @contamc = 2 and (@m_sai01-@m_ent01) > @m_abater_ht begin
select @dlivre = @dlivre - @m_abater_vl;
if @he_s2_d_fp > @m_abater_vl begin
select @he_s2_d_fp = @he_s2_d_fp - @m_abater_vl;
end else begin
if @he_s2_n_fp > @m_abater_vl begin
if @adc_intv=0 begin select @adic_nothe=@adic_nothe-@m_abater_vl; end;
select @he_s2_n_fp = @he_s2_n_fp - @m_abater_vl;
end;
end;
end;
select @acre_ent1=@he_e1_d + @he_e1_d_fp + @he_e1_n + @he_e1_n_fp + @he_e1_d_sg + @he_e1_d_fp_sg + @he_e1_n_sg + @he_e1_n_fp_sg;
select @acre_sai1=@he_s1_d + @he_s1_d_fp + @he_s1_n + @he_s1_n_fp + @he_s1_d_sg + @he_s1_d_fp_sg + @he_s1_n_sg + @he_s1_n_fp_sg;
select @acre_ent2=@he_e2_d + @he_e2_d_fp + @he_e2_n + @he_e2_n_fp + @he_e2_d_sg + @he_e2_d_fp_sg + @he_e2_n_sg + @he_e2_n_fp_sg;
select @acre_sai2=@he_s2_d + @he_s2_d_fp + @he_s2_n + @he_s2_n_fp + @he_s2_d_sg + @he_s2_d_fp_sg + @he_s2_n_sg + @he_s2_n_fp_sg;
select @total_s=0, @total_m=0;
if @opstols1a=1 begin select @total_s=@total_s+isnull(@acre_ent1,0); end;
if @opstols2a=1 begin select @total_s=@total_s+isnull(@acre_sai1,0); end;
if @opstols3a=1 begin select @total_s=@total_s+isnull(@acre_ent2,0); end;
if @opstols4a=1 begin select @total_s=@total_s+isnull(@acre_sai2,0); end;
if @opstolm1a=1 begin select @total_m=@total_m+isnull(@acre_ent1,0); end;
if @opstolm2a=1 begin select @total_m=@total_m+isnull(@acre_sai1,0); end;
if @opstolm3a=1 begin select @total_m=@total_m+isnull(@acre_ent2,0); end;
if @opstolm4a=1 begin select @total_m=@total_m+isnull(@acre_sai2,0); end;
select @tot_acre_dia=@acre_ent1+@acre_sai1+@acre_ent2+@acre_sai2;
if @tot_acre_dia>0 begin
if NOT EXISTS(SELECT id_pass FROM tbPtoAcrDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoAcrDia (id_pass, data, soma, tol_s, tol_m, flex) VALUES (@id_pass, @data, @tot_acre_dia, @total_s, @total_m, 0);
end else begin
UPDATE tbPtoAcrDia SET soma=@tot_acre_dia, tol_s=@total_s, tol_m=@total_m WHERE id_pass=@id_pass AND data=@data;
end;
end;
select @tot_acre_exc=0, @tolmes=1, @tolsemana=1, @tolsma=0;
if isnull(@id_tolera,0)>0 and @tot_acre_dia>0 begin
select @tolmes=0, @tolsemana=0, @tolsma=0;
if (@m_acre_soma_mes=-1 and @acre_soma_qmes=0) begin
select @tolmes=1;
end else begin
if @acre_exc=0 begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_m),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data BETWEEN @tolerancia_ini AND @tolerancia_fim AND tol_m>0;
if (@m_acre_soma_mes>-1 and @m_acre_soma_mes>=@vlr1 and @acre_soma_qmes > 0 and @acre_soma_qmes >=@vlr2) or
(@m_acre_soma_mes=-1 and @acre_soma_qmes > 0 and @acre_soma_qmes >=@vlr2) or
(@m_acre_soma_mes>-1 and @m_acre_soma_mes>=@vlr1 and @acre_soma_qmes = 0) begin
select @tolmes=1;
end;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_m),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data BETWEEN @tolerancia_ini AND @data AND tol_m>0;
if (@m_acre_soma_mes>-1 and @m_acre_soma_mes>=@vlr1 and @acre_soma_qmes > 0 and @acre_soma_qmes >=@vlr2) or
(@m_acre_soma_mes=-1 and @acre_soma_qmes > 0 and @acre_soma_qmes >=@vlr2) or
(@m_acre_soma_mes>-1 and @m_acre_soma_mes>=@vlr1 and @acre_soma_qmes = 0) begin
select @tolmes=1;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_m),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data BETWEEN @tolerancia_ini AND dateadd(d,-1,@data) AND tol_m>0;
if (@acre_soma_qmes<=0 or @acre_soma_qmes>=(@vlr2+1)) and
(@m_acre_soma_mes>-1 and @m_acre_soma_mes<(@vlr1+@tot_acre_dia))
begin
select @tot_acre_exc=@m_acre_soma_mes;
if @vlr1>@tot_acre_exc begin select @vlr1=@vlr1-@tot_acre_exc, @tot_acre_exc=0; end else begin select @tot_acre_exc=@tot_acre_exc-@vlr1,@vlr1=0; end;
select @vlr1=@tot_acre_dia;
if @vlr1>@tot_acre_exc begin select @vlr1=@vlr1-@tot_acre_exc, @tot_acre_exc=0; end else begin select @tot_acre_exc=@tot_acre_exc-@vlr1,@vlr1=0; end;
select @tot_acre_exc=@tot_acre_dia-@vlr1;
if @m_acre_soma>-1 and @m_acre_soma<@tot_acre_dia begin
if @m_acre_soma < @tot_acre_exc begin
select @tolmes=1, @tot_acre_exc=0; --Priorizar tolerncia diria, pois vai pagar mais
end;
end;
end;
end;
end;
end;
if @tolmes=1 begin
if @m_acre_soma_sem=-1 and @acre_soma_qsem=0 begin
select @tolsemana=1;
end else begin
if @acre_exc=0 begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_s),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND @sab_data AND tol_s>0;
if (@m_acre_soma_sem>-1 and @m_acre_soma_sem>=@vlr1 and @acre_soma_qsem>0 and @acre_soma_qsem >=@vlr2) or
(@m_acre_soma_sem=-1 and @acre_soma_qsem>0 and @acre_soma_qsem >=@vlr2) or
(@m_acre_soma_sem>-1 and @m_acre_soma_sem>=@vlr1 and @acre_soma_qsem=0) begin
select @tolsemana=1;
end;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_s),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND @data AND tol_s>0;
if (@m_acre_soma_sem>-1 and @m_acre_soma_sem>=@vlr1 and @acre_soma_qsem>0 and @acre_soma_qsem >=@vlr2) or
(@m_acre_soma_sem=-1 and @acre_soma_qsem>0 and @acre_soma_qsem >=@vlr2) or
(@m_acre_soma_sem>-1 and @m_acre_soma_sem>=@vlr1 and @acre_soma_qsem=0) begin
select @tolsemana=1;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_s),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND dateadd(d,-1,@data) AND tol_s>0;
if (@acre_soma_qsem<=0 or @acre_soma_qsem>=(@vlr2+1)) and
(@m_acre_soma_sem>-1 and @m_acre_soma_sem<(@vlr1+@tot_acre_dia))
begin
select @tot_acre_exc=@m_acre_soma_sem;
if @vlr1>@tot_acre_exc begin select @vlr1=@vlr1-@tot_acre_exc, @tot_acre_exc=0; end else begin select @tot_acre_exc=@tot_acre_exc-@vlr1,@vlr1=0; end;
select @vlr1=@tot_acre_dia;
if @vlr1>@tot_acre_exc begin select @vlr1=@vlr1-@tot_acre_exc, @tot_acre_exc=0; end else begin select @tot_acre_exc=@tot_acre_exc-@vlr1,@vlr1=0; end;
select @tot_acre_exc=@tot_acre_dia-@vlr1;
if @m_acre_soma>-1 and @m_acre_soma<@tot_acre_dia begin
if @m_acre_soma < @tot_acre_exc begin
select @tolsemana=1, @tot_acre_exc=0; --Priorizar tolerncia diria, pois vai pagar mais
end;
end;
end;
end;
end;
end;
end;
if @tolmes=1 and @tolsemana=1 begin
if @acre_exc=0 begin
if @m_acre_sai2>=(@he_s2_d+@he_s2_n+@he_s2_d_sg+@he_s2_n_sg) begin
select @he_s2_d=0, @he_s2_n=0, @he_s2_d_sg=0, @he_s2_n_sg=0;
end;
select @acre_sai2=@he_s2_d + @he_s2_d_fp + @he_s2_n + @he_s2_n_fp + @he_s2_d_sg + @he_s2_d_fp_sg + @he_s2_n_sg + @he_s2_n_fp_sg;
select @tot_acre_dia=@acre_ent1+@acre_sai1+@acre_ent2+@acre_sai2;
end;
if @m_acre_soma=-1 or @m_acre_soma>=@tot_acre_dia begin
select @tolsma=1;
end else begin
if @acre_exc=1 and @tot_acre_dia>@m_acre_soma begin select @tot_acre_exc=@m_acre_soma; end;
end;
end;
if @acre_exc=1 and @tot_acre_exc>0 begin
--Variveis sintticas
select @vlr1=@tot_acre_exc;
if @vlr1>@ant_1    begin select @vlr1=@vlr1-@ant_1, @ant_1=0;       end else begin select @ant_1=@ant_1-@vlr1,@vlr1=0; end;
if @id_he=0 or @he_itv=1 begin
if @vlr1>@itv_antc begin select @vlr1=@vlr1-@itv_antc, @itv_antc=0; end else begin select @itv_antc=@itv_antc-@vlr1,@vlr1=0; end;
end;
if @vlr1>@dep_1    begin select @vlr1=@vlr1-@dep_1, @dep_1=0;       end else begin select @dep_1=@dep_1-@vlr1,@vlr1=0; end;
if @vlr1>@ant_2    begin select @vlr1=@vlr1-@ant_2, @ant_2=0;       end else begin select @ant_2=@ant_2-@vlr1,@vlr1=0; end;
if @vlr1>@dep_2    begin select @vlr1=@vlr1-@dep_1, @dep_2=0;       end else begin select @dep_2=@dep_2-@vlr1,@vlr1=0; end;
if @vlr1>@ant_3    begin select @vlr1=@vlr1-@ant_3, @ant_3=0;       end else begin select @ant_3=@ant_3-@vlr1,@vlr1=0; end;
if @vlr1>@dep_3    begin select @vlr1=@vlr1-@dep_1, @dep_3=0;       end else begin select @dep_3=@dep_3-@vlr1,@vlr1=0; end;
if @vlr1>@ant_4    begin select @vlr1=@vlr1-@ant_4, @ant_4=0;       end else begin select @ant_4=@ant_4-@vlr1,@vlr1=0; end;
if @vlr1>@dep_4    begin select @vlr1=@vlr1-@dep_1, @dep_4=0;       end else begin select @dep_4=@dep_4-@vlr1,@vlr1=0; end;
if @ant_1=0 begin select @ult_he_ent=0; end;
--Variveis analticas
select @vlr1=@tot_acre_exc;
if @vlr1>@he_e1_d       begin select @vlr1=@vlr1-@he_e1_d,       @he_e1_d=0;       end else begin select @he_e1_d=      @he_e1_d-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_d_fp    begin select @vlr1=@vlr1-@he_e1_d_fp,    @he_e1_d_fp=0;    end else begin select @he_e1_d_fp=   @he_e1_d_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n       begin select @vlr1=@vlr1-@he_e1_n,       @he_e1_n=0;       end else begin select @he_e1_n=      @he_e1_n-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n_fp    begin select @vlr1=@vlr1-@he_e1_n_fp,    @he_e1_n_fp=0;    end else begin select @he_e1_n_fp=   @he_e1_n_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_d_sg    begin select @vlr1=@vlr1-@he_e1_d_sg,    @he_e1_d_sg=0;    end else begin select @he_e1_d_sg=   @he_e1_d_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_d_fp_sg begin select @vlr1=@vlr1-@he_e1_d_fp_sg, @he_e1_d_fp_sg=0; end else begin select @he_e1_d_fp_sg=@he_e1_d_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n_sg    begin select @vlr1=@vlr1-@he_e1_n_sg,    @he_e1_n_sg=0;    end else begin select @he_e1_n_sg=   @he_e1_n_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n_fp_sg begin select @vlr1=@vlr1-@he_e1_n_fp_sg, @he_e1_n_fp_sg=0; end else begin select @he_e1_n_fp_sg=@he_e1_n_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_d       begin select @vlr1=@vlr1-@he_s1_d,       @he_s1_d=0;       end else begin select @he_s1_d=      @he_s1_d-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_d_fp    begin select @vlr1=@vlr1-@he_s1_d_fp,    @he_s1_d_fp=0;    end else begin select @he_s1_d_fp=   @he_s1_d_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_n       begin select @vlr1=@vlr1-@he_s1_n,       @he_s1_n=0;       end else begin select @he_s1_n=      @he_s1_n-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_n_fp    begin select @vlr1=@vlr1-@he_s1_n_fp,    @he_s1_n_fp=0;    end else begin select @he_s1_n_fp=   @he_s1_n_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_d_sg    begin select @vlr1=@vlr1-@he_s1_d_sg,    @he_s1_d_sg=0;    end else begin select @he_s1_d_sg=   @he_s1_d_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_d_fp_sg begin select @vlr1=@vlr1-@he_s1_d_fp_sg, @he_s1_d_fp_sg=0; end else begin select @he_s1_d_fp_sg=@he_s1_d_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_n_sg    begin select @vlr1=@vlr1-@he_s1_n_sg,    @he_s1_n_sg=0;    end else begin select @he_s1_n_sg=   @he_s1_n_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s1_n_fp_sg begin select @vlr1=@vlr1-@he_s1_n_fp_sg, @he_s1_n_fp_sg=0; end else begin select @he_s1_n_fp_sg=@he_s1_n_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_d       begin select @vlr1=@vlr1-@he_e2_d,       @he_e2_d=0;       end else begin select @he_e2_d=      @he_e2_d-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_d_fp    begin select @vlr1=@vlr1-@he_e2_d_fp,    @he_e2_d_fp=0;    end else begin select @he_e2_d_fp=   @he_e2_d_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_n       begin select @vlr1=@vlr1-@he_e2_n,       @he_e2_n=0;       end else begin select @he_e2_n=      @he_e2_n-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_n_fp    begin select @vlr1=@vlr1-@he_e2_n_fp,    @he_e2_n_fp=0;    end else begin select @he_e2_n_fp=   @he_e2_n_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_d_sg    begin select @vlr1=@vlr1-@he_e2_d_sg,    @he_e2_d_sg=0;    end else begin select @he_e2_d_sg=   @he_e2_d_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_d_fp_sg begin select @vlr1=@vlr1-@he_e2_d_fp_sg, @he_e2_d_fp_sg=0; end else begin select @he_e2_d_fp_sg=@he_e2_d_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_n_sg    begin select @vlr1=@vlr1-@he_e2_n_sg,    @he_e2_n_sg=0;    end else begin select @he_e2_n_sg=   @he_e2_n_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e2_n_fp_sg begin select @vlr1=@vlr1-@he_e2_n_fp_sg, @he_e2_n_fp_sg=0; end else begin select @he_e2_n_fp_sg=@he_e2_n_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_d       begin select @vlr1=@vlr1-@he_s2_d,       @he_s2_d=0;       end else begin select @he_s2_d=      @he_s2_d-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_d_fp    begin select @vlr1=@vlr1-@he_s2_d_fp,    @he_s2_d_fp=0;    end else begin select @he_s2_d_fp=   @he_s2_d_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n       begin select @vlr1=@vlr1-@he_s2_n,       @he_s2_n=0;       end else begin select @he_s2_n=      @he_s2_n-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n_fp    begin select @vlr1=@vlr1-@he_s2_n_fp,    @he_s2_n_fp=0;    end else begin select @he_s2_n_fp=   @he_s2_n_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_d_sg    begin select @vlr1=@vlr1-@he_s2_d_sg,    @he_s2_d_sg=0;    end else begin select @he_s2_d_sg=   @he_s2_d_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_d_fp_sg begin select @vlr1=@vlr1-@he_s2_d_fp_sg, @he_s2_d_fp_sg=0; end else begin select @he_s2_d_fp_sg=@he_s2_d_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n_sg    begin select @vlr1=@vlr1-@he_s2_n_sg,    @he_s2_n_sg=0;    end else begin select @he_s2_n_sg=   @he_s2_n_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n_fp_sg begin select @vlr1=@vlr1-@he_s2_n_fp_sg, @he_s2_n_fp_sg=0; end else begin select @he_s2_n_fp_sg=@he_s2_n_fp_sg-@vlr1,@vlr1=0; end;
select @acre_ent1=@he_e1_d + @he_e1_d_fp + @he_e1_n + @he_e1_n_fp + @he_e1_d_sg + @he_e1_d_fp_sg + @he_e1_n_sg + @he_e1_n_fp_sg;
select @acre_sai1=@he_s1_d + @he_s1_d_fp + @he_s1_n + @he_s1_n_fp + @he_s1_d_sg + @he_s1_d_fp_sg + @he_s1_n_sg + @he_s1_n_fp_sg;
select @acre_ent2=@he_e2_d + @he_e2_d_fp + @he_e2_n + @he_e2_n_fp + @he_e2_d_sg + @he_e2_d_fp_sg + @he_e2_n_sg + @he_e2_n_fp_sg;
select @acre_sai2=@he_s2_d + @he_s2_d_fp + @he_s2_n + @he_s2_n_fp + @he_s2_d_sg + @he_s2_d_fp_sg + @he_s2_n_sg + @he_s2_n_fp_sg;
end;
if @tolmes=1 and @tolsemana=1 begin
if @acre_exc=1 and @m_acre_ent1>0 and @acre_ent1>@m_acre_ent1 begin
--Variveis sintticas
select @vlr1=@m_acre_ent1;
if @vlr1>@ant_1    begin select @vlr1=@vlr1-@ant_1, @ant_1=0;       end else begin select @ant_1=@ant_1-@vlr1,@vlr1=0; end;
if @ant_1=0 begin select @ult_he_ent=0; end;
--Variveis analticas
select @vlr1=@m_acre_ent1;
if @vlr1>@he_e1_d       begin select @vlr1=@vlr1-@he_e1_d,       @he_e1_d=0;       end else begin select @he_e1_d=      @he_e1_d-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_d_fp    begin select @vlr1=@vlr1-@he_e1_d_fp,    @he_e1_d_fp=0;    end else begin select @he_e1_d_fp=   @he_e1_d_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n       begin select @vlr1=@vlr1-@he_e1_n,       @he_e1_n=0;       end else begin select @he_e1_n=      @he_e1_n-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n_fp    begin select @vlr1=@vlr1-@he_e1_n_fp,    @he_e1_n_fp=0;    end else begin select @he_e1_n_fp=   @he_e1_n_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_d_sg    begin select @vlr1=@vlr1-@he_e1_d_sg,    @he_e1_d_sg=0;    end else begin select @he_e1_d_sg=   @he_e1_d_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_d_fp_sg begin select @vlr1=@vlr1-@he_e1_d_fp_sg, @he_e1_d_fp_sg=0; end else begin select @he_e1_d_fp_sg=@he_e1_d_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n_sg    begin select @vlr1=@vlr1-@he_e1_n_sg,    @he_e1_n_sg=0;    end else begin select @he_e1_n_sg=   @he_e1_n_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_e1_n_fp_sg begin select @vlr1=@vlr1-@he_e1_n_fp_sg, @he_e1_n_fp_sg=0; end else begin select @he_e1_n_fp_sg=@he_e1_n_fp_sg-@vlr1,@vlr1=0; end;
select @acre_ent1=@he_e1_d + @he_e1_d_fp + @he_e1_n + @he_e1_n_fp + @he_e1_d_sg + @he_e1_d_fp_sg + @he_e1_n_sg + @he_e1_n_fp_sg;
end else if (@m_acre_ent1=-1 and @tolsma=1) or (@m_acre_ent1>=@acre_ent1) begin
select @ant_1=0, @ult_he_ent=0;
select @he_e1_d=0, @he_e1_d_fp=0, @he_e1_n=0, @he_e1_n_fp=0, @he_e1_d_sg=0, @he_e1_d_fp_sg=0, @he_e1_n_sg=0, @he_e1_n_fp_sg=0;
end;
if (@m_acre_sai1=-1 and @tolsma=1) or (@m_acre_sai1>=@acre_sai1) begin
select @he_s1_d=0, @he_s1_d_fp=0, @he_s1_n=0, @he_s1_n_fp=0, @he_s1_d_sg=0, @he_s1_d_fp_sg=0, @he_s1_n_sg=0, @he_s1_n_fp_sg=0;
if @e2>-1 and @he_itv=1 begin select @dep_1=0; end;
if @e3>-1 begin select @dep_2=0; end; if @e4>-1 begin select @dep_3=0; end;
end;
if (@m_acre_ent2=-1 and @tolsma=1) or (@m_acre_ent2>=@acre_ent2) begin
select @he_e2_d=0, @he_e2_d_fp=0, @he_e2_n=0, @he_e2_n_fp=0, @he_e2_d_sg=0, @he_e2_d_fp_sg=0, @he_e2_n_sg=0, @he_e2_n_fp_sg=0;
if @m_acre_ent2>=@itv_antc begin
if @fxtmp>0 begin select @itv_antc = 0; end;
end;
if @e2>-1 and @he_itv=1 begin select @ant_2=0; end;
if @e3>-1 begin select @ant_3=0; end; if @e4>-1 begin select @ant_4=0; end;
end;
if @acre_exc=1 and @m_acre_sai2>0 and @acre_sai2>@m_acre_sai2 begin
--Variveis sintticas
select @vlr1=@m_acre_sai2;
if @e2=-1 begin
if @vlr1>@dep_1    begin select @vlr1=@vlr1-@dep_1, @dep_1=0;       end else begin select @dep_1=@dep_1-@vlr1,@vlr1=0; end;
end;
if @e3=-1 begin
if @vlr1>@dep_2    begin select @vlr1=@vlr1-@dep_1, @dep_2=0;       end else begin select @dep_2=@dep_2-@vlr1,@vlr1=0; end;
end;
if @e4=-1 begin
if @vlr1>@dep_3    begin select @vlr1=@vlr1-@dep_1, @dep_3=0;       end else begin select @dep_3=@dep_3-@vlr1,@vlr1=0; end;
end;
if @e4>-1 begin
if @vlr1>@dep_4    begin select @vlr1=@vlr1-@dep_1, @dep_4=0;       end else begin select @dep_4=@dep_4-@vlr1,@vlr1=0; end;
end;
--Variveis analticas
select @vlr1=@m_acre_sai2;
if @vlr1>@he_s2_d       begin select @vlr1=@vlr1-@he_s2_d,       @he_s2_d=0;       end else begin select @he_s2_d=      @he_s2_d-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_d_fp    begin select @vlr1=@vlr1-@he_s2_d_fp,    @he_s2_d_fp=0;    end else begin select @he_s2_d_fp=   @he_s2_d_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n       begin select @vlr1=@vlr1-@he_s2_n,       @he_s2_n=0;       end else begin select @he_s2_n=      @he_s2_n-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n_fp    begin select @vlr1=@vlr1-@he_s2_n_fp,    @he_s2_n_fp=0;    end else begin select @he_s2_n_fp=   @he_s2_n_fp-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_d_sg    begin select @vlr1=@vlr1-@he_s2_d_sg,    @he_s2_d_sg=0;    end else begin select @he_s2_d_sg=   @he_s2_d_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_d_fp_sg begin select @vlr1=@vlr1-@he_s2_d_fp_sg, @he_s2_d_fp_sg=0; end else begin select @he_s2_d_fp_sg=@he_s2_d_fp_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n_sg    begin select @vlr1=@vlr1-@he_s2_n_sg,    @he_s2_n_sg=0;    end else begin select @he_s2_n_sg=   @he_s2_n_sg-@vlr1,@vlr1=0; end;
if @vlr1>@he_s2_n_fp_sg begin select @vlr1=@vlr1-@he_s2_n_fp_sg, @he_s2_n_fp_sg=0; end else begin select @he_s2_n_fp_sg=@he_s2_n_fp_sg-@vlr1,@vlr1=0; end;
select @acre_sai2=@he_s2_d + @he_s2_d_fp + @he_s2_n + @he_s2_n_fp + @he_s2_d_sg + @he_s2_d_fp_sg + @he_s2_n_sg + @he_s2_n_fp_sg;
end else if (@m_acre_sai2=-1 and @tolsma=1) or (@m_acre_sai2>=@acre_sai2) begin
select @acre_sai2=0;
select @he_s2_d=0, @he_s2_d_fp=0, @he_s2_n=0, @he_s2_n_fp=0, @he_s2_d_sg=0, @he_s2_d_fp_sg=0, @he_s2_n_sg=0, @he_s2_n_fp_sg=0;
if @e2=-1 begin select @dep_1=0; end; if @e3=-1 begin select @dep_2=0; end;
if @e4=-1 begin select @dep_3=0; end; if @e4>-1 begin select @dep_4=0; end;
end;
end; --@tolmes=1 and @tolsemana=1
end else if isnull(@id_tolera,0)>0 begin
if @he_itv=0 or @tipohe='E' or @tipohe='S' begin
if (@m_acre_ent2>-1 and @m_acre_ent2>=@itv_antc) begin
select @he_e2_d=0, @he_e2_d_fp=0, @he_e2_n=0, @he_e2_n_fp=0, @he_e2_d_sg=0, @he_e2_d_fp_sg=0, @he_e2_n_sg=0, @he_e2_n_fp_sg=0;
if @fxtmp>0 begin select @itv_antc = 0; end;
if @e2>-1 and @he_itv=1 begin select @ant_2=0; end;
if @e3>-1 begin select @ant_3=0; end; if @e4>-1 begin select @ant_4=0; end;
end;
end;
end;
select @vlr1 = (@he_e1_d+@he_s1_d+@he_e2_d+@he_s2_d);
select @vlr1 = @vlr1 + (@he_e1_d_fp+@he_s1_d_fp+@he_e2_d_fp+@he_s2_d_fp);
select @vlr1 = @vlr1 + (@he_e1_n+@he_s1_n+@he_e2_n+@he_s2_n);
select @vlr1 = @vlr1 + (@he_e1_n_fp+@he_s1_n_fp+@he_e2_n_fp+@he_s2_n_fp);
select @vlr1 = @vlr1 + (@he_e1_d_sg+@he_s1_d_sg+@he_e2_d_sg+@he_s2_d_sg);
select @vlr1 = @vlr1 + (@he_e1_d_fp_sg+@he_s1_d_fp_sg+@he_e2_d_fp_sg+@he_s2_d_fp_sg);
select @vlr1 = @vlr1 + (@he_e1_n_sg+@he_s1_n_sg+@he_e2_n_sg+@he_s2_n_sg);
select @vlr1 = @vlr1 + (@he_e1_n_fp_sg+@he_s1_n_fp_sg+@he_e2_n_fp_sg+@he_s2_n_fp_sg);
if @dep_1>0 and @e2>-1 and @he_itv=0 and @m_sai01>@s1 begin
select @tot_acre_old=@tot_acre_old-@dep_1;
if @tot_acre_old<0 begin select @tot_acre_old=0; end;
end;
if @vlr1>=0 begin select @vlr1=@tot_acre_old-@vlr1; end;
if @sai_comp_tolerado>0 begin select @vlr1=@vlr1+@sai_comp_tolerado; end;
if @vlr1>0 begin exec AP_PTO018 @id_pass output, @data output, 105, @vlr1; end;
if @tipohe<>'X' begin
select @he_d = (@he_e1_d+@he_s1_d+@he_e2_d+@he_s2_d);
select @he_d_fp = (@he_e1_d_fp+@he_s1_d_fp+@he_e2_d_fp+@he_s2_d_fp);
select @he_n = (@he_e1_n+@he_s1_n+@he_e2_n+@he_s2_n);
select @he_n_fp = (@he_e1_n_fp+@he_s1_n_fp+@he_e2_n_fp+@he_s2_n_fp);
select @he_d_sg = (@he_e1_d_sg+@he_s1_d_sg+@he_e2_d_sg+@he_s2_d_sg);
select @he_d_fp_sg = (@he_e1_d_fp_sg+@he_s1_d_fp_sg+@he_e2_d_fp_sg+@he_s2_d_fp_sg);
select @he_n_sg = (@he_e1_n_sg+@he_s1_n_sg+@he_e2_n_sg+@he_s2_n_sg);
select @he_n_fp_sg = (@he_e1_n_fp_sg+@he_s1_n_fp_sg+@he_e2_n_fp_sg+@he_s2_n_fp_sg);
if @he_d+@he_d_fp+@he_n+@he_n_fp+@he_d_sg+@he_d_fp_sg+@he_n_sg+@he_n_fp_sg > 0 begin
select @he_inicio=0;
if @m_primeira>-1 and (@he_n+@he_n_fp+@he_n_sg+@he_n_fp_sg)>0 begin
if (@m_primeira>=1320 and @m_primeira<=1740) or (@m_primeira>=1320+1440 and @m_primeira<=1740+1440) or (@m_primeira>=1320+2880 and @m_primeira<=1740+2880) begin
select @he_inicio=1;
end;
end;
select @wdiafaixa=@wdiapto;
if @wdiapto=8 begin
if exists(SELECT TOP 1 id_he FROM tbFxsHE WHERE id_he=@id_he and dia=10) and DATEPART(dw,@data)=1 begin
select @wdiafaixa=10; --Folga em domingo
end else if @folga_dia=1 begin
select @wdiafaixa=DATEPART(dw,@data), @wdiafaixa=@wdiafaixa-1;
end;
end;
SELECT @he_opcao=isnull(opcao,0), @he_periodo=periodo FROM tbFxsHE WHERE id_he = @id_he and dia = @wdiafaixa;
select @wdiafaixa=@wdiapto_sg;
if @wdiapto_sg=8 begin
if exists(SELECT TOP 1 id_he FROM tbFxsHE WHERE id_he=@id_he and dia=10) and DATEPART(dw,dateadd(d,1,@data))=1 begin
select @wdiafaixa=10; --Folga em domingo
end else if @folga_dia=1 and @wdiapto_sg=8 begin
select @wdiafaixa=DATEPART(dw,dateadd(d,1,@data)), @wdiafaixa=@wdiafaixa-1;
end;
end;
SELECT @he_opcao_sg=isnull(opcao,0), @he_periodo_sg=periodo FROM tbFxsHE WHERE id_he = @id_he and dia=@wdiafaixa;
if NOT EXISTS(SELECT id_pass FROM tbPtoHEDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoHEDia (id_pass, data, opcao, periodo,he_d, he_d_fp, he_n, he_n_fp, opcao_sg, periodo_sg,he_d_sg, he_d_fp_sg, he_n_sg, he_n_fp_sg,he_inicio, abo_he_d, abo_he_d_fp, abo_he_n, abo_he_n_fp)
VALUES (@id_pass, @data, isnull(@he_opcao,0),isnull(@he_periodo,0),
@he_d, @he_d_fp, @he_n, @he_n_fp, isnull(@he_opcao_sg,0), isnull(@he_periodo_sg,0),
@he_d_sg, @he_d_fp_sg, @he_n_sg, @he_n_fp_sg, @he_inicio, 0, 0, 0, 0)
end else begin
UPDATE tbPtoHEDia SET opcao=isnull(@he_opcao,0),periodo=isnull(@he_periodo,0),
he_d=@he_d, he_d_fp=@he_d_fp, he_n=@he_n, he_n_fp=@he_n_fp,
opcao_sg=isnull(@he_opcao_sg,0), periodo_sg=isnull(@he_periodo_sg,0),
he_d_sg=@he_d_sg, he_d_fp_sg=@he_d_fp_sg, he_n_sg=@he_n_sg,
he_n_fp_sg=@he_n_fp_sg, he_inicio=@he_inicio
WHERE id_pass=@id_pass AND data=@data;
end;
end;
end;
if @fxtmp>0 begin
if @atr_1>0 and ((@contamc=2 and @m_ent01>=@fxini and (@m_sai01=-1 or @m_sai01>@fxfim)) or
(@contamc=4 and @m_ent01=-1 and @m_sai01=-1 and (@m_ent02>=@fxini or (@m_ent02=-1 and @m_sai02>=@fxini)))) begin
select @atr_1=0,@atr_f=0;
end;
if @atc_1>0 and @contamc=2 and @m_ent01>-1 and @m_ent01<@fxini and (@m_sai01<=@fxfim) begin
select @atc_1=0;
end;
end;
select @total_s=0, @total_m=0;
if @opstols1=1 begin select @total_s=@total_s+isnull((@atr_1+@atr_2+@atr_3+@atr_4),0); end;
if @opstols2=1 begin select @total_s=@total_s+isnull(@atc_f,0); end;
if @opstols3=1 begin select @total_s=@total_s+isnull(@atr_f,0); end;
if @opstols4=1 begin select @total_s=@total_s+isnull((@atc_1+@atc_2+@atc_3+@atc_4),0); end;
if @opstolm1=1 begin select @total_m=@total_m+isnull((@atr_1+@atr_2+@atr_3+@atr_4),0); end;
if @opstolm2=1 begin select @total_m=@total_m+isnull(@atc_f,0); end;
if @opstolm3=1 begin select @total_m=@total_m+isnull(@atr_f,0); end;
if @opstolm4=1 begin select @total_m=@total_m+isnull((@atc_1+@atc_2+@atc_3+@atc_4),0); end;
select @tot_desc_dia=@atr_1+@atr_2+@atr_3+@atr_4+@atc_1+@atc_2+@atc_3+@atc_4+@atc_f+@atr_f;
if @tot_desc_dia>0 begin
if NOT EXISTS(SELECT id_pass FROM tbPtoDscDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoDscDia (id_pass, data, soma, tol_s, tol_m, flex) VALUES (@id_pass, @data, @tot_desc_dia, @total_s, @total_m, 0);
end else begin
UPDATE tbPtoDscDia SET soma=@tot_desc_dia, tol_s=@total_s, tol_m=@total_m WHERE id_pass=@id_pass AND data=@data;
end;
end;
select @oatr_1=@atr_1, @oatr_2=@atr_2, @oatr_3=@atr_3, @oatr_4=@atr_4, @oatc_1=@atc_1, @oatc_2=@atc_2, @oatc_3=@atc_3, @oatc_4=@atc_4, @oatc_f=@atc_f, @oatr_f=@atr_f;
select @tot_desc_exc=0, @tolmes=1, @tolsemana=1, @tolsma=0;
if @tot_desc_dia>0 begin
select @tolmes=0, @tolsemana=0, @tolsma=0;
if (@m_desc_soma_mes=-1 and @desc_soma_qmes=0) begin
select @tolmes=1;
end else begin
if @desc_exc=0 begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_m),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoDscDia WHERE id_pass=@id_pass AND data BETWEEN @tolerancia_ini AND @tolerancia_fim AND tol_m>0;
if (@m_desc_soma_mes>-1 and @m_desc_soma_mes>=@vlr1 and @desc_soma_qmes > 0 and @desc_soma_qmes >=@vlr2) or
(@m_desc_soma_mes=-1 and @desc_soma_qmes > 0 and @desc_soma_qmes >=@vlr2) or
(@m_desc_soma_mes>-1 and @m_desc_soma_mes>=@vlr1 and @desc_soma_qmes = 0) begin
select @tolmes=1;
end;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_m),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoDscDia WHERE id_pass=@id_pass AND data BETWEEN @tolerancia_ini AND @data AND tol_m>0;
if (@m_desc_soma_mes>-1 and @m_desc_soma_mes>=@vlr1 and @desc_soma_qmes > 0 and @desc_soma_qmes >=@vlr2) or
(@m_desc_soma_mes=-1 and @desc_soma_qmes > 0 and @desc_soma_qmes >=@vlr2) or
(@m_desc_soma_mes>-1 and @m_desc_soma_mes>=@vlr1 and @desc_soma_qmes = 0) begin
select @tolmes=1;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_m),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoDscDia WHERE id_pass=@id_pass AND data BETWEEN @tolerancia_ini AND dateadd(d,-1,@data) AND tol_m>0;
if (@desc_soma_qmes<=0 or @desc_soma_qmes>=(@vlr2+1)) and
(@m_desc_soma_mes>-1 and @m_desc_soma_mes<(@vlr1+@tot_desc_dia))
begin
select @tot_desc_exc=@m_desc_soma_mes;
if @vlr1>@tot_desc_exc begin select @vlr1=@vlr1-@tot_desc_exc, @tot_desc_exc=0; end else begin select @tot_desc_exc=@tot_desc_exc-@vlr1,@vlr1=0; end;
select @vlr1=@tot_desc_dia;
if @vlr1>@tot_desc_exc begin select @vlr1=@vlr1-@tot_desc_exc, @tot_desc_exc=0; end else begin select @tot_desc_exc=@tot_desc_exc-@vlr1,@vlr1=0; end;
select @tot_desc_exc=@tot_desc_dia-@vlr1;
if @m_desc_soma>-1 and @m_desc_soma<@tot_desc_dia begin
if @m_desc_soma < @tot_desc_exc begin
select @tolmes=1, @tot_desc_exc=0; --Priorizar tolerncia diria, pois vai descontar mais
end;
end;
end;
end;
end;
end;
if @tolmes=1 begin
if (@m_desc_soma_sem=-1 and @desc_soma_qsem=0) begin
select @tolsemana=1;
end else begin
if @desc_exc=0 begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_s),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoDscDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND @sab_data AND tol_s>0;
if (@m_desc_soma_sem>-1 and @m_desc_soma_sem>=@vlr1 and @desc_soma_qsem>0 and @desc_soma_qsem >=@vlr2) or
(@m_desc_soma_sem=-1 and @desc_soma_qsem>0 and @desc_soma_qsem >=@vlr2) or
(@m_desc_soma_sem>-1 and @m_desc_soma_sem>=@vlr1 and @desc_soma_qsem=0) begin
select @tolsemana=1;
end;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_s),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoDscDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND @data AND tol_s>0;
if (@m_desc_soma_sem>-1 and @m_desc_soma_sem>=@vlr1 and @desc_soma_qsem>0 and @desc_soma_qsem >=@vlr2) or
(@m_desc_soma_sem=-1 and @desc_soma_qsem>0 and @desc_soma_qsem >=@vlr2) or
(@m_desc_soma_sem>-1 and @m_desc_soma_sem>=@vlr1 and @desc_soma_qsem=0) begin
select @tolsemana=1;
end else begin
select @vlr1=0,@vlr2=0;
SELECT @vlr1=isnull(SUM(tol_s),0), @vlr2=isnull(COUNT(data),0) FROM tbPtoDscDia WHERE id_pass=@id_pass AND data BETWEEN @dom_data AND dateadd(d,-1,@data) AND tol_s>0;
if (@desc_soma_qsem<=0 or @desc_soma_qsem>=(@vlr2+1)) and
(@m_desc_soma_sem>-1 and @m_desc_soma_sem<(@vlr1+@tot_desc_dia))
begin
select @tot_desc_exc=@m_desc_soma_sem;
if @vlr1>@tot_desc_exc begin select @vlr1=@vlr1-@tot_desc_exc, @tot_desc_exc=0; end else begin select @tot_desc_exc=@tot_desc_exc-@vlr1,@vlr1=0; end;
select @vlr1=@tot_desc_dia;
if @vlr1>@tot_desc_exc begin select @vlr1=@vlr1-@tot_desc_exc, @tot_desc_exc=0; end else begin select @tot_desc_exc=@tot_desc_exc-@vlr1,@vlr1=0; end;
select @tot_desc_exc=@tot_desc_dia-@vlr1;
if @m_desc_soma>-1 and @m_desc_soma<@tot_desc_dia begin
if @m_desc_soma < @tot_desc_exc begin
select @tolsemana=1, @tot_desc_exc=0; --Priorizar tolerncia diria, pois vai descontar mais
end;
end;
end;
end;
end;
end;
end;
if @tolmes=1 and @tolsemana=1 and @m_desc_soma > -1 begin
if @m_desc_soma>=@tot_desc_dia begin
select @tolsma=1;
end else if @desc_exc=1 begin
select @vlr2=@tot_desc_dia;
if @e2>-1 or @atc_f>-1 or @atr_f>-1 begin
if @m_desc_sai1>-1 begin
select @vlr1=@atc_f;
if @e2>-1 begin select @vlr1=@vlr1+@atc_1; end;
if @e3>-1 begin select @vlr1=@vlr1+@atc_2; end;
if @e4>-1 begin select @vlr1=@vlr1+@atc_3; end;
if @m_desc_sai1 < @vlr1 begin
select @vlr2 = @vlr2-@vlr1;
if @vlr2<0 begin select @vlr1=0; end;
end;
end;
if @m_desc_ent2>-1 begin
select @vlr1=@atr_f;
if @e2>-1 begin select @vlr1=@vlr1+@atr_2; end;
if @e3>-1 begin select @vlr1=@vlr1+@atr_3; end;
if @e4>-1 begin select @vlr1=@vlr1+@atr_4; end;
if @m_desc_ent2 < @vlr1 begin
select @vlr2 = @vlr2-@vlr1;
if @vlr2<0 begin select @vlr1=0; end;
end;
end;
end;
select @vlr1=@tot_desc_dia-@vlr2;
if @vlr2>@m_desc_soma begin
select @tot_desc_exc=@vlr1+@m_desc_soma;
end;
end;
end;
if @desc_exc=1 and @tot_desc_exc>0 begin
select @vlr1=@tot_desc_exc;
if @vlr1>@atr_1 begin select @vlr1=@vlr1-@atr_1, @atr_1=0; end else begin select @atr_1=@atr_1-@vlr1,@vlr1=0; end;
if @vlr1>@atr_2 begin select @vlr1=@vlr1-@atr_2, @atr_2=0; end else begin select @atr_2=@atr_2-@vlr1,@vlr1=0; end;
if @vlr1>@atr_3 begin select @vlr1=@vlr1-@atr_3, @atr_3=0; end else begin select @atr_3=@atr_3-@vlr1,@vlr1=0; end;
if @vlr1>@atr_4 begin select @vlr1=@vlr1-@atr_4, @atr_4=0; end else begin select @atr_4=@atr_4-@vlr1,@vlr1=0; end;
if @vlr1>@atc_1 begin select @vlr1=@vlr1-@atc_1, @atc_1=0; end else begin select @atc_1=@atc_1-@vlr1,@vlr1=0; end;
if @vlr1>@atc_2 begin select @vlr1=@vlr1-@atc_2, @atc_2=0; end else begin select @atc_2=@atc_2-@vlr1,@vlr1=0; end;
if @vlr1>@atc_3 begin select @vlr1=@vlr1-@atc_3, @atc_3=0; end else begin select @atc_3=@atc_3-@vlr1,@vlr1=0; end;
if @vlr1>@atc_4 begin select @vlr1=@vlr1-@atc_4, @atc_4=0; end else begin select @atc_4=@atc_4-@vlr1,@vlr1=0; end;
if @vlr1>@atc_f begin select @vlr1=@vlr1-@atc_f, @atc_f=0; end else begin select @atc_f=@atc_f-@vlr1,@vlr1=0; end;
if @vlr1>@atr_f begin select @vlr1=@vlr1-@atr_f, @atr_f=0; end else begin select @atr_f=@atr_f-@vlr1,@vlr1=0; end;
end;
if @tolmes=1 and @tolsemana=1 begin
if @desc_exc=1 and @m_desc_ent1>0 and @atr_1>@m_desc_ent1 begin
select @atr_1=@atr_1-@m_desc_ent1; -- Aplicar excedentes para tol. entrada
end else if (@m_desc_ent1=-1 and @tolsma=1) or @m_desc_ent1 >= @atr_1 begin
select @atr_1=0;
end;
select @vlr1=@atc_f;
if @e2>-1 begin select @vlr1=@vlr1+@atc_1; end;
if @e3>-1 begin select @vlr1=@vlr1+@atc_2; end;
if @e4>-1 begin select @vlr1=@vlr1+@atc_3; end;
if (@m_desc_sai1=-1 and @tolsma=1) or @m_desc_sai1 >= @vlr1 begin
select @atc_f=0;
if @e2>-1 begin select @atc_1=0; end; if @e3>-1 begin select @atc_2=0; end; if @e4>-1 begin select @atc_3=0; end;
end;
select @vlr1=@atr_f;
if @e2>-1 begin select @vlr1=@vlr1+@atr_2; end;
if @e3>-1 begin select @vlr1=@vlr1+@atr_3; end;
if @e4>-1 begin select @vlr1=@vlr1+@atr_4; end;
if (@m_desc_ent2=-1 and @tolsma=1) or @m_desc_ent2 >= @vlr1 begin
select @atr_f=0;
if @e2>-1 begin select @atr_2=0; end; if @e3>-1 begin select @atr_3=0; end; if @e4>-1 begin select @atr_4=0; end;
end;
select @vlr1=0;
if @s4>-1 begin select @vlr1=@atc_4;
end else begin if @s3>-1 begin select @vlr1=@atc_3;
end else begin if @s2>-1 begin select @vlr1=@atc_2;
end else begin if @s1>-1 begin select @vlr1=@atc_1;
end; end; end; end;
if @desc_exc=1 and @m_desc_sai2>0 and @vlr1>@m_desc_sai2 begin
-- Aplicar excedentes para tol. sada
select @vlr1=@vlr1-@m_desc_sai2;
if @s4>-1 begin select @atc_4=@vlr1;
end else begin if @s3>-1 begin select @atc_3=@vlr1;
end else begin if @s2>-1 begin select @atc_2=@vlr1;
end else begin if @s1>-1 begin select @atc_1=@vlr1;
end; end; end; end;
end else if (@m_desc_sai2=-1 and @tolsma=1) or @m_desc_sai2 >= @vlr1 begin
if @s4>-1 begin select @atc_4=0;
end else begin if @s3>-1 begin select @atc_3=0;
end else begin if @s2>-1 begin select @atc_2=0;
end else begin if @s1>-1 begin select @atc_1=0;
end; end; end; end;
end;
end; --@tolmes=1 and @tolsemana=1
end;
select @vlr1=0;
if (@atr_1>=0 and @oatr_1>@atr_1) begin select @vlr1=@vlr1+(@oatr_1-@atr_1); end;
if (@atr_2>=0 and @oatr_2>@atr_2) begin select @vlr1=@vlr1+(@oatr_2-@atr_2); end;
if (@atr_3>=0 and @oatr_3>@atr_3) begin select @vlr1=@vlr1+(@oatr_3-@atr_3); end;
if (@atr_4>=0 and @oatr_4>@atr_4) begin select @vlr1=@vlr1+(@oatr_4-@atr_4); end;
if (@atc_1>=0 and @oatc_1>@atc_1) begin select @vlr1=@vlr1+(@oatc_1-@atc_1); end;
if (@atc_2>=0 and @oatc_2>@atc_1) begin select @vlr1=@vlr1+(@oatc_2-@atc_2); end;
if (@atc_3>=0 and @oatc_3>@atc_1) begin select @vlr1=@vlr1+(@oatc_3-@atc_3); end;
if (@atc_4>=0 and @oatc_4>@atc_1) begin select @vlr1=@vlr1+(@oatc_4-@atc_4); end;
if (@atc_f>=0 and @oatc_f>@atc_f) begin select @vlr1=@vlr1+(@oatc_f-@atc_f); end;
if (@atr_f>=0 and @oatc_f>@atr_f) begin select @vlr1=@vlr1+(@oatr_f-@atr_f); end;
select @m_hrs_norm=@m_hrs_norm+@vlr1;
if @vlr1>0 begin exec AP_PTO018 @id_pass output, @data output, 104, @vlr1; end;
if @adic_tolera=1 begin
select @vlr1=0; if @atr_1>=0 and @oatr_1>@atr_1 begin select @vlr1=(@oatr_1-@atr_1); end;
if @vlr1>0 and ((@e1 <= @notf and @e1+@vlr1 >= @noti) or (@e1<=(@notf+1440) and @e1+@vlr1>=(@noti+1440))) begin
select @adic_not=@adic_not+@vlr1;
end;
select @vlr1=0, @vlr2=0;
if @s4>-1 begin select @vlr1=@atc_4, @vlr2=@oatc_4;
end else begin if @s3>-1 begin select @vlr1=@atc_3, @vlr2=@oatc_3;
end else begin if @s2>-1 begin select @vlr1=@atc_2, @vlr2=@oatc_2;
end else begin if @s1>-1 begin select @vlr1=@atc_1, @vlr2=@oatc_1;
end; end; end; end;
if @vlr1>=0 and @vlr2>@vlr1 begin select @vlr1=(@vlr2-@vlr1); end else begin select @vlr1=0; end;
if @vlr1>0 and @sai_dia>-1 and @sai_dia<=(@notf+1440) and @sai_dia+@vlr1>=(@noti+1440) begin
select @adic_not=@adic_not+@vlr1;
end;
end;
if @atr_1 > 0 begin exec AP_PTO018 @id_pass output, @data output, 13, @atr_1; end;
if @atc_1 > 0 begin exec AP_PTO018 @id_pass output, @data output, 17, @atc_1; end;
if @itv_1 > 0 begin exec AP_PTO018 @id_pass output, @data output, 77, @itv_1; end;
if @tipohe='X' or @id_he=0 begin
if @ant_1 > 0 begin exec AP_PTO018 @id_pass output, @data output, 21, @ant_1; end;
end;
if @tipohe='X' or @id_he=0 or (@e2>-1 and @he_itv=0 and (
(@m_sai01>@s1)
or (@fimper1=2 and @m_sai02>@s1))) begin
if @dep_1 > 0 begin exec AP_PTO018 @id_pass output, @data output, 25, @dep_1; end;
end;
if @atr_2 > 0 begin exec AP_PTO018 @id_pass output, @data output, 14, @atr_2; end;
if @atc_2 > 0 begin exec AP_PTO018 @id_pass output, @data output, 18, @atc_2; end;
if @itv_2 > 0 begin exec AP_PTO018 @id_pass output, @data output, 78, @itv_2; end;
if @tipohe='X' or @id_he=0 or (@e2>-1 and @he_itv=0) begin
if @ant_2 > 0 begin exec AP_PTO018 @id_pass output, @data output, 22, @ant_2; end;
end;
if @tipohe='X' or @id_he=0 begin
if @dep_2 > 0 begin exec AP_PTO018 @id_pass output, @data output, 26, @dep_2; end;
end;
if @atr_3 > 0 begin exec AP_PTO018 @id_pass output, @data output, 15, @atr_3; end;
if @atc_3 > 0 begin exec AP_PTO018 @id_pass output, @data output, 19, @atc_3; end;
if @itv_3 > 0 begin exec AP_PTO018 @id_pass output, @data output, 79, @itv_3; end;
if @tipohe='X' or @id_he=0 begin
if @ant_3 > 0 begin exec AP_PTO018 @id_pass output, @data output, 23, @ant_3; end;
if @dep_3 > 0 begin exec AP_PTO018 @id_pass output, @data output, 27, @dep_3; end;
end;
if @atr_4 > 0 begin exec AP_PTO018 @id_pass output, @data output, 16, @atr_4; end;
if @atc_4 > 0 begin exec AP_PTO018 @id_pass output, @data output, 20, @atc_4; end;
if @itv_4 > 0 begin exec AP_PTO018 @id_pass output, @data output, 80, @itv_4; end;
if @tipohe='X' or @id_he=0 begin
if @ant_4 > 0 begin exec AP_PTO018 @id_pass output, @data output, 24, @ant_4; end;
if @dep_4 > 0 begin exec AP_PTO018 @id_pass output, @data output, 28, @dep_4; end;
end;
if @atc_f > 0 begin exec AP_PTO018 @id_pass output, @data output, 60, @atc_f; end;
if @atr_f > 0 begin exec AP_PTO018 @id_pass output, @data output, 61, @atr_f; end;
if @tipohe='X' or @id_he=0 or @he_itv=0 begin
if @itv_antc > 0 and @itv_antc < @fxtmp begin exec AP_PTO018 @id_pass output, @data output, 63, @itv_antc;  end;
end;
if @tipohe='X' or @id_he=0 begin
if @dlivre > 0 begin exec AP_PTO018 @id_pass output, @data output, 33, @dlivre; end;
end;
if @ant_1 <= 0 begin
select @ult_he_ent=0;
end;
if @dlivre<=0 and @dep_1<=0 and @dep_2<=0 and @dep_3<=0 and @dep_4<=0 begin
select @pri_he_sai=0;
end;
if @id_adicional>0 and @wdiapto<10 and (@adic_not > 0 or @adic_nothe > 0) begin
if @adc_minhe>0 begin
if @adic_not<=@adc_min and @adic_nothe<=@adc_minhe begin
select @adic_not=0;
end;
end else begin
if @adic_not<=@adc_min begin select @adic_not=0; end;
end;
if @adic_nothe<=@adc_minhe begin select @adic_nothe=0; end;
if substring(@adc_w_hn,@wdiapto+1,1) <> '1' begin select @adic_not=0; end;
if substring(@adc_w_he,@wdiapto+1,1) <> '1' begin select @adic_nothe=0; end;
select @reduz_normal=0, @reduz_he=0;
if @adc_fator = 0 begin
select @adc_fator=(60/52.5)-1;
select @adc_fator_pad=1;
end else begin
select @adc_fator_pad=0;
end;
select @vlr1=@adic_not+@adic_nothe;
if @adc_fator_pad=1 begin
select @vlr2=round(@vlr1 * @adc_fator,0);
end else begin
select @vlr2=round(@vlr1 * @adc_fator,0,1);
end;
if @vlr2>0 begin
select @vlr1=@adic_not;
if @adc_fator_pad=1 begin
select @reduz_normal=round(@vlr1 * @adc_fator,0);
end else begin
select @reduz_normal=round(@vlr1 * @adc_fator,0,1);
end;
select @reduz_he=@vlr2-@reduz_normal;
if @reduz_he<0 begin select @reduz_he=0; end;
end;
if @reduzida=1 begin
if @reduz_normal>0 begin
select @achou=0, @id_divadc=0;
SELECT distinct @achou=1, @id_divadc=isnull(id_diverg,0) FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=1 AND dia=@wdiapto AND contafx=0;
if @id_divadc=0 or @id_divadc=45 begin
exec AP_PTO018 @id_pass output, @data output, 47, @reduz_normal;
end else if @id_divadc=81 begin
exec AP_PTO018 @id_pass output, @data output, 89, @reduz_normal;
end else if @id_divadc=82 begin
exec AP_PTO018 @id_pass output, @data output, 90, @reduz_normal;
end else if @id_divadc=83 begin
exec AP_PTO018 @id_pass output, @data output, 91, @reduz_normal;
end else if @id_divadc=84 begin
exec AP_PTO018 @id_pass output, @data output, 92, @reduz_normal;
end;
end;
if @reduz_he>0 begin
if @trabalhado=1 begin
select @achou=0, @id_divadc=0;
SELECT distinct @achou=1, @id_divadc=isnull(id_diverg,0) FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=0 AND dia=@wdiapto AND contafx=0;
if @id_divadc=0 or @id_divadc=46 begin
exec AP_PTO018 @id_pass output, @data output, 52, @reduz_he;
end else if @id_divadc=85 begin
exec AP_PTO018 @id_pass output, @data output, 93, @reduz_he;
end else if @id_divadc=86 begin
exec AP_PTO018 @id_pass output, @data output, 94, @reduz_he;
end else if @id_divadc=87 begin
exec AP_PTO018 @id_pass output, @data output, 95, @reduz_he;
end else if @id_divadc=88 begin
exec AP_PTO018 @id_pass output, @data output, 96, @reduz_he;
end;
end else begin
select @achou=0, @id_divadc=0;
SELECT distinct @achou=1, @id_divadc=isnull(id_diverg,0) FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=0 AND dia=@wdiapto AND contafx=0;
if @id_divadc=0 or @id_divadc=46 begin
exec AP_PTO018 @id_pass output, @data output, 53, @reduz_he;
end else if @id_divadc=85 begin
exec AP_PTO018 @id_pass output, @data output, 97, @reduz_he;
end else if @id_divadc=86 begin
exec AP_PTO018 @id_pass output, @data output, 98, @reduz_he;
end else if @id_divadc=87 begin
exec AP_PTO018 @id_pass output, @data output, 99, @reduz_he;
end else if @id_divadc=88 begin
exec AP_PTO018 @id_pass output, @data output, 100, @reduz_he;
end;
end;
end;
end;
if @adc_somar=1 begin
select @adic_not=@adic_not+@reduz_normal;
end;
--Faixas
select @contafx=0;
while (@contafx < 3 and @adic_not > 0) begin
select @achou=0, @m_faixa_fim=0, @id_divadc=0;
SELECT distinct @achou=1, @m_faixa_fim=m_faixa_fim, @id_divadc=id_diverg FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=1 AND dia=@wdiapto AND contafx=@contafx;
if @achou = 1 and @m_faixa_fim>-1 begin
select @vlr1=@m_faixa_fim;
if @vlr1 > 0 begin
if @vlr1 > @adic_not begin
select @vlr1=@adic_not, @adic_not=0;
end else begin
select @adic_not=@adic_not-@vlr1;
end;
if @id_divadc > 0 and @vlr1 > 0 begin
exec AP_PTO018 @id_pass output, @data output, @id_divadc, @vlr1, 1;
end;
end;
end;
select @contafx=@contafx+1
end;
if @adc_somar=1 begin
select @adic_nothe=@adic_nothe+@reduz_he;
end;
--Faixas
select @contafx=0;
while (@contafx < 3 and @adic_nothe > 0)  begin
select @achou=0, @m_faixa_fim=0, @id_divadc=0;
SELECT distinct @achou=1, @m_faixa_fim=m_faixa_fim, @id_divadc=id_diverg FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=0 AND dia=@wdiapto AND contafx=@contafx;
if @achou = 1 and @m_faixa_fim>-1 begin
select @vlr1=@m_faixa_fim;
if @vlr1 > 0 begin
if @vlr1 > @adic_nothe begin
select @vlr1=@adic_nothe, @adic_nothe=0;
end else begin
select @adic_nothe=@adic_nothe-@vlr1;
end;
if @id_divadc > 0 and @vlr1 > 0 begin
exec AP_PTO018 @id_pass output, @data output, @id_divadc, @vlr1, 1;
end;
end;
end;
select @contafx=@contafx+1
end;
if isnull(@redhen,0)=1 begin
if @adc_fator_pad=1 begin
UPDATE tbPtoHEDia SET he_n = round(isnull(he_n,0) * (@adc_fator+1),0),
he_n_sg = round(isnull(he_n_sg,0) * (@adc_fator+1),0),
he_n_fp = round(isnull(he_n_fp,0) * (@adc_fator+1),0),
he_n_fp_sg = round(isnull(he_n_fp_sg,0) * (@adc_fator+1),0)
WHERE id_pass=@id_pass AND data=@data;
end else begin
UPDATE tbPtoHEDia SET he_n = round(isnull(he_n,0) * (@adc_fator+1),0,1),
he_n_sg = round(isnull(he_n_sg,0) * (@adc_fator+1),0,1),
he_n_fp = round(isnull(he_n_fp,0) * (@adc_fator+1),0,1),
he_n_fp_sg = round(isnull(he_n_fp_sg,0) * (@adc_fator+1),0,1)
WHERE id_pass=@id_pass AND data=@data;
end;
end;
end;
if @m_hrs_norm>@m_hrs_prev begin select @m_hrs_norm=@m_hrs_prev; end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO025') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO025; END;
GO
CREATE PROCEDURE dbo.AP_PTO025(@id_pass int output, @data datetime output, @trabalhado bit, @id_phorario int, @apura_tipo int output,
@id_adicional int, @dom_data datetime, @sab_data datetime, @fechamento_ini datetime, @fechamento_fim datetime,
@contamc tinyint, @id_he int, @tipohe char(1), @m_hrs_prev int, @m_hrs_norm int output, @m_hn_tot int output, @m_trab_tot int output,
@m_ent01 int, @m_sai01 int, @m_ent02 int, @m_sai02 int, @m_ent03 int, @m_sai03 int, @m_ent04 int, @m_sai04 int,
@m_ent05 int, @m_sai05 int, @m_ent06 int, @m_sai06 int, @m_ent07 int, @m_sai07 int, @m_ent08 int, @m_sai08 int,
@wdiapto tinyint, @wdiapto_sg tinyint, @admissao bit, @demissao bit, @id_eveafa int) WITH ENCRYPTION AS
BEGIN
declare @i int; declare @ment int; declare @msai int; declare @msai_ant int; declare @ment_prox int; declare @msai_prox int;
declare @intv_feito int; declare @vlr1 int; declare @vlr2 int;
declare @adc_ext_per int; declare @adc_min int; declare @adc_minhe int; declare @adc_intv bit; declare @adc_somar bit;
declare @adc_w_hn char(10); declare @adc_w_he char(10); declare @redhen bit; declare @reduzida bit; declare @sai_prev int;
declare @adic_not int; declare @adic_nothe int; declare @adc_fator float; declare @adc_fator_pad bit;
declare @noti int; declare @notf int;
declare @m_primeira int; declare @m_ultima int; declare @m_ultadc int;
declare @he_opcao int; declare @he_periodo int; declare @he_opcao_sg int; declare @he_periodo_sg int;
declare @he_d int; declare @he_d_fp int; declare @he_n int; declare @he_n_fp int;
declare @he_d_sg int; declare @he_d_fp_sg int; declare @he_n_sg int; declare @he_n_fp_sg int;
declare @m_abater_ht int; declare @m_abater_vl int;
declare @he_itv bit; declare @folga_dia bit; declare @achou bit; declare @m_desc_soma_mes int;
declare @flx_trab_ant int; declare @flx_trab int;  declare @flx_livre int; declare @normais_ant int;
declare @m_intervalo int; declare @he_intervalo bit;
declare @m_tolera_desc int; declare @m_tolera_acre int;
declare @m_semanal int; declare @m_mensal int; declare @limite int; declare @mes_fec tinyint;
declare @ini_sema int; declare @ini_flex datetime; declare @fim_flex datetime;
declare @m_acre int;  declare @m_desc int; declare @dif_itv int;
declare @dif int; declare @m_descanso int, @m_descafa int, @dias_normais varchar(10); declare @he_descanso int;
declare @fm_itv bit, @fm_intervalo bit; declare @wdiafaixa tinyint; declare @he_inicio tinyint;
declare @reduz_normal int; declare @reduz_he int;
declare @contafx int; declare @m_faixa_fim int; declare @id_divadc int;
declare @ap_falta bit, @ab_reduz bit;
select @m_intervalo=0, @he_intervalo=1, @apura_tipo=0, @m_semanal=0, @m_mensal=0, @ini_sema=0, @m_tolera_desc=0, @m_tolera_acre=0, @m_descafa=0, @m_descanso=0, @he_descanso=0, @fm_intervalo=0, @ap_falta=0, @ab_reduz=0, @dias_normais='';
select @ini_flex=@data, @fim_flex=@data;
select @mes_fec=0;
select @mes_fec=month(@fechamento_ini);
if @mes_fec=2 and day(dateadd(d,-1,dateadd(m,1,@fechamento_ini))) = 29  begin
select @mes_fec=13;
end;
SELECT @m_intervalo=m_intervalo, @fm_intervalo=fm_intervalo, @apura_tipo=apura_tipo, @m_semanal=m_semanal, @ini_sema=ini_sema,
@he_intervalo=he_intervalo, @m_tolera_desc=m_tolera_desc, @m_tolera_acre=m_tolera_acre,
@m_descafa=m_descanso_afa,
@dias_normais=dias_normais,
@m_descanso=ISNULL((CASE WHEN @wdiapto=6 THEN m_descanso_sab WHEN @wdiapto=7 THEN m_descanso_fer
WHEN @wdiapto=8 THEN m_descanso_fol WHEN @wdiapto=9 THEN m_descanso_pon
WHEN @wdiapto=0 THEN m_descanso_dom ELSE 0 END),0),
@m_mensal=ISNULL((CASE
WHEN @mes_fec=1 THEN m_mensal_jan WHEN @mes_fec=2 THEN m_mensal_fev
WHEN @mes_fec=3 THEN m_mensal_mar WHEN @mes_fec=4 THEN m_mensal_abr
WHEN @mes_fec=5 THEN m_mensal_mai WHEN @mes_fec=6 THEN m_mensal_jun
WHEN @mes_fec=7 THEN m_mensal_jul WHEN @mes_fec=8 THEN m_mensal_ago
WHEN @mes_fec=9 THEN m_mensal_set WHEN @mes_fec=10 THEN m_mensal_out
WHEN @mes_fec=11 THEN m_mensal_nov WHEN @mes_fec=12 THEN m_mensal_dez
WHEN @mes_fec=13 THEN m_mensal_fev29 ELSE 0 END),0),
@ap_falta=isnull(ap_falta,0),
@ab_reduz=isnull(ab_reduz,0)
FROM tbPHorFlex WHERE id_pflex=@id_phorario;
select @limite=@m_hrs_prev;
if @apura_tipo=1 begin
select @ini_flex=dateadd(d,@ini_sema,@dom_data), @fim_flex=dateadd(d,@ini_sema,@sab_data);
if @ini_flex > @data begin select @ini_flex=dateadd(d,-7,@ini_flex), @fim_flex=dateadd(d,-7,@fim_flex); end;
select @limite=@m_semanal;
end else begin if @apura_tipo=2 begin
select @ini_flex=@fechamento_ini, @fim_flex=@fechamento_fim, @limite=@m_mensal;
end; end;
select @m_primeira=-1, @m_ultima=-1, @m_ultadc=-1;
if @contamc>0 begin
select @m_primeira=@m_ent01;
if @contamc>2 and @m_primeira=-1 begin select @m_primeira=@m_ent02; end; if @contamc>4 and @m_primeira=-1 begin select @m_primeira=@m_ent03; end;
if @contamc>6 and @m_primeira=-1 begin select @m_primeira=@m_ent04; end; if @contamc>8 and @m_primeira=-1 begin select @m_primeira=@m_ent05; end;
if @contamc>10 and @m_primeira=-1 begin select @m_primeira=@m_ent06; end; if @contamc>12 and @m_primeira=-1 begin select @m_primeira=@m_ent07; end;
if @contamc>14 and @m_primeira=-1 begin select @m_primeira=@m_ent08; end; if @contamc>14 and @m_ultima=-1 begin select @m_ultima=@m_sai08; end;
if @contamc>12 and @m_ultima=-1 begin select @m_ultima=@m_sai07; end; if @contamc>10 and @m_ultima=-1 begin select @m_ultima=@m_sai06; end;
if @contamc>8 and @m_ultima=-1 begin select @m_ultima=@m_sai05; end; if @contamc>6 and @m_ultima=-1 begin select @m_ultima=@m_sai04; end;
if @contamc>4 and @m_ultima=-1 begin select @m_ultima=@m_sai03; end; if @contamc>2 and @m_ultima=-1 begin select @m_ultima=@m_sai02; end;
if @m_ultima=-1 begin select @m_ultima=@m_sai01; end;
end;
select @noti=1320, @notf=1740, @adic_not=0, @adic_nothe=0;
select @adc_ext_per=0,@adc_min=0,@adc_minhe=0,@adc_intv=1,@adc_somar=0,@adc_w_hn='0000000000',@adc_w_he='0000000000',@reduzida=1, @redhen=0,@adc_fator=0,@adc_fator_pad=1;
if @id_adicional>0 begin
SELECT TOP 1 @noti=isnull(m_periodo_ini,1320), @notf=isnull(m_periodo_fim,300),
@adc_min=m_minimo_entrada,@adc_minhe=m_minimo_saida,@adc_intv=intervalo,@adc_somar=somar_reduzida,
@adc_w_hn=w_hn,@adc_w_he=w_he, @reduzida=isnull(reduzida,1), @redhen=isnull(redhen,0), @adc_ext_per=extender_periodo, @adc_fator=fator
FROM tbAdicNot WHERE id_adicional=@id_adicional;
if @noti > @notf begin select @notf=@notf+1440; end;
if @trabalhado=0 begin select @adc_intv=0; end; --No considerar intervalo em dia livre
if isnull(@m_ultima,-1) > -1 and @m_ultima < (@notf+1440) begin
select @adc_ext_per=0
end;
if @adc_ext_per=1 begin
select @m_ultadc=@m_ultima;
if (@m_ultadc-1440)>@notf and ((@m_ultadc-1440)-@notf) < 240 begin select @notf = (@m_ultadc-1440); end;
end;
end;
if @apura_tipo=0 and @limite>60 and @contamc>0 and @ab_reduz=1 begin
select @vlr2=0;
EXEC AP_PTO022 @m_primeira,@m_ultima,@noti,@notf,0,@vlr2 output;
if @vlr2>=60 begin --ao menos 1 hora
select @vlr2=round(@vlr2 * ((60/52.5)-1),0);
if @vlr2>60 begin select @vlr2=60; end;
if @vlr2<0 begin select @vlr2=0; end;
select @limite=@limite-@vlr2;
if @limite<0 begin select @limite=0; end;
end;
end;
select @intv_feito=0, @m_hrs_norm=0, @flx_trab_ant=0, @flx_trab=0, @flx_livre=0, @normais_ant=0;
if @apura_tipo>0 begin
SELECT @flx_trab_ant=isnull(SUM(efetuado),0) FROM tbPtoHFlx WHERE id_pass=@id_pass AND data>=@ini_flex AND data<@data;
SELECT @normais_ant=isnull(SUM(normais),0) FROM tbPtoHFlx   WHERE id_pass=@id_pass AND data>=@ini_flex AND data<@data;
end;
select @m_acre=0, @m_desc=0, @dif_itv=0, @fm_itv=0;
select @he_d=0, @he_d_fp=0, @he_n=0, @he_n_fp=0, @he_d_sg=0, @he_d_fp_sg=0, @he_n_sg=0, @he_n_fp_sg=0;
if @apura_tipo>0 begin
if @trabalhado=0 begin --Somar hrs de descanso
if len(isnull(@dias_normais,'')) >= @wdiapto begin
if SUBSTRING(@dias_normais,@wdiapto+1,1) = '1' begin
if @m_descanso<=0 and @m_descafa>0 begin
select @m_descanso=@m_descafa; --Verificar afastamento
end;
end else if @wdiapto=7 AND SUBSTRING(@dias_normais,DATEPART(dw,@data),1) = '0' begin
select @m_descanso=0;
end;
end;
if @m_descanso>0 begin
select @he_descanso=(@flx_trab_ant+@m_descanso)-@limite
if @he_descanso<0 begin select @he_descanso=0; end;
if @he_descanso>@m_descanso begin select @he_descanso=@m_descanso;  end;
select @flx_trab_ant=@flx_trab_ant+@m_descanso;
select @he_d_fp=@he_descanso, @m_acre=@he_descanso;
end;
end;
end;
select @i=0;
while (@i<8) begin
select @i=@i+1;
select @ment=@m_ent01, @msai_ant=-1, @msai=@m_sai01, @ment_prox=@m_ent02, @msai_prox=@m_sai02;
if @i=2 begin select @ment=@m_ent02, @msai_ant=@m_sai01, @msai=@m_sai02, @ment_prox=@m_ent03, @msai_prox=@m_sai03; end;
if @i=3 begin select @ment=@m_ent03, @msai_ant=@m_sai02, @msai=@m_sai03, @ment_prox=@m_ent04, @msai_prox=@m_sai04; end;
if @i=4 begin select @ment=@m_ent04, @msai_ant=@m_sai03, @msai=@m_sai04, @ment_prox=@m_ent05, @msai_prox=@m_sai05; end;
if @i=5 begin select @ment=@m_ent05, @msai_ant=@m_sai04, @msai=@m_sai05, @ment_prox=@m_ent06, @msai_prox=@m_sai06; end;
if @i=6 begin select @ment=@m_ent06, @msai_ant=@m_sai05, @msai=@m_sai06, @ment_prox=@m_ent07, @msai_prox=@m_sai07; end;
if @i=7 begin select @ment=@m_ent07, @msai_ant=@m_sai06, @msai=@m_sai07, @ment_prox=@m_ent08, @msai_prox=@m_sai08; end;
if @i=8 begin select @ment=@m_ent08, @msai_ant=@m_sai07, @msai=@m_sai08, @ment_prox=-1, @msai_prox=-1; end;
if @contamc>=(@i*2) begin
if @i>1 begin
if @ment>-1 and @msai_ant>-1 begin select @intv_feito=@intv_feito+(@ment-@msai_ant); end;
if @msai_ant=-1 or @ment=-1 begin select @fm_itv=1; end;
end;
if @ment>-1 and @msai=-1 and @ment_prox=-1 and @msai_prox>- 1 begin select @msai=@msai_prox; end;
if @ment>-1 and @msai>-1 begin
if @trabalhado=0 begin
select @flx_livre=@flx_livre+(@msai-@ment);
EXEC AP_PTO022 @ment,@msai,@noti,@notf,@m_ultadc,@adic_nothe output;
EXEC AP_PTO023 @ment, @msai, @noti, @notf, @he_d_fp out, @he_n_fp out, @he_d_fp_sg out, @he_n_fp_sg out;
end else begin
select @vlr1=(@msai-@ment);
select @dif=(@flx_trab_ant+@flx_trab+@vlr1) - @limite --Acrscimo no par de mcs
if @dif<0 begin select @dif=0; end;
if @dif>@vlr1 begin select @dif=@vlr1;  end;
select @flx_trab=@flx_trab+@vlr1;
if (@vlr1-@dif)>0  begin
select @vlr2=@ment+(@vlr1-@dif);
if @vlr2>=0 and @adc_intv=0 begin EXEC AP_PTO022 @ment,@vlr2,@noti,@notf,@m_ultadc,@adic_not output; end;
end;
select @vlr2=-1;
if @dif>0 begin select @vlr2=@msai-@dif; end;
if @adc_intv=0 and @vlr2>=0 begin
EXEC AP_PTO022 @vlr2,@msai,@noti,@notf,@m_ultadc,@adic_nothe output;
end;
if @vlr2>=0 begin
select @m_acre=@m_acre+(@msai-@vlr2);
if @i<3 begin
EXEC AP_PTO023 @vlr2, @msai, @noti, @notf, @he_d out, @he_n out, @he_d_sg out, @he_n_sg out;
end else begin
EXEC AP_PTO023 @vlr2, @msai, @noti, @notf, @he_d_fp out, @he_n_fp out, @he_d_fp_sg out, @he_n_fp_sg out;
end;
end;
end;
end;
end;
end;
if @adc_intv=1 begin
select @sai_prev=@m_ultima;
if @apura_tipo=0 begin
if @flx_trab>@limite begin select @sai_prev=@m_ultima-(@flx_trab_ant+@flx_trab-@limite); end;
end;
if @m_primeira>-1 and @m_ultima>-1 and @m_primeira<>@m_ultima and @m_primeira<=@m_ultima begin
if @sai_prev<@m_primeira BEGIN
EXEC AP_PTO022 @m_primeira,@m_ultima,@noti,@notf,@m_ultadc,@adic_nothe output;
end else begin
if @sai_prev<@m_ultima begin
EXEC AP_PTO022 @sai_prev,@m_ultima,@noti,@notf,@m_ultadc,@adic_nothe output;
EXEC AP_PTO022 @m_primeira,@sai_prev,@noti,@notf,@m_ultadc,@adic_not output;
end else begin
EXEC AP_PTO022 @m_primeira,@m_ultima,@noti,@notf,@m_ultadc,@adic_not output;
end;
end;
end;
end;
if @flx_trab<0 begin select @flx_trab=0; end;
if @flx_livre<0 begin select @flx_livre=0; end;
if @m_descanso<0 begin select @m_descanso=0; end;
if @m_intervalo<0 begin select @m_intervalo=0; end;
--if @fm_itv=1 and @intv_feito<@m_intervalo begin select @intv_feito=@m_intervalo; end;
if @fm_intervalo=1 and @intv_feito<=0 and @m_intervalo>0 begin
if @apura_tipo=0 and @flx_trab>@flx_livre begin
select @flx_trab=@flx_trab-@m_intervalo;
if @flx_trab<0 begin select @flx_trab=0; end;
select @m_acre=@m_acre-@m_intervalo;
if @m_acre<0 begin select @m_acre=0; end;
end;
end else if @m_intervalo>0 begin
if @intv_feito<=0 begin
select @intv_feito=@m_intervalo;
end;
select @vlr1=@m_intervalo-@intv_feito;
if @vlr1>0 begin
if @flx_trab>@flx_livre begin
if @apura_tipo=0 begin
select @dif_itv=@vlr1;
select @flx_trab=(@flx_trab+@intv_feito)-@m_intervalo;
if @flx_trab<0 begin select @flx_trab=0; end;
select @m_acre=@m_acre-@vlr1;
if @m_acre<0 begin select @m_acre=0; end;
end;
end;
end else if @vlr1<0 begin
if @apura_tipo=0 and @flx_trab>@flx_livre begin
select @dif_itv=@vlr1;
select @flx_trab=(@flx_trab+@intv_feito)-@m_intervalo;
if @flx_trab<0 begin select @flx_trab=0; end;
select @m_desc=@m_desc+@vlr1;
if @m_desc<0 begin select @m_desc=0; end;
end;
end;
end;
select @vlr1=@flx_trab_ant+@flx_trab-@limite;
if @vlr1<0 begin
select @m_desc=@vlr1*(-1);
end;
if @m_acre>0 begin
if @m_tolera_acre>-1 and @m_tolera_acre>=@m_acre begin
if @m_acre>0 begin exec AP_PTO018 @id_pass output, @data output, 105, @m_acre; end; --Acrscimo tolerado
select @m_acre=0;
end;
end else begin
if @m_tolera_desc>-1 and @m_tolera_desc>=@m_desc begin
if @fim_flex=@data and @m_desc>0 begin exec AP_PTO018 @id_pass output, @data output, 104, @m_desc; end; --Desconto tolerado
select @m_desc=0;
end;
end;
if @m_tolera_acre>-1 and @m_tolera_acre>=@flx_livre begin
if @flx_livre>0 begin exec AP_PTO018 @id_pass output, @data output, 105, @flx_livre; end; --Desconto tolerado
select @flx_livre=0;
end;
select @m_hrs_norm=0;
if @trabalhado=1 begin
select @m_hrs_norm=@flx_trab-@m_acre;
if @apura_tipo=0 and @m_hrs_norm>@m_hrs_prev begin select @m_hrs_norm=@m_hrs_prev; end;
end else begin if @apura_tipo>0 and (@m_descanso-@he_descanso)>0 begin --Dia livre com horas de descanso
select @m_hrs_norm=(@m_descanso-@he_descanso);
end; end;
if @m_hrs_norm<0 begin select @m_hrs_norm=0; end;
select @m_hn_tot=0, @m_trab_tot=0;
if @apura_tipo>0 begin
select @m_hn_tot=@normais_ant+@m_hrs_norm;
select @m_trab_tot=@flx_trab_ant+@flx_trab;
end;
select @achou=0, @m_abater_ht=-1, @m_abater_vl=-1, @he_itv=1, @folga_dia=0;
SELECT @achou=1, @m_abater_ht=m_abater_ht, @m_abater_vl=m_abater_vl, @he_itv=he_itv, @folga_dia=isnull(folga_dia,0)
FROM tbHE WHERE id_he=@id_he;
if @tipohe='E' begin select @adic_nothe=@adic_nothe-(@he_n_fp+@he_n_fp_sg), @he_n_fp=0, @he_n_fp_sg=0; end;
select @vlr1=@m_intervalo-@intv_feito;
if @vlr1>0 and (@intv_feito<=0 or @he_intervalo=0 or @tipohe='E' or @tipohe='S') begin
if @he_d>=@vlr1       begin select @he_d=@he_d-@vlr1, @vlr1=0; end else begin select @he_d=0; end;
if @he_d_fp>=@vlr1    begin select @he_d_fp=@he_d_fp-@vlr1, @vlr1=0; end else begin select @he_d_fp=0; end;
if @he_n>=@vlr1       begin select @he_n=@he_n-@vlr1, @adic_nothe=@adic_nothe-@vlr1, @vlr1=0; end else begin select @he_n=0; end;
if @he_n_fp>=@vlr1    begin select @he_n_fp=@he_n_fp-@vlr1, @adic_nothe=@adic_nothe-@vlr1, @vlr1=0; end else begin select @he_n_fp=0; end;
if @he_d_sg>=@vlr1    begin select @he_d_sg=@he_d_sg-@vlr1, @vlr1=0; end else begin select @he_d_sg=0; end;
if @he_d_fp_sg>=@vlr1 begin select @he_d_fp_sg=@he_d_fp_sg-@vlr1, @vlr1=0; end else begin select @he_d_fp_sg=0; end;
if @he_n_sg>=@vlr1    begin select @he_n_sg=@he_n_sg-@vlr1, @adic_nothe=@adic_nothe-@vlr1, @vlr1=0; end else begin select @he_n_sg=0; end;
if @he_n_fp_sg>=@vlr1 begin select @he_n_fp_sg=@he_n_fp_sg-@vlr1, @adic_nothe=@adic_nothe-@vlr1, @vlr1=0; end else begin select @he_n_fp_sg=0; end;
end;
if @tipohe='S' begin select @adic_nothe=@adic_nothe-(@he_n+@he_n_sg), @he_n=0, @he_n_sg=0; end;
if @tipohe<>'X' and (@m_tolera_acre=-1 or @m_tolera_acre<(@he_d+@he_d_fp+@he_n+@he_n_fp+@he_d_sg+@he_d_fp_sg+@he_n_sg+@he_n_fp_sg)) begin
if @he_d+@he_d_fp+@he_n+@he_n_fp+@he_d_sg+@he_d_fp_sg+@he_n_sg+@he_n_fp_sg > 0 begin
select @he_inicio=0;
if @m_primeira>-1 and (@he_n+@he_n_fp+@he_n_sg+@he_n_fp_sg)>0 begin
if (@m_primeira>=1320 and @m_primeira<=1740) or (@m_primeira>=1320+1440 and @m_primeira<=1740+1440) or (@m_primeira>=1320+2880 and @m_primeira<=1740+2880) begin
select @he_inicio=1;
end;
end;
select @wdiafaixa=@wdiapto;
if @folga_dia=1 and @wdiapto=8 begin
select @wdiafaixa=DATEPART(dw,@data), @wdiafaixa=@wdiafaixa-1;
end;
SELECT @he_opcao=isnull(opcao,0), @he_periodo=periodo FROM tbFxsHE WHERE id_he = @id_he and dia = @wdiafaixa;
select @wdiafaixa=@wdiapto_sg;
if @folga_dia=1 and @wdiapto_sg=8 begin
select @wdiafaixa=DATEPART(dw,@data), @wdiafaixa=@wdiafaixa-1;
end;
SELECT @he_opcao_sg=isnull(opcao,0), @he_periodo_sg=periodo FROM tbFxsHE WHERE id_he = @id_he and dia = @wdiafaixa;
if NOT EXISTS(SELECT id_pass FROM tbPtoHEDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoHEDia (id_pass, data, opcao, periodo,he_d, he_d_fp, he_n, he_n_fp, opcao_sg, periodo_sg,he_d_sg, he_d_fp_sg, he_n_sg, he_n_fp_sg,he_inicio,abo_he_d, abo_he_d_fp, abo_he_n, abo_he_n_fp)
VALUES (@id_pass, @data, isnull(@he_opcao,0),isnull(@he_periodo,0),
@he_d, @he_d_fp, @he_n, @he_n_fp, isnull(@he_opcao_sg,0), isnull(@he_periodo_sg,0),
@he_d_sg, @he_d_fp_sg, @he_n_sg, @he_n_fp_sg, @he_inicio, 0, 0, 0, 0)
end else begin
UPDATE tbPtoHEDia SET opcao=isnull(@he_opcao,0),periodo=isnull(@he_periodo,0),
he_d=@he_d, he_d_fp=@he_d_fp, he_n=@he_n, he_n_fp=@he_n_fp,
opcao_sg=isnull(@he_opcao_sg,0), periodo_sg=isnull(@he_periodo_sg,0),
he_d_sg=@he_d_sg, he_d_fp_sg=@he_d_fp_sg, he_n_sg=@he_n_sg,
he_n_fp_sg=@he_n_fp_sg, he_inicio=@he_inicio
WHERE id_pass=@id_pass AND data=@data;
end;
end;
end;
if @fim_flex=@data and @m_desc>0 begin
if @data <= getdate() begin
if @contamc=0 and @apura_tipo=0 and @ap_falta=1 begin
exec AP_PTO018 @id_pass output, @data output, 29, @m_desc;
end else begin
exec AP_PTO018 @id_pass output, @data output, 66, @m_desc;
end;
end;
end;
if @tipohe='X' or @id_he=0 begin if @m_acre>0 begin exec AP_PTO018 @id_pass output, @data output, 67, @m_acre; end;  end;
if @dif_itv>0 begin
if @m_tolera_acre>-1 and @m_tolera_acre>=@dif_itv begin
select @dif_itv=0;
end;
if @dif_itv>0 and (@tipohe='X' or @id_he=0 or @he_intervalo=0) begin exec AP_PTO018 @id_pass output, @data output, 73, @dif_itv; end;
end else if @dif_itv<0 begin
select @dif_itv=@dif_itv*(-1);
if @m_tolera_desc>-1 and @m_tolera_desc>=@dif_itv begin
select @dif_itv=0;
end;
if @dif_itv>0 and @m_intervalo>0 begin exec AP_PTO018 @id_pass output, @data output, 32, @dif_itv; end;
end;
if @flx_livre>0 begin exec AP_PTO018 @id_pass output, @data output, 69, @flx_livre; end;
if @id_adicional>0 and @wdiapto<10 and (@adic_not > 0 or @adic_nothe > 0) begin
if @adc_minhe>0 begin
if @adic_not<=@adc_min and @adic_nothe<=@adc_minhe begin
select @adic_not=0;
end;
end else begin
if @adic_not<=@adc_min begin select @adic_not=0; end;
end;
if @adic_nothe<=@adc_minhe begin select @adic_nothe=0; end;
if substring(@adc_w_hn,@wdiapto+1,1) <> '1' begin select @adic_not=0; end;
if substring(@adc_w_he,@wdiapto+1,1) <> '1' begin select @adic_nothe=0; end;
select @reduz_normal=0, @reduz_he=0;
if @adc_fator = 0 begin
select @adc_fator=(60/52.5)-1;
select @adc_fator_pad=1;
end else begin
select @adc_fator_pad=0;
end;
select @vlr1=@adic_not+@adic_nothe;
if @adc_fator_pad=1 begin
select @vlr2=round(@vlr1 * @adc_fator,0);
end else begin
select @vlr2=round(@vlr1 * @adc_fator,0,1);
end;
if @vlr2>0 begin
select @vlr1=@adic_not;
if @adc_fator_pad=1 begin
select @reduz_normal=round(@vlr1 * @adc_fator,0);
end else begin
select @reduz_normal=round(@vlr1 * @adc_fator,0,1);
end;
select @reduz_he=@vlr2-@reduz_normal;
if @reduz_he<0 begin select @reduz_he=0; end;
end;
if @reduzida=1 begin
if @reduz_normal>0 begin
select @achou=0, @id_divadc=0;
SELECT distinct @achou=1, @id_divadc=isnull(id_diverg,0) FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=1 AND dia=@wdiapto AND contafx=0;
if @id_divadc=0 or @id_divadc=45 begin
exec AP_PTO018 @id_pass output, @data output, 47, @reduz_normal;
end else if @id_divadc=81 begin
exec AP_PTO018 @id_pass output, @data output, 89, @reduz_normal;
end else if @id_divadc=82 begin
exec AP_PTO018 @id_pass output, @data output, 90, @reduz_normal;
end else if @id_divadc=83 begin
exec AP_PTO018 @id_pass output, @data output, 91, @reduz_normal;
end else if @id_divadc=84 begin
exec AP_PTO018 @id_pass output, @data output, 92, @reduz_normal;
end;
end;
if @reduz_he>0 begin
if @trabalhado=1 begin
select @achou=0, @id_divadc=0;
SELECT distinct @achou=1, @id_divadc=isnull(id_diverg,0) FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=0 AND dia=@wdiapto AND contafx=0;
if @id_divadc=0 or @id_divadc=46 begin
exec AP_PTO018 @id_pass output, @data output, 52, @reduz_he;
end else if @id_divadc=85 begin
exec AP_PTO018 @id_pass output, @data output, 93, @reduz_he;
end else if @id_divadc=86 begin
exec AP_PTO018 @id_pass output, @data output, 94, @reduz_he;
end else if @id_divadc=87 begin
exec AP_PTO018 @id_pass output, @data output, 95, @reduz_he;
end else if @id_divadc=88 begin
exec AP_PTO018 @id_pass output, @data output, 96, @reduz_he;
end;
end else begin
select @achou=0, @id_divadc=0;
SELECT distinct @achou=1, @id_divadc=isnull(id_diverg,0) FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=0 AND dia=@wdiapto AND contafx=0;
if @id_divadc=0 or @id_divadc=46 begin
exec AP_PTO018 @id_pass output, @data output, 53, @reduz_he;
end else if @id_divadc=85 begin
exec AP_PTO018 @id_pass output, @data output, 97, @reduz_he;
end else if @id_divadc=86 begin
exec AP_PTO018 @id_pass output, @data output, 98, @reduz_he;
end else if @id_divadc=87 begin
exec AP_PTO018 @id_pass output, @data output, 99, @reduz_he;
end else if @id_divadc=88 begin
exec AP_PTO018 @id_pass output, @data output, 100, @reduz_he;
end;
end;
end;
end;
if @adc_somar=1 begin
select @adic_not=@adic_not+@reduz_normal;
end;
--Faixas
select @contafx=0;
while (@contafx < 3 and @adic_not > 0) begin
select @achou=0, @m_faixa_fim=0, @id_divadc=0;
SELECT distinct @achou=1, @m_faixa_fim=m_faixa_fim, @id_divadc=id_diverg FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=1 AND dia=@wdiapto AND contafx=@contafx;
if @achou = 1 and @m_faixa_fim>-1 begin
select @vlr1=@m_faixa_fim;
if @vlr1 > 0 begin
if @vlr1 > @adic_not begin
select @vlr1=@adic_not, @adic_not=0;
end else begin
select @adic_not=@adic_not-@vlr1;
end;
if @id_divadc > 0 and @vlr1 > 0 begin
exec AP_PTO018 @id_pass output, @data output, @id_divadc, @vlr1, 1;
end;
end;
end;
select @contafx=@contafx+1
end;
if @adc_somar=1 begin
select @adic_nothe=@adic_nothe+@reduz_he;
end;
--Faixas
select @contafx=0;
while (@contafx < 3 and @adic_nothe > 0)  begin
select @achou=0, @m_faixa_fim=0, @id_divadc=0;
SELECT distinct @achou=1, @m_faixa_fim=m_faixa_fim, @id_divadc=id_diverg FROM tbFxsAdc
WHERE id_adicional=@id_adicional AND normal=0 AND dia=@wdiapto AND contafx=@contafx;
if @achou = 1 and @m_faixa_fim>-1 begin
select @vlr1=@m_faixa_fim;
if @vlr1 > 0 begin
if @vlr1 > @adic_nothe begin
select @vlr1=@adic_nothe, @adic_nothe=0;
end else begin
select @adic_nothe=@adic_nothe-@vlr1;
end;
if @id_divadc > 0 and @vlr1 > 0 begin
exec AP_PTO018 @id_pass output, @data output, @id_divadc, @vlr1, 1;
end;
end;
select @contafx=@contafx+1
end;
end;
if isnull(@redhen,0)=1 begin
if @adc_fator_pad=1 begin
UPDATE tbPtoHEDia SET he_n = round(isnull(he_n,0) * (@adc_fator+1),0),
he_n_sg = round(isnull(he_n_sg,0) * (@adc_fator+1),0),
he_n_fp = round(isnull(he_n_fp,0) * (@adc_fator+1),0),
he_n_fp_sg = round(isnull(he_n_fp_sg,0) * (@adc_fator+1),0)
WHERE id_pass=@id_pass AND data=@data;
end else begin
UPDATE tbPtoHEDia SET he_n = round(isnull(he_n,0) * (@adc_fator+1),0,1),
he_n_sg = round(isnull(he_n_sg,0) * (@adc_fator+1),0,1),
he_n_fp = round(isnull(he_n_fp,0) * (@adc_fator+1),0,1),
he_n_fp_sg = round(isnull(he_n_fp_sg,0) * (@adc_fator+1),0,1)
WHERE id_pass=@id_pass AND data=@data;
end;
end;
end;
if @trabalhado=1 begin
if @flx_trab>0 or @m_hrs_norm>0 begin
if NOT EXISTS(SELECT id_pass FROM tbPtoHFlx WHERE id_pass=@id_pass AND data=@data) begin
INSERT INTO tbPtoHFlx(id_pass, data, efetuado, normais) VALUES (@id_pass, @data, @flx_trab, @m_hrs_norm);
end else begin
UPDATE tbPtoHFlx SET efetuado=@flx_trab, normais=@m_hrs_norm WHERE id_pass=@id_pass AND data=@data;
end;
end;
end else begin if @m_descanso>0 or @m_hrs_norm>0 begin
if NOT EXISTS(SELECT id_pass FROM tbPtoHFlx WHERE id_pass=@id_pass AND data=@data) begin
INSERT INTO tbPtoHFlx(id_pass, data, efetuado, normais) VALUES (@id_pass, @data, @m_descanso, @m_hrs_norm);
end else begin
UPDATE tbPtoHFlx SET efetuado=@m_descanso, normais=@m_hrs_norm WHERE id_pass=@id_pass AND data=@data;
end;
end; end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO051') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO051; END
GO
CREATE PROCEDURE dbo.AP_PTO051(@id_pass int output, @data datetime output, @opcao int, @somar_fora_per bit, @id_diverg int, @vlr int, @tipo_he tinyint) WITH ENCRYPTION AS
BEGIN
declare @vlr_abo int; declare @vlr_bco int; declare @vlr1 int; declare @vlr1_fp int;
EXEC AP_PTO018 @id_pass output, @data output, @id_diverg, @vlr, 1;
EXEC AP_PTO017 @id_pass output, @data output, @id_diverg;
select @vlr_abo=0;
SELECT TOP 1 @vlr_abo=isnull(m_abonado,0) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg;
if @vlr_abo>@vlr begin select @vlr_abo=@vlr; end;
if (@vlr_abo>0) AND EXISTS(SELECT id_pass FROM tbFunc WHERE id_pass=@id_pass AND id_tabbco>0) begin
select @vlr_bco=0;
SELECT @vlr_bco=isnull(SUM(a.m_valor),0) FROM tbPtoAboDia a
INNER JOIN tbEvsAbono e ON a.id_eveabo = e.id_eveabo
WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg AND e.abo_banco=1;
select @vlr_abo=@vlr_abo-@vlr_bco;
end;
if @vlr_abo>0 begin
if @tipo_he=1 begin
if @somar_fora_per=1 begin
select @vlr1=0, @vlr1_fp=0;
SELECT TOP 1 @vlr1=(he_d-abo_he_d), @vlr1_fp=(he_d_fp-abo_he_d_fp) FROM tbPtoHEDia WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
if @vlr1>0 begin
if @vlr_abo>@vlr1 begin select @vlr1_fp=@vlr_abo-@vlr1; end else begin select @vlr1=@vlr_abo, @vlr1_fp=0; end;
end else if @vlr1_fp>0 begin
if @vlr_abo>@vlr1_fp begin select @vlr1=@vlr_abo-@vlr1_fp; end else begin select @vlr1_fp=@vlr_abo, @vlr1=0; end;
end else begin
select @vlr1=0, @vlr1_fp=0;
end;
UPDATE tbPtoHEDia SET abo_he_d=abo_he_d+@vlr1, abo_he_d_fp=abo_he_d_fp+@vlr1_fp WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
end else begin
UPDATE tbPtoHEDia SET abo_he_d=abo_he_d+@vlr_abo WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
end;
end else if @tipo_he=2 begin
UPDATE tbPtoHEDia SET abo_he_d_fp=abo_he_d_fp+@vlr_abo WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
end else if @tipo_he=3 begin
if @somar_fora_per=1 begin
select @vlr1=0, @vlr1_fp=0;
SELECT TOP 1 @vlr1=(he_n-abo_he_n), @vlr1_fp=(he_n_fp-abo_he_n_fp) FROM tbPtoHEDia WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
if @vlr1>0 begin
if @vlr_abo>@vlr1 begin select @vlr1_fp=@vlr_abo-@vlr1; end else begin select @vlr1=@vlr_abo, @vlr1_fp=0; end;
end else if @vlr1_fp>0 begin
if @vlr_abo>@vlr1_fp begin select @vlr1=@vlr_abo-@vlr1_fp; end else begin select @vlr1_fp=@vlr_abo, @vlr1=0; end;
end else begin
select @vlr1=0, @vlr1_fp=0;
end;
UPDATE tbPtoHEDia SET abo_he_n=abo_he_n+@vlr1, abo_he_n_fp=abo_he_n_fp+@vlr1_fp WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
end else begin
UPDATE tbPtoHEDia SET abo_he_n=abo_he_n+@vlr_abo WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
end;
end else if @tipo_he=4 begin
UPDATE tbPtoHEDia SET abo_he_n_fp=abo_he_n_fp+@vlr_abo WHERE id_pass=@id_pass AND data=@data AND opcao=@opcao;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO026') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO026; END
GO
CREATE PROCEDURE dbo.AP_PTO026(@id_pass int output, @data datetime output, @somar_fora_per bit, @id_he int, @opcao int, @he_d int,@he_d_fp int, @he_n int, @he_n_fp int, @ahe_d int, @ahe_d_fp int, @ahe_n int, @ahe_n_fp int, @he_inicio tinyint) WITH ENCRYPTION AS
BEGIN
declare @achou bit;     declare @contafx int;        declare @m_faixa_ini int; declare @m_ini_cp int; declare @m_faixa_fim int, @vlr_faixa int; declare @vlr int; declare @vlr2 int;
declare @id_divdia int; declare @id_divdia_fora int; declare @id_divnoite int; declare @id_divnoite_fora int;
if @somar_fora_per=1 begin
select @he_d=@he_d+@he_d_fp;
select @he_n=@he_n+@he_n_fp;
select @he_d_fp=0,@he_n_fp=0;
select @ahe_d=@ahe_d+@ahe_d_fp;
select @ahe_n=@ahe_n+@ahe_n_fp;
select @ahe_d_fp=0,@ahe_n_fp=0;
end;
select @ahe_d=@ahe_d+@ahe_d_fp+@ahe_n+@ahe_n_fp; --somar todas as anteriores
select @contafx=0
while (@contafx < 6 and (@he_d+@he_d_fp+@he_n+@he_n_fp) > 0) begin
select @achou=0, @id_divdia=0, @id_divdia_fora=0, @id_divnoite=0,@id_divnoite_fora=0,@m_faixa_ini=0, @m_ini_cp=0,@m_faixa_fim=0,@vlr_faixa=0;
SELECT distinct @achou=1, @m_faixa_ini=m_faixa_ini, @m_faixa_fim=m_faixa_fim, @id_divdia=id_divdia, @id_divdia_fora=id_divdia_fora, @id_divnoite=id_divnoite,@id_divnoite_fora=id_divnoite_fora
FROM tbFxsHE WHERE id_he=@id_he AND opcao = @opcao AND contafx=@contafx;
if @achou = 1 and @m_faixa_fim>-1 begin
select @vlr_faixa=@m_faixa_fim, @m_ini_cp=0;
if @contafx=0 begin
select @m_ini_cp=@m_faixa_ini;
end else if @vlr_faixa<59999 begin
select @vlr_faixa=@vlr_faixa-(@m_faixa_ini-1);
if @vlr_faixa<0 begin select @vlr_faixa=0; end;
end;
if @vlr_faixa>@ahe_d begin
select @vlr_faixa=@vlr_faixa-@ahe_d, @ahe_d=0;
end else begin
select @ahe_d=@ahe_d-@vlr_faixa, @vlr_faixa=0;
end;
if @vlr_faixa>0 begin
if @he_inicio=0 begin
select @vlr=0;
if @vlr_faixa > @he_d begin
select @vlr=@he_d, @vlr_faixa=@vlr_faixa-@he_d, @he_d=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_d=@he_d-@vlr;
end;
if @id_divdia > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divdia, @vlr, 1;
end;
select @vlr=0;
if @vlr_faixa > @he_d_fp begin
select @vlr=@he_d_fp, @vlr_faixa=@vlr_faixa-@he_d_fp, @he_d_fp=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_d_fp=@he_d_fp-@vlr;
end;
if @id_divdia_fora > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divdia_fora, @vlr, 2;
end;
select @vlr=0;
if @vlr_faixa > @he_n begin
select @vlr=@he_n, @vlr_faixa=@vlr_faixa-@he_n, @he_n=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_n=@he_n-@vlr;
end;
if @id_divnoite > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divnoite, @vlr, 3;
end;
select @vlr=0;
if @vlr_faixa > @he_n_fp begin
select @vlr=@he_n_fp, @vlr_faixa=@vlr_faixa-@he_n_fp, @he_n_fp=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_n_fp=@he_n_fp-@vlr;
end;
if @id_divnoite_fora > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divnoite_fora, @vlr, 4;
end;
end else begin
select @vlr=0;
if @vlr_faixa > @he_n begin
select @vlr=@he_n, @vlr_faixa=@vlr_faixa-@he_n, @he_n=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_n=@he_n-@vlr;
end;
if @id_divnoite > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divnoite, @vlr, 3;
end;
select @vlr=0;
if @vlr_faixa > @he_n_fp begin
select @vlr=@he_n_fp, @vlr_faixa=@vlr_faixa-@he_n_fp, @he_n_fp=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_n_fp=@he_n_fp-@vlr;
end;
if @id_divnoite_fora > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divnoite_fora, @vlr, 4;
end;
select @vlr=0;
if @vlr_faixa > @he_d begin
select @vlr=@he_d, @vlr_faixa=@vlr_faixa-@he_d, @he_d=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_d=@he_d-@vlr;
end;
if @id_divdia > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divdia, @vlr, 1;
end;
select @vlr=0;
if @vlr_faixa > @he_d_fp begin
select @vlr=@he_d_fp, @vlr_faixa=@vlr_faixa-@he_d_fp, @he_d_fp=0;
end else begin
select @vlr=@vlr_faixa, @vlr_faixa=0, @he_d_fp=@he_d_fp-@vlr;
end;
if @id_divdia_fora > 0 and @vlr>0 begin
select @vlr=@vlr-@m_ini_cp, @m_ini_cp=0;
if @vlr>0
EXEC AP_PTO051 @id_pass output, @data output, @opcao, @somar_fora_per, @id_divdia_fora, @vlr, 2;
end;
end;
end;
end;
select @contafx=@contafx+1
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO027') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO027; END;
GO
CREATE PROCEDURE dbo.AP_PTO027(@he_ini datetime, @dom_data datetime, @id_pass int output, @data datetime output, @id_he int) WITH ENCRYPTION AS
BEGIN
declare @somar_fora_per bit; declare @quebra bit, @quebra_a bit, @quebra_b bit, @quebra_c bit, @quebra_d bit, @quebra_e bit; declare @achou bit;
declare @he_d int; declare @he_d_fp int;   declare @he_n int; declare @he_n_fp int;
declare @ahe_d int; declare @ahe_d_fp int; declare @ahe_n int; declare @ahe_n_fp int;
declare @abo_he_d int; declare @abo_he_d_fp int; declare @abo_he_n int; declare @abo_he_n_fp int;
declare @opcao int; declare @periodo int; declare @he_inicio tinyint
select @he_d=0,@he_d_fp=0, @he_n=0, @he_n_fp=0, @ahe_d=0,@ahe_d_fp=0, @ahe_n=0, @ahe_n_fp=0, @he_inicio=0, @quebra_a=0, @quebra_b=0, @quebra_c=0, @quebra_d=0, @quebra_e=0, @abo_he_d=0, @abo_he_d_fp=0, @abo_he_n=0, @abo_he_n_fp=0;
select @achou=0;
SELECT top 1 @achou=1, @somar_fora_per=somar_fora_per, @quebra_a=quebra, @quebra_b=isnull(quebra_b,quebra), @quebra_c=isnull(quebra_c,quebra), @quebra_d=isnull(quebra_d,quebra), @quebra_e=isnull(quebra_e,quebra) FROM tbHE WHERE id_he=@id_he;
if @achou=1 begin
select @achou=0;
SELECT @achou=1, @opcao=opcao FROM tbPtoHEDia WHERE id_pass=@id_pass AND data=@data;
select @quebra=@quebra_a;
if @achou=1 begin
if @opcao=2 begin select @quebra=@quebra_b; end;
if @opcao=3 begin select @quebra=@quebra_c; end;
if @opcao=4 begin select @quebra=@quebra_d; end;
if @opcao=5 begin select @quebra=@quebra_e; end;
end;
if @quebra=0 begin
select @achou=0;
SELECT @achou=1, @opcao=opcao, @periodo=periodo, @he_d=he_d+he_d_sg, @he_d_fp=he_d_fp+he_d_fp_sg, @he_n=he_n+he_n_sg, @he_n_fp=he_n_fp+he_n_fp_sg, @he_inicio=isnull(he_inicio,0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data=@data;
if @achou=1 begin
if @periodo=1 begin
if not @dom_data is null begin
SELECT @ahe_d=isnull(SUM(he_d+he_d_sg),0), @ahe_d_fp=isnull(SUM(he_d_fp+he_d_fp_sg),0), @ahe_n=isnull(SUM(he_n+he_n_sg),0), @ahe_n_fp=isnull(SUM(he_n_fp+he_n_fp_sg),0),
@abo_he_d=isnull(SUM(abo_he_d),0), @abo_he_d_fp=isnull(SUM(abo_he_d_fp),0), @abo_he_n=isnull(SUM(abo_he_n),0), @abo_he_n_fp=isnull(SUM(abo_he_n_fp),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@dom_data AND data<@data AND opcao=@opcao;
end;
end;
if @periodo=2 begin
if not @he_ini is null and not @he_ini is null begin
SELECT @ahe_d=isnull(SUM(he_d+he_d_sg),0), @ahe_d_fp=isnull(SUM(he_d_fp+he_d_fp_sg),0), @ahe_n=isnull(SUM(he_n+he_n_sg),0), @ahe_n_fp=isnull(SUM(he_n_fp+he_n_fp_sg),0),
@abo_he_d=isnull(SUM(abo_he_d),0), @abo_he_d_fp=isnull(SUM(abo_he_d_fp),0), @abo_he_n=isnull(SUM(abo_he_n),0), @abo_he_n_fp=isnull(SUM(abo_he_n_fp),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@he_ini AND data<@data AND opcao=@opcao;
end;
end;
select @ahe_d=@ahe_d-@abo_he_d;
select @ahe_d_fp=@ahe_d_fp-@abo_he_d_fp;
select @ahe_n=@ahe_n-@abo_he_n;
select @ahe_n_fp=@ahe_n_fp-@abo_he_n_fp;
if @ahe_d<0 begin select @ahe_d=0; end;
if @ahe_d_fp<0 begin select @ahe_d_fp=0; end;
if @ahe_n<0 begin select @ahe_n=0; end;
if @ahe_n_fp<0 begin select @ahe_n_fp=0; end;
--if (@periodo=1 or @periodo=2)
--   select @he_inicio=0;
EXEC AP_PTO026 @id_pass output, @data output, @somar_fora_per, @id_he, @opcao, @he_d, @he_d_fp, @he_n, @he_n_fp, @ahe_d, @ahe_d_fp, @ahe_n, @ahe_n_fp, @he_inicio;
end;
end else begin
select @achou=0;
SELECT @achou=1, @opcao=opcao, @periodo=periodo,
@he_d=(CASE WHEN opcao=opcao_sg THEN he_d+he_d_sg ELSE he_d END),
@he_d_fp=(CASE WHEN opcao=opcao_sg THEN he_d_fp+he_d_fp_sg ELSE he_d_fp END),
@he_n=(CASE WHEN opcao=opcao_sg THEN he_n+he_n_sg ELSE he_n END),
@he_n_fp=(CASE WHEN opcao=opcao_sg THEN he_n_fp+he_n_fp_sg ELSE he_n_fp END), @he_inicio=isnull(he_inicio,0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data=@data;
if @achou=1 begin
if @periodo=1 begin
if not @dom_data is null begin
SELECT @ahe_d=isnull(SUM(he_d),0), @ahe_d_fp=isnull(SUM(he_d_fp),0),  @ahe_n=isnull(SUM(he_n),0), @ahe_n_fp=isnull(SUM(he_n_fp),0),
@abo_he_d=isnull(SUM(abo_he_d),0), @abo_he_d_fp=isnull(SUM(abo_he_d_fp),0),  @abo_he_n=isnull(SUM(abo_he_n),0), @abo_he_n_fp=isnull(SUM(abo_he_n_fp),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@dom_data AND data<@data AND opcao=@opcao;
SELECT @ahe_d=@ahe_d+isnull(SUM(he_d_sg),0), @ahe_d_fp=@ahe_d_fp+isnull(SUM(he_d_fp_sg),0),@ahe_n=@ahe_n+isnull(SUM(he_n_sg),0), @ahe_n_fp=@ahe_n_fp+isnull(SUM(he_n_fp_sg),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@dom_data AND data<@data AND opcao_sg=@opcao;
end;
end;
if @periodo=2 begin
if not @he_ini is null and not @he_ini is null begin
SELECT @ahe_d=isnull(SUM(he_d),0), @ahe_d_fp=isnull(SUM(he_d_fp),0), @ahe_n=isnull(SUM(he_n),0), @ahe_n_fp=isnull(SUM(he_n_fp),0),
@abo_he_d=isnull(SUM(abo_he_d),0), @abo_he_d_fp=isnull(SUM(abo_he_d_fp),0), @abo_he_n=isnull(SUM(abo_he_n),0), @abo_he_n_fp=isnull(SUM(abo_he_n_fp),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@he_ini AND data<@data AND opcao=@opcao;
SELECT @ahe_d=@ahe_d+isnull(SUM(he_d_sg),0), @ahe_d_fp=@ahe_d_fp+isnull(SUM(he_d_fp_sg),0),@ahe_n=@ahe_n+isnull(SUM(he_n_sg),0), @ahe_n_fp=@ahe_n_fp+isnull(SUM(he_n_fp_sg),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@he_ini AND data<@data AND opcao_sg=@opcao;
end;
end;
select @ahe_d=@ahe_d-@abo_he_d;
select @ahe_d_fp=@ahe_d_fp-@abo_he_d_fp;
select @ahe_n=@ahe_n-@abo_he_n;
select @ahe_n_fp=@ahe_n_fp-@abo_he_n_fp;
if @ahe_d<0 begin select @ahe_d=0; end;
if @ahe_d_fp<0 begin select @ahe_d_fp=0; end;
if @ahe_n<0 begin select @ahe_n=0; end;
if @ahe_n_fp<0 begin select @ahe_n_fp=0; end;
--if (@periodo=1 or @periodo=2)
--   select @he_inicio=0;
EXEC AP_PTO026 @id_pass output, @data output, @somar_fora_per, @id_he, @opcao, @he_d, @he_d_fp, @he_n, @he_n_fp, @ahe_d, @ahe_d_fp, @ahe_n, @ahe_n_fp, @he_inicio;
end;
select @achou=0, @he_d=0,@he_d_fp=0, @he_n=0, @he_n_fp=0, @ahe_d=0,@ahe_d_fp=0, @ahe_n=0, @ahe_n_fp=0, @abo_he_d=0, @abo_he_d_fp=0, @abo_he_n=0, @abo_he_n_fp=0;
SELECT @achou=1, @opcao=opcao_sg, @periodo=periodo_sg, @he_d=he_d_sg, @he_d_fp=he_d_fp_sg,@he_n=he_n_sg, @he_n_fp=he_n_fp_sg
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data=@data and opcao_sg<>opcao;
if @achou=1 begin
if @periodo=1 begin
if not @dom_data is null begin
SELECT @ahe_d=isnull(SUM(he_d),0), @ahe_d_fp=isnull(SUM(he_d_fp),0), @ahe_n=isnull(SUM(he_n),0), @ahe_n_fp=isnull(SUM(he_n_fp),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@dom_data AND data<@data AND opcao=@opcao;
SELECT @ahe_d=@ahe_d+isnull(SUM(he_d_sg),0), @ahe_d_fp=@ahe_d_fp+isnull(SUM(he_d_fp_sg),0), @ahe_n=@ahe_n+isnull(SUM(he_n_sg),0), @ahe_n_fp=@ahe_n_fp+isnull(SUM(he_n_fp_sg),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@dom_data AND data<@data AND opcao_sg=@opcao;
end;
end;
if @periodo=2 begin
if not @he_ini is null and not @he_ini is null begin
SELECT @ahe_d=isnull(SUM(he_d),0), @ahe_d_fp=isnull(SUM(he_d_fp),0), @ahe_n=isnull(SUM(he_n),0), @ahe_n_fp=isnull(SUM(he_n_fp),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@he_ini AND data<@data AND opcao=@opcao;
SELECT @ahe_d=@ahe_d+isnull(SUM(he_d_sg),0), @ahe_d_fp=@ahe_d_fp+isnull(SUM(he_d_fp_sg),0), @ahe_n=@ahe_n+isnull(SUM(he_n_sg),0), @ahe_n_fp=@ahe_n_fp+isnull(SUM(he_n_fp_sg),0)
FROM tbPtoHEDia WHERE id_pass=@id_pass AND data>=@he_ini AND data<@data AND opcao_sg=@opcao;
end;
end;
select @ahe_d=@ahe_d-@abo_he_d;
select @ahe_d_fp=@ahe_d_fp-@abo_he_d_fp;
select @ahe_n=@ahe_n-@abo_he_n;
select @ahe_n_fp=@ahe_n_fp-@abo_he_n_fp;
if @ahe_d<0 begin select @ahe_d=0; end;
if @ahe_d_fp<0 begin select @ahe_d_fp=0; end;
if @ahe_n<0 begin select @ahe_n=0; end;
if @ahe_n_fp<0 begin select @ahe_n_fp=0; end;
select @he_inicio=1;
--if (@periodo=1 or @periodo=2)
--   select @he_inicio=0;
EXEC AP_PTO026 @id_pass output, @data output, @somar_fora_per, @id_he, @opcao, @he_d, @he_d_fp, @he_n, @he_n_fp, @ahe_d, @ahe_d_fp, @ahe_n, @ahe_n_fp, @he_inicio;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO028') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO028; END;
GO
CREATE PROCEDURE dbo.AP_PTO028(@id_pass int output, @data datetime output, @id_dsr int, @per_dsr int, @fechamento_fim datetime, @mes_ini datetime, @mes_fim datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @dtIni_ava datetime; declare @dtFim_ava datetime;
declare @dataAtual datetime;
declare @dtIni_dsc datetime; declare @dtFim_dsc datetime; declare @dia_dsr int;
declare @psi int;  declare @m_umdsr int, @m_domingo int, @m_feriado int, @m_folga int;
declare @m_folga_old int; declare @desc_proporcional bit, @prop_diver bit;
declare @desc_semavaliar int;  declare @desc_semdescontar int;
declare @calc_dias bit; declare @dias_semana int; declare @pagar_dsr bit;
declare @m_tolera_valor int, @m_tolera_dia int, @m_totdia int; declare @tolera_qtde int; declare @achou bit;
declare @dtAtu datetime; declare @tot_dsc int; declare @tot_qdsc int, @tot_mqdsc float;
declare @dias_trab int; declare @dtDSR datetime; declare @dtF1 datetime;
declare @dtF2 datetime; declare @dtF3 datetime; declare @dtF4 datetime;
declare @dtF5 datetime; declare @dtF6 datetime; declare @dtF7 datetime;
declare @trabalhado bit; declare @eve_calc_hn bit; declare @folga bit; declare @tipodia char(1);
declare @descontar bit; declare @acres_dsr int; declare @desc_dsr int;
declare @m_vlrDSR int; declare @m_vlrDesc int; declare @admissao bit; declare @demissao bit;
declare @folg_prox int; declare @categoria tinyint;
declare @descontar_folga bit; declare @proximo_folga datetime;
select @dataAtual = convert(datetime,convert(varchar,getdate(),101));
select @dia_dsr=1, @m_domingo=-1,@m_feriado=-1,@m_folga=-1, @m_folga_old=-1,@desc_proporcional=0, @prop_diver=0,@desc_semavaliar=0,@desc_semdescontar=0;
select @calc_dias=0,@dias_semana=0,@pagar_dsr=1,@m_tolera_valor=-1, @m_tolera_dia=-1, @m_totdia=0, @tolera_qtde=0,@folg_prox=0;
select @achou=0;
SELECT @achou=1, @dia_dsr=isnull(dia_dsr,1), @m_domingo=m_domingo,@m_feriado=m_feriado,@m_folga=m_folga,@desc_proporcional=desc_proporcional,@prop_diver=prop_diver,
@desc_semavaliar=desc_semavaliar,@desc_semdescontar=desc_semdescontar,@calc_dias=calc_dias,
@dias_semana=dias_semana,@pagar_dsr=pagar_dsr,@m_tolera_valor=m_tolera_valor, @m_tolera_dia=m_tolera_dia,@tolera_qtde=tolera_qtde, @folg_prox=isnull(folg_prox,0)
FROM tbDSR WHERE id_dsr = @id_dsr;
select @categoria=0;
SELECT @categoria=isnull(categoria,0) FROM tbFunc WHERE id_pass = @id_pass;
if @folg_prox=1 and @categoria=1 begin
select @m_folga_old=@m_folga;
select @m_domingo=0, @m_folga=0;
end;
select @m_umdsr=0;
if @m_folga>0 begin   select @m_umdsr=@m_folga; end;
if @m_feriado>0 begin select @m_umdsr=@m_feriado; end;
if @m_domingo>0 begin select @m_umdsr=@m_domingo; end;
if @achou=1 and (@m_domingo>0 or @m_feriado>0 or @m_folga>0 or @m_folga_old>0)  begin
select @psi=(DATEPART(dw,@data)-1)*(-1);
select @dtIni_ava = dateadd(d,@psi,@data);
if @desc_semavaliar=1 begin
select @dtIni_ava = dateadd(d,1,@dtIni_ava);
end;
select @dtFim_ava = dateadd(d,6,@dtIni_ava);
if @dtIni_ava>@data begin
select @dtIni_ava=dateadd(d,-7,@dtIni_ava), @dtFim_ava=dateadd(d,-7,@dtFim_ava);
end;
select @dtIni_dsc=@dtIni_ava, @dtFim_dsc=@dtFim_ava;
if @desc_semdescontar=1 begin
select @dtIni_dsc=dateadd(d,7,@dtIni_dsc), @dtFim_dsc=dateadd(d,7,@dtFim_dsc);
end;
select @descontar=0;
select @tot_dsc=0,@tot_qdsc=0,@tot_mqdsc=0,@dias_trab=0,@descontar=0;
select @dtAtu=@dtIni_ava;
while (@dtAtu<=@dtFim_ava) begin
if not EXISTS(SELECT id_pass FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dtAtu) begin
EXEC AP_PTO009 @id_pass output, @dtAtu output, 0;
end;
select @trabalhado=0,@folga=0,@tipodia='N';
SELECT @trabalhado=isnull(trabalhado,0), @folga=isnull(folga,0), @tipodia=isnull(tipodia,'N')
FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dtAtu;
if @trabalhado=1 begin select @dias_trab=@dias_trab+1; end;
if @dtAtu < @dataAtual  begin
select @m_totdia=0;
--Divergncias que no consideram abono
if EXISTS(SELECT top 1 s.id_diverg FROM tbDivDescDSR s
WHERE s.id_dsr=@id_dsr AND s.ignora_abono_total=0 AND s.ignora_abono_parcial=0
) begin
SELECT @m_totdia=@m_totdia+isnull(sum(d.m_valor),0) FROM tbPtoDivsDia d
INNER JOIN tbDivDescDSR s ON s.id_dsr=@id_dsr AND d.id_diverg = s.id_diverg
AND s.ignora_abono_total=0 AND s.ignora_abono_parcial=0
WHERE d.id_pass = @id_pass AND d.data=@dtAtu;
end;
--Divergncias abonadas parcialmente
if EXISTS(SELECT top 1 s.id_diverg FROM tbDivDescDSR s
WHERE s.id_dsr=@id_dsr AND s.ignora_abono_total=1 AND s.ignora_abono_parcial=0
) begin
SELECT @m_totdia=@m_totdia+isnull(sum((d.m_valor-d.m_abonado)),0) FROM tbPtoDivsDia d
INNER JOIN tbDivDescDSR s ON s.id_dsr=@id_dsr AND d.id_diverg = s.id_diverg
AND s.ignora_abono_total=1 AND s.ignora_abono_parcial=0
AND (d.m_valor-d.m_abonado)>0
WHERE d.id_pass = @id_pass AND d.data=@dtAtu;
end;
--Divergncias que no abonadas
if EXISTS(SELECT top 1 s.id_diverg FROM tbDivDescDSR s
WHERE s.id_dsr=@id_dsr AND s.ignora_abono_total=1 AND s.ignora_abono_parcial=1
) begin
SELECT @m_totdia=@m_totdia+isnull(sum(d.m_valor),0) FROM tbPtoDivsDia d
INNER JOIN tbDivDescDSR s ON s.id_dsr=@id_dsr AND d.id_diverg = s.id_diverg
AND s.ignora_abono_total=1 AND s.ignora_abono_parcial=1
AND d.m_abonado<=0
WHERE d.id_pass = @id_pass AND d.data=@dtAtu;
end;
if @m_totdia > 0 begin
select @tot_qdsc=@tot_qdsc+1;
select @tot_dsc=@tot_dsc+@m_totdia;
if @m_tolera_dia>0 and @m_totdia>@m_tolera_dia begin
select @descontar=1;
end;
if (@prop_diver=0) or (@m_totdia >= @m_umdsr) or (@m_umdsr<=0) or
EXISTS(SELECT id_pass FROM tbPtoApDia WHERE id_pass=@id_pass AND data=@dtAtu AND falta=1)
begin
select @tot_mqdsc=@tot_mqdsc+1;
end else begin
--Proporcional por divergncia
select @tot_mqdsc=@tot_mqdsc+(convert(float,@m_totdia) / convert(float,@m_umdsr));
end;
end;
end;
select @dtAtu=dateadd(d,1,@dtAtu);
end;
if @tot_dsc>0 or @tot_qdsc>0 begin
if @m_tolera_valor=-1 and @m_tolera_dia=-1 and @tolera_qtde=0 begin
select @descontar=1; --no tem tolerncia
end else if (@m_tolera_valor>=0 and @tot_dsc>@m_tolera_valor)
or (@tolera_qtde>0 and @tot_qdsc>@tolera_qtde) begin
select @descontar=1;
end;
end;
if @calc_dias=0 begin
select @dias_trab=@dias_semana;
end;
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data>=@dtIni_dsc AND data<=@dtFim_dsc;
select @dtAtu=@dtIni_dsc, @m_vlrDSR=0;
while (@dtAtu<=@dtFim_dsc) begin
if not EXISTS(SELECT id_pass FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dtAtu) begin
EXEC AP_PTO009 @id_pass output, @dtAtu output, 0;
end;
select @trabalhado=0,@eve_calc_hn=0,@admissao=0,@demissao=0,@folga=0,@tipodia='N';
SELECT @trabalhado=isnull(d.trabalhado,0), @folga=isnull(d.folga,0), @tipodia=isnull(d.tipodia,'N'),
@eve_calc_hn=isnull(e.calc_hn,0), @admissao=admissao,@demissao=demissao
FROM tbPtoDia d LEFT JOIN tbEvsAbono e ON d.id_eveafa=e.id_eveabo
WHERE d.id_pass = @id_pass AND d.data = @dtAtu;
if (@trabalhado=0 or (DATEPART(dw,@dtAtu)=@dia_dsr and @m_domingo>0)) AND @eve_calc_hn=0 AND @admissao=0 AND @demissao=0 begin
if DATEPART(dw,@dtAtu)=@dia_dsr and @m_domingo>0 begin
select @dtDSR=@dtAtu, @m_vlrDSR=@m_domingo;
end else begin
if @m_feriado>0 and @tipodia='V' begin
if @dtF1 is null begin select @dtF1=@dtAtu;
end else begin if @dtF2 is null begin select @dtF2=@dtAtu;
end else begin if @dtF3 is null begin select @dtF3=@dtAtu;
end else begin if @dtF4 is null begin select @dtF4=@dtAtu;
end else begin if @dtF5 is null begin select @dtF5=@dtAtu;
end else begin if @dtF6 is null begin select @dtF6=@dtAtu;
end else begin if @dtF7 is null begin select @dtF7=@dtAtu;
end; end; end; end; end; end; end;
end else begin
if @m_folga>0 and @folga=1 and @dtDSR is null begin
select @dtDSR=@dtAtu, @m_vlrDSR=@m_folga;
end;
end;
end;
end;
select @dtAtu=dateadd(d,1,@dtAtu);
end;
if not @dtDSR is null begin
select @m_vlrDesc=0;
if @descontar=1 begin
if @desc_proporcional=0 begin
select @m_vlrDesc=@m_vlrDSR;
end else begin
if @dias_trab>0 begin
select @m_vlrDesc=round((convert(float,@m_vlrDSR)/convert(float,@dias_trab)) * @tot_mqdsc,0);
end;
end;
end;
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtDSR;
INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtDSR, @m_vlrDSR,@m_vlrDesc);
end;
if not @dtF1 is null begin
select @m_vlrDesc=0;
if @descontar=1 begin
if @desc_proporcional=0 begin
select @m_vlrDesc=@m_feriado;
end else begin
if @dias_trab>0 begin
select @m_vlrDesc=round((convert(float,@m_feriado)/convert(float,@dias_trab)) * @tot_mqdsc,0);
end;
end;
end;
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtF1; INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtF1, @m_feriado, @m_vlrDesc);
if not @dtF2 is null begin
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtF2; INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtF2, @m_feriado, @m_vlrDesc);
end;
if not @dtF3 is null begin
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtF3; INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtF3, @m_feriado, @m_vlrDesc);
end;
if not @dtF4 is null begin
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtF4; INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtF4, @m_feriado, @m_vlrDesc);
end;
if not @dtF5 is null begin
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtF5; INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtF5, @m_feriado, @m_vlrDesc);
end;
if not @dtF6 is null begin
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtF6; INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtF6, @m_feriado, @m_vlrDesc);
end;
if not @dtF7 is null begin
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtF7; INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtF7, @m_feriado, @m_vlrDesc);
end;
end;
if @folg_prox=1 and @categoria=1 and @m_folga_old>0 begin
select @m_folga=@m_folga_old;
select @psi=(DATEPART(dw,@data)-1)*(-1);
select @dtIni_ava = dateadd(d,@psi,@data);
if @desc_semavaliar=1 begin
select @dtIni_ava = dateadd(d,1,@dtIni_ava);
end;
select @dtFim_ava = dateadd(d,6,@dtIni_ava);
if @dtIni_ava>@data begin
select @dtIni_ava=dateadd(d,-7,@dtIni_ava), @dtFim_ava=dateadd(d,-7,@dtFim_ava);
end;
select @proximo_folga=dateadd(d,-1,@dtIni_ava);
select @dtAtu=dateadd(d,-1,@dtIni_ava), @psi=0;
while (@psi<6) begin
if not EXISTS(SELECT id_pass FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dtAtu) begin
EXEC AP_PTO009 @id_pass output, @dtAtu output, 0;
end;
select @trabalhado=0,@admissao=0,@demissao=0,@folga=0,@tipodia='N';
SELECT @trabalhado=isnull(d.trabalhado,0), @folga=isnull(d.folga,0), @tipodia=isnull(d.tipodia,'N'),
@admissao=admissao,@demissao=demissao
FROM tbPtoDia d LEFT JOIN tbEvsAbono e ON d.id_eveafa=e.id_eveabo
WHERE d.id_pass = @id_pass AND d.data = @dtAtu;
if @admissao=1 OR @demissao=1 begin
select @psi=10;
end else if @trabalhado=0 AND @folga=1 begin
select @dtIni_ava=dateadd(d,1,@dtAtu);
select @proximo_folga=@dtIni_ava;
select @psi=10;
end;
select @dtAtu=dateadd(d,-1,@dtAtu);
select @psi=@psi+1;
end;
select @dtAtu=@dtFim_ava, @psi=0;
while (@psi<6) begin
select @dtAtu=dateadd(d,1,@dtAtu);
if not EXISTS(SELECT id_pass FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dtAtu) begin
EXEC AP_PTO009 @id_pass output, @dtAtu output, 0;
end;
select @trabalhado=0,@demissao=0,@folga=0,@tipodia='N';
SELECT @trabalhado=isnull(d.trabalhado,0), @folga=isnull(d.folga,0), @tipodia=isnull(d.tipodia,'N'),
@admissao=admissao,@demissao=demissao
FROM tbPtoDia d LEFT JOIN tbEvsAbono e ON d.id_eveafa=e.id_eveabo
WHERE d.id_pass = @id_pass AND d.data = @dtAtu;
if @demissao=1 begin
select @psi=10;
end else if @trabalhado=0 AND @folga=1 and @admissao=0 begin
select @dtFim_ava=@dtAtu;
select @psi=10;
end;
select @psi=@psi+1;
end;
select @dtAtu=@dtIni_ava, @descontar_folga=0;
while (@dtAtu<=@dtFim_ava) begin
select @trabalhado=0,@admissao=0,@demissao=0,@folga=0,@tipodia='N';
SELECT @trabalhado=isnull(d.trabalhado,0), @folga=isnull(d.folga,0), @tipodia=isnull(d.tipodia,'N'),
@admissao=admissao,@demissao=demissao
FROM tbPtoDia d LEFT JOIN tbEvsAbono e ON d.id_eveafa=e.id_eveabo
WHERE d.id_pass = @id_pass AND d.data = @dtAtu;
if (@tipodia<>'V' OR @m_feriado<=0) AND @trabalhado=0 AND @folga=1 AND @admissao=0 AND @demissao=0 begin
DELETE FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@dtAtu;
INSERT INTO tbPtoDSRDia (id_pass, data, acres_dsr, desc_dsr) VALUES (@id_pass, @dtAtu, 0, 0);
if @proximo_folga<>@dtAtu begin
UPDATE tbPtoDSRDia SET acres_dsr=@m_folga WHERE id_pass=@id_pass AND data=@dtAtu;
end;
select @proximo_folga=dateadd(d,1,@dtAtu);
if @descontar_folga=1 begin
select @descontar_folga=0;
UPDATE tbPtoDSRDia SET desc_dsr=@m_folga WHERE id_pass=@id_pass AND data=@dtAtu;
end;
end else begin if @descontar_folga=0 begin
if EXISTS(SELECT d.m_valor FROM tbPtoDivsDia d
INNER JOIN tbDivDescDSR s ON s.id_dsr=@id_dsr AND d.id_diverg = s.id_diverg
AND (s.ignora_abono_total=0 OR (d.m_valor-d.m_abonado)>0)
AND (s.ignora_abono_parcial=0 OR d.m_abonado=0)
WHERE d.id_pass = @id_pass AND d.data=@dtAtu) begin
select @descontar_folga=1;
end;
end; end;
select @dtAtu=dateadd(d,1,@dtAtu);
end; --while (@dtAtu<=@dtFim_ava)
end;
end;
select @acres_dsr=0, @desc_dsr=0;
if isnull(@per_dsr,0)=0 begin
SELECT @acres_dsr=isnull(acres_dsr,0), @desc_dsr=isnull(desc_dsr,0) FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@data;
end else begin
SELECT @desc_dsr=isnull(desc_dsr,0) FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data=@data;
if @data=@fechamento_fim begin
SELECT @acres_dsr=sum(isnull(acres_dsr,0)) FROM tbPtoDSRDia WHERE id_pass=@id_pass AND data>=@mes_ini AND data<=@mes_fim;
end;
end;
if exists(SELECT admissao FROM tbFunc WHERE id_pass=@id_pass AND admissao>=@data) begin
select @acres_dsr=0, @desc_dsr=0;
end else begin
if exists(SELECT dtdemissao FROM tbFunc WHERE id_pass=@id_pass AND dtdemissao<@data) begin
select @acres_dsr=0, @desc_dsr=0;
end;
end;
if @pagar_dsr=1 AND isnull(@acres_dsr,0)>0 begin EXEC AP_PTO018 @id_pass output, @data output, 50, @acres_dsr, 0; end;
if isnull(@desc_dsr,0)>0 begin  EXEC AP_PTO018 @id_pass output, @data output, 51, @desc_dsr, 0;  end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO029') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO029; END;
GO
CREATE PROCEDURE dbo.AP_PTO029(@id_pass int output, @data datetime output, @banco_ini datetime, @banco_fim datetime, @ano_bco int, @mes_bco int) WITH ENCRYPTION AS
BEGIN
declare @per_bco int; declare @per_bco_ini int;
declare @tb_union TABLE(data datetime, id_diverg int, soma bit, m_horas int, m_semabo int);
declare @tb_soma TABLE(idSoma int IDENTITY(1,1), data datetime, id_diverg int, soma bit, m_horas int, m_semabo int);
declare @psi int; declare @numregs int; declare @achou bit;
declare @dtreg datetime; declare @id_diverg int; declare @m_horas int; declare @soma bit; declare @m_semabo int;
declare @horas varchar(8); declare @antes varchar(8); declare @creditos varchar(8);
declare @debitos varchar(8); declare @pago varchar(8);
declare @descontado varchar(8); declare @acumulado varchar(8);
declare @compensado varchar(8); declare @saldo varchar(8);
declare @m_antes int; declare @m_creditos int; declare @m_debitos int; declare @m_pago int;
declare @m_descontado int; declare @m_acumulado int; declare @m_compensado int, @m_compensado_corrente int, @m_saldo int, @m_sldfinal int;
declare @per_atu int; declare @m_sldcre int; declare @m_slddeb int; declare @m_comp_per int;
declare @comp_per varchar(8); declare @validade_cre tinyint; declare @validade_deb tinyint;
declare @datamax datetime; declare @saldo_sinal bit; declare @saldo_vlr int;
declare @zerar_bco_mes bit, @pagar_bco_mes bit, @m_credpgto int, @m_debpgto int, @m_credpgto_atu int, @m_debpgto_atu int;
declare @liq_cred bit, @liq_deb bit, @m_lmtcred int, @m_lmtdeb int;
declare @id_tabbco int; declare @banco_fim_trat datetime
DELETE FROM tbPtoBcoDivs WHERE id_pass = @id_pass AND data>=@data;
select @per_bco=0,@per_bco_ini=0, @id_tabbco=0;
if isnull(@ano_bco,0)>0 and isnull(@mes_bco,0)>0 begin
select @per_bco=@ano_bco*100+@mes_bco;
SELECT @per_bco_ini=per_bco_ini, @id_tabbco=(CASE WHEN banco=1 THEN id_tabbco ELSE 0 END)
FROM tbFunc WHERE id_pass=@id_pass;
SELECT TOP 1 @id_tabbco=id_tabbco FROM tbPtoDia WHERE id_pass=@id_pass AND data=@data;
end;
if @per_bco>0 and @per_bco>=isnull(@per_bco_ini,0) begin
DELETE FROM tbPtoBco WHERE id_pass=@id_pass AND data>=@banco_ini;
DELETE FROM tbPtoBcoCmp WHERE id_pass=@id_pass AND per_cmp>=@per_bco;
DELETE FROM tbPtoBcoCmp WHERE id_pass=@id_pass AND per_bco<@per_bco_ini;
DELETE FROM tbPtoBcoSld WHERE id_pass=@id_pass AND per_bco>=@per_bco;
DELETE FROM tbPtoBcoSld WHERE id_pass=@id_pass AND per_bco<@per_bco_ini;
end;
if isnull(@id_tabbco,0)>0 and @per_bco>0 and @per_bco>=isnull(@per_bco_ini,0) begin
select @zerar_bco_mes=0;
if not exists(SELECT id_pass FROM tbPtoBcoZera WHERE id_pass=@id_pass AND per_bco=@per_bco AND acao=1) begin
SELECT @zerar_bco_mes=1 FROM tbPtoBcoZera WHERE id_pass=@id_pass AND per_bco=@per_bco AND acao=0;
end;
select @pagar_bco_mes=0, @m_credpgto=0, @m_debpgto=0;
select @liq_cred=0, @liq_deb=0, @m_lmtcred=0, @m_lmtdeb=0;
SELECT TOP 1 @liq_cred=isnull(cred, 0), @liq_deb=isnull(deb, 0), @m_lmtcred=isnull(m_creditos,0), @m_lmtdeb=isnull(m_debitos,0) FROM tbTabBcoPag WHERE id_tabbco=@id_tabbco AND per_bco=@per_bco;
if @liq_cred=1 or @liq_deb=1 begin
select @pagar_bco_mes=1;
if @liq_cred=1 begin
if @m_lmtcred>0
select @m_credpgto=@m_lmtcred;
else
select @m_credpgto=599999;
end;
if @liq_deb=1 begin
if @m_lmtdeb>0
select @m_debpgto=@m_lmtdeb;
else
select @m_debpgto=599999;
end;
end;
if not exists(SELECT id_pass FROM tbPtoBcoPgto WHERE id_pass=@id_pass AND per_bco=@per_bco AND acao=1) begin
if exists(SELECT id_pass FROM tbPtoBcoPgto WHERE id_pass=@id_pass AND per_bco=@per_bco AND acao=0) begin
SELECT @pagar_bco_mes=1, @m_credpgto=m_creditos, @m_debpgto=m_debitos FROM tbPtoBcoPgto WHERE id_pass=@id_pass AND per_bco=@per_bco AND acao=0;
end;
end;
select @liq_cred=0, @liq_deb=0;
if @pagar_bco_mes=1 begin
if @m_credpgto>0
select @liq_cred=1;
if @m_debpgto>0
select @liq_deb=1;
end else begin
select @m_credpgto=0, @m_debpgto=0;
end;
select @datamax = convert(datetime,convert(varchar,getdate(),101));
select @banco_fim_trat = @banco_fim;
if @banco_fim is null OR @datamax <= @banco_fim_trat begin select @banco_fim_trat=@datamax; end;
if not @banco_fim is null begin
if @banco_fim_trat <= @data begin
DELETE FROM tbPtoBcoDivs WHERE id_pass = @id_pass AND data>=@banco_fim_trat;
end else begin
DELETE FROM tbPtoBcoDivs WHERE id_pass = @id_pass AND data=@banco_fim;
end;
end;
select @achou=0;
SELECT @achou=1, @m_antes=m_antes, @m_creditos=m_creditos, @m_debitos=m_debitos, @m_acumulado=m_acumulado FROM tbPtoBcoSMes WHERE id_pass=@id_pass AND per_bco=@per_bco;
select @m_compensado_corrente=0;
if @achou=0 begin
if not @banco_ini is null AND not @banco_fim_trat is null AND @banco_ini <= @banco_fim_trat begin
INSERT INTO @tb_union (data, id_diverg, soma, m_horas, m_semabo)
SELECT xa.data, xa.id_diverg, xa.soma,
(CASE WHEN xa.m_tirabco>=xa.m_valor THEN 0 ELSE (xa.m_valor-xa.m_tirabco) END)*xa.percbco,
(CASE WHEN xa.m_tirabco+xa.m_tiraabo>=xa.m_valor THEN 0 ELSE (xa.m_valor-(xa.m_tirabco+xa.m_tiraabo)) END)
FROM (
SELECT d.data, d.id_diverg, v.soma, d.m_valor, v.percbco,
ISNULL((
SELECT SUM(ab1.m_valor) FROM tbPtoAboDia ab1
INNER JOIN tbEvsAbono ev1 ON ab1.id_eveabo = ev1.id_eveabo AND isnull(ev1.banco,0)=0 AND isnull(ev1.abo_banco,0)=1 AND isnull(ev1.calculo,1)=1
WHERE d.id_pass=ab1.id_pass AND d.data = ab1.data AND d.id_diverg = ab1.id_diverg
),0) as m_tirabco,
ISNULL((
SELECT SUM(ab1.m_valor) FROM tbPtoAboDia ab1
INNER JOIN tbEvsAbono ev1 ON ab1.id_eveabo = ev1.id_eveabo AND (isnull(ev1.banco,0)=1 OR isnull(ev1.abo_banco,0)=0) AND isnull(ev1.calculo,1)=1
WHERE d.id_pass=ab1.id_pass AND d.data = ab1.data AND d.id_diverg = ab1.id_diverg
),0) as m_tiraabo
FROM tbPtoDivsDia d
INNER JOIN tbDivergencias v ON d.id_diverg = v.id_diverg AND v.ativada=1
WHERE d.id_pass = @id_pass AND d.data >= @banco_ini AND d.data <= @banco_fim_trat AND isnull(d.id_associ,0)=0 AND d.id_diverg IN (
SELECT db.id_diverg FROM tbDivsBco db WHERE db.id_tabbco = @id_tabbco
)
) as xa;
INSERT INTO @tb_union (data, id_diverg, soma, m_horas, m_semabo)
SELECT xb.data, xb.id_diverg, xb.soma,
(CASE WHEN xb.m_enviabco>=xb.m_valor THEN xb.m_valor ELSE xb.m_enviabco END)*xb.percbco,
0
FROM (
SELECT d.data, d.id_diverg, v.soma, d.m_valor, v.percbco,
ISNULL((
SELECT SUM(ab1.m_valor) FROM tbPtoAboDia ab1
INNER JOIN tbEvsAbono ev1 ON ab1.id_eveabo = ev1.id_eveabo AND isnull(ev1.banco,0)=1 AND isnull(ev1.calculo,1)=1
WHERE d.id_pass=ab1.id_pass AND d.data = ab1.data AND d.id_diverg = ab1.id_diverg
),0) as m_enviabco
FROM tbPtoDivsDia d
INNER JOIN tbDivergencias v ON d.id_diverg = v.id_diverg AND v.ativada=1
WHERE d.id_pass = @id_pass AND d.data >= @banco_ini AND d.data <= @banco_fim_trat AND isnull(d.id_associ,0)=0 AND d.id_diverg NOT IN (
SELECT db.id_diverg FROM tbDivsBco db WHERE db.id_tabbco = @id_tabbco
)
AND EXISTS(
SELECT TOP 1 ev2.id_eveabo FROM tbPtoAboDia ab2
INNER JOIN tbEvsAbono ev2 ON ab2.id_eveabo = ev2.id_eveabo AND ev2.banco=1 AND isnull(ev2.calculo,1)=1
WHERE d.id_pass=ab2.id_pass AND d.data = ab2.data AND d.id_diverg = ab2.id_diverg
)
) as xb;
end;
INSERT INTO @tb_soma (data, id_diverg, soma, m_horas, m_semabo)
SELECT data, id_diverg, soma, sum(m_horas), sum(m_semabo) FROM @tb_union GROUP BY data, id_diverg, soma;
DELETE FROM @tb_soma WHERE m_horas=0;
select @m_antes=0,@m_creditos=0,@m_debitos=0,@m_pago=0,@m_descontado=0,@m_acumulado=0,@m_compensado=0,@m_saldo=0;
select @psi=0, @numregs=0;
SELECT @numregs=isnull(max(idSoma),0) FROM @tb_soma;
while @psi<@numregs begin
select @psi=@psi+1, @achou=0;
SELECT @achou=1,@dtreg=data, @id_diverg=id_diverg, @soma=soma, @m_horas=m_horas, @m_semabo=m_semabo FROM @tb_soma WHERE idSoma = @psi;
if @achou=1 begin
if @soma=1 begin
select @m_creditos=@m_creditos+@m_horas;
end else begin
select @m_debitos=@m_debitos+@m_horas, @m_horas=@m_horas*(-1);
end;
EXEC AP_PTO004 @m_horas, @horas output;
INSERT INTO tbPtoBco (id_pass, data, per_bco, id_diverg, horas, m_horas, m_semabo)
VALUES (@id_pass, @dtreg, @per_bco, @id_diverg, @horas, @m_horas, @m_semabo);
end;
end;
select @validade_cre=0, @validade_deb=0;
SELECT @validade_cre=isnull(b.validade_cre,0), @validade_deb=isnull(b.validade_deb,0) FROM tbTabBco b
WHERE b.id_tabbco = @id_tabbco
select @m_sldcre=@m_creditos, @m_slddeb=@m_debitos;
select @per_atu=0
SELECT @per_atu=isnull(max(per_bco),0) FROM tbPtoBcoSMes WHERE id_pass=@id_pass AND per_bco>=@per_bco_ini and per_bco<@per_bco;
if @per_atu=0 begin
select @per_atu=@per_bco_ini;
end;
if @zerar_bco_mes=1 begin
select @per_atu=@per_bco, @m_antes=0;
end else if @per_atu<@per_bco begin
SELECT @per_atu=isnull(max(z1.per_bco),@per_atu) FROM tbPtoBcoZera z1
WHERE z1.id_pass=@id_pass AND z1.per_bco>=@per_atu AND z1.per_bco<@per_bco AND z1.acao=0
AND NOT EXISTS(
SELECT z2.id_pass FROM tbPtoBcoZera z2
WHERE z2.id_pass=@id_pass AND z2.per_bco=z1.per_bco AND z2.acao=1
);
end;
while @per_atu>0 and @per_atu<@per_bco begin
select @achou=0, @m_saldo=0, @m_compensado=0, @m_acumulado=0;
SELECT @achou=1, @m_acumulado=m_acumulado, @m_saldo=m_saldo FROM tbPtoBcoSld WHERE id_pass=@id_pass AND per_bco = @per_atu;
if @achou=1 begin
SELECT @m_compensado=isnull(sum(m_horas),0) FROM tbPtoBcoCmp WHERE id_pass=@id_pass AND per_bco=@per_atu;
select @m_saldo=@m_saldo+@m_compensado;
select @m_antes=@m_acumulado;
select @m_comp_per=0;
if @m_saldo>0 begin
if @m_slddeb>@m_saldo begin
select @m_comp_per=@m_comp_per-@m_saldo, @m_slddeb=@m_slddeb-@m_saldo, @m_saldo=0;
end else begin
select @m_comp_per=@m_comp_per-@m_slddeb, @m_saldo=@m_saldo-@m_slddeb, @m_slddeb=0;
end;
end else if @m_saldo<0 begin
if @m_sldcre>abs(@m_saldo) begin
select @m_comp_per=@m_comp_per+abs(@m_saldo), @m_sldcre=@m_sldcre+@m_saldo, @m_saldo=0;
end else begin
select @m_comp_per=@m_comp_per+@m_sldcre, @m_saldo=@m_saldo+@m_sldcre, @m_sldcre=0;
end;
end;
if @m_comp_per<> 0 begin
EXEC AP_PTO004 @m_comp_per, @comp_per output;
INSERT INTO tbPtoBcoCmp (id_pass, per_bco, per_cmp, tipo_cmp, horas, m_horas)
VALUES (@id_pass, @per_atu, @per_bco, (CASE WHEN @m_comp_per<0 THEN 0 ELSE 1 END),@comp_per, @m_comp_per)
select @m_compensado=@m_compensado+@m_comp_per;
end;
select @m_credpgto_atu=@m_credpgto, @m_debpgto_atu=@m_debpgto;
if @m_saldo>0 and (
@liq_cred=1 or (@validade_cre>0 and @validade_cre=((@per_bco+1)-@per_atu))
)
begin
if @liq_cred=0 begin
select @m_credpgto_atu=@m_saldo; --pagamento por validade
end else begin
if @m_credpgto_atu>(@m_saldo+abs(@m_pago)) begin
select @m_credpgto_atu=@m_saldo;
end else if @m_credpgto_atu>abs(@m_pago) begin
select @m_credpgto_atu=@m_credpgto_atu-abs(@m_pago)
end else begin
select @m_credpgto_atu=0;
end;
end;
if @m_credpgto_atu>0 begin
select @m_saldo=@m_saldo-@m_credpgto_atu;
select @m_comp_per=@m_credpgto_atu*(-1), @m_pago=@m_pago-@m_credpgto_atu;
EXEC AP_PTO004 @m_comp_per, @comp_per output;
INSERT INTO tbPtoBcoCmp (id_pass, per_bco, per_cmp, tipo_cmp, horas, m_horas)
VALUES (@id_pass, @per_atu, @per_bco, 3, @comp_per, @m_comp_per)
select @m_compensado=@m_compensado+@m_comp_per;
end;
end;
if @m_saldo<0 and (
@liq_deb=1 or (@validade_deb > 0 and @validade_deb=((@per_bco+1)-@per_atu))
)
begin
if @liq_deb=0 begin
select @m_debpgto_atu=abs(@m_saldo); --desconto por validade
end else begin
if @m_debpgto_atu>(abs(@m_saldo)+@m_descontado) begin
select @m_debpgto_atu=abs(@m_saldo);
end else if @m_debpgto_atu>@m_descontado begin
select @m_debpgto_atu=@m_debpgto_atu-@m_descontado
end else begin
select @m_debpgto_atu=0;
end;
end;
if @m_debpgto_atu>0 begin
select @m_debpgto_atu=@m_debpgto_atu*(-1);
select @m_saldo=(abs(@m_saldo)-abs(@m_debpgto_atu)) * (-1);
select @m_comp_per=abs(@m_debpgto_atu), @m_descontado=@m_descontado+abs(@m_debpgto_atu);
EXEC AP_PTO004 @m_comp_per, @comp_per output;
INSERT INTO tbPtoBcoCmp (id_pass, per_bco, per_cmp, tipo_cmp, horas, m_horas)
VALUES (@id_pass, @per_atu, @per_bco, 2, @comp_per, @m_comp_per)
select @m_compensado=@m_compensado+@m_comp_per;
end;
end;
EXEC AP_PTO004 @m_compensado, @compensado output;
EXEC AP_PTO004 @m_saldo, @saldo output;
UPDATE tbPtoBcoSld SET compensado=@compensado, m_compensado=@m_compensado, saldo_fim=@saldo, m_saldo_fim=@m_saldo WHERE id_pass=@id_pass AND per_bco = @per_atu;
end;
select @per_atu=@per_atu+1;
if @per_atu%100 > 12 begin
select @per_atu=((round(@per_atu/100,0)+1)*100)+(@per_atu%100)-12;
end;
end; --while @per_atu<@per_bco begin
if @m_antes = 0 begin
select @m_saldo = @m_creditos - abs(@m_debitos);
end else if @m_antes < 0 begin
if abs(@m_antes) > @m_creditos begin
select @m_saldo = abs(@m_debitos) * (-1);
end else begin
select @m_saldo = @m_creditos + @m_antes - abs(@m_debitos);
end;
end else begin
if @m_antes > @m_debitos begin
select @m_saldo = @m_creditos;
end else begin
select @m_saldo = @m_creditos + @m_antes - abs(@m_debitos);
end;
end;
if @pagar_bco_mes=1 begin
select @m_credpgto_atu=@m_credpgto, @m_debpgto_atu=@m_debpgto;
select @m_sldfinal=(@m_creditos+@m_antes)-@m_debitos;
if @m_credpgto_atu>0
select @m_pago=0;
if @m_sldfinal>0 and @m_credpgto_atu>0 begin
if @m_credpgto_atu> @m_sldfinal begin
select @m_credpgto_atu=@m_sldfinal;
end;
if @m_credpgto_atu>0 begin
select @m_comp_per=@m_credpgto_atu*(-1), @m_pago= abs(@m_credpgto_atu)*(-1);
EXEC AP_PTO004 @m_comp_per, @comp_per output;
INSERT INTO tbPtoBcoCmp (id_pass, per_bco, per_cmp, tipo_cmp, horas, m_horas)
VALUES (@id_pass, @per_bco, @per_bco, 3, @comp_per, @m_comp_per)
select @m_compensado_corrente=@m_compensado_corrente+@m_comp_per;
end;
end;
if @m_debpgto_atu>0
select @m_descontado = 0;
if @m_sldfinal<0 and @m_debpgto_atu>0 begin
if @m_debpgto_atu>(abs(@m_sldfinal)) begin
select @m_debpgto_atu=abs(@m_sldfinal);
end;
if @m_debpgto_atu>0 begin
select @m_debpgto_atu=@m_debpgto_atu*(-1);
select @m_comp_per=abs(@m_debpgto_atu), @m_descontado=abs(@m_debpgto_atu);
EXEC AP_PTO004 @m_comp_per, @comp_per output;
INSERT INTO tbPtoBcoCmp (id_pass, per_bco, per_cmp, tipo_cmp, horas, m_horas)
VALUES (@id_pass, @per_bco, @per_bco, 2, @comp_per, @m_comp_per)
select @m_compensado_corrente=@m_compensado_corrente+@m_comp_per;
end;
end;
end; --if @pagar_bco_mes=1 begin
select @m_debitos = abs(@m_debitos)*(-1);
select @m_acumulado=@m_antes+@m_creditos+@m_debitos+@m_pago+@m_descontado;
end else begin
select @m_pago=0,@m_descontado=0,@m_saldo=0;
if @m_antes = 0 begin
select @m_saldo = @m_creditos - abs(@m_debitos);
end else if @m_antes < 0 begin
if abs(@m_antes) > @m_creditos begin
select @m_saldo = abs(@m_debitos) * (-1);
end else begin
select @m_saldo = @m_creditos + @m_antes - abs(@m_debitos);
end;
end else begin
if @m_antes > @m_debitos begin
select @m_saldo = @m_creditos;
end else begin
select @m_saldo = @m_creditos + @m_antes - abs(@m_debitos);
end;
end;
end;
select @m_debitos=abs(@m_debitos)*(-1);
EXEC AP_PTO004 @m_antes, @antes output;
EXEC AP_PTO004 @m_creditos, @creditos output;
EXEC AP_PTO004 @m_debitos, @debitos output;
EXEC AP_PTO004 @m_pago, @pago output;
EXEC AP_PTO004 @m_descontado, @descontado output;
EXEC AP_PTO004 @m_acumulado, @acumulado output;
EXEC AP_PTO004 @m_saldo, @saldo output;
INSERT INTO tbPtoBcoSld (id_pass, per_bco, antes, creditos, debitos, pago, descontado,
acumulado, saldo, compensado, saldo_fim, m_antes, m_creditos,m_debitos, m_pago,m_descontado,
m_acumulado, m_saldo, m_compensado, m_saldo_fim)
VALUES (@id_pass, @per_bco, @antes, @creditos, @debitos, @pago, @descontado,
@acumulado, @saldo, '+  00:00', @saldo, @m_antes, @m_creditos,@m_debitos, @m_pago,@m_descontado,
@m_acumulado, @m_saldo, @m_compensado_corrente, @m_saldo);
if @m_acumulado<0 begin
select @saldo_sinal=0,@saldo_vlr=@m_acumulado*-1;
end else begin
select @saldo_sinal=1,@saldo_vlr=@m_acumulado;
end;
if not @banco_fim is null begin
if (@m_pago <> 0 or @m_descontado <> 0 or @saldo_vlr <> 0) begin
INSERT INTO tbPtoBcoDivs (id_pass, data, pagar, descontar, saldo_sinal, saldo_vlr)
VALUES (@id_pass, @banco_fim, abs(@m_pago), abs(@m_descontado), @saldo_sinal, @saldo_vlr);
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO030') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO030; END;
GO
CREATE PROCEDURE dbo.AP_PTO030(@id_pass int output, @data datetime output, @id_arredonda int, @associa bit, @id_diverg int, @horas int output) WITH ENCRYPTION AS
BEGIN
declare @achou bit; declare @arr_para int; declare @vlraux varchar(7);
declare @so_min int; declare @id_associ int; declare @soma bit; declare @somadiv bit;
declare @id_divassoc_nh int;
select @somadiv=0;
SELECT @somadiv=soma FROM tbDivergencias WHERE id_diverg=@id_diverg;
if isnull(@id_arredonda,0) > 0 AND @id_diverg NOT IN (102,103) begin
select @achou=0,@arr_para=0;
SELECT @achou=1,@arr_para=m_arredonda FROM tbArredFxs
WHERE id_arredonda=@id_arredonda AND id_diverg=@id_diverg AND @horas BETWEEN m_faixa_ini AND m_faixa_fim;
if @achou=1 begin
EXEC AP_PTO003 @arr_para, @vlraux output;
UPDATE tbPtoDivsDia SET m_ant_arred=@horas, m_valor=@arr_para, valor=@vlraux
WHERE id_pass = @id_pass AND data = @data AND id_diverg=@id_diverg;
select @horas=@arr_para;
end else begin
select @achou=0,@so_min=@horas%60,@arr_para=0;
SELECT @achou=1,@arr_para=m_arredonda FROM tbArredFxs
WHERE id_arredonda=@id_arredonda AND id_diverg=@id_diverg AND minutos=1 AND @so_min BETWEEN m_faixa_ini AND m_faixa_fim;
if @achou=1 begin
select @arr_para = @arr_para+(@horas-@so_min);
EXEC AP_PTO003 @arr_para, @vlraux output;
UPDATE tbPtoDivsDia SET m_ant_arred=@horas, m_valor=@arr_para, valor=@vlraux
WHERE id_pass = @id_pass AND data = @data AND id_diverg=@id_diverg;
select @horas=@arr_para;
end;
end;
end;
if @associa=1 begin
select @achou=0;
if @id_diverg = 44 begin
select @id_divassoc_nh=0;
SELECT @id_divassoc_nh=isnull(id_divassoc,0) FROM tbHNormais h
INNER JOIN tbPtoDia d ON h.id_hnormais = d.id_hnormais AND d.id_pass = @id_pass AND d.data = @data
if @id_divassoc_nh>0 begin
SELECT TOP 1 @achou=1, @id_associ=v.id_diverg, @soma=v.soma FROM tbDivAssoc a INNER JOIN tbDivergencias v ON v.id_diverg = a.id_divassoc WHERE a.id_diverg = @id_diverg AND a.id_divassoc=@id_divassoc_nh ORDER BY v.descricao;
end else begin
SELECT TOP 1 @achou=1, @id_associ=v.id_diverg, @soma=v.soma FROM tbDivAssoc a INNER JOIN tbDivergencias v ON v.id_diverg = a.id_divassoc WHERE a.id_diverg = @id_diverg ORDER BY v.descricao;
end;
end else begin
SELECT TOP 1 @achou=1, @id_associ=v.id_diverg, @soma=v.soma FROM tbDivAssoc a INNER JOIN tbDivergencias v ON v.id_diverg = a.id_divassoc WHERE a.id_diverg = @id_diverg ORDER BY v.descricao;
end;
if @achou=1 begin
if @soma <> @somadiv begin select @horas=@horas * (-1); end;
EXEC AP_PTO018 @id_pass output, @data output, @id_associ, @horas, 1;
EXEC AP_PTO017 @id_pass output, @data output, @id_associ;
UPDATE tbPtoDivsDia SET id_associ=@id_associ WHERE id_pass = @id_pass AND data = @data AND id_diverg=@id_diverg;
end else begin
EXEC AP_PTO017 @id_pass output, @data output, @id_diverg;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO036') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO036; END;
GO
CREATE PROCEDURE dbo.AP_PTO036(@m_marc int, @g_m1 int output, @g_m2 int output, @g_m3 int output, @g_m4 int output, @g_m5 int output, @g_m6 int output,
@g_m7 int output, @g_m8 int output, @g_m9 int output, @g_m10 int output) WITH ENCRYPTION AS
BEGIN
if @g_m1=-1 begin select @g_m1=@m_marc;
end else begin if @g_m2=-1 begin select @g_m2=@m_marc;
end else begin if @g_m3=-1 begin select @g_m3=@m_marc;
end else begin if @g_m4=-1 begin select @g_m4=@m_marc;
end else begin if @g_m5=-1 begin select @g_m5=@m_marc;
end else begin if @g_m6=-1 begin select @g_m6=@m_marc;
end else begin if @g_m7=-1 begin select @g_m7=@m_marc;
end else begin if @g_m8=-1 begin select @g_m8=@m_marc;
end else begin if @g_m9=-1 begin select @g_m9=@m_marc;
end else begin if @g_m10=-1 begin select @g_m10=@m_marc;
end;end;end;end;end;end;end;end;end;end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO037') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO037; END;
GO
CREATE PROCEDURE dbo.AP_PTO037(@id_pass int output, @data datetime output, @itv_normal bit, @itv_l_qtde int, @itv_l_tmp int, @itv_dias char(10),
@id_phorario int, @flexivel bit, @tipodia char(1), @folga bit, @trabalhado bit, @m_hrs_trab int, @contamc tinyint, @m_hrs_prev int,
@m_primeira int, @m_ultima int, @m_ent01 int, @m_sai01 int, @m_ent02 int, @m_sai02 int, @m_ent03 int, @m_sai03 int, @m_ent04 int, @m_sai04 int, @m_ent05 int, @m_sai05 int, @m_ent06 int, @m_sai06 int,
@m_ent07 int, @m_sai07 int, @m_ent08 int, @m_sai08 int, @fimper1 tinyint, @fimper2 tinyint, @fimper3 tinyint, @fimper4 tinyint, @iniflex tinyint, @fimflex tinyint,
@alterou bit output, @g_m1 int output, @g_m2 int output, @g_m3 int output, @g_m4 int output, @g_m5 int output, @g_m6 int output,
@g_m7 int output, @g_m8 int output, @g_m9 int output, @g_m10 int output
) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @permc tinyint; declare @intvflex bit;
declare @fmE bit; declare @fmS bit;
declare @fmE1 bit; declare @fmS1 bit; declare @fmE2 bit; declare @fmS2 bit;
declare @fmE3 bit; declare @fmS3 bit; declare @fmE4 bit; declare @fmS4 bit;
declare @fmE5 bit; declare @fmS5 bit;
declare @falt1 bit; declare @falt2 bit; declare @falt3 bit; declare @falt4 bit;
declare @fmFE bit; declare @fmFS bit; declare @faltF bit;
declare @hent int; declare @iniper tinyint; declare @fimper tinyint;
declare @i int; declare @ment int; declare @msai int; declare @msai_ant int;
declare @difitv int; declare @wdia int;
declare @trab1 int; declare @trab2 int; declare @trab3 int; declare @trab4 int; declare @trab int;
declare @g_s1 bit; declare @g_e2 bit; declare @g_s2 bit; declare @g_e3 bit;
declare @g_s3 bit; declare @g_e4 bit; declare @g_fi bit; declare @g_ff bit;
declare @g_intv bit; declare @achou bit; declare @m_intervalo int;
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int; declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int; declare @fxini int; declare @fxfim int; declare @fxtmp int;
declare @m_marc int;
select @alterou=isnull(@alterou,0);
select @trab1=0,@trab2=0,@trab3=0,@trab4=0, @trab=0;
select @g_s1=0,@g_e2=0,@g_s2=0,@g_e3=0,@g_s3=0,@g_e4=0,@g_fi=0,@g_ff=0,@g_intv=0;
select @wdia=datepart(dw,@data);
select @e1=-1,@s1=-1,@e2=-1,@s2=-1,@e3=-1,@s3=-1,@e4=-1,@s4=-1,@fxini=-1,@fxfim=-1,@fxtmp=0;
if @id_phorario>0 and @flexivel=0 begin
EXEC AP_PTO007 @id_phorario, @wdia, 0, 4320,@e1 output, @s1 output, @e2 output, @s2 output, @e3 output,@s3 output,
@e4 output, @s4 output, @fxini output, @fxfim output, @fxtmp output,'', '', '', '','', '', '', '','', '', '', '', '';
end;
select @difitv=@fxtmp;
if @itv_normal = 1 begin
select @g_intv=1;
if @e2>0 begin select @g_s1=1, @g_e2=1; end;
if @e3>0 begin select @g_s2=1, @g_e3=1; end;
if @e4>0 begin select @g_s3=1, @g_e4=1; end;
if @trabalhado=1 begin
if @fxini>-1 and @fxfim>-1 and @fxtmp>0 begin
if @m_primeira<>@m_ultima begin
if @m_primeira >= @fxini or @m_ultima <= @fxfim begin select @g_intv=0; end;
end else begin
if @m_primeira >= @fxini and @m_primeira <= @fxfim begin select @g_intv=0; end;
end;
end;
if @m_primeira<>@m_ultima begin
if @e2>0 and (@m_primeira >= @s1 or @m_ultima <= @e2) begin select @g_s1=0, @g_e2=0; end;
if @e3>0 and (@m_primeira >= @s2 or @m_ultima <= @e3) begin select @g_s2=0, @g_e3=0; end;
if @e4>0 and (@m_primeira >= @s3 or @m_ultima <= @e4) begin select @g_s3=0, @g_e4=0; end;
end else begin
if @e2>0 and @m_primeira >= @s1 and @m_primeira <= @e2 begin select @g_s1=0, @g_e2=0; end;
if @e3>0 and @m_primeira >= @s2 and @m_primeira <= @e3 begin select @g_s2=0, @g_e3=0; end;
if @e4>0 and @m_primeira >= @s3 and @m_primeira <= @e4 begin select @g_s3=0, @g_e4=0; end;
end;
end;
end;
if @contamc>0 begin
if @trabalhado=0 begin
if @itv_l_tmp>0 and @itv_l_qtde<=@m_hrs_trab and @m_hrs_trab>0 begin
if ((@tipodia='V' or @tipodia='P') and substring(@itv_dias,1,1)='1') or
(@wdia=7 and substring(@itv_dias,2,1)='1') or (@wdia=1 and substring(@itv_dias,3,1)='1') or (@folga=1 and substring(@itv_dias,4,1)='1') begin
if @contamc=2 and @m_ent01>0 and @m_sai01>0 begin
select @alterou=1;
select @m_marc=@m_ent01+((@m_sai01-@m_ent01)/2);
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
select @m_marc=(@m_marc+@itv_l_tmp);
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end else begin if @contamc=4 and @m_ent01>0 and @m_sai01=-1 and @m_ent02=-1 and @m_sai02>0 begin
select @alterou=1;
select @m_marc=@m_ent01+((@m_sai02-@m_ent01)/2);
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
select @m_marc=(@m_marc+@itv_l_tmp);
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end; end;
end;
end;
end else begin
if @flexivel=0 begin
select @fmE1=0,@fmS1=0,@fmE2=0,@fmS2=0,@fmE3=0,@fmS3=0,@fmE4=0,@fmS4=0;
select @fmE5=0,@fmS5=0,@fmFE=0,@fmFS=0,@falt1=1,@falt2=1,@falt3=1,@falt4=1,@faltF=1;
select @i=0;
while (@i<8) begin
select @i=@i+1;
select @ment=@m_ent01, @msai_ant=-1, @msai=@m_sai01;
if @i=2 begin select @ment=@m_ent02, @msai_ant=@m_sai01, @msai=@m_sai02; end;
if @i=3 begin select @ment=@m_ent03, @msai_ant=@m_sai02, @msai=@m_sai03; end;
if @i=4 begin select @ment=@m_ent04, @msai_ant=@m_sai03, @msai=@m_sai04; end;
if @i=5 begin select @ment=@m_ent05, @msai_ant=@m_sai04, @msai=@m_sai05; end;
if @i=6 begin select @ment=@m_ent06, @msai_ant=@m_sai05, @msai=@m_sai06; end;
if @i=7 begin select @ment=@m_ent07, @msai_ant=@m_sai06, @msai=@m_sai07; end;
if @i=8 begin select @ment=@m_ent08, @msai_ant=@m_sai07, @msai=@m_sai08; end;
if @contamc>=(@i*2) begin
select @permc=0, @hent=-1, @fimper=0, @iniper=0;
if @fimper1 >=@i begin select @permc=1, @hent=@e1, @iniper=1, @fimper=@fimper1, @fmE=@fmE1, @fmS=@fmS1,@trab=@trab1;
end else begin if @fimper2 >=@i begin select @permc=2, @hent=@e2, @iniper=@fimper1+1, @fimper=@fimper2, @fmE=@fmE2, @fmS=@fmS2,@trab=@trab2;
end else begin if @fimper3 >=@i begin select @permc=3, @hent=@e3, @iniper=(CASE WHEN @fimper2>0 THEN @fimper2+1 ELSE @fimper1+1 END), @fimper=@fimper3, @fmE=@fmE3, @fmS=@fmS3,@trab=@trab3;
end else begin if @fimper4 >=@i begin select @permc=4, @hent=@e4, @iniper=(CASE WHEN @fimper3>0 THEN @fimper3+1 WHEN @fimper2>0 THEN @fimper2+1 ELSE @fimper1+1 END), @fimper=@fimper4, @fmE=@fmE4, @fmS=@fmS4,@trab=@trab4;
end; end; end; end;
if @ment=-1 begin if @permc>0 and @iniper=@i begin select @fmE=1; end; end;
if @msai=-1 begin if @permc>0 and @fimper=@i begin select @fmS=1; end; end;
if @permc>0 and @ment>-1 and @msai>-1 begin select @trab=@trab+(@msai-@ment); end;
if @permc=1 begin select @fmE1=@fmE,@fmS1=@fmS,@falt1=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt1 END),@trab1=@trab;
end else begin if @permc=2 begin select @fmE2=@fmE,@fmS2=@fmS,@falt2=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt2 END),@trab2=@trab;
end else begin if @permc=3 begin select @fmE3=@fmE,@fmS3=@fmS,@falt3=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt3 END),@trab3=@trab;
end else begin if @permc=4 begin select @fmE4=@fmE,@fmS4=@fmS,@falt4=(CASE WHEN @ment>-1 or @msai>-1 THEN 0 ELSE @falt4 END),@trab4=@trab;
end; end; end; end;
if @iniflex<=@i and @fimflex>=@i begin
if @iniflex=@i and @msai=-1 begin
select @fmFS=1;
end else begin if @fimflex=@i and @ment=-1 begin
select @fmFE=1;
end; end;
if @difitv>0 and @ment>-1 and @msai_ant>-1 and @i>@iniflex begin
if @ment<=@fxfim and @msai_ant>=@fxini begin
select @difitv=@difitv-(@ment-@msai_ant);
end else begin
if @msai_ant>=@fxini begin
select @difitv=@difitv-(@fxfim-@msai_ant);
end else begin if @ment<=@fxfim begin
select @difitv=@difitv-(@ment-@fxini);
end else begin
select @difitv=@difitv-(@fxfim-@fxini);
end; end;
end;
if @difitv<0 begin select @difitv=0; end;
if (@iniflex<>@i and @ment>-1) or (@fimflex<>@i and @msai>-1) begin select @faltF = 0; end;
end;
end;
end;
end;
if @e1>-1 and (@falt1=1 or @fmS1=1) begin
if (@fmS1=1 or @falt1=1) and @g_s1=1 begin
select @alterou=1, @m_marc=@s1;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
if @g_e2=1 and @g_s2=0 and @m_ultima=@m_ent02 and @m_ent02>@e2 begin
select @m_marc=@e2;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end;
end;
if @g_intv=1 and @fxini>-1 and @fxfim>-1 and @fxtmp>0 and @faltF=1 and @m_ent01<@fxfim and (@m_ent01>-1 or @m_ent02<@fxfim) begin
if @fmFE=@fmFS begin
select @alterou=1;
select @fxtmp=@fxtmp;
select @fxini=@fxini+((@fxfim-@fxini)/2-(@fxtmp/2));
select @fxfim=(@fxini+@fxtmp);
EXEC AP_PTO036 @fxini, @g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
EXEC AP_PTO036 @fxfim, @g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end else begin
if @m_sai01=-1 and @m_ent02>-1 and @m_ent02-@fxtmp>=@fxini begin
if @m_sai02=-1 and @m_ent02>@fxfim begin
select @alterou=1;
select @fxtmp=@fxtmp;
select @fxini=@fxini+((@fxfim-@fxini)/2-(@fxtmp/2));
select @fxfim=(@fxini+@fxtmp);
EXEC AP_PTO036 @fxini, @g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
EXEC AP_PTO036 @fxfim, @g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end else begin
select @fxtmp=@fxtmp;
select @fxini=@m_ent02-@fxtmp;
if @m_ent01=-1 or @m_ent01< @fxini begin
select @alterou=1;
EXEC AP_PTO036 @fxini, @g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end;
end else begin if @m_sai01>-1 and @m_ent02=-1 and @m_sai01+@fxtmp<=@fxfim begin
select @fxtmp=@fxtmp;
select @fxfim=@m_sai01+@fxtmp;
if @m_sai02=-1 or @fxfim<@m_sai02 begin
select @alterou=1;
EXEC AP_PTO036 @fxfim, @g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end; end;
end;
end;
if @e2>-1 and (@falt2=1 or @fmE2=1 or @fmS2=1) begin
if (@fmE2=1 or @falt2=1) and @g_e2=1 begin
if @g_s1=1 and @g_s2=0 and @m_primeira=@m_sai01 and @m_sai01<@s1 begin
select @m_marc=@s1;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
select @alterou=1, @m_marc=@e2;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
if (@fmS2=1 or @falt2=1) and @g_s2=1 begin
select @alterou=1, @m_marc=@s2;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end;
if @e3>-1 and (@falt3=1 or @fmE3=1 or @fmS3=1) begin
if (@fmE3=1 or @falt3=1) and @g_e3=1 begin
select @alterou=1, @m_marc=@e3;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
if (@fmS3=1 or @falt3=1) and @g_s3=1 begin
select @alterou=1, @m_marc=@s3;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end;
if @e4>-1 and (@falt4=1 or @fmE4=1 or @fmS4=1) begin
if (@fmE4=1 or @falt4=1) and @g_e4=1 begin
select @alterou=1, @m_marc=@e4;
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end;
end else begin
select @m_intervalo=0;
SELECT @m_intervalo=m_intervalo FROM tbPHorFlex WHERE id_pflex=@id_phorario;
if @g_intv=1 and @m_intervalo>0 and @itv_l_qtde<=@m_hrs_trab begin
select @m_intervalo=@m_intervalo;
if @contamc=2 and @m_ent01>0 and @m_sai01>0 begin
if (@m_sai01-@m_ent01) >= @m_intervalo*2 begin
select @alterou=1;
select @m_marc=@m_ent01+((@m_sai01-@m_ent01)/2-(@m_intervalo/2));
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
select @m_marc=(@m_marc+@m_intervalo);
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end else begin if @contamc=4 and @m_ent01>0 and @m_sai01=-1 and @m_ent02=-1 and @m_sai02>0 begin
if (@m_sai02-@m_ent01) >= @m_intervalo*2 begin
select @alterou=1;
select @m_marc=@m_ent01+((@m_sai02-@m_ent01)/2-(@m_intervalo/2));
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
select @m_marc=(@m_marc+@m_intervalo);
EXEC AP_PTO036 @m_marc,@g_m1 out,@g_m2 out,@g_m3 out,@g_m4 out,@g_m5 out,@g_m6 out,@g_m7 out,@g_m8 out,@g_m9 out,@g_m10 out;
end;
end; end;
end;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO038') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO038; END;
GO
CREATE PROCEDURE dbo.AP_PTO038(@id_pass int output, @data datetime output, @m_marc int, @id_usuario int) WITH ENCRYPTION AS
BEGIN
declare @marc datetime;
EXEC AP_PTO011 @data, @m_marc,@marc output;
EXEC AP_PTO015 @id_pass output,@data output,@marc,1,1,0,@id_usuario
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO039') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO039; END;
GO
CREATE PROCEDURE dbo.AP_PTO039(@id_pass int output, @data datetime output, @itv_normal bit, @itv_l_qtde int, @itv_l_tmp int, @itv_dias char(10), @id_usuario int, @automatica bit) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON
declare @id_phorario int; declare @trabalhado bit; declare @flexivel bit; declare @m_hrs_prev int;
declare @norm_ini int; declare @norm_fim int;
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int;
declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int; declare @ult_sai_prev int; declare @ult_sai int; declare @psi_ult_sai int;
declare @fxini int; declare @fxfim int; declare @fxtmp int;
declare @folga bit; declare @tipodia char(1); declare @wdia tinyint; declare @psi int; declare @wdiapto tinyint;
declare @admissao bit; declare @demissao bit; declare @id_eveafa int; declare @funcao_pri tinyint;
declare @m_ent01 int; declare @m_sai01 int; declare @m_ent02 int; declare @m_sai02 int;
declare @m_ent03 int; declare @m_sai03 int; declare @m_ent04 int; declare @m_sai04 int;
declare @m_ent05 int; declare @m_sai05 int; declare @m_ent06 int; declare @m_sai06 int;
declare @m_ent07 int; declare @m_sai07 int; declare @m_ent08 int; declare @m_sai08 int;
declare @contamc tinyint; declare @original bit; declare @fimper1 tinyint; declare @fimper2 tinyint; declare @fimper3 tinyint; declare @fimper4 tinyint;
declare @iniflex tinyint; declare @fimflex tinyint; declare @primeira datetime; declare @ultima datetime;
declare @m_primeira int; declare @m_ultima int; declare @fmsaida bit;
declare @hrs_trab varchar(5); declare @m_hrs_trab int;
declare @alterou bit; declare @ult_he_ent int; declare @pri_he_sai int;
declare @g_m1 int; declare @g_m2 int; declare @g_m3 int; declare @g_m4 int; declare @g_m5 int; declare @g_m6 int; declare @g_m7 int; declare @g_m8 int;
declare @g_m9 int; declare @g_m10 int; declare @geradas int; declare @achou bit;
declare @gerar_mc bit;
select @geradas=0;
select @id_phorario=0,@trabalhado=0,@flexivel=0,@m_hrs_prev=0,@norm_ini=0,@norm_fim=0,@e1=-1,@s1=-1,@e2=-1,@s2=-1,@e3=-1,@s3=-1,@e4=-1,@s4=-1,@fxini=-1,@fxfim=-1,@fxtmp=0,
@folga=0,@tipodia='N',@wdia=0,@psi=0,@wdiapto=0,@admissao=0,@demissao=0,
@id_eveafa=0,@alterou=0;
select @g_m1=-1,@g_m2=-1,@g_m3=-1,@g_m4=-1,@g_m5=-1,@g_m6=-1,@g_m7=-1,@g_m8=-1,@g_m9=-1,@g_m10=-1;
EXEC AP_PTO009 @id_pass output, @data output, 0;
SELECT @id_phorario=id_phorario, @trabalhado=trabalhado, @flexivel=flexivel, @m_hrs_prev=m_hrs_prev,
@norm_ini=norm_ini, @norm_fim=norm_fim,@e1=e1,@s1=s1,@e2=e2,@s2=s2,@e3=e3,@s3=s3,@e4=e4,@s4=s4,@fxini=fxini,@fxfim=fxfim,@fxtmp=fxtmp,
@folga=folga, @tipodia=tipodia, @admissao=admissao,@demissao=demissao, @id_eveafa=id_eveafa
FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data;
select @wdia = DATEPART(dw,@data), @wdiapto=@wdia-1;
if @folga=1 begin select @wdiapto=8; end;
if @tipodia='V' begin select @wdiapto=7; end;
if @tipodia='P' begin select @wdiapto=9; end;
if @admissao=0 and @demissao=0 and @id_eveafa=0 and @tipodia<>'A' begin
select @contamc=0, @m_ent01=-1,@m_sai01=-1,@m_ent02=-1,@m_sai02=-1,@m_ent03=-1,@m_sai03=-1,
@m_ent04=-1,@m_sai04=-1,@m_ent05=-1,@m_sai05=-1,@m_ent06=-1,@m_sai06=-1,
@m_ent07=-1,@m_sai07=-1,@m_ent08=-1,@m_sai08=-1,@hrs_trab='00:00',@m_hrs_trab=0,
@original=0,@fmsaida=0,@funcao_pri=0,@fimper1=0,@fimper2=0,@fimper3=0,@fimper4=0,@iniflex=0,@fimflex=0,
@ult_he_ent=0,@pri_he_sai=0, @m_primeira=-1, @m_ultima=-1;
SELECT top 1 @contamc=contamc, @original=original, @fmsaida=fmsaida,@funcao_pri=funcao_pri,
@m_ent01=m_ent01,@m_sai01=m_sai01,@m_ent02=m_ent02,@m_sai02=m_sai02,@m_ent03=m_ent03,@m_sai03=m_sai03,
@m_ent04=m_ent04,@m_sai04=m_sai04,@m_ent05=m_ent05,@m_sai05=m_sai05,@m_ent06=m_ent06,@m_sai06=m_sai06,
@m_ent07=m_ent07,@m_sai07=m_sai07,@m_ent08=m_ent08,@m_sai08=m_sai08,@hrs_trab=hrs_trab,@m_hrs_trab=m_hrs_trab,
@ult_he_ent=ult_he_ent, @pri_he_sai=pri_he_sai,@m_primeira=m_primeira, @m_ultima=m_ultima
FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data ORDER BY original;
EXEC AP_PTO019 @contamc,
@m_ent01, @m_sai01, @m_ent02, @m_sai02, @m_ent03, @m_sai03, @m_ent04, @m_sai04,
@m_ent05, @m_sai05, @m_ent06, @m_sai06, @m_ent07, @m_sai07, @m_ent08, @m_sai08,
@e1, @s1, @e2, @s2, @e3, @s3, @e4, @s4, @fxini, @fxfim, @fxtmp,
@fimper1 output, @fimper2 output, @fimper3 output, @fimper4 output,@iniflex output, @fimflex output;
select @gerar_mc=1;
-- if @automatica=1 begin
--   if @contamc=0 or (@contamc>3 and @m_sai01>-1 and @m_ent02>-1) begin
--      select @gerar_mc=0;
--   end else if @contamc=2 begin
--      if @fxini>-1 and @fxtmp>0 begin
--         if @m_sai01>-1 and @m_sai01 <= @fxfim begin
--            select @gerar_mc=0;
--         end;
--      end else if @e2>-1 begin
--         if @m_sai01>-1 and @m_sai01 <= @e2 begin
--            select @gerar_mc=0;
--         end;
--      end;
--   end;
--end;
if @gerar_mc=1 begin
EXEC AP_PTO037 @id_pass output, @data output, @itv_normal, @itv_l_qtde, @itv_l_tmp, @itv_dias,
@id_phorario, @flexivel, @tipodia, @folga, @trabalhado, @m_hrs_trab, @contamc, @m_hrs_prev,
@m_primeira, @m_ultima, @m_ent01, @m_sai01, @m_ent02, @m_sai02, @m_ent03, @m_sai03, @m_ent04, @m_sai04, @m_ent05, @m_sai05, @m_ent06, @m_sai06,
@m_ent07, @m_sai07, @m_ent08, @m_sai08, @fimper1, @fimper2, @fimper3, @fimper4, @iniflex, @fimflex,
@alterou output, @g_m1 output, @g_m2 output, @g_m3 output, @g_m4 output, @g_m5 output, @g_m6 output,
@g_m7 output, @g_m8 output, @g_m9 output, @g_m10 output;
end;
end;
if @alterou=1 begin
if not EXISTS(SELECT id_pass FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data AND original=0) begin
INSERT INTO tbPtoEnq (id_pass,data,original,contamc,fmsaida,funcao_pri,m_ent01, m_sai01, m_ent02, m_sai02,
m_ent03, m_sai03, m_ent04, m_sai04,m_ent05, m_sai05, m_ent06, m_sai06,m_ent07, m_sai07,
m_ent08, m_sai08, hrs_trab, m_hrs_trab,fimper1,fimper2,fimper3,fimper4,iniflex,fimflex,
ult_he_ent, pri_he_sai, id_usuario, apontado)
VALUES (@id_pass,@data,0,@contamc,@fmsaida,@funcao_pri,@m_ent01, @m_sai01, @m_ent02, @m_sai02,
@m_ent03, @m_sai03, @m_ent04, @m_sai04,@m_ent05, @m_sai05, @m_ent06, @m_sai06,@m_ent07, @m_sai07,
@m_ent08, @m_sai08, @hrs_trab, @m_hrs_trab,@fimper1,@fimper2,@fimper3,@fimper4,@iniflex,@fimflex,
@ult_he_ent, @pri_he_sai, @id_usuario, 0);
end;
if @g_m1>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m1, @id_usuario; select @geradas=@geradas+1; end;
if @g_m2>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m2, @id_usuario; select @geradas=@geradas+1; end;
if @g_m3>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m3, @id_usuario; select @geradas=@geradas+1; end;
if @g_m4>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m4, @id_usuario; select @geradas=@geradas+1; end;
if @g_m5>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m5, @id_usuario; select @geradas=@geradas+1; end;
if @g_m6>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m6, @id_usuario; select @geradas=@geradas+1; end;
if @g_m7>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m7, @id_usuario; select @geradas=@geradas+1; end;
if @g_m8>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m8, @id_usuario; select @geradas=@geradas+1; end;
if @g_m9>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m9, @id_usuario; select @geradas=@geradas+1; end;
if @g_m10>0 begin EXEC AP_PTO038 @id_pass output, @data output, @g_m10, @id_usuario; select @geradas=@geradas+1; end;
end;
if @automatica=0 begin
select @id_pass as id_pass, @data as data, @geradas as geradas;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO047') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO047; END;
GO
CREATE PROCEDURE dbo.AP_PTO047(@id_pass int output, @data datetime output, @ano int, @mes int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @achou bit;
declare @id_diverg int;
declare @m_valor int;
declare @vlr1 int, @vlr2 int, @valor varchar(7);
declare @id_eveabo int;
select @achou=1, @id_diverg=0;
WHILE (@achou=1)
begin
select @achou=0;
SELECT TOP 1 @achou=1, @id_diverg=id_diverg, @m_valor=m_valor FROM tbAptManuais
WHERE id_pass = @id_pass AND ano=@ano AND mes=@mes AND id_diverg>@id_diverg
ORDER by id_diverg;
if @achou=1 begin
--Atualizar abonos anteriores
select @vlr1=0, @vlr2=0;
SELECT @vlr1=isnull(m_valor,0), @vlr2=isnull(m_abonado,0) FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg;
if @vlr1>0 and @vlr2 > 0 begin
EXEC AP_PTO003 @vlr1, @valor output;
UPDATE tbPtoAboDia SET valor=@valor, m_valor=@vlr1 WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg;
select @id_eveabo=0;
SELECT TOP 1 @id_eveabo=isnull(a.id_eveabo,0) FROM tbPtoAboDia a
INNER JOIN tbEvsAbono e ON a.id_eveabo=e.id_eveabo
WHERE a.id_pass=@id_pass AND a.data=@data AND a.id_diverg=@id_diverg
ORDER BY e.descricao;
if @id_eveabo>0 begin
DELETE FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg AND id_eveabo<>@id_eveabo;
end;
end else begin
DELETE FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg;
end;
--Somar
exec AP_PTO018 @id_pass output,  @data output, @id_diverg, @m_valor, 1, 0, 0;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO055') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO055; END;
GO
CREATE PROCEDURE dbo.AP_PTO055(@id_pass int output, @data datetime output) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @achou bit, @id_empresa int, @id_phorario int;
declare @alrt_interjor BIT; declare @alrt_min_interjor INT;
declare @alrt_he_intv BIT; declare @alrt_min_intervalo INT; declare @alrt_he_dia BIT; declare @alrt_min_he_dia INT;
declare @alrt_atraso_dia bit, @alrt_min_atraso_dia INT; declare @alrt_falta_dia BIT;
declare @alrt_anterior datetime, @alrt_atual datetime;
declare @m_vlraux int, @dia_tipo tinyint;
declare @dia_previsto bit, @dia_inativo bit, @dia_ausencia bit;
declare @m_previsto int, @m_ausencia int, @m_acres_d int, @m_acres_n int, @m_acres_dp int, @m_acres_np int, @m_acres_b int, @m_acres_bp int, @m_inativo int, @id_evento int;
declare @m_vlrdesc int, @m_vlrabo int, @id_eveabo int, @id_eveafa int, @id_abodia int;
declare @dia_cid varchar(10);
declare @tipodia char(1), @wdia tinyint;
declare @entrada1 varchar(6); declare @saida1 varchar(6);
declare @entrada2 varchar(6); declare @saida2 varchar(6);
declare @entrada3 varchar(6); declare @saida3 varchar(6);
declare @entrada4 varchar(6); declare @saida4 varchar(6);
declare @flex_ini varchar(6); declare @flex_fim varchar(6), @flex_tempo varchar(6);
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int;
declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int;
declare @fxini int; declare @fxfim int; declare @fxtmp int;
declare @hrs_prev varchar(7); declare @m_hrs_prev int;
declare @flexivel bit, @id_hnormais int, @metodo tinyint, @hnorm_por_dia int;
declare @dia_trab bit, @mes_fec int, @ano_fec int, @mes_hn int;
declare @fechamento_ini datetime, @mes_ini datetime;
declare @psi int;
select @entrada1='__:__',@saida1='__:__',@entrada2='__:__',@saida2='__:__';
select @entrada3='__:__',@saida3='__:__',@entrada4='__:__',@saida4='__:__';
select @flex_ini='__:__',@flex_fim='__:__',@flex_tempo='__:__';
select @e1=-1,@s1=-1,@e2=-1,@s2=-1,@e3=-1,@s3=-1,@e4=-1,@s4=-1;
select @fxini=-1,@fxfim=-1,@fxtmp=0;
select @wdia = DATEPART(dw,@data);
SELECT @id_empresa=isnull(id_empresa,0) FROM tbPass WHERE id_pass=@id_pass;
select @mes_fec=0,@ano_fec=0;
SELECT @mes_fec=mes,@ano_fec=ano,@fechamento_ini=fechamento_ini FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN fechamento_ini AND fechamento_fim;
if @fechamento_ini is null begin
select @psi=(day(@data)-1)*(-1);
select @fechamento_ini = dateadd(d,@psi,@data);
select @mes_fec=month(@fechamento_ini),@ano_fec=year(@fechamento_ini);
end;
select @mes_ini=CONVERT(datetime,right('00'+ltrim(str(@mes_fec)),2)+'/01/'+ltrim(str(@ano_fec)));
select @mes_fec=0;
select @mes_fec=month(@fechamento_ini);
if @mes_fec=2 and day(dateadd(d,-1,dateadd(m,1,@fechamento_ini))) = 29  begin
select @mes_fec=13;
end;
select @mes_hn=0;
select @mes_hn=@mes_fec;
if @mes_hn=2 and day(dateadd(d,-1,dateadd(m,1,@mes_ini))) = 29  begin
select @mes_hn=13;
end;
select @tipodia='N',@id_phorario=0, @flexivel=0;
select @dia_tipo=0, @dia_previsto=0, @dia_inativo=0, @dia_ausencia=0, @m_previsto=0, @m_ausencia=0, @m_acres_d=0, @m_acres_n=0, @m_acres_dp=0, @m_acres_np=0, @m_acres_b=0, @m_acres_bp=0, @m_inativo=0;
select @id_evento=0, @id_eveabo=0, @id_eveafa=0, @id_abodia=0, @dia_cid='';
select @m_vlrdesc=0, @m_vlrabo=0
SELECT @tipodia=isnull(tipodia,'Z'), @id_phorario=isnull(id_phorario,0), @flexivel=isnull(flexivel,0),
@dia_tipo=(CASE WHEN isnull(p.admissao,0)=1 THEN 1 WHEN isnull(p.demissao,0)=1 THEN 4 ELSE 0 END),
@dia_previsto=isnull(p.trabalhado,0), @m_previsto=isnull(m_hrs_prev,0),
@id_eveabo=isnull(p.id_eveabo,0),
@id_eveafa=isnull(p.id_eveafa,0),
@id_hnormais=isnull(id_hnormais,0)
FROM tbPtoDia p WHERE p.id_pass=@id_pass AND p.data=@data
if @m_previsto<0 begin select @m_previsto=0; end;
select @m_hrs_prev=0, @hrs_prev='  00:00';
if @m_previsto=0 and @id_phorario>0 begin
if @flexivel=0 begin
--horrio fixo (aquii)
EXEC dbo.AP_PTO007 @id_phorario, @wdia, 0, 4320,
@e1 output, @s1 output,@e2 output, @s2 output,@e3 output, @s3 output,
@e4 output, @s4 output,@fxini output, @fxfim output,@fxtmp output,
@entrada1 output, @saida1 output, @entrada2 output, @saida2 output,
@entrada3 output, @saida3 output, @entrada4 output, @saida4 output,
@flex_ini output, @flex_fim output, @flex_tempo output,
@hrs_prev output, @m_hrs_prev output
end;
end;
select @dia_trab=0;
if @m_previsto>0 or (@m_hrs_prev>0 and @tipodia='N' AND @dia_tipo=0 AND @id_eveafa>0 AND @id_phorario>0) begin
select @dia_trab=1;
end;
if @id_hnormais>0 and @dia_trab=1 begin
select @achou=0;
SELECT @achou=1, @metodo=metodo FROM tbHNormais WHERE id_hnormais=@id_hnormais;
if @achou=1 and (@metodo=1 OR @metodo=2)  begin
select @hnorm_por_dia=0;
if @metodo=1 begin
SELECT @hnorm_por_dia=ISNULL((CASE
WHEN @wdia=1 THEN m_hn_dia_01 WHEN @wdia=2 THEN m_hn_dia_02
WHEN @wdia=3 THEN m_hn_dia_03 WHEN @wdia=4 THEN m_hn_dia_04
WHEN @wdia=5 THEN m_hn_dia_05 WHEN @wdia=6 THEN m_hn_dia_06
WHEN @wdia=7 THEN m_hn_dia_07 ELSE 0 END),0)
FROM tbHNormais WHERE id_hnormais=@id_hnormais;
end else if @metodo=2 begin
SELECT @hnorm_por_dia=ISNULL((CASE
WHEN @mes_hn=1 THEN m_hn_dia_01 WHEN @mes_hn=2 THEN m_hn_dia_02
WHEN @mes_hn=3 THEN m_hn_dia_03 WHEN @mes_hn=4 THEN m_hn_dia_04
WHEN @mes_hn=5 THEN m_hn_dia_05 WHEN @mes_hn=6 THEN m_hn_dia_06
WHEN @mes_hn=7 THEN m_hn_dia_07 WHEN @mes_hn=8 THEN m_hn_dia_08
WHEN @mes_hn=9 THEN m_hn_dia_09 WHEN @mes_hn=10 THEN m_hn_dia_10
WHEN @mes_hn=11 THEN m_hn_dia_11 WHEN @mes_hn=12 THEN m_hn_dia_12
WHEN @mes_hn=13 THEN m_hn_dia_13 ELSE 0 END),0)
FROM tbHNormais WHERE id_hnormais=@id_hnormais;
end;
if @hnorm_por_dia>0 begin
select @m_previsto=@hnorm_por_dia;
end;
end;
end;
SELECT @m_vlrdesc=isnull(SUM(a.m_valor),0), @m_vlrabo=isnull(SUM(a.m_abonado),0)
FROM tbPtoDivsDia a
INNER JOIN tbDivergencias d ON a.id_diverg = d.id_diverg
WHERE a.id_pass=@id_pass AND a.data=@data AND d.ativada = 1 AND isnull(a.id_associ,0)=0 AND d.soma=0 AND (d.classe=0 or d.classe=9)
if @m_previsto>0 and @m_vlrdesc=0 and (@id_eveabo>0 or @id_eveafa>0) begin
select @m_vlrdesc=@m_previsto,@m_vlrabo=@m_previsto;
end;
if @m_previsto=0 AND @dia_trab=1 begin
select @m_vlrdesc=0,@m_vlrabo=0;
if @flexivel=0 begin
--horrio fixo (aquii)
if @m_hrs_prev>0 begin
select @dia_previsto=1;
select @m_previsto=@m_hrs_prev;
select @m_vlrdesc=@m_hrs_prev,@m_vlrabo=@m_hrs_prev;
end;
end;
end;
if @id_eveafa>0 begin
select @achou=0;
SELECT TOP 1 @achou=1 FROM tbAfast WHERE id_pass=@id_pass AND id_eveabo=@id_eveafa AND @data=datafim
if @achou=1 begin
select @dia_tipo=3;
end else begin
SELECT TOP 1 @achou=1 FROM tbAfast WHERE id_pass=@id_pass AND id_eveabo=@id_eveafa AND @data=dataini
if @achou=1 begin
select @dia_tipo=2;
end;
end;
end;
if @id_eveafa>0 begin
select @id_evento=@id_eveafa;
end else if @id_eveabo>0 begin
select @id_evento=@id_eveabo;
end else begin
SELECT TOP 1 @id_abodia=isnull(a.id_eveabo,0) FROM tbPtoAboDia a
WHERE a.id_pass=@id_pass AND a.data=@data AND a.id_diverg IN (
SELECT TOP 1 a2.id_diverg FROM tbPtoDivsDia a2
INNER JOIN tbDivergencias d ON a2.id_diverg = d.id_diverg
WHERE a2.id_pass=@id_pass AND a2.data=@data AND d.ativada = 1 AND isnull(a2.id_associ,0)=0 AND d.soma=0 AND (d.classe=0 or d.classe=9)
ORDER BY a2.m_abonado DESC
);
select @id_evento=@id_abodia;
end;
if @id_evento>0 AND @m_vlrabo>0 begin
if exists(SELECT * FROM tbEvsAbono WHERE id_eveabo=@id_evento AND isnull(absent,0)=1) BEGIN
select @dia_ausencia=1, @m_ausencia=@m_vlrabo;
end else begin
select @dia_inativo=1, @m_inativo=@m_vlrabo;
end;
end else if @m_vlrdesc>0 begin
select @dia_ausencia=1, @m_ausencia=@m_vlrdesc;
end;
SELECT @m_acres_d=isnull(SUM(a.m_valor),0) FROM tbPtoDivsDia a
INNER JOIN tbDivergencias d ON a.id_diverg = d.id_diverg
WHERE a.id_pass=@id_pass AND a.data=@data AND d.ativada = 1 AND isnull(a.id_associ,0)=0 AND d.soma=1
AND isnull(d.tipo_he,0)=1
if @m_acres_d>0 begin
SELECT @m_acres_dp=convert(int,isnull(SUM(convert(float,a.m_valor) * isnull(d.perche,1)),0)) FROM tbPtoDivsDia a
INNER JOIN tbDivergencias d ON a.id_diverg = d.id_diverg
WHERE a.id_pass=@id_pass AND a.data=@data AND d.ativada = 1 AND isnull(a.id_associ,0)=0 AND d.soma=1
AND isnull(d.tipo_he,0)=1
if @m_acres_dp<@m_acres_d begin select @m_acres_dp=@m_acres_d; end;
end;
SELECT @m_acres_n=isnull(SUM(a.m_valor),0) FROM tbPtoDivsDia a
INNER JOIN tbDivergencias d ON a.id_diverg = d.id_diverg
WHERE a.id_pass=@id_pass AND a.data=@data AND d.ativada = 1 AND isnull(a.id_associ,0)=0 AND d.soma=1
AND isnull(d.tipo_he,0)=2
if @m_acres_n>0 begin
SELECT @m_acres_np=convert(int,isnull(SUM(convert(float,a.m_valor) * isnull(d.perche,1)),0)) FROM tbPtoDivsDia a
INNER JOIN tbDivergencias d ON a.id_diverg = d.id_diverg
WHERE a.id_pass=@id_pass AND a.data=@data AND d.ativada = 1 AND isnull(a.id_associ,0)=0 AND d.soma=1
AND isnull(d.tipo_he,0)=2
if @m_acres_np<@m_acres_n begin select @m_acres_np=@m_acres_n; end;
end;
SELECT @m_acres_b=convert(int,isnull(SUM(convert(float,b.m_horas) / isnull(d.percbco,1)),0)) FROM tbPtoBco b
INNER JOIN tbDivergencias d ON b.id_diverg=d.id_diverg AND d.ativada=1 AND d.soma=1
WHERE b.id_pass=@id_pass AND b.data=@data
AND isnull(d.tipo_he,0)>0;
if @m_acres_b>0 begin
SELECT @m_acres_bp=isnull(SUM(b.m_horas),0) FROM tbPtoBco b
INNER JOIN tbDivergencias d ON b.id_diverg=d.id_diverg AND d.ativada=1 AND d.soma=1
WHERE b.id_pass=@id_pass AND b.data=@data
AND isnull(d.tipo_he,0)>0;
if @m_acres_bp<@m_acres_b begin select @m_acres_bp=@m_acres_b; end;
end;
if @m_ausencia>@m_previsto begin
select @m_ausencia=@m_previsto;
end;
if @m_inativo>@m_previsto begin
select @m_inativo=@m_previsto;
end;
SELECT @dia_cid=isnull(cid,'') FROM tbPtoCIDDia WHERE id_pass = @id_pass AND data = @data;
UPDATE tbPtoEstat SET dia_tipo=@dia_tipo, dia_previsto=@dia_previsto, dia_inativo=@dia_inativo, dia_ausencia=@dia_ausencia,
m_previsto=@m_previsto,m_ausencia=@m_ausencia, m_inativo=@m_inativo,
id_eveabo=@id_evento, dia_cid=@dia_cid,
m_acres_d=@m_acres_d, m_acres_n=@m_acres_n, m_acres_dp=@m_acres_dp, m_acres_np=@m_acres_np, m_acres_b=@m_acres_b, m_acres_bp=@m_acres_bp
WHERE id_pass=@id_pass AND data=@data;
select @achou=0;
SELECT TOP 1 @achou=isnull(alerta,0), @alrt_interjor=isnull(interjor,0), @alrt_min_interjor=isnull(min_interjor,0),
@alrt_he_intv=isnull(he_intervalo,0),  @alrt_min_intervalo=isnull(min_intervalo,0), @alrt_he_dia=isnull(he_dia,0),
@alrt_min_he_dia=isnull(min_he_dia,0), @alrt_atraso_dia=isnull(atraso_dia,0), @alrt_min_atraso_dia=isnull(min_atraso_dia,0),
@alrt_falta_dia=isnull(falta_dia,0) FROM tbPtoAlerta;
select @alrt_anterior=null, @alrt_atual=null;
SELECT @alrt_anterior=ultima FROM tbPtoEnq WHERE id_pass=@id_pass AND data=dateadd(d,-1,@data);
SELECT @alrt_atual=primeira FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data;
if not @alrt_anterior is null and not @alrt_atual is null begin
if @alrt_anterior < @alrt_atual begin
select @m_vlraux=datediff(n,@alrt_anterior,@alrt_atual);
UPDATE tbPtoEstat SET m_intjr=@m_vlraux WHERE id_pass=@id_pass AND data=@data;
if @achou=1 and @alrt_interjor=1 and @m_vlraux<@alrt_min_interjor begin
UPDATE tbPtoEstat SET alerta_dia=1, alrt_interjor=1 WHERE id_pass=@id_pass AND data=@data;
end;
end;
end;
if @achou=1 and @alrt_he_intv=1 begin
UPDATE tbPtoEstat SET alerta_dia=1, alrt_he_intv=1 WHERE id_pass=@id_pass AND data=@data AND m_he_intervalo>@alrt_min_intervalo;
end;
if @achou=1 and @alrt_he_dia=1 begin
UPDATE tbPtoEstat SET alerta_dia=1, alrt_he_dia=1 WHERE id_pass=@id_pass AND data=@data AND m_he_dia>@alrt_min_he_dia;
end;
if @achou=1 and @alrt_atraso_dia=1 begin
UPDATE tbPtoEstat SET alerta_dia=1, alrt_atraso_dia=1 WHERE id_pass=@id_pass AND data=@data AND m_atrasos>@alrt_min_atraso_dia;
end;
if @achou=1 and @alrt_falta_dia=1 begin
UPDATE tbPtoEstat SET alerta_dia=1, alrt_falta_dia=1 WHERE id_pass=@id_pass AND data=@data AND m_faltas>0;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO056') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO056; END;
GO
CREATE PROCEDURE dbo.AP_PTO056(@id_pass int, @id_premio int, @dtIni datetime, @dtFim datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @achou bit;
declare @dtRef datetime;
declare @c_dias varchar(15);
declare @c_normal bit, @c_ferias bit, @fer_normal bit, @id_phorario int, @flexivel bit;
declare @tipodia char(1), @dia_tipo tinyint, @dia_previsto bit, @id_eveafa int, @id_eveabo int, @folga bit;
declare @concede bit, @perde bit, @perde_data datetime;
declare @wdiapto tinyint, @procurar_apts bit, @considerar_abono_dia bit;
declare @m_valor int;
SELECT @achou=0;
SELECT @achou=1, @c_dias=c_dias, @c_normal=c_normal, @c_ferias=isnull(c_ferias,0)
FROM tbPtoPremio WHERE id_premio=@id_premio;
if @achou=1 begin
select @concede=0;
select @procurar_apts=0;
if EXISTS(SELECT top 1 id_diverg FROM tbPtoPremioDivs WHERE id_premio=@id_premio AND concede=1) begin
select @procurar_apts=1;
end;
select @dtRef=@dtIni, @wdiapto=0;
while (@dtRef<=@dtFim and @concede=0) begin
select @tipodia='N', @dia_tipo=0, @dia_previsto=0, @id_eveafa=0, @id_eveabo=0, @id_phorario=0, @flexivel=0;
SELECT @tipodia=isnull(tipodia,'Z'),
@dia_tipo=(CASE WHEN isnull(p.admissao,0)=1 THEN 1 WHEN isnull(p.demissao,0)=1 THEN 4 ELSE 0 END),
@dia_previsto=isnull(p.trabalhado,0),
@id_eveafa=isnull(p.id_eveafa,0),
@id_eveabo=isnull(p.id_eveabo,0),
@folga=isnull(p.folga,0),
@id_phorario=isnull(id_phorario,0),
@flexivel=isnull(flexivel,0)
FROM tbPtoDia p WHERE p.id_pass=@id_pass AND p.data=@dtRef;
select @fer_normal=0;
if @c_normal=1 AND @id_eveafa=1 AND @c_ferias=1 begin
if @id_phorario>0 AND (@flexivel=1 OR
EXISTS(SELECT top 1 id_phorario FROM tbFxPHorarios WHERE id_phorario=@id_phorario AND wdia=datepart(dw,@dtRef) AND m_entrada1 > 0)
) begin
select @fer_normal=1;
end;
end;
if @dia_tipo=0 AND (@c_normal=0 OR @fer_normal=1 OR (@dia_previsto=1 AND @id_eveafa=0) ) begin
select @wdiapto = DATEPART(dw,@dtRef), @wdiapto=@wdiapto-1;
if @folga=1 begin select @wdiapto=8; end;
if @tipodia='V' begin select @wdiapto=7; end;
if @tipodia='P' begin select @wdiapto=9; end;
if substring(@c_dias,@wdiapto+1,1) = '1' or EXISTS(SELECT d.data FROM tbPtoPremioDatas d WHERE d.id_premio=@id_premio AND d.data=@dtRef) begin
if @procurar_apts=0 begin
select @concede=1;
end else begin
select @considerar_abono_dia=1;
if @id_eveafa>0 begin
if EXISTS(SELECT id_eveabo FROM tbPtoPremioEvs WHERE id_premio=@id_premio AND concede=1 AND id_eveabo=@id_eveafa) begin
select @considerar_abono_dia=0;
end;
end;
if @considerar_abono_dia=1 and @id_eveabo>0 begin
if EXISTS(SELECT id_eveabo FROM tbPtoPremioEvs WHERE id_premio=@id_premio AND concede=1 AND id_eveabo=@id_eveabo) begin
select @considerar_abono_dia=0;
end;
end;
if @considerar_abono_dia=1 begin
if EXISTS(
SELECT e.id_eveabo FROM tbPtoPremioEvs e
INNER JOIN tbPtoAboDia a ON a.data=@dtRef AND a.id_eveabo = e.id_eveabo
INNER JOIN tbPtoPremioDivs d ON d.id_premio=e.id_premio And d.concede=e.concede AND d.id_diverg=a.id_diverg
WHERE e.id_premio=@id_premio AND e.concede=1)
begin
select @considerar_abono_dia=0;
end;
end;
select @m_valor=0;
SELECT @m_valor=isnull((
SUM((CASE WHEN @considerar_abono_dia=1 THEN (a2.m_valor-a2.m_abonado) ELSE a2.m_valor END))),0)
FROM tbPtoDivsDia a2
INNER JOIN tbDivergencias d ON a2.id_diverg = d.id_diverg
INNER JOIN tbPtoPremioDivs pm ON pm.id_premio=@id_premio AND pm.concede=1 AND a2.id_diverg = pm.id_diverg
WHERE a2.id_pass=@id_pass AND a2.data=@dtRef AND d.ativada = 1 AND isnull(a2.id_associ,0)=0
AND (CASE WHEN @considerar_abono_dia=1 THEN (a2.m_valor-a2.m_abonado) ELSE a2.m_valor END) > pm.m_s_min
if @m_valor>0 begin
select @concede=1;
end;
end;
end;--substring(@c_dias,@wdiapto+1,1) = '1' or EXISTS(SELECT d.data FROM tbPtoPremioDatas d WHERE d.id_premio=@id_premio AND d.data=@dtRef) begin
end;--@dia_tipo=0
select @dtRef=dateadd(d,1,@dtRef);
end; --while (@dtRef<=@dtFim and @concede=0) begin
select @perde=0, @perde_data=@dtFim;
if @concede=1 begin
select @procurar_apts=0;
if EXISTS(SELECT top 1 id_diverg FROM tbPtoPremioDivs WHERE id_premio=@id_premio AND concede=0) begin
select @procurar_apts=1;
end;
if @procurar_apts>0 begin
select @dtRef=@dtIni, @wdiapto=0;
while (@dtRef<=@dtFim and @perde=0) begin
select @tipodia='N', @dia_tipo=0, @dia_previsto=0, @id_eveafa=0, @id_eveabo=0;
SELECT @tipodia=isnull(tipodia,'Z'),
@dia_tipo=(CASE WHEN isnull(p.admissao,0)=1 THEN 1 WHEN isnull(p.demissao,0)=1 THEN 4 ELSE 0 END),
@dia_previsto=isnull(p.trabalhado,0),
@id_eveafa=isnull(p.id_eveafa,0),
@id_eveabo=isnull(p.id_eveabo,0),
@folga=isnull(p.folga,0)
FROM tbPtoDia p WHERE p.id_pass=@id_pass AND p.data=@dtRef
if @dia_tipo=0 AND ((@dia_previsto=1 AND @id_eveafa=0) OR @c_normal=0) begin
select @wdiapto = DATEPART(dw,@dtRef), @wdiapto=@wdiapto-1;
if @folga=1 begin select @wdiapto=8; end;
if @tipodia='V' begin select @wdiapto=7; end;
if @tipodia='P' begin select @wdiapto=9; end;
if substring(@c_dias,@wdiapto+1,1) = '1' or EXISTS(SELECT d.data FROM tbPtoPremioDatas d WHERE d.id_premio=@id_premio AND d.data=@dtRef) begin
select @considerar_abono_dia=0;
if @id_eveafa>0 begin
if EXISTS(SELECT id_eveabo FROM tbPtoPremioEvs WHERE id_premio=@id_premio AND concede=0 AND id_eveabo=@id_eveafa) begin
select @considerar_abono_dia=1;
end;
end;
if @considerar_abono_dia=0 and @id_eveabo>0 begin
if EXISTS(SELECT id_eveabo FROM tbPtoPremioEvs WHERE id_premio=@id_premio AND concede=0 AND id_eveabo=@id_eveabo) begin
select @considerar_abono_dia=1;
end;
end;
if @considerar_abono_dia=0 begin
if EXISTS(
SELECT e.id_eveabo FROM tbPtoPremioEvs e
INNER JOIN tbPtoAboDia a ON a.data=@dtRef AND a.id_eveabo = e.id_eveabo
INNER JOIN tbPtoPremioDivs d ON d.id_premio=e.id_premio And d.concede=e.concede AND d.id_diverg=a.id_diverg
WHERE e.id_premio=@id_premio AND e.concede=0)
begin
select @considerar_abono_dia=1;
end;
end;
select @m_valor=0;
SELECT @m_valor=isnull((
SUM((CASE WHEN @considerar_abono_dia=1 THEN (a2.m_valor-a2.m_abonado) ELSE a2.m_valor END))
),0)
FROM tbPtoDivsDia a2
INNER JOIN tbDivergencias d ON a2.id_diverg = d.id_diverg
INNER JOIN tbPtoPremioDivs pm ON pm.id_premio=@id_premio AND pm.concede=0 AND a2.id_diverg = pm.id_diverg
WHERE a2.id_pass=@id_pass AND a2.data=@dtRef AND d.ativada = 1 AND isnull(a2.id_associ,0)=0
and (CASE WHEN @considerar_abono_dia=1 THEN (a2.m_valor-a2.m_abonado) ELSE a2.m_valor END) > pm.m_s_min
if @m_valor>0 begin
select @perde=1;
end;
end;--if substring(@c_dias,@wdiapto+1,1) = '1' or EXISTS(SELECT d.data FROM tbPtoPremioDatas d WHERE d.id_premio=@id_premio AND d.data=@dtRef) begin
end;--if @dia_tipo=0 begin
if @perde=1 begin
select @perde_data=@dtRef, @concede=0;
end;
select @dtRef=dateadd(d,1,@dtRef);
end; --while (@dtRef<=@dtFim and @concede=0) begin
end; --if @procurar_apts>0 begin
end; --@concede=1
if @concede>0 begin
DELETE FROM tbPtoPremioConcede WHERE id_pass=@id_pass AND data=@dtFim AND id_premio=@id_premio;
INSERT INTO tbPtoPremioConcede (id_pass, data, id_premio) VALUES (@id_pass, @dtFim, @id_premio);
end;
if @perde>0 begin
DELETE FROM tbPtoPremioPerde WHERE id_pass=@id_pass AND data=@dtFim AND id_premio=@id_premio;
INSERT INTO tbPtoPremioPerde (id_pass, data, id_premio, perde_data) VALUES (@id_pass, @dtFim, @id_premio, @perde_data);
end;
end; --@achou=1
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO057') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO057; END;
GO
CREATE PROCEDURE dbo.AP_PTO057(@id_pass int output, @data datetime output, @dom_data datetime, @sab_data datetime, @fechamento_ini datetime, @fechamento_fim datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_premio int;
declare @achou bit, @ok bit, @dtIni datetime;
declare @data_ini datetime;
declare @periodo tinyint;
declare @dtRef datetime;
declare @mes_ini datetime, @mes_fim datetime;
select @mes_fim=dateadd(d,-1,dateadd(m,1,CONVERT(datetime,right('00'+ltrim(str(month(@data))),2)+'/01/'+ltrim(str(year(@data))))));
select @mes_ini=CONVERT(datetime,right('00'+ltrim(str(month(@data))),2)+'/01/'+ltrim(str(year(@data))));
select @achou=1, @id_premio=0;
while (@achou=1) begin
SELECT @achou=0;
SELECT TOP 1 @achou=1, @id_premio=a.id_premio,
@periodo=b.periodo, @data_ini=data_ini
FROM tbPtoPremioPass a
INNER JOIN tbPtoPremio b ON a.id_premio = b.id_premio
WHERE a.id_pass=@id_pass and a.id_premio>@id_premio
AND @data BETWEEN b.data_ini AND b.data_fim
ORDER BY a.id_premio;
select @ok=@achou, @dtIni=@data;
if @ok=1 begin
select @ok=0;
if @periodo=0 begin
if @data=@fechamento_fim begin
select @ok=1, @dtIni=@fechamento_ini;
end;
end else if @periodo=1 begin
if @data=@mes_fim begin
select @ok=1, @dtIni=@mes_ini;
end;
end else if @periodo=2 begin
if @data=@sab_data begin
select @ok=1, @dtIni=@dom_data;
end;
end else if @periodo=3 begin
if @data=@dom_data begin
select @ok=1, @dtIni=dateadd(d,-6,@dom_data);
end;
end else if @periodo=4 begin
select @ok=1, @dtIni=@data;
end;
end;
if @ok=1 begin
if @dtIni<@data_ini begin
select @dtIni=@data_ini;
end;
EXEC AP_PTO056 @id_pass, @id_premio, @dtIni, @data;
end;
end; /*@ while (@achou=1) begin */
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO060') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO060; END;
GO
CREATE PROCEDURE dbo.AP_PTO060(@id_pass int output, @data datetime output) WITH ENCRYPTION AS
BEGIN
declare @achou bit;
declare @original bit;
declare @primeira datetime, @m_primeira int, @ultima datetime, @m_ultima int, @ultold datetime;
declare @fxini datetime, @fxfim datetime, @dtref datetime;
declare @ent_dia int, @sai_dia int, @pri_dia int, @ult_dia int;
if not exists(SELECT TOP 1 id_diverg FROM tbDivergencias WHERE id_diverg IN (102, 103) AND ativada=1) begin
RETURN(0);
end;
select @original=1;
SELECT TOP 1 @original=original, @pri_dia=m_primeira, @ult_dia=m_ultima
FROM tbPtoEnq
WHERE id_pass=@id_pass AND data=@data
ORDER BY original;
if isnull(@original,1)=0 begin
SELECT @original=original FROM tbPtoAce WHERE id_pass=@id_pass AND data=@data;
if isnull(@original,1)=0 begin
RETURN(0); --As marcaes do dia foram alteradas pelo usurio
end;
end;
SELECT TOP 1 @ent_dia=e1, @sai_dia=(CASE WHEN s4>=0 THEN s4 WHEN s3>=0 THEN s3 WHEN s2>=0 THEN s2 ELSE s1 END)
FROM tbPtoDia WHERE id_pass=@id_pass AND data=@data;
select @ent_dia=isnull(@ent_dia,-1); select @sai_dia=isnull(@sai_dia,-1)
select @pri_dia=isnull(@pri_dia,-1); select @ult_dia=isnull(@ult_dia,-1)
select @primeira=null, @m_primeira=-1;
select @ultima=null,   @m_ultima=-1;
select @ultold=null;
SELECT @ultold=ultima FROM tbPtoAce WHERE id_pass=@id_pass AND data=dateadd(d,-1,@data);
select @fxini=@data;
select @fxfim=dateadd(d,1,@data);
if @pri_dia>=0 and @pri_dia>@ent_dia  begin
select @fxfim=dateadd(mi,@pri_dia+180,dateadd(d,-1,@data));
select @fxini=dateadd(hh,-10,@fxfim);
end else if @ent_dia>=0 begin
select @fxfim=dateadd(mi,@ent_dia+180,dateadd(d,-1,@data));
select @fxini=dateadd(hh,-10,@fxfim);
end;
if (@fxini<@data) begin select @fxini=@data; end;
if @fxini<@fxfim begin
select @achou=1;
while (@achou=1) begin
SELECT @dtref=max(m.data) FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbBloq b ON m.relogio=b.id_bloq
INNER JOIN tbGBloq g ON b.id_gbloq=g.id_gbloq and g.primario=1
INNER JOIN tbEventoSist e ON m.evento = e.id_evento and e.flagimpedimento=0
WHERE id_pass=@id_pass AND m.data>@fxini and m.data<@fxfim
AND m.status=0 AND m.ponto=0;
if not @dtref is null begin
if @dtref < isnull(@ultold,@data)  begin
select @achou=0;
end else begin
select @primeira=@dtref;
select @fxfim=@dtref;
select @fxini=dateadd(hh,-8,@dtref);
end;
end else begin
select @achou=0;
end;
end;
end;
if not @primeira is null begin
select @fxini=@primeira;
select @fxfim=dateadd(hh,14,@primeira);
end else begin
if (isnull(@ultold,@data)<=@data) begin
select @fxini=@data;
end else begin
select @fxini=@ultold;
end;
select @fxfim=dateadd(d,1,@data);
end;
if @ult_dia>=0 and @ult_dia>@sai_dia begin
if dateadd(mi,@ult_dia+480,dateadd(d,-1,@data))>@fxfim begin
select @fxfim=dateadd(mi,@ult_dia+480,dateadd(d,-1,@data));
select @fxini=dateadd(hh,-14,@fxfim);
end;
end else if @sai_dia>=0 begin
if dateadd(mi,@sai_dia+480,dateadd(d,-1,@data))>@fxfim begin
select @fxfim=dateadd(mi,@sai_dia+480,dateadd(d,-1,@data));
select @fxini=dateadd(hh,-14,@fxfim);
end;
end;
if @fxini<@fxfim begin
select @achou=1;
while (@achou=1) begin
SELECT @dtref=min(m.data) FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbBloq b ON m.relogio=b.id_bloq
INNER JOIN tbGBloq g ON b.id_gbloq=g.id_gbloq and g.primario=1
INNER JOIN tbEventoSist e ON m.evento = e.id_evento and e.flagimpedimento=0
WHERE id_pass=@id_pass AND m.data>@fxini and m.data<@fxfim
AND m.status=1 AND m.ponto=0;
if not @dtref is null begin
select @ultima=@dtref;
if (@dtref>=dateadd(hh,20,@data)) begin
select @achou=0;
end else begin
select @fxini=@dtref;
select @fxfim=dateadd(hh,8,@dtref);
end;
end else begin
select @achou=0;
end;
end;
end;
if not @primeira is null begin
EXEC AP_PTO001 @primeira, @m_primeira output;
SELECT @m_primeira = @m_primeira + (1440 * (datediff(d,@data,@primeira) + 1));
end;
if not @ultima is null begin
EXEC AP_PTO001 @ultima, @m_ultima output;
SELECT @m_ultima = @m_ultima + (1440 * (datediff(d,@data,@ultima) + 1));
end;
if @primeira is null and @ultima is null begin
DELETE FROM tbPtoAce WHERE id_pass=@id_pass AND data=@data;
end else if exists(SELECT id_pass FROM tbPtoAce WHERE id_pass=@id_pass and data=@data) begin
UPDATE tbPtoAce SET original=@original,
primeira=@primeira, ultima=@ultima,
m_primeira=@m_primeira, m_ultima=@m_ultima
WHERE id_pass=@id_pass AND data=@data;
end else begin
INSERT INTO tbPtoAce (id_pass, data, original, primeira, ultima, m_primeira, m_ultima)
VALUES (@id_pass, @data, @original, @primeira, @ultima, @m_primeira, @m_ultima);
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO031') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO031; END;
GO
CREATE PROCEDURE dbo.AP_PTO031(@id_pass int output, @data datetime output) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @achou bit; declare @dtseguinte datetime;
declare @falta bit; declare @falta_aux bit; declare @hrs_norm varchar(7); declare @m_hrs_norm int;
declare @m_hn_tot int; declare @hn_tot varchar(7); declare @m_hn_tmpdia int; declare @m_dhn_tmpdia int;
declare @m_trab_tot int; declare @trab_tot varchar(7); declare @per_hn int; declare @per_dsr int;
declare @id_phorario int; declare @id_tolera int; declare @id_arredonda int; declare @trabalhado bit;
declare @id_he int; declare @id_dsr int; declare @apura_tipo int;
declare @flexivel bit; declare @m_hrs_prev int; declare @id_hnormais int;
declare @metodo tinyint, @abate_dsr bit, @id_divassoc_nh int; declare @hnorm_diario int;
declare @abate_dia bit; declare @m_hn_mes int;
declare @obs varchar(30); declare @m_hrs_trab int; declare @original bit;
declare @m_ent01 int; declare @m_sai01 int; declare @m_ent02 int; declare @m_sai02 int;
declare @m_ent03 int; declare @m_sai03 int; declare @m_ent04 int; declare @m_sai04 int;
declare @m_ent05 int; declare @m_sai05 int; declare @m_ent06 int; declare @m_sai06 int;
declare @m_ent07 int; declare @m_sai07 int; declare @m_ent08 int; declare @m_sai08 int;
declare @contamc tinyint; declare @ult_he_ent tinyint; declare @pri_he_sai tinyint;
declare @fimper1 tinyint; declare @fimper2 tinyint;
declare @fimper3 tinyint; declare @fimper4 tinyint;
declare @iniflex tinyint; declare @fimflex tinyint;
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int;
declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int;
declare @fxini int; declare @fxfim int; declare @fxtmp int;
declare @folga bit; declare @tipodia char(1); declare @tipohe char(1);
declare @folga_sg bit; declare @tipodia_sg char(1);
declare @wdia tinyint; declare @psi int; declare @id_diverg int;
declare @wdiapto tinyint;  declare @wdiapto_sg tinyint;
declare @norm_ini int;  declare @norm_fim int; declare @id_adicional int;
declare @m_vlraux int; declare @m_vlraux2 int; declare @vlraux varchar(7); declare @achouDivDia bit;
declare @id_associ int; declare @lancado bit;
declare @id_empresa int; declare @hnorm_por_dia int; declare @dias_norm int;
declare @fechamento_ini datetime; declare @fechamento_fim datetime;
declare @fechmesref_ini datetime; declare @fechmesref_fim datetime;
declare @dom_data datetime; declare @sab_data datetime; declare @he_ini datetime; declare @he_fim datetime;
declare @he_permitida bit; declare @tolerancia_ini datetime; declare @tolerancia_fim datetime;
declare @pagou_bco int; declare @desc_bco int; declare @id_eveabo int, @id_eveafa int; declare @m_horas_abono int;
declare @saldo_sinal bit; declare @saldo_vlr int;
declare @eve_calc_hn bit; declare @admissao bit; declare @demissao bit;
declare @mes_ini datetime; declare @mes_fim datetime; declare @mes_fec int; declare @ano_fec int; declare @mes_hn int;
declare @hrs_reais varchar(7); declare @m_hrs_reais int;
declare @gravouAbo bit; declare @gera_itv_l bit;
declare @dtmc_anterior datetime; declare @dtmc_atual datetime;
if EXISTS(SELECT enc.id_empresa FROM tbEncEmp enc INNER JOIN tbPass p ON p.id_pass=@id_pass AND p.id_empresa=enc.id_empresa WHERE enc.ult_data>=@data) begin
RETURN(0);
end;
select @falta=0, @falta_aux=0, @hrs_norm='  00:00', @m_hrs_norm=0, @hn_tot='  00:00', @m_hn_tot=0, @m_hn_tmpdia=0,@m_dhn_tmpdia=0, @obs='', @trab_tot='  00:00', @m_trab_tot=0;
select @trabalhado=0, @id_phorario=0, @id_tolera=0, @id_arredonda=0, @id_he=0, @id_dsr=0, @id_adicional=0,
@id_hnormais=0, @per_hn=0, @per_dsr=0, @flexivel=0, @m_hrs_trab=0,@original=1,@id_eveabo=0, @id_eveafa=0, @m_horas_abono=0, @apura_tipo=0;
select @contamc=0, @m_ent01=-1,@m_sai01=-1,@m_ent02=-1,@m_sai02=-1,@m_ent03=-1,@m_sai03=-1,
@m_ent04=-1,@m_sai04=-1,@m_ent05=-1,@m_sai05=-1,@m_ent06=-1,@m_sai06=-1,
@m_ent07=-1,@m_sai07=-1,@m_ent08=-1,@m_sai08=-1,@folga=0,@tipodia='N',@tipohe='N', @ult_he_ent=0, @pri_he_sai=0;
select @eve_calc_hn=0, @admissao=0, @demissao=0, @m_hrs_reais=0, @hrs_reais='  00:00';
DELETE FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data = @data AND lancado=0;
DELETE FROM tbPtoAboDia WHERE id_pass = @id_pass AND data = @data AND gerado=1;
DELETE FROM tbPtoAboDia WHERE id_pass = @id_pass AND data = @data AND id_ptocp>0 AND id_ptocp NOT IN (SELECT p.id_ptocp FROM tbPtoCp p WHERE id_pass=@id_pass AND p.data=@data AND p.id_diverg=tbPtoAboDia.id_diverg);
DELETE FROM tbPtoBenf WHERE id_pass = @id_pass AND data = @data;
DELETE FROM tbPtoCpCmp WHERE id_pass = @id_pass AND data = @data;
DELETE FROM tbPtoPremioConcede WHERE id_pass = @id_pass AND data = @data;
DELETE FROM tbPtoPremioPerde WHERE id_pass = @id_pass AND data = @data;
if EXISTS(SELECT id_pass FROM tbPtoAcrDia WHERE id_pass = @id_pass AND data = @data) begin
UPDATE tbPtoAcrDia SET soma=0, tol_s=0, tol_m=0, flex=0 WHERE id_pass=@id_pass AND data=@data;
end;
if EXISTS(SELECT id_pass FROM tbPtoDscDia WHERE id_pass = @id_pass AND data = @data) begin
UPDATE tbPtoDscDia SET soma=0, tol_s=0, tol_m=0, flex=0 WHERE id_pass=@id_pass AND data=@data;
end;
if EXISTS(SELECT id_pass FROM tbPtoHEDia WHERE id_pass = @id_pass AND data = @data) begin
UPDATE tbPtoHEDia SET periodo=0, he_d=0, he_d_fp=0, he_n=0, he_n_fp=0, opcao_sg=0, periodo_sg=0, he_d_sg=0, he_d_fp_sg=0, he_n_sg=0, he_n_fp_sg=0, he_inicio=0, abo_he_d=0, abo_he_d_fp=0, abo_he_n=0, abo_he_n_fp=0 WHERE id_pass=@id_pass AND data=@data;
end;
if EXISTS(SELECT id_pass FROM tbPtoHFlx WHERE id_pass=@id_pass AND data=@data) begin
UPDATE tbPtoHFlx SET efetuado=0, normais=0 WHERE id_pass=@id_pass AND data=@data;
end;
if NOT EXISTS(SELECT id_pass FROM tbPtoEstat WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoEstat (id_pass,data,m_intjr,m_atrasos,m_he_dia,m_he_intervalo,m_faltas,alerta_dia,dia_tipo,dia_previsto,dia_ausencia,dia_inativo,m_previsto,m_ausencia,m_inativo,id_eveabo,alrt_interjor,alrt_he_intv,alrt_he_dia,alrt_atraso_dia,alrt_falta_dia,m_acres_d,m_acres_n,m_acres_dp,m_acres_np,m_acres_b,m_acres_bp) VALUES (@id_pass,@data,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
end else begin
UPDATE tbPtoEstat SET m_intjr=0, m_atrasos=0, m_he_dia=0, m_he_intervalo=0, m_faltas=0,
alerta_dia=0, dia_tipo=0, dia_previsto=0, dia_ausencia=0, dia_inativo=0, m_previsto=0,
m_ausencia=0,m_inativo=0,id_eveabo=0,alrt_interjor=0, alrt_he_intv=0,alrt_he_dia=0,alrt_atraso_dia=0,alrt_falta_dia=0,
m_acres_d=0,m_acres_n=0,m_acres_dp=0,m_acres_np=0,m_acres_b=0,m_acres_bp=0
WHERE id_pass=@id_pass AND data=@data;
end;
if @data>=DATEADD(d,-40,getdate()) begin
DELETE FROM tbPtoAboDia WHERE id_pass = @id_pass AND data = @data AND id_diverg NOT IN (
SELECT d.id_diverg FROM tbDivergencias d WHERE d.ativada=1 AND d.id_diverg NOT IN (SELECT a.id_diverg FROM tbDivAssoc a)
)
end;
select @id_empresa=0;
SELECT @id_empresa=id_empresa FROM tbPass WHERE id_pass=@id_pass;
SELECT @he_permitida=he_permitida FROM tbEmpresas WHERE id_empresa=@id_empresa;
select @he_permitida=isnull(@he_permitida,0);
select @psi=(DATEPART(dw,@data)-1)*(-1);
select @dom_data = dateadd(d,@psi,@data); select @sab_data = dateadd(d,6,@dom_data);
select @mes_fec=0,@ano_fec=0;
SELECT @mes_fec=mes,@ano_fec=ano,@fechamento_ini=fechamento_ini, @fechamento_fim=fechamento_fim FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN fechamento_ini AND fechamento_fim;
SELECT @he_ini=he_ini, @he_fim=he_fim FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN he_ini AND he_fim;
SELECT @tolerancia_ini=tolerancia_ini, @tolerancia_fim=tolerancia_fim FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN tolerancia_ini AND tolerancia_fim;
if @fechamento_ini is null begin
select @psi=(day(@data)-1)*(-1);
select @fechamento_ini = dateadd(d,@psi,@data);
select @fechamento_fim = dateadd(d,-1,dateadd(m,1,@fechamento_ini));
select @mes_fim=@fechamento_fim,@mes_fec=month(@fechamento_ini),@ano_fec=year(@fechamento_ini);
end else begin
select @mes_fim=dateadd(d,-1,dateadd(m,1,CONVERT(datetime,right('00'+ltrim(str(@mes_fec)),2)+'/01/'+ltrim(str(@ano_fec)))));
end;
select @mes_ini=CONVERT(datetime,right('00'+ltrim(str(@mes_fec)),2)+'/01/'+ltrim(str(@ano_fec)));
select @fechmesref_ini=@mes_ini, @fechmesref_fim=@mes_fim;
if @fechmesref_ini<>@fechamento_ini or @fechmesref_fim<>@fechamento_fim begin
SELECT @fechmesref_ini=fechamento_ini, @fechmesref_fim=fechamento_fim FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @mes_ini BETWEEN fechamento_ini AND fechamento_fim;
if @fechmesref_ini is null begin select @fechmesref_ini=@mes_ini,@fechmesref_fim=@mes_fim; end;
end;
if @he_ini is null begin
select @he_ini=@fechamento_ini;
select @he_fim=@fechamento_fim;
end;
if @tolerancia_ini is null begin
select @tolerancia_ini=@fechamento_ini;
select @tolerancia_fim=@fechamento_fim;
end;
select @folga_sg=0,@tipodia_sg='N', @dtseguinte = dateadd(d,1,@data);
EXEC AP_PTO009 @id_pass output, @dtseguinte output, 0;
SELECT @folga_sg=folga, @tipodia_sg=tipodia, @id_phorario=isnull(id_phorario,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @dtseguinte;
select @wdiapto_sg=DATEPART(dw,@dtseguinte)-1;
if @folga_sg=1 begin select @wdiapto_sg=8; end;
if @tipodia_sg='V' begin
if NOT EXISTS(SELECT feriado_normal FROM tbPHorarios WHERE id_phorario=@id_phorario AND feriado_normal=1)
AND NOT EXISTS(SELECT feriado_normal FROM tbFunc WHERE id_pass=@id_pass AND feriado_normal=1 AND categoria=1) BEGIN
select @wdiapto_sg=7;
END;
end;
if @tipodia_sg='P' begin select @wdiapto_sg=9; end;
select @id_phorario=0;
EXEC AP_PTO009 @id_pass output, @data output, 1;
SELECT @id_phorario=d.id_phorario, @trabalhado=d.trabalhado, @flexivel=d.flexivel, @m_hrs_prev=d.m_hrs_prev, @obs=d.obs,
@id_he=isnull(d.id_he,0), @id_dsr=isnull(d.id_dsr,0), @id_tolera=isnull(d.id_tolera,0),
@id_adicional=isnull(d.id_adicional,0), @id_arredonda=isnull(d.id_arredonda,0), @id_hnormais=isnull(d.id_hnormais,0), @per_hn=isnull(h.per_hn,0), @per_dsr=isnull(ds.per_dsr,0),
@norm_ini=d.norm_ini, @norm_fim=d.norm_fim,@e1=d.e1,@s1=d.s1,@e2=d.e2,@s2=d.s2,@e3=d.e3,@s3=d.s3,@e4=d.e4,@s4=d.s4,@fxini=d.fxini,@fxfim=d.fxfim,@fxtmp=d.fxtmp,
@folga=d.folga, @tipodia=d.tipodia, @tipohe=d.tipohe, @id_eveabo=isnull(d.id_eveabo,0), @id_eveafa=isnull(d.id_eveafa,0), @m_horas_abono=isnull(d.m_horas_abono,0),
@eve_calc_hn=isnull(e.calc_hn,0), @admissao=d.admissao, @demissao=d.demissao
FROM tbPtoDia d LEFT JOIN tbEvsAbono e ON d.id_eveafa=e.id_eveabo LEFT JOIN tbHNormais h ON d.id_hnormais=h.id_hnormais LEFT JOIN tbDSR ds ON d.id_dsr=ds.id_dsr
WHERE d.id_pass = @id_pass AND d.data = @data
select @wdia = DATEPART(dw,@data), @wdiapto=@wdia-1;
if @folga=1 begin select @wdiapto=8; end;
if @tipodia='V' begin
if NOT EXISTS(SELECT feriado_normal FROM tbPHorarios WHERE id_phorario=@id_phorario AND feriado_normal=1)
AND NOT EXISTS(SELECT feriado_normal FROM tbFunc WHERE id_pass=@id_pass AND feriado_normal=1 AND categoria=1) BEGIN
select @wdiapto=7;
end;
end;
if @tipodia='P' begin select @wdiapto=9; end;
if @he_permitida=0 and @tipohe='N' begin select @tipohe='X' end;
SELECT top 1 @contamc=contamc, @m_hrs_trab=m_hrs_trab, @original=original,
@m_ent01=m_ent01,@m_sai01=m_sai01,@m_ent02=m_ent02,@m_sai02=m_sai02,@m_ent03=m_ent03,@m_sai03=m_sai03,
@m_ent04=m_ent04,@m_sai04=m_sai04,@m_ent05=m_ent05,@m_sai05=m_sai05,@m_ent06=m_ent06,@m_sai06=m_sai06,
@m_ent07=m_ent07,@m_sai07=m_sai07,@m_ent08=m_ent08,@m_sai08=m_sai08,
@ult_he_ent=ult_he_ent, @pri_he_sai=pri_he_sai, @hrs_reais=hrs_trab, @m_hrs_reais=m_hrs_trab
FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data ORDER BY original;
if @original=0 and @s1>0 and @e2>0 and @m_sai01>-1 and @m_ent02>-1 and (@m_ent02-@m_sai01 = @e2-@s1) begin
if (@m_sai01<@s1 or @m_ent02>@e2) and @m_sai01 > @e1 and @m_ent02 < @s2 begin
if exists(SELECT top 1 id_pass FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data AND original=1 AND (m_sai01<>@m_sai01 OR m_ent02<>@m_ent02)) begin
select @s1=@m_sai01, @e2=@m_ent02;
end;
end;
end;
EXEC AP_PTO019 @contamc,
@m_ent01, @m_sai01, @m_ent02, @m_sai02, @m_ent03, @m_sai03, @m_ent04, @m_sai04,
@m_ent05, @m_sai05, @m_ent06, @m_sai06, @m_ent07, @m_sai07, @m_ent08, @m_sai08,
@e1, @s1, @e2, @s2, @e3, @s3, @e4, @s4, @fxini, @fxfim, @fxtmp,
@fimper1 output, @fimper2 output, @fimper3 output, @fimper4 output,@iniflex output, @fimflex output;
exec AP_PTO060 @id_pass output, @data output;
select @achou=0;
SELECT @achou=1, @gera_itv_l=gera_itv_l FROM tbFunc WHERE id_pass=@id_pass AND isnull(gera_itv,0)=1
if @achou=1 and dateadd(d,-100,getdate()) <= @data  begin
if isnull(@gera_itv_l,0) = 1 begin
exec AP_PTO039 @id_pass output, @data output, 1, 300, 60, '1111000000', 0, 1;
end else begin
exec AP_PTO039 @id_pass output, @data output, 1, 0, 0, '1111000000', 0, 1;
end;
SELECT top 1 @contamc=contamc, @m_hrs_trab=m_hrs_trab, @original=original,
@m_ent01=m_ent01,@m_sai01=m_sai01,@m_ent02=m_ent02,@m_sai02=m_sai02,@m_ent03=m_ent03,@m_sai03=m_sai03,
@m_ent04=m_ent04,@m_sai04=m_sai04,@m_ent05=m_ent05,@m_sai05=m_sai05,@m_ent06=m_ent06,@m_sai06=m_sai06,
@m_ent07=m_ent07,@m_sai07=m_sai07,@m_ent08=m_ent08,@m_sai08=m_sai08,
@ult_he_ent=ult_he_ent, @pri_he_sai=pri_he_sai, @hrs_reais=hrs_trab, @m_hrs_reais=m_hrs_trab
FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data ORDER BY original;
EXEC AP_PTO019 @contamc,
@m_ent01, @m_sai01, @m_ent02, @m_sai02, @m_ent03, @m_sai03, @m_ent04, @m_sai04,
@m_ent05, @m_sai05, @m_ent06, @m_sai06, @m_ent07, @m_sai07, @m_ent08, @m_sai08,
@e1, @s1, @e2, @s2, @e3, @s3, @e4, @s4, @fxini, @fxfim, @fxtmp,
@fimper1 output, @fimper2 output, @fimper3 output, @fimper4 output,@iniflex output, @fimflex output;
end;
if @m_hrs_trab > 0 begin
exec AP_PTO018 @id_pass output, @data output, 49, @m_hrs_trab;
end;
select @ult_he_ent=0, @pri_he_sai=0;
if @flexivel=0 begin
EXEC AP_PTO020 @id_pass output, @data output, @id_phorario, @id_tolera, @trabalhado, @contamc, @m_hrs_prev,
@m_ent01,@m_sai01,@m_ent02,@m_sai02,@m_ent03,@m_sai03, @m_ent04,@m_sai04,@m_ent05,@m_sai05,@m_ent06,@m_sai06, @m_ent07,@m_sai07,@m_ent08, @m_sai08,
@fimper1, @fimper2, @fimper3, @fimper4, @iniflex, @fimflex,
@e1, @s1, @e2, @s2, @e3, @s3, @e4, @s4, @fxini, @fxfim, @fxtmp,
@falta output, @falta_aux output, @obs output;
if @falta_aux=0 begin
EXEC AP_PTO024 @id_pass output, @data output, @trabalhado, @id_adicional,
@dom_data, @sab_data, @tolerancia_ini, @tolerancia_fim,
@contamc, @id_phorario, @id_arredonda, @id_tolera, @id_he, @tipohe, @m_hrs_prev, @m_hrs_norm output,
@m_ent01, @m_sai01, @m_ent02, @m_sai02, @m_ent03, @m_sai03, @m_ent04, @m_sai04,
@m_ent05, @m_sai05, @m_ent06, @m_sai06, @m_ent07, @m_sai07, @m_ent08, @m_sai08,
@wdiapto, @wdiapto_sg, @fimper1, @fimper2, @fimper3, @fimper4, @iniflex, @fimflex,
@e1, @s1, @e2, @s2, @e3, @s3, @e4, @s4, @fxini, @fxfim, @fxtmp, @ult_he_ent output, @pri_he_sai output;
if @m_hrs_norm > 0 begin EXEC AP_PTO003 @m_hrs_norm, @hrs_norm output; end;
if @id_he > 0 begin EXEC AP_PTO027 @he_ini, @dom_data, @id_pass output, @data output, @id_he; end;
end;
end else begin
if @m_ent01>-1 and @m_sai01 >-1 and @m_ent02 > -1 and @m_sai02 = -1 begin
select @m_sai01=@m_ent02, @m_ent02=-1;
end;
EXEC AP_PTO021 @id_pass output, @data output, @trabalhado, @id_phorario, @contamc,
@m_ent01, @m_sai01, @m_ent02, @m_sai02, @m_ent03, @m_sai03, @m_ent04, @m_sai04,
@m_ent05, @m_sai05, @m_ent06, @m_sai06, @m_ent07, @m_sai07, @m_ent08, @m_sai08,
@falta output, @falta_aux output, @obs output;
EXEC AP_PTO025 @id_pass output, @data output, @trabalhado, @id_phorario, @apura_tipo output,
@id_adicional, @dom_data, @sab_data, @fechamento_ini, @fechamento_fim,
@contamc, @id_he, @tipohe, @m_hrs_prev, @m_hrs_norm output, @m_hn_tot output, @m_trab_tot output,
@m_ent01, @m_sai01, @m_ent02, @m_sai02, @m_ent03, @m_sai03, @m_ent04, @m_sai04,
@m_ent05, @m_sai05, @m_ent06, @m_sai06, @m_ent07, @m_sai07, @m_ent08, @m_sai08,
@wdiapto, @wdiapto_sg, @admissao, @demissao, @id_eveafa;
if @m_hrs_norm > 0 begin EXEC AP_PTO003 @m_hrs_norm, @hrs_norm output; end;
if @m_hn_tot > 0 begin   EXEC AP_PTO003 @m_hn_tot, @hn_tot output;     end;
if @m_trab_tot > 0 begin EXEC AP_PTO003 @m_trab_tot, @trab_tot output; end;
if @id_he > 0 begin EXEC AP_PTO027 @he_ini, @dom_data, @id_pass output, @data output, @id_he; end;
end;
select @dtmc_anterior=null, @dtmc_atual=null;
SELECT TOP 1 @dtmc_anterior=ultima FROM tbPtoEnq WHERE id_pass=@id_pass AND data=dateadd(d,-1,@data) ORDER BY original;
SELECT TOP 1 @dtmc_atual=primeira FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data ORDER BY original;
if not @dtmc_anterior is null and not @dtmc_atual is null begin
if @dtmc_anterior < @dtmc_atual begin
select @m_vlraux=datediff(n,@dtmc_anterior,@dtmc_atual);
if @m_vlraux>0 AND @m_vlraux<660 begin
select @m_vlraux=660-@m_vlraux;
exec AP_PTO018 @id_pass output, @data output, 106, @m_vlraux;
end;
end;
end;
select @m_hrs_reais=0, @hrs_reais='  00:00';
if @m_ent01>-1 and @m_sai01>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai01-@m_ent01); end;
if @m_ent02>-1 and @m_sai02>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai02-@m_ent02); end;
if @m_ent03>-1 and @m_sai03>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai03-@m_ent03); end;
if @m_ent04>-1 and @m_sai04>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai04-@m_ent04); end;
if @m_ent05>-1 and @m_sai05>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai05-@m_ent05); end;
if @m_ent06>-1 and @m_sai06>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai06-@m_ent06); end;
if @m_ent07>-1 and @m_sai07>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai07-@m_ent07); end;
if @m_ent08>-1 and @m_sai08>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai08-@m_ent08); end;
if @flexivel=1 or exists(select acresce_falta from tbPHorarios where id_phorario=@id_phorario and isnull(acresce_falta,0)=1) begin
if @m_ent01>-1 and @m_sai01=-1 and @m_ent02=-1 and @m_sai02>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai02-@m_ent01); end;
if @m_ent03>-1 and @m_sai03=-1 and @m_ent04=-1 and @m_sai04>-1 begin select @m_hrs_reais=@m_hrs_reais+(@m_sai04-@m_ent03); end;
end;
EXEC AP_PTO003 @m_hrs_reais, @hrs_reais output;
select @achou=0, @pagou_bco=0, @desc_bco=0, @saldo_sinal=0, @saldo_vlr=0;
SELECT @achou=1, @pagou_bco=pagar, @desc_bco=descontar, @saldo_sinal=saldo_sinal, @saldo_vlr=saldo_vlr FROM tbPtoBcoDivs WHERE id_pass=@id_pass AND data=@data;
if @achou=1 begin
if @pagou_bco>0 begin exec AP_PTO018 @id_pass output, @data output, 34, @pagou_bco; end;
if @desc_bco>0 begin exec AP_PTO018 @id_pass output, @data output, 35, @desc_bco; end;
if @saldo_vlr>0 begin
if @saldo_sinal=1 begin
exec AP_PTO018 @id_pass output, @data output, 36, @saldo_vlr;
end else begin
exec AP_PTO018 @id_pass output, @data output, 37, @saldo_vlr;
end;
end;
end;
select @psi=1, @achouDivDia=1, @gravouAbo=0;
if @id_eveabo>0 and NOT EXISTS(SELECT id_eveabo FROM tbEvsAbono WHERE id_eveabo=@id_eveabo AND calculo=0) begin
WHILE ( @achouDivDia = 1 ) BEGIN
select @achouDivDia=0;
SELECT @achouDivDia=1, @id_diverg=d.id_diverg, @m_vlraux=d.m_valor, @lancado=lancado
FROM tbPtoDivsDia d INNER JOIN tbDivergencias v ON v.id_diverg = d.id_diverg
WHERE d.id_pass = @id_pass AND d.data = @data AND d.contadia=@psi;
if @achouDivDia=1 and @m_horas_abono>0 and @lancado=0 begin
if @id_diverg IN (1,2,3,4,13,14,15,16,17,18,19,20,29) or (@id_diverg IN (66,68) and @apura_tipo=0) begin
select @id_associ=isnull((SELECT top 1 id_divassoc FROM tbDivAssoc WHERE id_diverg=@id_diverg),@id_diverg);
if @m_horas_abono>=599999  begin
EXEC AP_PTO041 @id_empresa output, @id_pass output, @data output, @id_associ, @id_eveabo, @m_vlraux, 0, 1;
select @gravouAbo=1;
end else begin if @m_horas_abono>0 begin
if @m_horas_abono>=@m_vlraux begin
select @m_horas_abono=@m_horas_abono-@m_vlraux;
EXEC AP_PTO041 @id_empresa output, @id_pass output, @data output, @id_associ, @id_eveabo, @m_vlraux, 0, 1;
select @gravouAbo=1;
end else begin
select @m_vlraux=@m_vlraux-@m_horas_abono;
EXEC AP_PTO041 @id_empresa output, @id_pass output, @data output, @id_associ, @id_eveabo, @m_horas_abono, 0, 1;
select @m_horas_abono=0;
select @gravouAbo=1;
end;
end; end;
end;
end;
select @psi=@psi+1;
end;
end;
if @id_eveafa=0 AND @id_eveabo>0 AND @gravouAbo=0 begin
IF NOT EXISTS(SELECT id_pass FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND id_eveabo=@id_eveabo)
EXEC AP_PTO041 @id_empresa output, @id_pass output, @data output, 0, @id_eveabo, 0, 0, 1;
end;
if @id_eveafa>0 begin
if NOT EXISTS(SELECT id_pass FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND id_eveabo=@id_eveafa) begin
select @m_vlraux=0;
select @m_vlraux=ISNULL(
(SELECT TOP 1 nd.m_hrs_prev FROM tbPtoDia nd
WHERE nd.id_pass=@id_pass and nd.data<=@data AND nd.m_hrs_prev>0
ORDER BY nd.data DESC),0);
EXEC AP_PTO041 @id_empresa output, @id_pass output, @data output, 0, @id_eveafa, @m_vlraux, 0, 1;
end;
end;
UPDATE tbPtoDivsDia SET m_valor=0 WHERE id_pass = @id_pass AND data = @data AND m_valor<0;
select @psi=1, @achouDivDia=1;
while( @achouDivDia = 1 ) begin
select @achouDivDia=0;
SELECT @achouDivDia=1, @id_diverg=id_diverg, @m_vlraux=m_valor, @id_associ=id_associ, @lancado=lancado FROM tbPtoDivsDia
WHERE id_pass = @id_pass AND data = @data AND contadia=@psi;
if @achouDivDia=1 begin
if @id_associ = 0 and @lancado=0 begin
EXEC AP_PTO030 @id_pass output,@data output, @id_arredonda, 1, @id_diverg, @m_vlraux output;
end;
EXEC AP_PTO017 @id_pass output, @data output, @id_diverg;
end else begin
SELECT @achouDivDia=1 FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data = @data AND contadia>@psi;
end;
select @psi=@psi+1;
end;
IF @m_hrs_prev>0 BEGIN
SELECT @m_vlraux=0;
SELECT @m_vlraux=isnull(SUM((case when a.m_valor=599999 then d.m_abonado else a.m_valor end)),0) FROM tbPtoDivsDia d
INNER JOIN tbPtoAboDia a ON d.id_pass=a.id_pass AND a.data=d.data AND d.id_diverg = a.id_diverg
INNER JOIN tbEvsAbono v ON a.id_eveabo=v.id_eveabo AND v.calc_hn=0
INNER JOIN tbDivergencias div ON a.id_diverg = div.id_diverg AND div.ativada=1 AND div.soma=0
WHERE d.id_pass = @id_pass AND d.data=@data;
IF ISNULL(@m_vlraux,0)>0 BEGIN
select @m_hrs_norm = @m_hrs_norm + @m_vlraux;
if @m_hrs_norm>@m_hrs_prev begin select @m_hrs_norm=@m_hrs_prev; end;
if @m_hrs_norm > 0 begin EXEC AP_PTO003 @m_hrs_norm, @hrs_norm output; end;
END;
END;
if @id_hnormais > 0 begin
select @achou=0;
SELECT @achou=1, @metodo=metodo, @id_divassoc_nh=id_divassoc FROM tbHNormais WHERE id_hnormais=@id_hnormais;
if @achou=1 and @metodo=0 and @m_hrs_norm > 0 and isnull(@id_divassoc_nh,0)<>48 begin
exec AP_PTO018 @id_pass output, @data output, 44, @m_hrs_norm;
end;
end;
if @m_hrs_norm > 0 and @tipodia = 'V' begin
if EXISTS(SELECT feriado_normal FROM tbPHorarios WHERE id_phorario=@id_phorario AND feriado_normal=1)
or EXISTS(SELECT feriado_normal FROM tbFunc WHERE id_pass=@id_pass AND isnull(feriado_normal,0)=1 AND categoria=1 )
begin
exec AP_PTO018 @id_pass output, @data output, 75, @m_hrs_norm;
end;
end;
EXEC AP_PTO058 @id_empresa output, @id_pass output, @data output, @tipodia;
EXEC AP_PTO049 @id_empresa output, @id_pass output, @data output, @wdiapto;
if @id_dsr > 0 begin
EXEC AP_PTO028 @id_pass output,@data output,@id_dsr,@per_dsr,@fechamento_fim,@mes_ini,@mes_fim;
select @m_vlraux=0;
SELECT @m_vlraux=m_valor FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=50 AND lancado=0;
if @m_vlraux > 0 begin
exec AP_PTO030 @id_pass output,@data output, @id_arredonda, 1, 50,@m_vlraux;
end;
select @m_vlraux=0;
SELECT @m_vlraux=m_valor FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=51 AND lancado=0;
if @m_vlraux > 0 begin
exec AP_PTO030 @id_pass output,@data output, @id_arredonda, 1, 51, @m_vlraux;
end;
end;
if @id_hnormais > 0 begin
select @mes_hn=0;
select @mes_hn=@mes_fec;
if @mes_hn<4 begin
if day(dateadd(d,1,convert(datetime, '02/28/' + ltrim(str(@ano_fec)))))  = 29 begin
if isnull(@per_hn,0) = 1 begin
if dateadd(d,1,convert(datetime, '02/28/' + ltrim(str(@ano_fec)))) between @mes_ini and @mes_fim begin
select @mes_hn=13;
end;
end else begin
if dateadd(d,1,convert(datetime, '02/28/' + ltrim(str(@ano_fec)))) between @fechamento_ini and @fechamento_fim begin
select @mes_hn=13;
end;
end;
end;
end;
select @achou=0, @m_hn_mes=0, @hnorm_por_dia=0, @hnorm_diario=0;
SELECT @achou=1, @metodo=metodo, @abate_dia=abate_dia, @abate_dsr=abate_dsr, @id_divassoc_nh=id_divassoc, @m_hn_mes=ISNULL((CASE
WHEN @mes_hn=1 THEN m_hn_mes_01 WHEN @mes_hn=2 THEN m_hn_mes_02
WHEN @mes_hn=3 THEN m_hn_mes_03 WHEN @mes_hn=4 THEN m_hn_mes_04
WHEN @mes_hn=5 THEN m_hn_mes_05 WHEN @mes_hn=6 THEN m_hn_mes_06
WHEN @mes_hn=7 THEN m_hn_mes_07 WHEN @mes_hn=8 THEN m_hn_mes_08
WHEN @mes_hn=9 THEN m_hn_mes_09 WHEN @mes_hn=10 THEN m_hn_mes_10
WHEN @mes_hn=11 THEN m_hn_mes_11 WHEN @mes_hn=12 THEN m_hn_mes_12
WHEN @mes_hn=13 THEN m_hn_mes_13 ELSE 0 END),0),
@hnorm_por_dia=ISNULL((CASE
WHEN @mes_hn=1 THEN m_hn_dia_01 WHEN @mes_hn=2 THEN m_hn_dia_02
WHEN @mes_hn=3 THEN m_hn_dia_03 WHEN @mes_hn=4 THEN m_hn_dia_04
WHEN @mes_hn=5 THEN m_hn_dia_05 WHEN @mes_hn=6 THEN m_hn_dia_06
WHEN @mes_hn=7 THEN m_hn_dia_07 WHEN @mes_hn=8 THEN m_hn_dia_08
WHEN @mes_hn=9 THEN m_hn_dia_09 WHEN @mes_hn=10 THEN m_hn_dia_10
WHEN @mes_hn=11 THEN m_hn_dia_11 WHEN @mes_hn=12 THEN m_hn_dia_12
WHEN @mes_hn=13 THEN m_hn_dia_13 ELSE 0 END),0),
@hnorm_diario=ISNULL((CASE
WHEN @wdia=1 AND (@folga=0 or isnull(m_hn_dia_13,0)=1) THEN m_hn_dia_01
WHEN @wdia=2 AND (@folga=0 or isnull(m_hn_dia_13,0)=1) THEN m_hn_dia_02
WHEN @wdia=3 AND (@folga=0 or isnull(m_hn_dia_13,0)=1) THEN m_hn_dia_03
WHEN @wdia=4 AND (@folga=0 or isnull(m_hn_dia_13,0)=1) THEN m_hn_dia_04
WHEN @wdia=5 AND (@folga=0 or isnull(m_hn_dia_13,0)=1) THEN m_hn_dia_05
WHEN @wdia=6 AND (@folga=0 or isnull(m_hn_dia_13,0)=1) THEN m_hn_dia_06
WHEN @wdia=7 AND (@folga=0 or isnull(m_hn_dia_13,0)=1) THEN m_hn_dia_07 ELSE 0 END),0)
FROM tbHNormais WHERE id_hnormais=@id_hnormais;
if @m_hn_mes<0 begin select @m_hn_mes=0; end;
if isnull(@hnorm_por_dia,-1)<0 begin select @hnorm_por_dia=0; end; --metodo mensal
if isnull(@hnorm_diario,-1)<0 begin select @hnorm_diario=0 end; --metodo diario
select @dias_norm=0;
if @achou=1 begin
if (@metodo=1 or (@metodo=2 and @data=@fechamento_fim)) begin
select @m_vlraux=0, @m_vlraux2=0;
if @metodo=1 begin
if @hnorm_diario>0 and @tipodia<>'V' and @admissao=0 and @demissao=0 and @eve_calc_hn=0 begin
SELECT @m_vlraux=SUM(m_valor-m_abonado) FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data = @data AND id_diverg IN (SELECT tbHNDivs.id_diverg FROM tbHNDivs INNER JOIN tbDivergencias ON tbDivergencias.id_diverg = tbHNDivs.id_diverg AND tbDivergencias.soma = 1 WHERE tbHNDivs.id_hnormais=@id_hnormais);
SELECT @m_vlraux2=SUM(m_valor-m_abonado) FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data = @data AND id_diverg IN (SELECT tbHNDivs.id_diverg FROM tbHNDivs INNER JOIN tbDivergencias ON tbDivergencias.id_diverg = tbHNDivs.id_diverg AND tbDivergencias.soma = 0 WHERE tbHNDivs.id_hnormais=@id_hnormais);
SELECT @m_vlraux2=isnull(@m_vlraux2,0)+isnull(SUM((case when a.m_valor=599999 then d.m_abonado else a.m_valor end)),0) FROM tbPtoDivsDia d
INNER JOIN tbPtoAboDia a ON d.id_pass=a.id_pass AND a.data=d.data AND d.id_diverg = a.id_diverg
INNER JOIN tbEvsAbono v ON a.id_eveabo=v.id_eveabo AND v.calc_hn=1
WHERE d.id_pass = @id_pass AND d.data = @data;
if @abate_dia=0 begin
select @m_vlraux = (@hnorm_diario + isnull(@m_vlraux,0))-isnull(@m_vlraux2,0);
if @m_vlraux<0 begin select @m_vlraux=0; end;
end else begin
if isnull(@m_vlraux2,0) <= 0 or isnull(@m_vlraux,0) > 0 begin
select @m_vlraux=@hnorm_diario;
end else begin
select @m_vlraux=0;
end;
end;
select @m_hn_tmpdia=@hnorm_diario, @m_dhn_tmpdia=@m_vlraux-@hnorm_diario;
end;
if isnull(@per_hn,0) = 1 begin
select @m_vlraux=0;
if @data=@fechmesref_fim begin
SELECT @m_vlraux=SUM(isnull(m_hn_tmpdia,0)) FROM tbPtoApDia WHERE id_pass=@id_pass AND data>= @mes_ini AND data<= @mes_fim;
SELECT @m_vlraux2=SUM(isnull(m_dhn_tmpdia,0)) FROM tbPtoApDia WHERE id_pass=@id_pass AND data>= @fechmesref_ini AND data<= @fechmesref_fim;
select @m_vlraux=isnull(@m_vlraux,0)+isnull(@m_vlraux2,0); if @m_vlraux<0 begin select @m_vlraux=0; end;
end;
end;
end else begin
if @abate_dia=0 begin
SELECT @m_vlraux=SUM(m_valor-m_abonado) FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data >= @fechamento_ini and data <= @fechamento_fim AND id_diverg IN (SELECT tbHNDivs.id_diverg FROM tbHNDivs INNER JOIN tbDivergencias ON tbDivergencias.id_diverg = tbHNDivs.id_diverg AND tbDivergencias.soma = 1 WHERE tbHNDivs.id_hnormais=@id_hnormais);
SELECT @m_vlraux2=SUM(m_valor-m_abonado) FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data >= @fechamento_ini and data <= @fechamento_fim AND id_diverg IN (SELECT tbHNDivs.id_diverg FROM tbHNDivs INNER JOIN tbDivergencias ON tbDivergencias.id_diverg = tbHNDivs.id_diverg AND tbDivergencias.soma = 0 WHERE tbHNDivs.id_hnormais=@id_hnormais);
SELECT @m_vlraux2=isnull(@m_vlraux2,0)+isnull(SUM((case when a.m_valor=599999 then d.m_abonado else a.m_valor end)),0) FROM tbPtoDivsDia d
INNER JOIN tbPtoAboDia a ON d.id_pass=a.id_pass AND a.data=d.data AND d.id_diverg = a.id_diverg
INNER JOIN tbEvsAbono v ON a.id_eveabo=v.id_eveabo AND v.calc_hn=1
WHERE d.id_pass = @id_pass AND d.data >= @fechamento_ini and d.data <= @fechamento_fim;
select @m_vlraux = (@m_hn_mes + isnull(@m_vlraux,0))-isnull(@m_vlraux2,0);
end else begin
if @hnorm_por_dia>0 begin
SELECT @m_vlraux=COUNT(a.data) FROM tbPtoApDia a
WHERE a.id_pass=@id_pass AND a.data >= @fechamento_ini and a.data <= @fechamento_fim
AND EXISTS(
SELECT d.data FROM tbPtoDivsDia d WHERE d.id_pass=a.id_pass and d.data=a.data AND d.m_valor-d.m_abonado>0
AND d.id_diverg IN (SELECT tbHNDivs.id_diverg FROM tbHNDivs INNER JOIN tbDivergencias ON tbDivergencias.id_diverg = tbHNDivs.id_diverg AND tbDivergencias.soma = 1 WHERE tbHNDivs.id_hnormais=@id_hnormais)
);
SELECT @m_vlraux2=COUNT(a.data) FROM tbPtoApDia a
WHERE a.id_pass=@id_pass AND a.data >= @fechamento_ini and a.data <= @fechamento_fim
AND EXISTS(
SELECT d.data FROM tbPtoDivsDia d WHERE d.id_pass=a.id_pass and d.data=a.data AND d.m_valor-d.m_abonado>0
AND d.id_diverg IN (SELECT tbHNDivs.id_diverg FROM tbHNDivs INNER JOIN tbDivergencias ON tbDivergencias.id_diverg = tbHNDivs.id_diverg AND tbDivergencias.soma = 0 WHERE tbHNDivs.id_hnormais=@id_hnormais)
);
SELECT @m_vlraux2=isnull(@m_vlraux2,0)+isnull(COUNT(d.data),0) FROM tbPtoDivsDia d
WHERE d.id_pass = @id_pass AND d.data >= @fechamento_ini and d.data <= @fechamento_fim
AND (d.id_diverg NOT IN (SELECT tbHNDivs.id_diverg FROM tbHNDivs INNER JOIN tbDivergencias ON tbDivergencias.id_diverg = tbHNDivs.id_diverg AND tbDivergencias.soma = 0 WHERE tbHNDivs.id_hnormais=@id_hnormais)
OR d.m_valor-d.m_abonado<=0
) AND EXISTS (SELECT a.id_pass FROM tbPtoAboDia a INNER JOIN tbEvsAbono v ON a.id_eveabo=v.id_eveabo AND v.calc_hn=1
WHERE d.id_pass=a.id_pass AND a.data=d.data AND d.id_diverg = a.id_diverg
);
select @m_vlraux=(@m_hn_mes + (@hnorm_por_dia*isnull(@m_vlraux,0)))-(isnull(@m_vlraux2,0)*@hnorm_por_dia);
end else begin
select @m_vlraux=@m_hn_mes;
end;
end;
if @hnorm_por_dia>0 begin
select @m_vlraux2=0;
if isnull(@per_hn,0) = 0 begin
SELECT @m_vlraux2=isnull(COUNT(id_pass),0) FROM tbPtoDia WHERE id_pass = @id_pass AND data >= @fechamento_ini and data <= @fechamento_fim AND (admissao=1 or demissao=1);
end else begin
SELECT @m_vlraux2=isnull(COUNT(id_pass),0) FROM tbPtoDia WHERE id_pass = @id_pass AND data >= @mes_ini and data <= @mes_fim AND (admissao=1 or demissao=1);
end;
select @m_vlraux = @m_vlraux - (@m_vlraux2 * @hnorm_por_dia);
select @m_vlraux2=0;
if isnull(@per_hn,0) = 0 begin
SELECT @m_vlraux2=isnull(COUNT(d.id_pass),0) FROM tbPtoDia d INNER JOIN tbEvsAbono e ON d.id_eveafa=e.id_eveabo
WHERE d.id_pass = @id_pass AND d.data >= @fechamento_ini and d.data <= @fechamento_fim AND e.calc_hn=1
end else begin
SELECT @m_vlraux2=isnull(COUNT(d.id_pass),0) FROM tbPtoDia d INNER JOIN tbEvsAbono e ON d.id_eveafa=e.id_eveabo
WHERE d.id_pass = @id_pass AND d.data >= @mes_ini and d.data <= @mes_fim AND e.calc_hn=1
end;
select @m_vlraux = @m_vlraux - (@m_vlraux2 * @hnorm_por_dia);
end;
if isnull(@abate_dsr,0) = 1 and @m_vlraux>0 begin
select @m_vlraux2=0;
if isnull(@per_hn,0) = 1 begin
SELECT @m_vlraux2=SUM(m_valor-m_abonado) FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data >= @mes_ini and data <= @mes_fim AND id_diverg=50;
end else begin
SELECT @m_vlraux2=SUM(m_valor-m_abonado) FROM tbPtoDivsDia WHERE id_pass = @id_pass AND data >= @fechamento_ini and data <= @fechamento_fim AND id_diverg=50;
end;
if @m_vlraux2>=@m_vlraux begin
select @m_vlraux=0;
end else begin
select @m_vlraux=@m_vlraux-@m_vlraux2;
end;
end;
if @hnorm_por_dia>0 begin
select @dias_norm=round((convert(float,@m_vlraux)/convert(float,@hnorm_por_dia)),0)*60;
end;
end;
if @m_vlraux>0 and isnull(@id_divassoc_nh,0) <> 48 begin
exec AP_PTO018 @id_pass output, @data output, 44, @m_vlraux;
EXEC AP_PTO030 @id_pass output,@data output, @id_arredonda, 1, 44, @m_vlraux;
end;
end;
if @data = @fechamento_fim and isnull(@id_divassoc_nh,0) <> 44 begin
if @metodo<>2 begin
SELECT @dias_norm=COUNT(a.data) FROM tbPtoApDia a
WHERE a.id_pass=@id_pass AND a.data >= @fechamento_ini and a.data <= @fechamento_fim
AND a.m_hrs_norm>0;
select @dias_norm=@dias_norm*60;
end;
if @dias_norm>0 begin
exec AP_PTO018 @id_pass output, @data output, 48, @dias_norm;
exec AP_PTO030 @id_pass output,@data output, @id_arredonda, 1, 48, @dias_norm;
end;
end;
end;
end;
if @data>=@fechamento_fim begin
EXEC AP_PTO046 @id_pass, @fechamento_ini, @fechamento_fim;
end;
EXEC AP_PTO045 @id_pass output, @data output, @mes_fec, @ano_fec, @fechamento_ini, @fechamento_fim, @trabalhado, @falta, @m_hrs_trab;
if @fechamento_fim = @data begin
exec AP_PTO047 @id_pass output, @data output, @ano_fec, @mes_fec;
end;
EXEC AP_PTO057 @id_pass output, @data output, @dom_data, @sab_data, @fechamento_ini, @fechamento_fim;
if not exists(SELECT id_pass FROM tbPtoApDia WHERE id_pass = @id_pass AND data = @data) begin
INSERT INTO tbPtoApDia (id_pass, data, falta, hrs_norm, m_hrs_norm, hn_tot, m_hn_tot, trab_tot, m_trab_tot,m_hn_tmpdia,m_dhn_tmpdia)
VALUES (@id_pass, @data, @falta, @hrs_norm, @m_hrs_norm, @hn_tot, @m_hn_tot, @trab_tot, @m_trab_tot,@m_hn_tmpdia,@m_dhn_tmpdia);
end else begin
UPDATE tbPtoApDia SET id_pass=@id_pass, data=@data, falta=@falta, hrs_norm=@hrs_norm, m_hrs_norm=@m_hrs_norm,
hn_tot=@hn_tot, m_hn_tot=@m_hn_tot, trab_tot=@trab_tot, m_trab_tot=@m_trab_tot,m_hn_tmpdia=@m_hn_tmpdia,m_dhn_tmpdia=@m_dhn_tmpdia
WHERE id_pass = @id_pass AND data = @data;
end;
UPDATE tbPtoEnq SET fimper1=@fimper1,fimper2=@fimper2,fimper3=@fimper3,fimper4=@fimper4,iniflex=@iniflex,fimflex=@fimflex,
ult_he_ent=@ult_he_ent, pri_he_sai=@pri_he_sai, hrs_trab=@hrs_reais,m_hrs_trab=@m_hrs_reais
WHERE id_pass=@id_pass AND data=@data and original=@original;
UPDATE tbPtoEnq SET apontado=1 WHERE id_pass=@id_pass AND data=@data;
UPDATE tbPtoDia SET apontado=1 WHERE id_pass=@id_pass AND data=@data;
EXEC AP_PTO055 @id_pass output, @data output;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO032') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO032; END
GO
CREATE PROCEDURE dbo.AP_PTO032(@id_pass int, @data datetime, @apenas_dia bit = 0) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_empresa int; declare @fechamento_ini datetime; declare @fechamento_fim datetime;
declare @psi int; declare @id_phorario int; declare @id_tolera int; declare @mes_fim datetime; declare @mes_ini datetime; declare @mes_fec int; declare @ano_fec int;
declare @tolerancia_ini datetime; declare @tolerancia_fim datetime; declare @reproc_ultdia bit; declare @dtreproc datetime;
declare @banco_ini datetime; declare @banco_fim datetime; declare @ano_bco int; declare @mes_bco int;
declare @dom_data datetime;  declare @dtIni datetime; declare @dtFim datetime; declare @dtAtu datetime;
declare @id_dsr int; declare @dataBco datetime; declare @achou bit;
declare @dt_ini_cmp datetime, @dt_fim_cmp datetime; declare @ult_apt datetime;
declare @apura_tipo int; declare @desc_semavaliar int;  declare @desc_semdescontar int;
if not @id_pass is null and not @data is null begin
EXEC AP_PTO031 @id_pass output, @data output;
select @id_empresa=0;
SELECT @id_empresa=id_empresa FROM tbPass WHERE id_pass=@id_pass;
select @psi=(DATEPART(dw,@data)-1)*(-1);
select @dom_data = dateadd(d,@psi,@data);
select @mes_fec=0,@ano_fec=0, @reproc_ultdia=0;
SELECT @mes_fec=mes,@ano_fec=ano,@fechamento_ini=fechamento_ini, @fechamento_fim=fechamento_fim FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN fechamento_ini AND fechamento_fim;
SELECT @tolerancia_ini=tolerancia_ini, @tolerancia_fim=tolerancia_fim FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN tolerancia_ini AND tolerancia_fim;
if @fechamento_ini is null begin
select @psi=(day(@data)-1)*(-1);
select @fechamento_ini = dateadd(d,@psi,@data);
select @fechamento_fim = dateadd(d,-1,dateadd(m,1,@fechamento_ini));
select @mes_fim=@fechamento_fim,@mes_fec=month(@fechamento_ini),@ano_fec=year(@fechamento_ini);
end else begin
select @mes_fim=dateadd(d,-1,dateadd(m,1,CONVERT(datetime,right('00'+ltrim(str(@mes_fec)),2)+'/01/'+ltrim(str(@ano_fec)))));
end;
select @mes_ini=CONVERT(datetime,right('00'+ltrim(str(@mes_fec)),2)+'/01/'+ltrim(str(@ano_fec)));
if @tolerancia_ini is null begin
select @tolerancia_ini=@fechamento_ini;
select @tolerancia_fim=@fechamento_fim;
end;
if @apenas_dia=0 begin
select @id_dsr=0;
SELECT @id_dsr=isnull(id_dsr,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data;
if @id_dsr>0 begin
SELECT TOP 1 @desc_semavaliar=isnull(desc_semavaliar,0), @desc_semdescontar=isnull(desc_semdescontar,0) FROM tbDSR WHERE id_dsr=@id_dsr;
if isnull(@desc_semavaliar,0)=1 and DATEPART(dw,@data)=1 begin
select @dtIni=dateadd(d,-7,@dom_data)
end else begin
select @dtIni=@dom_data;
end;
if @desc_semdescontar=1 begin
select @dtFim=dateadd(d,14,@dtIni);
end else begin
select @dtFim=dateadd(d,7,@dtIni);
end;
end;
end;
select @id_tolera=0;
SELECT @id_tolera=isnull(id_tolera,0) FROM tbPtoDia WHERE id_pass = @id_pass AND data = @data AND flexivel = 0;
if @id_tolera>0 begin
if EXISTS( SELECT id_tolera FROM tbTolera WHERE id_tolera = @id_tolera AND  (
isnull(m_desc_soma_sem,0)>0 OR isnull(desc_soma_qsem,0)>0 OR isnull(m_acre_soma_sem,0)>0 OR isnull(acre_soma_qsem,0)>0
)) begin
if @dom_data<=isnull(@dtIni,dateadd(d,6,@dom_data)) begin select @dtIni = @dom_data; end;
if dateadd(d,6,@dom_data)>=isnull(@dtFim,@data) begin select @dtFim=dateadd(d,6,@dom_data); end;
end;
if @apenas_dia=0 begin
if EXISTS( SELECT id_tolera FROM tbTolera WHERE id_tolera = @id_tolera AND  (
isnull(m_desc_soma_mes,0)>0 OR isnull(desc_soma_qmes,0)>0 OR isnull(m_acre_soma_mes,0)>0 OR isnull(acre_soma_qmes,0)>0
)) begin
if @tolerancia_ini<=isnull(@dtIni,@tolerancia_ini) begin select @dtIni=@tolerancia_ini; end;
if @tolerancia_fim>=isnull(@dtFim,@tolerancia_fim) begin select @dtFim=@tolerancia_fim; end;
end;
end;
end;
if  @mes_fim>@fechamento_fim begin
if exists(SELECT d.id_hnormais FROM tbPtoDia d INNER JOIN tbHNormais h ON d.id_hnormais=h.id_hnormais and isnull(h.per_hn,0)=1 WHERE d.id_pass=@id_pass AND d.data=@data)
or exists(SELECT d.id_dsr FROM tbPtoDia d INNER JOIN tbDSR h ON d.id_dsr=h.id_dsr and isnull(h.per_dsr,0)=1 WHERE d.id_pass=@id_pass AND d.data=@data) begin
if @data=@fechamento_fim begin
select @reproc_ultdia=1;
if dateadd(d,1,@data) <= isnull(@dtIni,dateadd(d,1,@data))begin select @dtIni=dateadd(d,1,@data); end;
if @mes_fim>=isnull(@dtFim,@mes_fim) begin select @dtFim=@mes_fim; end;
end else begin if @apenas_dia=0 begin
select @dtreproc=dateadd(d,-1,@fechamento_ini);
if @data<@mes_ini and isnull(@dtIni,@mes_ini)>@dtreproc begin
EXEC AP_PTO031 @id_pass output, @dtreproc output;
end;
end; end;
end;
end;
if @apenas_dia=0 begin
select @achou=0;
SELECT TOP 1 @achou=1, @dt_fim_cmp=dt_fim_cmp, @dt_ini_cmp=(CASE WHEN dt_ini_cmp<data THEN dt_ini_cmp ELSE data END)
FROM tbPtoCp
WHERE id_pass=@id_pass AND @data BETWEEN (CASE WHEN dt_ini_cmp<data THEN dt_ini_cmp ELSE data END) AND dt_fim_cmp
ORDER BY dt_fim_cmp DESC;
if @achou=1 begin
if @dtIni is null begin
select @dtIni=@dt_ini_cmp;
end;
if @dtIni >= @dt_ini_cmp begin
select @dtIni=@dt_ini_cmp;
end;
if isnull(@dtFim,'01/01/2000') < @dt_fim_cmp begin
select @dtFim=@dt_fim_cmp;
if isnull(@fechamento_fim,@dtFim) < @dtFim begin
select @dtFim=@fechamento_fim;
end;
end;
end;
end;
if @dtIni is null begin
SELECT @id_phorario=id_phorario FROM tbPtoDia WHERE id_pass=@id_pass AND data=@data;
if NOT @id_phorario IS NULL begin
select @apura_tipo=0
SELECT @apura_tipo=isnull(apura_tipo,0) FROM tbPHorFlex WHERE id_pflex=@id_phorario;
if @apura_tipo>0 begin
select @dtIni = @dom_data;
select @dtFim=dateadd(d,6,@dom_data);
end;
end;
end;
if not @dtIni is null and not @dtFim is null begin
select @dtAtu=@dtIni;
while @dtAtu<=@dtFim begin
if @dtAtu>=@dom_data begin
EXEC AP_PTO031 @id_pass output, @dtAtu output;
end else begin
if DATEPART(dw,@dtAtu)=1 OR
EXISTS(SELECT id_pass from tbPtoDia WHERE id_pass=@id_pass AND data=@dtAtu AND (folga=1 or isnull(desc_feriado,'') <> '')) or
EXISTS(SELECT id_pass FROM tbPtoDscDia WHERE id_pass=@id_pass AND data=@dtAtu) or
EXISTS(SELECT id_pass FROM tbPtoAcrDia WHERE id_pass=@id_pass AND data=@dtAtu) begin
EXEC AP_PTO031 @id_pass output, @dtAtu output;
end;
end;
select @dtAtu=DATEADD(d,1,@dtAtu);
end;
end;
if @reproc_ultdia=1 or (@apenas_dia=0 and @data < @fechamento_fim and @fechamento_fim >= isnull(@dtFim,@data)) begin
EXEC AP_PTO031 @id_pass output, @fechamento_fim output;
end;
SELECT @ano_bco=isnull(ano,0), @mes_bco=isnull(mes,0), @banco_ini=banco_ini, @banco_fim=banco_fim
FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN banco_ini AND banco_fim;
if @apenas_dia=0 or (not @banco_fim is null and @data=@banco_fim) begin
if @banco_ini is null or @banco_fim is null begin
select @ano_bco=0, @mes_bco=0;
end;
EXEC AP_PTO029 @id_pass output, @data output, @banco_ini, @banco_fim, @ano_bco, @mes_bco;
if not @banco_fim is null and EXISTS(SELECT banco FROM tbFunc WHERE id_pass=@id_pass AND banco=1) begin
EXEC AP_PTO031 @id_pass output, @banco_fim output;
end;
select @achou=1, @dataBco=@data;
while (@achou=1) begin
select @achou=0;
SELECT TOP 1 @achou=1,
@ano_bco=isnull(ano,0), @mes_bco=isnull(mes,0), @banco_ini=banco_ini, @banco_fim=banco_fim, @dataBco=banco_fim
FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND banco_ini>@dataBco AND banco_ini<=getdate() ORDER BY banco_ini;
if @achou=1 begin
EXEC AP_PTO029 @id_pass output, @dataBco output, @banco_ini, @banco_fim, @ano_bco, @mes_bco;
EXEC AP_PTO031 @id_pass output, @dataBco output;
end;
end;
end;
if @data < dateadd(d,-2,Convert(datetime,Convert(varchar,Getdate(),101))) begin
select @ult_apt=null;
SELECT @ult_apt=ult_apt FROM tbFunc WHERE id_pass=@id_pass;
if not @ult_apt is null begin
if (@ult_apt = dateadd(d,-1,@data)) or (@ult_apt>getdate()) begin
UPDATE tbFunc SET ult_apt=@data WHERE id_pass=id_pass;
end;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO033') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO033; END;
GO
CREATE PROCEDURE dbo.AP_PTO033(@id_pass int, @dtRef datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @ano_ini int; declare @mes_ini int declare @ano_fim int; declare @mes_fim int
declare @ano int;     declare @mes int;
declare @id_empresa int; declare @id_tabbco int;
declare @achou bit; declare @banco_fim datetime;
select @id_tabbco=0;
SELECT @id_empresa=isnull(p.id_empresa,0), @id_tabbco=isnull((CASE WHEN f.banco=1 THEN f.id_tabbco ELSE 0 END),0) FROM tbPass p
INNER JOIN tbFunc f ON p.id_pass = f.id_pass WHERE p.id_pass = @id_pass;
SELECT TOP 1 @id_tabbco=id_tabbco FROM tbPtoDia WHERE id_pass=@id_pass AND data=@dtRef;
if isnull(@id_tabbco,0) > 0 begin
select @achou=0, @ano_ini=0, @mes_ini=0;
SELECT @achou=1, @ano_ini=ano, @mes_ini=mes FROM tbPerEmpresas
WHERE id_empresa=@id_empresa AND @dtRef BETWEEN banco_ini AND banco_fim
if @achou=1 begin
select @achou=0, @ano_fim=0, @mes_fim=0;
SELECT @achou=1, @ano_fim=isnull(ano,0), @mes_fim=isnull(mes,0) FROM tbPerEmpresas
WHERE id_empresa=@id_empresa AND convert(datetime,convert(varchar,getdate(),101)) BETWEEN banco_ini AND banco_fim
if @achou=0 or @ano_fim*100+@mes_fim < @ano_ini*100+@mes_ini begin
select @ano_fim = @ano_ini;
select @mes_fim = @mes_ini;
end;
select @ano = @ano_ini;
while @ano <= @ano_fim begin
select @mes = 1;
while @mes <= 12 begin
if (@ano <> @ano_ini Or @mes >= @mes_ini) And (@ano <> @ano_fim Or @mes <= @mes_fim) begin
select @achou=0;
SELECT @achou=1, @banco_fim=banco_fim FROM tbPerEmpresas WHERE id_empresa = @id_empresa AND ano=@ano AND mes=@mes
if @achou=1 begin EXEC AP_PTO032 @id_pass, @banco_fim, 0 end;
end;
select @mes=@mes+1;
end;
select @ano=@ano+1;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO034') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO034; END;
GO
CREATE PROCEDURE dbo.AP_PTO034(@id_pass int, @data datetime, @id_diverg int,  @id_eveabo int, @m_valor int, @cod_cid varchar(10), @id_usuario int, @str_obs varchar(30) = null) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @valor varchar(7); declare @contadia smallint; declare @achou bit; declare @gerado bit;
if not @id_pass is null and not @data is null begin
select @achou=0;
SELECT @achou=1, @gerado=gerado FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND id_diverg=@id_diverg AND id_eveabo=@id_eveabo
if EXISTS(SELECT calculo FROM tbEvsAbono WHERE id_eveabo = @id_eveabo AND calculo=0) begin
select @m_valor=0;
end;
EXEC AP_PTO003 @m_valor, @valor output;
if @achou=1 begin
if @gerado=0 begin
UPDATE tbPtoAboDia SET m_valor = @m_valor, valor=@valor, cid=@cod_cid, id_usuario=@id_usuario, obs=@str_obs
WHERE id_pass=@id_pass AND data=@data AND id_diverg = @id_diverg AND id_eveabo = @id_eveabo;
end;
end else begin
SELECT @contadia=0;
SELECT @contadia=isnull(MAX(contadia),0) FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data
SELECT @contadia=@contadia+1;
INSERT INTO tbPtoAboDia (id_pass, data, id_diverg, id_eveabo, contadia, gerado, valor, m_valor, cid, id_usuario, obs)
VALUES (@id_pass, @data, @id_diverg, @id_eveabo, @contadia, 0, @valor, @m_valor, @cod_cid, @id_usuario, @str_obs);
end;
if len(ltrim(isnull(@cod_cid,''))) > 0 begin
UPDATE tbPtoAboDia SET cid=@cod_cid WHERE id_pass=@id_pass AND data=@data;
end;
EXEC AP_PTO017 @id_pass output, @data output, @id_diverg;
EXEC AP_PTO032 @id_pass, @data, 0;
EXEC AP_PTO033 @id_pass, @data;
end;
END;
GO
IF EXISTS (SELECT name FROM sysobjects WHERE id = OBJECT_ID(N'dbo.ENQUADRA_TRG_PTO') AND type = 'TR') BEGIN DROP TRIGGER dbo.ENQUADRA_TRG_PTO; END;
GO
CREATE TRIGGER dbo.ENQUADRA_TRG_PTO ON tbMovim WITH ENCRYPTION AFTER INSERT  AS
BEGIN
SET NOCOUNT ON
SET LANGUAGE English
declare @marc datetime; declare @funcao tinyint; declare @id_pass int;
declare @evento tinyint; declare @ponto tinyint;
declare @data datetime;
SELECT @marc=data, @id_pass=id_pass, @evento=evento, @funcao=funcao,@ponto=ponto FROM inserted;
if isnull(@ponto,0) > 0 begin
if not exists(SELECT flagimpedimento FROM tbEventoSist WHERE id_evento = @evento AND flagimpedimento=1) begin
select @funcao = isnull(@funcao,0);
EXEC AP_PTO016 @id_pass, @marc, @funcao, @ponto, 0;
select @data = convert(datetime,convert(varchar,@marc,101));
EXEC AP_PTO031 @id_pass output, @data output;
UPDATE tbPtoDia SET apontado=0 WHERE id_pass=@id_pass AND data=@data;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_INFO_BLOQ') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.P_INFO_BLOQ; END;
GO
CREATE PROCEDURE dbo.P_INFO_BLOQ(@id_bloq int, @descricao varchar(100), @tipo_info tinyint, @valor int, @desc_valor varchar(100), @reset bit, @m_persiste int, @m_validade int) WITH ENCRYPTION AS
BEGIN
declare @acao tinyint, @dt_persiste datetime, @data datetime, @dt_validade datetime, @valoratu int, @dataatu datetime, @dt_peratu datetime, @dt_valatu datetime;
select @data=getdate(), @dt_persiste=@data, @dt_validade=null, @descricao=isnull(@descricao,''), @desc_valor=isnull(@desc_valor,'');
if @tipo_info=0 begin
select @descricao='Status';
if @desc_valor='' begin
if @valor=1 begin select @desc_valor='Sem comunicao!'; end;
if @valor=2 begin select @desc_valor='Ativo';       end;
if @valor=3 begin select @desc_valor='Transmitindo'; end;
if @valor=4 begin select @desc_valor='Recebendo';   end;
if @valor=5 begin select @desc_valor='Aberto';      end;
if @valor=6 begin select @desc_valor='Emergncia';  end;
if @valor=7 begin select @desc_valor='Pouco papel'; end;
if @valor=8 begin select @desc_valor='Sem papel';   end;
if @valor=9 begin select @desc_valor='Com alerta';      end;
if @desc_valor='' begin
select @valor=0,@desc_valor='Sem informao';
end;
end;
end;
if @m_persiste>0 begin select @dt_persiste=DateAdd(mi,@m_persiste,@data); end;
if @m_validade>0 begin select @dt_validade=DateAdd(mi,@m_validade,@data); end;
DELETE FROM tbInfoBloq WHERE id_bloq=@id_bloq AND dt_validade < GETDATE();
select @acao=1;
SELECT @acao=0, @valoratu=valor, @dataatu=data, @dt_peratu=dt_persiste, @dt_valatu=dt_validade FROM tbInfoBloq WHERE id_bloq=@id_bloq AND descricao=@descricao;
if @acao=0 begin
if @reset=1 begin
select @acao=2;
end else if @valoratu=@valor begin
select @acao=2, @data=@dataatu;
end else if @dt_peratu<=@data or isnull(@dt_valatu,@data)<@data begin
select @acao=2;
end;
end;
if @acao=1 begin
--Inserir info
INSERT INTO tbInfoBloq (id_bloq, descricao, tipo_info, valor, desc_valor, dt_persiste, data, dt_validade)
VALUES (@id_bloq, @descricao, @tipo_info, @valor, @desc_valor, @dt_persiste, @data, @dt_validade);
end else if @acao=2 begin
--Alterar info
UPDATE tbInfoBloq
SET id_bloq=@id_bloq, descricao=@descricao, tipo_info=@tipo_info, valor=@valor, desc_valor=@desc_valor,
dt_persiste=@dt_persiste, data=@data, dt_validade=@dt_validade
WHERE id_bloq=@id_bloq AND descricao=@descricao;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.REL_VISI_FREQ') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.REL_VISI_FREQ; END;
GO
CREATE PROCEDURE dbo.REL_VISI_FREQ(@id_empresa FLOAT, @dl FLOAT, @hl INTEGER, @df FLOAT, @hf INTEGER, @QtdMin INTEGER) WITH ENCRYPTION AS
BEGIN
select v.id_pass, p.id_empresa, e.descricao, count(m.data) as Acesso, p.nome, v.doc_rg, v.doc_cic, v.doc_outros
from tbVisi v
inner join tbPass p on v.id_pass = p.id_pass
inner join tbMovim m on m.id_pass = v.id_pass and m.status = 0 and evento in (select id_evento from tbEventoSist where flagimpedimento = 0)
and (m.id_empresa = @id_empresa or @id_empresa = 0)
and convert(FLOAT,convert(varchar,m.data,112)) >= @dl AND convert(FLOAT,convert(varchar,m.data,112)) <= @df
and convert(integer,replace(left(convert(varchar,m.hora,114),5),':','')) >= @hl AND convert(integer,replace(left(convert(varchar,m.hora,114),5),':','')) <= @hf
left join tbEmpresas e on p.id_empresa = e.id_empresa
group by v.id_pass, p.id_empresa, e.descricao, p.nome, v.doc_rg, v.doc_cic, v.doc_outros having count(m.data) >= @QtdMin
union all
select v.id_pass, p.id_empresa, e.descricao, count(m.data) as Acesso, p.nome, v.doc_rg, v.doc_cic, v.doc_outros
from tbVisi v
inner join tbVisiBai p on v.id_pass = p.id_pass
inner join tbMovim m on m.id_pass = v.id_pass and m.status = 0 and evento in (select id_evento from tbEventoSist where flagimpedimento = 0)
and (m.id_empresa = @id_empresa or @id_empresa = 0)
and convert(FLOAT,convert(varchar,m.data,112)) >= @dl AND convert(FLOAT,convert(varchar,m.data,112)) <= @df
and convert(integer,replace(left(convert(varchar,m.hora,114),5),':','')) >= @hl AND convert(integer,replace(left(convert(varchar,m.hora,114),5),':','')) <= @hf
left join tbEmpresas e on p.id_empresa = e.id_empresa
group by v.id_pass, p.id_empresa, e.descricao, p.nome, v.doc_rg, v.doc_cic, v.doc_outros having count(m.data) >= @QtdMin
order by descricao, Acesso desc, p.nome;
END
GO
IF EXISTS(SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'dbo.REL_ESCALAS') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.REL_ESCALAS; END
GO
CREATE PROCEDURE dbo.REL_ESCALAS(@id_empresa float, @mes integer, @ano integer) WITH ENCRYPTION AS
BEGIN
declare @l_DataIni datetime; declare @l_DataFim datetime
select @mes = isnull(@mes,month(getdate()));
select @ano = isnull(@ano,year(getdate()));
select @l_DataIni = convert(datetime,right('00'+ltrim(str(@mes)),2)+'/01/'+right('0000'+ltrim(str(@ano)),4)+' 00:00:00');
select @l_DataFim = dateadd(s,-1,dateadd(m,1,@l_DataIni));
select tbEscalas.id_empresa, tbEmpresas.descricao as razao, tbEscalas.id_escala, tbEscalas.descricao, tbEscalas.id_horario,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 1 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 1 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia1,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 2 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 2 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia2,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 3 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 3 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia3,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 4 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 4 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia4,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 5 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 5 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia5,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 6 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 6 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia6,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 7 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 7 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia7,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 8 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 8 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia8,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 9 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 9 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia9,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 10 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 10 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia10,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 11 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 11 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia11,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 12 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 12 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia12,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 13 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 13 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia13,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 14 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 14 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia14,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 15 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 15 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia15,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 16 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 16 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia16,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 17 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 17 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia17,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 18 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 18 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia18,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 19 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 19 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia19,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 20 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 20 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia20,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 21 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 21 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia21,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 22 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 22 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia22,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 23 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 23 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia23,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 24 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 24 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia24,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 25 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 25 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia25,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 26 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 26 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia26,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 27 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 27 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia27,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 28 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 28 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia28,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 29 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 29 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia29,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 30 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 30 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia30,
case when (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 31 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then (select tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalas.id_horario)
else (select top 1 case when tbEscalasHorarios.folga = 1 then 'F' else (SELECT tbHorarios.codigo from tbHorarios tbHorarios where tbHorarios.id_horario = tbEscalasHorarios.id_horario) end from tbEscalasHorarios tbEscalasHorarios
where day(tbEscalasHorarios.data) = 31 and tbEscalas.id_escala = tbEscalasHorarios.id_escala and tbEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia31
from tbEscalas tbEscalas, tbEmpresas tbEmpresas
where (tbEscalas.id_empresa = @id_empresa or tbEscalas.geral = 1)
and tbEmpresas.id_empresa = @id_empresa
END
GO
IF EXISTS(SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'dbo.REL_ESCALAS_PTO') AND xtype = 'P') BEGIN  DROP PROCEDURE dbo.REL_ESCALAS_PTO; END
GO
CREATE PROCEDURE dbo.REL_ESCALAS_PTO(@mes integer, @ano integer, @ids varchar(3000)) WITH ENCRYPTION AS
BEGIN
declare @l_DataIni datetime; declare @l_DataFim datetime
select @mes = isnull(@mes,month(getdate()));
select @ano = isnull(@ano,year(getdate()));
select @l_DataIni = convert(datetime,right('00'+ltrim(str(@mes)),2)+'/01/'+right('0000'+ltrim(str(@ano)),4)+' 00:00:00');
select @l_DataFim = dateadd(s,-1,dateadd(m,1,@l_DataIni));
select tbPEscalas.id_empresa, tbEmpresas.descricao as razao, tbPEscalas.id_pescala, tbPEscalas.descricao, tbPEscalas.id_phorario,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 1 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 1 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia1,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 2 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 2 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia2,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 3 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 3 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia3,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 4 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 4 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia4,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 5 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 5 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia5,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 6 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 6 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia6,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 7 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 7 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia7,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 8 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 8 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia8,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 9 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 9 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia9,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 10 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 10 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia10,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 11 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 11 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia11,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 12 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 12 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia12,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 13 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 13 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia13,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 14 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 14 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia14,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 15 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 15 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia15,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 16 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 16 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia16,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 17 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 17 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia17,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 18 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 18 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia18,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 19 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 19 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia19,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 20 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 20 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia20,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 21 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 21 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia21,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 22 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 22 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia22,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 23 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 23 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia23,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 24 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 24 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia24,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 25 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 25 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia25,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 26 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 26 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia26,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 27 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 27 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia27,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 28 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 28 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia28,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 29 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 29 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia29,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 30 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 30 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia30,
case when (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 31 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim) is null
then 'T'
else (select top 1 case when tbPEscalasHorarios.folga = 1 then 'F' else 'T' end from tbPEscalasHorarios tbPEscalasHorarios
where day(tbPEscalasHorarios.data) = 31 and tbPEscalas.id_pescala = tbPEscalasHorarios.id_pescala and tbPEscalasHorarios.data between @l_DataIni and @l_DataFim)
end as dia31
from tbPEscalas tbPEscalas
inner join tbPGHorarios g on tbPEscalas.id_pescala=g.id_phorario
left join tbEmpresas tbEmpresas ON tbEmpresas.id_empresa = tbPEscalas.id_empresa
where (len(ltrim(isnull(@ids,'')))=0
or CHARINDEX('#'+rtrim(ltrim(convert(varchar,tbPEscalas.id_pescala)))+'#',@ids)>0
) and isnull(g.inativo,0)=0
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_CONSIST_ITV') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.P_CONSIST_ITV; END;
GO
CREATE PROCEDURE dbo.P_CONSIST_ITV(@id_pass int, @marc datetime, @stat_atu int, @id_bloq int, @rst int output) WITH ENCRYPTION AS
BEGIN
declare @tb_itv TABLE(idItv int IDENTITY(1,1), dtmarc datetime, refeit bit, relogio int, status tinyint);
declare @psi int; declare @numregs int;
declare @apenas_data datetime; declare @minutos int;
declare @id_horario int; declare @id_escala int; declare @id_gbloq int; declare @primario bit;
declare @itv_fxi char(5); declare @itv_fxf char(5); declare @itv_min char(5); declare @itv_max char(5);
declare @m_itv_fxi int; declare @m_itv_fxf int; declare @m_itv_min int; declare @m_itv_max int;
declare @achou bit;
declare @dtmarc datetime; declare @min_ant int; declare @min int; declare @gprim_ant bit;
declare @refeit bit; declare @relogio int; declare @status tinyint; declare @status_ant tinyint;
declare @valida_itv bit; declare @bloq_itv bit;
declare @tot_itv int; declare @gprim bit;
SET NOCOUNT ON;
select @rst=99;
select @id_gbloq=0,@primario=0, @achou=0;
if isnull(@id_bloq,0) > 0 begin
SELECT top 1 @achou=1, @id_gbloq=g.id_gbloq, @primario=g.primario, @valida_itv=valida_itv,@bloq_itv=bloq_itv FROM tbGBloq g INNER JOIN tbBloq b ON g.id_gbloq = b.id_gbloq AND b.id_bloq=@id_bloq;
if @achou=1 and isnull(@valida_itv,0) = 1 begin
select @rst=0;
end;
end;
if @rst=0 begin
select @apenas_data = convert(datetime,convert(varchar,isnull(@marc,'00:00:00'),101));
exec AP_PTO001 @marc, @minutos output;
select @id_horario=0,@m_itv_fxi=-1,@m_itv_fxf=-1,@m_itv_min=-1,@m_itv_max=-1;
SELECT @id_horario=id_horario FROM tbPass WHERE id_pass=@id_pass; select @id_horario=isnull(@id_horario,0);
select @achou=0;
SELECT @achou=1 from tbGHorarios where id_horario = @id_horario and escala = 1;
if @achou = 1 begin
select @id_escala = @id_horario;
select @achou = 0;
SELECT @achou = 1, @id_horario = (case when folga = 1 then -1 else id_horario end) from tbEscalasHorarios where id_escala = @id_escala and data=@apenas_data;
if @achou = 0 begin
select @achou = 0;
SELECT @achou = 1, @id_horario = id_horario from tbEscalas where id_escala = @id_escala;
if @achou = 0 begin select @id_horario = -1; end
end
end
if @id_horario>0 begin
SELECT @itv_fxi=itv_fxi, @itv_fxf=itv_fxf, @itv_min=itv_min, @itv_max=itv_max FROM tbHorarios WHERE id_horario=@id_horario;
if isnull(@itv_fxi,'__:__')<>'__:__' begin
select @m_itv_fxi = (convert(float,left(@itv_fxi,2))*60) + convert(float,right(@itv_fxi,2));
select @m_itv_fxf = (convert(float,left(@itv_fxf,2))*60) + convert(float,right(@itv_fxf,2));
if isnull(@itv_min,'__:__')<>'__:__' begin
select @m_itv_min = (convert(float,left(@itv_min,2))*60) + convert(float,right(@itv_min,2));
end;
if isnull(@itv_max,'__:__')<>'__:__' begin
select @m_itv_max = (convert(float,left(@itv_max,2))*60) + convert(float,right(@itv_max,2));
end;
end;
end;
if @m_itv_fxi>-1 begin
if @bloq_itv=1 and (@minutos < @m_itv_fxi or @minutos > @m_itv_fxf) begin
select @rst=1;
end else begin if @minutos >= @m_itv_fxi begin
INSERT @tb_itv (dtmarc, refeit, relogio, status)
SELECT m.data AS dtmarc, 0, m.relogio, m.status AS stat FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento=0
INNER JOIN tbBloq b ON m.relogio = b.id_bloq
INNER JOIN tbGBloq g ON b.id_gbloq = g.id_gbloq AND isnull(g.valida_itv,0)=1
WHERE m.id_pass=@id_pass AND m.data >= @apenas_data AND m.data <= @marc
UNION ALL SELECT r.data AS dtmarc, 1, r.relogio, r.status AS stat FROM tbMRefeit r WITH (NOLOCK)
INNER JOIN tbEventoSist e2 ON r.evento = e2.id_evento AND e2.flagimpedimento=0
INNER JOIN tbBloq b2 ON r.relogio = b2.id_bloq
INNER JOIN tbGBloq g2 ON b2.id_gbloq = g2.id_gbloq AND isnull(g2.valida_itv,0)=1
WHERE r.id_pass=@id_pass AND r.data >= @apenas_data AND r.data <= @marc
ORDER BY dtmarc, stat;
select @tot_itv=0, @gprim_ant=0, @status_ant=2, @psi=0, @numregs=0, @min_ant=-1;
SELECT @numregs=isnull(max(idItv),0) FROM @tb_itv;
while @psi<@numregs begin
select @psi=@psi+1, @achou=0;
SELECT @achou=1,@dtmarc=dtmarc,@refeit=refeit,@relogio=relogio,@status=status FROM @tb_itv WHERE idItv=@psi;
if @achou=1 begin
select @achou=0;
SELECT @achou=1,@valida_itv=g.valida_itv,@bloq_itv=g.bloq_itv, @gprim=g.primario FROM tbGBloq g
INNER JOIN tbBloq b ON g.id_gbloq=b.id_gbloq WHERE b.id_bloq=@relogio;
if @achou=1 begin
exec AP_PTO001 @dtmarc, @min output;
if @min>=@min_ant and @min_ant>-1 and ((@min>=@m_itv_fxi and @min <=@m_itv_fxf) or
(@min_ant>=@m_itv_fxi and @min_ant <=@m_itv_fxf) or
(@min_ant<@m_itv_fxi and @min>@m_itv_fxf)) begin
if (@gprim=1 and @gprim_ant=1 and @status_ant=1 and @status=0) or (@gprim=0 and @gprim_ant=0 and @status_ant=0 and @status=1) begin
select @tot_itv=@tot_itv+(@min-@min_ant);
end;
end;
select @min_ant=@min,@gprim_ant=@gprim,@status_ant=@status;
end;
end;
end;
if @min_ant>-1 and @minutos>=@min_ant and ((@minutos>=@m_itv_fxi and @minutos <=@m_itv_fxf) or
(@min_ant>=@m_itv_fxi and @min_ant <=@m_itv_fxf) or
(@min_ant<@m_itv_fxi and @minutos>@m_itv_fxf)) begin
if (@primario=1 and @gprim_ant=1 and @status_ant=1 and @stat_atu=0)
or (@primario=0 and @gprim_ant=0 and @status_ant=0 and @stat_atu=1) begin
select @tot_itv=@tot_itv+(@minutos-@min_ant);
if @m_itv_min>-1 and @tot_itv<@m_itv_min and ((@primario=1 and @stat_atu=0) or (@primario=0 and @stat_atu=1)) begin
SELECT @rst=2;
end else begin
if @m_itv_max>-1 and @tot_itv>@m_itv_max begin SELECT @rst=3; end;
end;
end else begin if (@minutos>=@m_itv_fxi and @minutos <=@m_itv_fxf) and ((@primario=1 and @stat_atu=1) or (@primario=0 and @stat_atu=0)) begin
if @m_itv_max>-1 and @tot_itv>=@m_itv_max begin SELECT @rst=3; end;
end; end;
end;
end; end;
end;
end; -- @rst=0
if @rst=99 begin
select @rst=0;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_ACESSO_AUTORIZADO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.P_ACESSO_AUTORIZADO END;
GO
CREATE PROCEDURE dbo.P_ACESSO_AUTORIZADO(@id_pass int, @id_gbloq int, @data_hora_atual datetime, @TemAutorizacaoAcesso int output) WITH ENCRYPTION AS
BEGIN
SELECT @TemAutorizacaoAcesso = ISNULL(@TemAutorizacaoAcesso,0);
IF @TemAutorizacaoAcesso = 0  --Vai fazer o select 1 vez por passante: 0 => Fazer select, 1 => Tem Autorizao, 2 => No tem autorizao
BEGIN
SELECT @TemAutorizacaoAcesso = 2;
SELECT @TemAutorizacaoAcesso = 1 FROM tbLibAcesso
WHERE id_pass = @id_pass
AND @data_hora_atual between data and dataf
AND patindex('%'+right('000'+rtrim(ltrim(convert(char(3),@id_gbloq))),3)+'*%',isnull(grupo,'')) > 0
END;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.INSERE_CDREFEITORIO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.INSERE_CDREFEITORIO; END
GO
CREATE PROCEDURE dbo.INSERE_CDREFEITORIO(@id_pass int, @id_refeit int, @quantidade integer, @dtvalidade datetime, @id_usuario int, @origem int, @id_cxcredref int, @ano_hcxcr int, @id_hcxcr int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @retorna integer;
declare @descricao varchar(50);
declare @achou bit;
declare @vlunitario float;
declare @id_empresa int;
declare @dtlancado datetime;
declare @saldo int;
select @retorna = 0;
select @descricao = 'Crditos lanados';
select @vlunitario = 0;
select @id_empresa = 0;
--Achar valor unitrio da refeio
Select @achou = 0;
Select top 1 @achou = 1, @vlunitario = convert(float,replace(isnull(valor,'0'),',','.')) from tbRefeit where id_refeit = @id_refeit;
if @achou = 0 begin
select @retorna = 1;
select @descricao = 'Categoria de refeio no localizada';
end;
--Achar empresa do passante
if @retorna = 0
begin
Select @achou = 0;
Select top 1 @achou = 1, @id_empresa = id_empresa from tbPass where id_pass = @id_pass;
if @achou = 0 begin
select @retorna = 2;
select @descricao = 'Passante no localizado';
end;
end;
--Achar usurio
if @retorna = 0
begin
if not exists(Select top 1 id_usuario from tbUsuarios where id_usuario = @id_usuario) begin
select @retorna = 3;
select @descricao = 'Usurio no localizado';
end;
end;
--Verificar data de validade
if @retorna = 0
begin
select @dtlancado = getdate();
select @dtlancado = convert(datetime,convert(varchar,@dtlancado,101) + ' ' + convert(varchar,@dtlancado,108));
if (not @dtvalidade is null) and (@dtvalidade < @dtlancado) begin
select @retorna = 4;
select @descricao = 'Data de validade invlida';
end;
end;
--Verificar se o passante tem acesso a esta categoria de refeio
if @retorna = 0
begin
if not exists(select id_pass from tbFaixasRefeitPass where id_pass = @id_pass and @id_refeit = id_refeit) begin
select @retorna = 5;
select @descricao = 'Passante sem direito a esta categoria de refeio';
end;
end;
--Gravar
if @retorna = 0 begin
select @saldo = @quantidade;
--Gravar
INSERT INTO tbCredRefeit (id_pass,id_refeit,id_empresa,dtlancado,dtvalidade,
quantidade,saldo,vlunitario,cancelado,usuario_inc,usuario_ext,origem,
id_cxcredref, ano_hcxcr, id_hcxcr)
VALUES (@id_pass,@id_refeit,@id_empresa,@dtlancado,@dtvalidade,@quantidade,
@saldo,@vlunitario,0,@id_usuario,null,@origem,
@id_cxcredref, @ano_hcxcr, @id_hcxcr);
end;
if @origem<>6 begin
select @retorna as coderro, @descricao as descerro;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AUTOLANC_REFEITORIO') AND xtype = 'P') BEGIN  DROP PROCEDURE dbo.AUTOLANC_REFEITORIO; END
GO
CREATE PROCEDURE dbo.AUTOLANC_REFEITORIO(@id_pass int, @id_refeit float) WITH ENCRYPTION AS
BEGIN
declare @minimo int;     declare @quantidade int; declare @dias_validade int;
declare @id_usuario int; declare @achou bit; declare @ref_nro_ref int;
declare @data_hora_atual datetime; declare @data_validade datetime;
select @achou=0;
SELECT @achou=1, @minimo=minimo, @quantidade=quantidade,@dias_validade=dias_validade,@id_usuario=id_usuario FROM tbCredAut
WHERE id_pass=@id_pass AND id_refeit=@id_refeit;
if @achou=1 and @minimo>0 and @quantidade>0 begin
select @data_hora_atual = getdate();
select @ref_nro_ref = 0;
SELECT @ref_nro_ref = SUM(saldo) FROM tbCredRefeit
where id_pass=@id_pass AND id_refeit=@id_refeit AND saldo>0 AND isnull(dtvalidade,'01/01/2200') > @data_hora_atual AND cancelado = 0;
if isnull(@ref_nro_ref,0)<@minimo begin
if isnull(@dias_validade,0) > 0 begin
select @data_validade = dateadd(d,@dias_validade,@data_hora_atual);
select @data_validade = convert(datetime,convert(varchar,@data_validade,101) + ' 23:59:59.930');
end else  begin
select @data_validade = null;
end;
exec INSERE_CDREFEITORIO @id_pass, @id_refeit, @quantidade, @data_validade, @id_usuario, 6, 0, 0, 0;
end;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.DEBITA_ACESSO_EM_REFEITORIO') AND xtype = 'P') BEGIN  DROP PROCEDURE dbo.DEBITA_ACESSO_EM_REFEITORIO; END
GO
CREATE PROCEDURE dbo.DEBITA_ACESSO_EM_REFEITORIO(@id_pass int, @id_refeit float, @id_credref BIGINT) WITH ENCRYPTION AS
BEGIN
if isnull(@id_credref,0) = 0 begin
update tbRefeitPass
set nro_ref = (case when nro_ref <= 0 then 0 else nro_ref - 1 end)
where id_pass = @id_pass;
end else begin
UPDATE tbCredRefeit SET saldo=(case when saldo<0 then saldo else saldo-1 end) WHERE id_credref=@id_credref;
exec AUTOLANC_REFEITORIO @id_pass, @id_refeit;
end
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.ATUALIZAR_REFAVULSA') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.ATUALIZAR_REFAVULSA  END
GO
CREATE PROCEDURE dbo.ATUALIZAR_REFAVULSA (@idPass int, @idRefeit int, @evento int, @dataMarc datetime, @valor float) WITH ENCRYPTION AS
BEGIN
if isnull(@idPass,0)>0 AND (isnull(@evento,0)=101 OR isnull(@evento,0)=92) AND EXISTS(SELECT TOP 1 id_pass FROM tbRefAvulsa)
begin
--Apagar
DELETE FROM tbRefAvulsa WHERE id_pass = @idPass AND data BETWEEN @dataMarc AND DATEADD(s,1,@dataMarc) AND id_refeit>0 AND valor <=0;
--Incluir
if isnull(@valor,0)>0 begin
INSERT INTO tbRefAvulsa (id_pass,data,id_refeit,valor,id_usuario) VALUES (@idPass, @dataMarc, @idRefeit, @valor*(-1), 0);
end;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.OBTER_VREF') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.OBTER_VREF END
GO
CREATE PROCEDURE dbo.OBTER_VREF(@idPass int, @idRefeit int, @dataMarc datetime, @valor float output, @repasse float output, @consulta bit = 0, @valida_on bit = 0) WITH ENCRYPTION AS
BEGIN
declare @idAgrupamento int; declare @valor2 float; declare @repasse2 float;
select @valor=0, @repasse=0, @valor2=0, @repasse2=0;
SELECT TOP 1
@valor = convert(float,replace(valor,',','.')),
@valor2 = convert(float,replace(isnull(valor2,'0,00'),',','.')),
@repasse = convert(float,replace(isnull(repasse,'0,00'),',','.')),
@repasse2 = convert(float,replace(isnull(repasse2,'0,00'),',','.'))
FROM tbRefeit WHERE id_refeit = isnull(@idRefeit,0);
select @idAgrupamento = 0;
if isnull(@idPass,0)>0 begin
SELECT TOP 1 @idAgrupamento=id_agrupamento FROM tbPass WHERE id_pass = @idPass;
if (isnull(@idAgrupamento,0)=0) begin
SELECT TOP 1 @idAgrupamento=id_agrupamento FROM tbVisiBai WHERE id_pass = @idPass;
end;
if isnull(@idAgrupamento,0)>0 begin
SELECT TOP 1
@valor = convert(float,replace(valor,',','.')),
@valor2 = convert(float,replace(isnull(valor2,'0,00'),',','.')),
@repasse = convert(float,replace(isnull(repasse,'0,00'),',','.')),
@repasse2 = convert(float,replace(isnull(repasse2,'0,00'),',','.'))
FROM tbRefAgrup WHERE id_refeit = isnull(@idRefeit,0) AND id_agrupamento = @idAgrupamento;
end;
end;
if @idPass>0 and (@valida_on=1 or isnull(@valor2,0)>0) begin
if EXISTS(
SELECT TOP 1 id_mrefeit FROM tbMRefeit WITH (NOLOCK)
WHERE id_pass=@idPass AND id_refeit = isnull(@idRefeit,0)
AND data BETWEEN DATEADD(HH,-12,@dataMarc) AND DATEADD(s,-1,@dataMarc)
AND status=0 AND evento IN (select id_evento from tbEventoSist where flagimpedimento=0)
)
begin
select @valor=@valor2, @repasse=@repasse2;
end;
end;
select @valor=isnull(@valor,0), @repasse=isnull(@repasse,0);
if @consulta=1 begin
select @valor as valor, @repasse as repasse;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.INSERE_MOVIMENTO_REFEITORIO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.INSERE_MOVIMENTO_REFEITORIO; END
GO
CREATE PROCEDURE dbo.INSERE_MOVIMENTO_REFEITORIO(@id_pass int, @l_Empresa float, @l_IdRefeit float, @Valor float,
@l_Cracha float,  @l_Tipo char(1), @l_NumRel int, @l_Status tinyint,
@l_Evento As int, @l_Funcao As int, @l_Data datetime, @id_credref bigint) WITH ENCRYPTION AS
BEGIN
declare @data_hora datetime;
declare @Repasse float; declare @id_depart int; declare @id_custo int;
select @l_Status=isnull(@l_Status,0);
select @Repasse=@Valor;
select @id_depart=null, @id_custo=null;
SELECT TOP 1 @id_depart=id_depart, @id_custo=id_custo FROM tbPass WHERE id_pass=@id_pass;
if not exists(SELECT id_bloq FROM tbBloq WHERE id_bloq = @l_NumRel AND tipo_controle = 'S')
BEGIN
if @l_Data is null
begin
select @data_hora = getdate();
end else begin
select @data_hora = @l_Data;
end
if isnull(@Valor,0) = 0  begin
--Calcular valor
EXEC OBTER_VREF @id_pass, @l_IdRefeit, @data_hora, @Valor output, @Repasse output;
end;
if (isnull(@l_Evento,0)=101 OR isnull(@l_Evento,0)=92) AND isnull(@Valor,0)>0 AND EXISTS(SELECT TOP 1 id_pass FROM tbRefAvulsa) begin
--Verificar saldo avulso
INSERT INTO tbRefAvulsa (id_pass,data,id_refeit,valor,id_usuario) VALUES (@id_pass, @data_hora, @l_IdRefeit, @Valor*(-1), 0);
end;
insert into tbMRefeit (
id_pass, valor_refeit, valor_repasse, id_empresa, data,
hora, cracha, id_refeit, relogio,
status, evento, tipo, funcao, id_credref, id_depart, id_custo
) values (
@id_pass, @Valor, @Repasse, @l_Empresa,
@data_hora, @data_hora,
@l_Cracha, @l_IdRefeit, @l_NumRel, @l_Status,
@l_Evento, @l_Tipo, @l_Funcao, @id_credref, @id_depart, @id_custo
);
while (@@ERROR = 2627)
begin
select @data_hora = DATEADD(second, 1, @data_hora);
insert into tbMRefeit (
id_pass, valor_refeit, valor_repasse, id_empresa, data,
hora, cracha, id_refeit, relogio,
status, evento, tipo, funcao, id_credref, id_depart, id_custo
) values (
@id_pass, @Valor, @Repasse, @l_Empresa,
@data_hora, @data_hora,
@l_Cracha, @l_IdRefeit, @l_NumRel, @l_Status,
@l_Evento, @l_Tipo, @l_Funcao, @id_credref, @id_depart, @id_custo
);
END
if @l_Status = 0
AND EXISTS(SELECT id_pass FROM tbMRefeit WITH (NOLOCK) WHERE id_pass=@id_pass AND id_empresa=@l_Empresa AND data=@data_hora  AND hora=@data_hora AND cracha=@l_Cracha AND relogio=@l_NumRel AND status=@l_Status AND valor_refeit=@Valor)
AND EXISTS(SELECT id_evento FROM tbEventoSist WHERE id_evento=@l_Evento AND flagimpedimento=0)
BEGIN
EXEC DEBITA_ACESSO_EM_REFEITORIO @id_pass, @l_IdRefeit, @id_credref;
END;
END
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.CANCELA_CDREFEITORIO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.CANCELA_CDREFEITORIO; END
GO
CREATE PROCEDURE dbo.CANCELA_CDREFEITORIO(@id_credref bigint, @usuario_ext int) WITH ENCRYPTION  AS
BEGIN
SET NOCOUNT ON;
declare @retorna integer;
declare @descricao varchar(50);
declare @achou bit;
declare @saldo int;
declare @quantidade int;
declare @dtvalidade datetime;
declare @cancelado datetime;
select @retorna = 0;
select @descricao = 'Crdito cancelado';
--Ver se o registro existe
Select @achou = 0;
SELECT TOP 1 @achou=1, @dtvalidade=dtvalidade, @saldo=saldo, @quantidade=quantidade, @cancelado=cancelado
FROM tbCredRefeit WHERE id_credref = @id_credref ORDER BY cancelado;
if @achou = 0 begin
select @retorna = 1;
select @descricao = 'Crditos no localizados no banco de dados';
end;
-- Ver se j est cancelado
if @retorna = 0 and isnull(@cancelado,0) = 1
begin
select @retorna = 2;
select @descricao = 'Estes crditos j esto cancelados';
end;
-- Ver se est vencido
if @retorna = 0 and not @dtvalidade is null and @dtvalidade < Getdate()
begin
select @retorna = 3;
select @descricao = 'Estes crditos esto vencidos';
end;
-- Ver se alguma refeio j foi consumida
if @retorna = 0 and @saldo <> @quantidade begin
if not exists(Select top 1 * from tbUsuarios where id_usuario = @usuario_ext and nivel < 3)
begin
select @retorna = 4;
select @descricao = 'O passante j consumiu crditos';
end;
end;
-- Ver se o usurio est cadastrado
if @retorna = 0
begin
if not exists(Select top 1 id_usuario from tbUsuarios where id_usuario = @usuario_ext) begin
select @retorna = 5;
select @descricao = 'Usurio no localizado';
end;
end;
-- Ver se  registro Bathc
if @retorna = 0 and @quantidade = 0 and @saldo < 0
begin
if not exists(Select top 1 * from tbUsuarios where id_usuario = @usuario_ext and nivel < 3)
begin
select @retorna = 6;
select @descricao = 'Registro de ''Acesso indevido em batch''';
end;
end;
--Realizar o cancelamento
if @retorna = 0 begin
UPDATE tbCredRefeit set cancelado = 1, usuario_ext = @usuario_ext WHERE id_credref = @id_credref;
end;
select @retorna as coderro, @descricao as descerro;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.VALOR_ESTAC') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.VALOR_ESTAC; END;
GO
CREATE PROCEDURE dbo.VALOR_ESTAC(@id_movim_atu bigint) WITH ENCRYPTION AS
BEGIN
declare @idTestac int; declare @f_valor numeric(9,2); declare @data_ent datetime; declare @m_tempo numeric(9,2);
declare @achou bit; declare @id_movim_prx bigint;
declare @idPass int; declare @tipo char(1); declare @data datetime; declare @status tinyint; declare @evento tinyint;
declare @fxTempo int; declare @fxOldTempo int; declare @fxValor numeric(5,2); declare @porHora int;
declare @dif numeric(9,2); declare @hr int;
select @idTestac = null, @f_valor = null, @data_ent = null, @m_tempo = null;
select @achou=0;
SELECT @achou=1, @idPass=id_pass, @tipo=tipo, @data=data, @status=status, @evento=evento FROM tbMovim WHERE id_movim = isnull(@id_movim_atu,0);
if @achou=0 or NOT EXISTS(SELECT e.id_evento FROM tbEventoSist e WHERE e.id_evento = @evento AND e.flagimpedimento = 0) begin
RETURN;
end;
if @status=0 begin
select @id_movim_prx=0;
SELECT TOP 1 @id_movim_prx=m.id_movim FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbMHAuto mh ON m.id_movim = mh.id_movim
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento=0
WHERE m.id_pass = @idPass AND m.data > @data ORDER BY m.data;
if @id_movim_prx=0 begin
RETURN;
end;
select @id_movim_atu=@id_movim_prx, @achou=0;
SELECT @achou=1, @idPass=id_pass, @tipo=tipo, @data=data, @status=status, @evento=evento FROM tbMovim WHERE id_movim = isnull(@id_movim_atu,0);
if @achou=0 or @status=0 or NOT EXISTS(SELECT e.id_evento FROM tbEventoSist e WHERE e.id_evento = @evento AND e.flagimpedimento = 0) begin
RETURN;
end;
end;
select @data_ent=null;
SELECT TOP 1 @data_ent=m.data, @status=status FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbMHAuto mh ON m.id_movim = mh.id_movim
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento=0
WHERE m.id_pass = @idPass AND m.data < @data ORDER BY m.data DESC;
if @data_ent IS NULL or @status<>0 begin
RETURN;
end;
select @m_tempo = datediff(mi,@data_ent,@data);
if @m_tempo<=0 begin
select @m_tempo=0;
end;
if @m_tempo>10080 begin
select @m_tempo=10080; --limitado a uma semana, por segurana
end;
select @idTestac=null;
select TOP 1 @idTestac=e.id_testac FROM tbTEstac e WHERE e.id_testac IN (SELECT t.id_testac FROM tbTPEstac t WHERE t.tipo=@tipo);
if NOT @idTestac IS NULL begin
select @f_valor=0, @fxOldTempo=0;
select @achou=0;
SELECT @achou=1, @fxTempo=m_tempo, @fxValor=f_valor, @porHora=por_hora FROM tbTFEstac WHERE id_testac=@idTestac AND faixa=1;
if (@achou=1) begin
select @fxOldTempo=@fxTempo;
select @dif=@m_tempo;
if (@dif>@fxTempo) begin
select @dif=@fxTempo;
end;
if (@dif>10) begin --Tolerncia de 10 min
if @porHora=0 begin
select @f_valor=@f_valor+@fxValor;
end else begin
select @hr=0;
while (@dif>0) begin
select @hr=@hr+1;
select @dif=@dif-60;
if @dif<0 or @dif<=10 begin
select @dif=0;
end;
end;
select @f_valor=@f_valor+(@fxValor * @hr);
end;
end;
end;
select @achou=0;
SELECT @achou=1, @fxTempo=m_tempo, @fxValor=f_valor, @porHora=por_hora FROM tbTFEstac WHERE id_testac=@idTestac AND faixa=2;
if (@achou=1) begin
select @dif=@m_tempo;
if (@dif>@fxTempo) begin
select @dif=@fxTempo;
end;
select @dif=@dif-@fxOldTempo;
if (@dif>10) begin --Tolerncia de 10 min
if @porHora=0 begin
select @f_valor=@f_valor+@fxValor;
end else begin
select @hr=0;
while (@dif>0) begin
select @hr=@hr+1;
select @dif=@dif-60;
if @dif<0 or @dif<=10 begin
select @dif=0;
end;
end;
select @f_valor=@f_valor+(@fxValor * @hr);
end;
end;
end;
select @achou=0;
SELECT @achou=1, @fxTempo=m_tempo, @fxValor=f_valor, @porHora=por_hora FROM tbTFEstac WHERE id_testac=@idTestac AND faixa=3;
if (@achou=1) begin
select @dif=@m_tempo;
if (@dif<=@fxTempo) begin
select @dif=0;
end else begin
select @dif=@dif-@fxTempo;
end;
if (@dif>10) begin --Tolerncia de 10 min
if @porHora=0 begin
select @f_valor=@f_valor+@fxValor;
end else begin
select @hr=0;
while (@dif>0) begin
select @hr=@hr+1;
select @dif=@dif-60;
if @dif<0 or @dif<=10 begin
select @dif=0;
end;
end;
select @f_valor=@f_valor+(@fxValor * @hr);
end;
end;
end;
end;
UPDATE tbMHAuto SET id_testac=@idTestac, f_valor=@f_valor, data_ent=@data_ent, m_tempo=@m_tempo WHERE id_movim=@id_movim_atu;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.ACESSO_COMBINADO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.ACESSO_COMBINADO; END
GO
CREATE PROCEDURE dbo.ACESSO_COMBINADO(@id_bloq int, @processo int, @id_movim_atu bigint, @id_pass_atu int, @data_atu datetime, @funcao int, @evento tinyint, @aguardaAceComb bit output) WITH ENCRYPTION AS
BEGIN
select getdate();
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.INSERE_MOVIMENTO_INTERNA') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.INSERE_MOVIMENTO_INTERNA; END
GO
CREATE PROCEDURE dbo.INSERE_MOVIMENTO_INTERNA(@id_pass int, @l_Empresa float, @l_Cracha float, @l_NumRel int, @tipo_controle char(1),
@l_Status char(1), @l_Evento As int, @l_Funcao As int,
@l_Data datetime, @l_IdEventVisi As float, @l_TPass char(1),
@l_IdDepart float, @l_IdAuto float) WITH ENCRYPTION AS
BEGIN
declare @data_hora datetime;  declare @id_local integer;
declare @id_sublocal integer; declare @visitado varchar(50);
declare @pass_visi integer;   declare @paci_visi integer;
declare @ponto tinyint; declare @id_movim_atu bigint; declare @aguardaAceComb bit;
declare @id_hauto bigint;
if @l_Data is null
begin
select @data_hora = getdate();
end else begin
select @data_hora = @l_Data;
end
if not len(@l_TPass) > 0
begin
select top 1 @l_TPass = tipo, @id_local = id_local, @id_sublocal = id_sublocal,
@visitado = visitado, @pass_visi = pass_visi, @paci_visi = paci_visi
from tbPass where id_pass = @id_pass;
if not len(isnull(@l_TPass,'')) > 0
begin
select @l_TPass = 'N';
end
end else begin
if @l_TPass = 'V'
begin
select top 1 @id_local = id_local, @id_sublocal = id_sublocal,
@visitado = visitado, @pass_visi = pass_visi, @paci_visi = paci_visi
from tbPass where id_pass = @id_pass;
end
end
if @l_IdEventVisi <= 0 and @l_TPass = 'V'
begin
select top 1 @l_IdEventVisi = isnull(id_eventvisi,0) from tbVisi where id_pass = @id_pass;
end
select @ponto=0;
if @tipo_controle = 'P' begin
select @ponto=1;
end;
INSERT INTO tbMovim ( id_pass, cracha, id_empresa,
data, hora, relogio, status, evento,
id_eventvisi, tipo, id_depart, funcao,
id_local, id_sublocal, visitado, pass_visi, paci_visi, id_auto, ponto)
VALUES ( @id_pass, @l_Cracha, @l_Empresa, @data_hora, @data_hora,
@l_NumRel, @l_Status, @l_Evento, @l_IdEventVisi,
(case when len(@l_TPass) > 0 then @l_TPass else 'N' end),
(case when @l_IdDepart > 0 then @l_IdDepart else 0 end),
@l_Funcao, @id_local, @id_sublocal, @visitado, @pass_visi, @paci_visi, @l_IdAuto, @ponto);
SET @id_movim_atu = SCOPE_IDENTITY();
if exists(select id_evento from tbEventoSist where id_evento = @l_Evento and flagimpedimento=0) begin
exec ACESSO_COMBINADO @l_NumRel, 3, @id_movim_atu, @id_pass, @data_hora, @l_Funcao, @l_Evento, @aguardaAceComb output;
end else begin
exec ACESSO_COMBINADO @l_NumRel, 2, @id_movim_atu, @id_pass, @data_hora, @l_Funcao, @l_Evento, @aguardaAceComb output;
end;
select @id_hauto=0;
if @l_IdAuto>0 begin
if exists(SELECT id_evento FROM tbEventoSist WHERE id_evento = @l_Evento AND flagimpedimento=0) begin
UPDATE tbAuto SET status = (case when @l_Status = '1' then 'N' else 'D' end),
ult_acessd = @data_hora, ult_idbloq = @l_NumRel,
ult_direc = (case when @l_Status = '1' then 1 else 0 end),
ult_id_pass = @id_pass
WHERE id_auto = @l_IdAuto AND isnull(ult_acessd,convert(datetime,'01/01/1900')) <= @data_hora;
end;
SELECT TOP 1 @id_hauto=h.id_hauto FROM tbHistAuto h
WHERE h.id_auto=@l_IdAuto AND @data_hora BETWEEN h.data_ini AND isnull(h.data_fim,@data_hora)
ORDER BY h.data_ini DESC;
end;
if @tipo_controle = 'V' begin
INSERT tbMHAuto (id_movim, id_hauto) VALUES (@id_movim_atu, @id_hauto);
EXEC VALOR_ESTAC @id_movim_atu;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.INSERE_MOVIMENTO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.INSERE_MOVIMENTO; END
GO
CREATE PROCEDURE dbo.INSERE_MOVIMENTO(@id_pass int, @l_Empresa float, @l_Cracha float, @l_NumRel int, @tipo_controle char(1),
@l_Status char(1), @l_Evento As int, @l_Funcao As int,
@l_Data datetime, @l_IdEventVisi As float, @l_TPass char(1), @l_IdDepart float) WITH ENCRYPTION AS
BEGIN
declare @data_hora datetime;
declare @id_auto integer;
declare @estacionamento bit;
declare @ace_comb tinyint;
declare @id_cauto integer;
if @l_Data is null
begin
select @data_hora = getdate();
end else begin
select @data_hora = @l_Data;
end
select @estacionamento=0, @ace_comb=0;
select @estacionamento=1, @ace_comb=ace_comb from tbBloq where id_bloq = @l_NumRel and isnull(tipo_controle,'A') = 'V';
if @estacionamento = 1 or @l_NumRel = 0 begin
select @id_auto = 0;
if @id_pass > 0 begin
-- Localizar ltimo veculo cadastrado para o passante
SELECT TOP 1 @id_auto = id_auto from tbHistAuto where id_pass = @id_pass and data_fim is null and inativo=0 ORDER BY data_ini DESC;
if @id_auto = 0 begin
SELECT TOP 1 @id_auto = id_auto FROM tbHistAuto WHERE id_pass = @id_pass AND @data_hora >= data_ini AND @data_hora <= isnull(data_fim,@data_hora) ORDER BY data_fim DESC;
end;
end;
if (@ace_comb=2 or @ace_comb=3) and @l_NumRel>0 begin
select @id_cauto=0;
-- ltimo acesso
SELECT TOP 1 @id_cauto=isnull(id_auto,0) FROM tbBloqSPark WHERE id_bloq=@l_NumRel AND cracha=@l_Cracha AND data BETWEEN DATEADD(ss,-15, GETDATE()) AND GETDATE();
-- Localizar veculo pelo crach
if @id_cauto=0 and @id_pass>0 begin
SELECT TOP 1 @id_cauto=a.id_auto FROM tbAuto a INNER JOIN tbHistAuto h ON h.id_auto=a.id_auto AND h.id_pass = @id_pass WHERE a.cracha=@l_Cracha ORDER BY h.data_ini DESC;
end;
if @id_cauto=0 begin
SELECT TOP 1 @id_cauto=a.id_auto FROM tbAuto a WHERE a.cracha=@l_Cracha;
end;
if @id_cauto>0 begin
select @id_auto=@id_cauto;
if @id_pass = 0 begin
-- Localizar pessoa
SELECT TOP 1 @id_pass=id_pass FROM tbMovim WITH (NOLOCK) WHERE data BETWEEN DATEADD(ss,-20, GETDATE()) AND GETDATE() AND relogio=@l_NumRel AND evento=51 ORDER BY data DESC;
if @id_pass = 0 begin
SELECT TOP 1 @id_pass=h.id_pass FROM tbHistAuto h WHERE h.id_auto=@id_auto ORDER BY h.data_ini DESC;
end;
if @id_pass>0 begin
select @l_Empresa=0;
SELECT @l_Empresa=isnull(id_empresa,0), @l_TPass=isnull(tipo,'N'), @l_IdDepart=isnull(id_depart,0) FROM tbPass WHERE id_pass=@id_pass;
if @l_Empresa=0 begin
SELECT @l_Empresa=isnull(id_empresa,0), @l_TPass=isnull(tipo,'N'), @l_IdDepart=isnull(id_depart,0) FROM tbVisiBai WHERE id_pass=@id_pass;
end;
end;
end;
end;
end;
end;
EXEC INSERE_MOVIMENTO_INTERNA @id_pass, @l_Empresa, @l_Cracha, @l_NumRel, @tipo_controle, @l_Status, @l_Evento, @l_Funcao, @data_hora, @l_IdEventVisi, @l_TPass, @l_IdDepart, @id_auto;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.INSERE_MOVPTO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.INSERE_MOVPTO; END
GO
CREATE PROCEDURE dbo.INSERE_MOVPTO(@id_bloq INT, @id_afd BIGINT, @id_modelo INT, @rep CHAR(17), @cnpj CHAR(14), @id_emp_r3 INT, @marc DATETIME,
@dtref DATETIME, @r301 CHAR(9), @r302 CHAR(1),  @r303 CHAR(8), @r304 CHAR(4), @r305 CHAR(12), @info CHAR(255) ) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
SET LANGUAGE English;
declare @achou bit, @marc_nova bit;
declare @data datetime;
declare @id_pass int, @id_empresa float, @cracha float, @id_depart int;
declare @gBloq varchar(3);
select @marc_nova=0;
if isnull(@id_bloq,0) <= 0 or isnull(@id_afd,0) <= 0 or @id_modelo is null or
len(ltrim(isnull(@rep,''))) <> 17 or len(ltrim(isnull(@cnpj,''))) <> 14 or
@id_emp_r3 is null or @marc is null or @dtref is null or @r301 is null or @r302 is null or
@r303 is null or @r304 is null or @r305 is null or @info is null
begin
select @marc_nova as marc_nova, 0 as id_pass;
return;
end;
select @data = convert(datetime,convert(varchar,isnull(@marc,'00:00:00'),101));
select @achou=0;
SELECT TOP 1 @achou=1 FROM tbAFDR3 WHERE rep=@rep AND r305=@r305 AND marc=@marc AND r301=@r301;
if len(ltrim(rtrim(isnull(@info,'')))) < 5 begin
select @achou=1;
end;
if @achou=0 begin
select @id_pass=0, @id_empresa=@id_emp_r3, @cracha=0, @id_depart=0;
select @gBloq = '000';
SELECT TOP 1 @gBloq = RIGHT('000' + ltrim(isnull(id_gbloq,0)),3) FROM tbBloq WHERE id_bloq = @id_bloq;
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE ltrim(rtrim(f.doc_pis))=@r305
AND p.id_empresa=@id_emp_r3
AND isnull(p.inativo,0) = 0
AND isnull(f.admissao, @data) <= @data AND isnull(f.dtdemissao,@data) >= @data
AND (p.vip = 1 or patindex('%'+@gBloq+'*%',isnull(p.g_bloq,'')) > 0);
if isnull(@id_pass,0) = 0 begin
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE ltrim(rtrim(f.doc_pis))=@r305
AND isnull(p.inativo,0)=0
AND isnull(f.admissao, @data) <= @data AND isnull(f.dtdemissao,@data) >= @data
AND (p.vip = 1 or patindex('%'+@gBloq+'*%',isnull(p.g_bloq,'')) > 0);
end;
if isnull(@id_pass,0) = 0 begin
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE ltrim(rtrim(f.doc_pis))=@r305
AND isnull(f.admissao, @data) <= @data AND isnull(f.dtdemissao,@data) >= @data
AND (p.vip = 1 or patindex('%'+@gBloq+'*%',isnull(p.g_bloq,'')) > 0)
ORDER BY isnull(p.inativo,0);
end;
if isnull(@id_pass,0) = 0 begin
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE ltrim(rtrim(f.doc_pis))=@r305
AND p.id_empresa=@id_emp_r3
AND isnull(p.inativo,0) = 0
AND isnull(f.admissao, @data) <= @data AND isnull(f.dtdemissao,@data) >= @data;
end;
if isnull(@id_pass,0) = 0 begin
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE ltrim(rtrim(f.doc_pis))=@r305
AND isnull(p.inativo,0)=0
AND isnull(f.admissao, @data) <= @data AND isnull(f.dtdemissao,@data) >= @data;
end;
if isnull(@id_pass,0) = 0 begin
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE ltrim(rtrim(f.doc_pis))=@r305
AND isnull(f.admissao, @data) <= @data AND isnull(f.dtdemissao,@data) >= @data
ORDER BY isnull(p.inativo,0);
end;
if isnull(@id_pass,0) = 0 begin
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE ltrim(rtrim(f.doc_pis))=@r305
ORDER BY isnull(p.inativo,0);
end;
if isnull(@id_pass,0) = 0 begin
SELECT TOP 1 @id_pass=p.id_pass, @cracha=p.cracha, @id_depart=isnull(p.id_depart,0), @id_empresa=p.id_empresa
FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
INNER JOIN tbFHistPIS fh ON f.id_pass = fh.id_pass
WHERE ltrim(rtrim(fh.doc_pis))=@r305
AND isnull(p.inativo,0)=0
AND isnull(f.admissao, @data) <= @data AND isnull(f.dtdemissao,@data) >= @data
ORDER BY fh.data DESC;
end;
select @id_pass=isnull(@id_pass,0);
INSERT INTO tbAFDR3 (id_afd, cnpj, id_emp_r3, id_pass, dtref, ordem,rep, marc, r301, r302, r303, r304, r305, cksum)
VALUES (@id_afd, @cnpj, @id_emp_r3, @id_pass, @dtref, 0, @rep, @marc, @r301, @r302, @r303, @r304, @r305, @info);
UPDATE tbEmpresas SET nrmc=isnull(nrmc,0)+1 WHERE id_empresa=@id_emp_r3;
select @marc_nova=1;
if @id_pass > 0 begin
EXEC INSERE_MOVIMENTO @id_pass, @id_empresa, @cracha, @id_bloq, 'P', '0', 80, 1, @marc, 0, 'F', @id_depart;
end;
end; -- if @achou=1 begin
select @marc_nova as marc_nova, isnull(@id_pass,0) as id_pass;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.BAIXA_VISITANTE') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.BAIXA_VISITANTE; END
GO
CREATE PROCEDURE dbo.BAIXA_VISITANTE(@CRACHA FLOAT, @LFUSO DATETIME = NULL) WITH ENCRYPTION AS
BEGIN
declare @id_pass int;
declare @id_auto int;
insert into tbVisiBai
(  id_pass, id_empresa, cracha, nome, via,
tipo, vip, nasc, indesejado, bloqueado,
id_horario, id_consist, data_ini, data_fim, per_indet,
id_msgrel, id_msgtela, msg_qtd_p, foto, fotodoc,
g_bloq, feriado, ult_acess, ult_acessd, ult_idbloq,
ult_direc, indgbloq, status, data, usu_resp,
senha, data_bai, resp_bai, id_depart, contador, reinic,
acessos_dia,id_local,id_sublocal,pass_visi,paci_visi,visitado,
id_custo, id_agrupamento
) select top 1
id_pass, id_empresa, cracha, nome, via,
tipo, vip, nasc, indesejado, bloqueado,
id_horario, id_consist, data_ini, data_fim, 0,
id_msgrel, id_msgtela,  msg_qtd_p, foto, fotodoc,
g_bloq, feriado, ult_acess, ult_acessd, isnull(ult_idbloq,0),
ult_direc, indgbloq, 'N', data, usu_resp,
isnull(senha,0), isnull(@LFUSO,getdate()), 1, id_depart, contador, reinic,
acessos_dia,id_local,id_sublocal,pass_visi,paci_visi,visitado,
id_custo, id_agrupamento
from tbPass where cracha = @CRACHA and tipo = 'V';
select @id_pass = 0;
select @id_pass = id_pass from tbPass where cracha = @CRACHA and tipo = 'V';
if @id_pass > 0 begin
UPDATE tbHistVisi set data_ent = isnull(@LFUSO,getdate()), hora_ent = isnull(@LFUSO,getdate()) WHERE id_pass = @id_pass;
UPDATE tbHistCracha SET data_fim=isnull(@LFUSO,getdate()) WHERE id_pass=@id_pass AND cracha=@CRACHA AND data_fim IS NULL;
end;
delete from tbPass where cracha = @CRACHA and tipo = 'V';
select @id_auto=0;
SELECT TOP 1 @id_auto=tbHistAuto.id_auto FROM tbHistAuto WHERE tbHistAuto.id_pass=@id_pass AND data_fim is null
if isnull(@id_auto,0) > 0 begin
UPDATE tbVagas SET id_auto=0 WHERE id_auto=@id_auto;
UPDATE tbAuto SET id_pass=null, identificacao=null, id_vaga=null, status='N' WHERE id_auto=@id_auto;
end;
UPDATE tbHistAuto SET data_fim = isnull(@LFUSO,getdate()) WHERE tbHistAuto.id_pass = @id_pass AND data_fim is null;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.GRAVA_STATUS_PASSANTE') AND xtype = 'P') BEGIN  DROP PROCEDURE dbo.GRAVA_STATUS_PASSANTE; END
GO
CREATE PROCEDURE dbo.GRAVA_STATUS_PASSANTE (@PRIMARIO BIT, @IDBLOQ FLOAT, @IDGBLOQ FLOAT, @TIPOBLOQ INT, @ID_PASS FLOAT,
@CRACHA FLOAT, @ENTSAI INT, @TIPO CHAR(1), @STATUS CHAR(1), @TIMEOUT BIT,
@INDGBLOQ varchar(300), @TIPO_CONTROLE char(1), @FORCARBAIXA BIT, @LFUSO DATETIME = null) WITH ENCRYPTION AS
BEGIN
declare @sequencia varchar(1600);  declare @aces_p smallint;
declare @data_hora datetime;       declare @psi int;
declare @st_ult tinyint, @st_eve tinyint;
select @data_hora = isnull(@LFUSO,getdate());
if @STATUS = 'S' or len(@STATUS) = 0
begin
SELECT @STATUS = 'N'
end
select @INDGBLOQ = left(rtrim(@INDGBLOQ)+replicate('0',300),300);
if @TIMEOUT = 0 and @STATUS <> 'E'
begin
if @PRIMARIO = 1 and @STATUS = 'N'
begin
if not exists(SELECT id_bloq from tbBloq where flagsecundario = 1)
begin
select @INDGBLOQ = replace(@INDGBLOQ, '1', '0');
end else begin
select @psi = 0;
while (@psi <= 300)
begin
select @psi = @psi + 1;
if substring(@INDGBLOQ,@psi,1) = '1'
begin
if not exists(select id_gbloq from tbBloq where id_gbloq = @psi and flagsecundario = 1)
begin
select @INDGBLOQ = LEFT(@INDGBLOQ,@psi-1)+'0'+RIGHT(@INDGBLOQ,300-@psi)
end
end
end
end
end else begin
select @INDGBLOQ =
case when @ENTSAI = 0 then
LEFT(@INDGBLOQ,@IDGBLOQ-1)+'1'+RIGHT(@INDGBLOQ,300-@IDGBLOQ)
else
LEFT(@INDGBLOQ,@IDGBLOQ-1)+'0'+RIGHT(@INDGBLOQ,300-@IDGBLOQ)
end
end
end
select @sequencia = ',';
if @PRIMARIO = 0
begin
select @sequencia = rtrim(isnull(sequencia,',')) from tbPass where id_pass = @ID_PASS;
end
if not (@TIMEOUT = 1 or @TIPO_CONTROLE = 'R' or @TIPO_CONTROLE = 'P') and @PRIMARIO = 0
begin
if exists(select travaseq from tbParSist where isnull(travaseq,0) = 1) and
exists(select travasequencia FROM tbBloq WHERE id_bloq = @IDBLOQ and isnull(travasequencia,1) = 0)
begin
if @ENTSAI = 0
begin
if len(@sequencia) < 1550
begin
if len(@sequencia) >= 4
begin
if right(@sequencia,4) <> right('000'+rtrim(ltrim(convert(varchar,@IDGBLOQ))),3) +','
select @sequencia = @sequencia + right('000'+rtrim(ltrim(convert(varchar,@IDGBLOQ))),3) +',';
end else begin
select @sequencia = @sequencia + right('000'+rtrim(ltrim(convert(varchar,@IDGBLOQ))),3) +',';
end
end else begin
select @sequencia = ',';
end
end else begin
if len(@sequencia) > 4
begin
if right(@sequencia,4) = right('000'+rtrim(ltrim(convert(varchar,@IDGBLOQ))),3) +','
select @sequencia = left(@sequencia,len(@sequencia)-4);
end else begin
select @sequencia = ',';
end
end
end
end
if (@TIPO_CONTROLE='R' AND (@PRIMARIO=0 OR @TIPO<>'V')) OR @TIPO_CONTROLE = 'P' begin
select @STATUS = null;
end;
if @TIPO_CONTROLE = 'P' begin
select @INDGBLOQ = null;
end;
update tbPass
set ult_acess  = @data_hora, ult_acessd = @data_hora, ult_idbloq = @IDBLOQ, ult_direc = @ENTSAI,
reinic = (case when @PRIMARIO = 1 then 0 else reinic end),
indgbloq = isnull(@INDGBLOQ,indgbloq), status = isnull(@STATUS, status), ult_lib = null,
sequencia = @sequencia
where id_pass = @ID_PASS
if @TIMEOUT = 0
begin
if @ENTSAI = 0
begin
update tbBloq set qtdpass = qtdpass + 1 where id_bloq = @IDBLOQ;
end else begin
update tbBloq set qtdpass = (case when (qtdpass <= 0) then 0 else (qtdpass - 1)end ) where id_bloq = @IDBLOQ;
end
end
if @TIPO = 'V' and @TIMEOUT = 0 AND not @STATUS is null begin
If @PRIMARIO = 1 begin
if @STATUS = 'D' begin
update tbVisi set aces_p = case when aces_p <= 0 then 0 else (aces_p - 1) end where id_pass = @ID_PASS;
end else if not exists(SELECT p.id_pass FROM tbPass p
INNER JOIN tbConsist c ON c.id_consist = p.id_consist AND isnull(c.c13,0)=0
WHERE p.id_pass= @ID_PASS) begin
select @aces_p = 0;
select @aces_p = isnull(aces_p,0) from tbVisi where id_pass = @ID_PASS;
/* Verificar se h marcao em batch */
if @aces_p=1 begin
select @st_ult=2, @st_eve=0;
SELECT TOP 1 @st_ult=isnull(m.status,2), @st_eve=isnull(m.evento,0) FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento=0
INNER JOIN tbBloq b ON b.id_bloq = m.relogio
INNER JOIN tbGBloq g ON g.id_gbloq = b.id_gbloq AND g.primario=1
WHERE m.id_pass=@ID_PASS
AND m.data BETWEEN convert(datetime,convert(varchar,@data_hora,101)) AND @data_hora
ORDER BY m.data DESC
if @st_ult=0 and @st_eve=5 begin
select @aces_p=0;
end;
end;
if @aces_p <= 0 begin
if @FORCARBAIXA = 1 or exists(select baixa_manual FROM tbParSist where isnull(baixa_manual,0) = 0) begin
select @CRACHA=ISNULL((SELECT cracha FROM tbPass WHERE id_pass=@ID_PASS),@CRACHA);
exec BAIXA_VISITANTE @CRACHA, @data_hora;
end
end
end
end
end
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.ACESSO_COMBINADO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.ACESSO_COMBINADO; END
GO
CREATE PROCEDURE dbo.ACESSO_COMBINADO(@id_bloq int, @processo int, @id_movim_atu bigint, @id_pass_atu int, @data_atu datetime, @funcao int, @evento tinyint, @aguardaAceComb bit output) WITH ENCRYPTION AS
BEGIN
declare @ace_comb tinyint;
declare @ult_id_movim bigint;
declare @ult_data datetime;
declare @ult_dif as int;
declare @qtde_ini int;
declare @qtde_tot int;
declare @id_mv int; declare @id_pass_mv int;
declare @achou bit;
declare @PRIMARIO BIT, @IDGBLOQ FLOAT, @TIPOBLOQ INT;
declare @CRACHA FLOAT, @ENTSAI INT, @TIPO CHAR(1), @STATUS CHAR(1);
declare @INDGBLOQ varchar(300), @TIPO_CONTROLE char(1);
SET NOCOUNT ON;
select @ace_comb=0, @aguardaAceComb=0, @TIPO_CONTROLE='';
SELECT @ace_comb=isnull(ace_comb,0), @TIPO_CONTROLE=isnull(tipo_controle,'A') FROM tbBloq WHERE id_bloq = @id_bloq;
select @ult_id_movim=0, @ult_dif=0, @qtde_ini=0, @qtde_tot=0;
if @ace_comb>0 and @TIPO_CONTROLE<>'V' begin
SELECT TOP 1 @ult_id_movim=isnull(id_movim,0), @ult_data=data
FROM tbBloqAcComb WHERE id_bloq = @id_bloq ORDER BY id_movim DESC;
if @ult_id_movim>0 begin
select @ult_dif=abs(datediff(s,@ult_data,@data_atu));
end;
if @ult_dif>10 and @processo<>3 begin
--Passou 10 segundos, zerar acesso combinado
UPDATE tbMovim SET evento = 53 WHERE id_movim IN (SELECT b.id_movim FROM tbBloqAcComb b WHERE b.id_bloq=@id_bloq);
DELETE FROM tbBloqAcComb WHERE id_bloq = @id_bloq;
end else begin
if @ult_id_movim>0 begin
SELECT @funcao=isnull(funcao,@funcao) FROM tbMovim WHERE id_movim=@ult_id_movim;
end;
end;
SELECT TOP 1 @qtde_tot=count(distinct id_pass) FROM tbBloqAcComb WHERE id_bloq = @id_bloq;
select @id_pass_atu=isnull(@id_pass_atu,0);
select @qtde_tot=isnull(@qtde_tot,0);
select @qtde_ini=1;
if @ace_comb>0 and @ace_comb<100 begin
select @qtde_ini=@ace_comb;
end else if isnull(@funcao,0)>0 and @ace_comb=100 begin
select @qtde_ini=@funcao;
end;
if @qtde_ini>1 begin
if @id_movim_atu>0
UPDATE tbMovim SET funcao=@qtde_ini WHERE id_movim=@id_movim_atu;
if @processo=1 begin --Liberar
if @id_pass_atu > 0 and @qtde_tot<@qtde_ini begin
if @qtde_tot<(@qtde_ini-1) or exists(select id_pass from tbBloqAcComb where id_bloq=@id_bloq and id_pass=@id_pass_atu) begin
select @aguardaAceComb=1;
end;
end;
end else if @processo=2 begin --gravar impedimento
if @evento=51 begin
if not exists(select id_pass from tbBloqAcComb where id_bloq=@id_bloq and id_pass=@id_pass_atu) begin
INSERT INTO tbBloqAcComb(id_bloq, id_movim, id_pass, data) VALUES (@id_bloq, @id_movim_atu, @id_pass_atu, @data_atu);
end;
end else begin
--Mudar evento de todos os anteriores
UPDATE tbMovim SET evento=53 WHERE id_movim IN (SELECT b.id_movim FROM tbBloqAcComb b WHERE b.id_bloq=@id_bloq);
DELETE FROM tbBloqAcComb WHERE id_bloq = @id_bloq;
end;
end else if @processo=3 begin --gravar liberao
--Inserir marcao atual
INSERT INTO tbBloqAcComb(id_bloq, id_movim, id_pass, data) VALUES (@id_bloq, @id_movim_atu, @id_pass_atu, @data_atu);
select @ENTSAI=0;
SELECT @ENTSAI=isnull(status,0) FROM tbMovim WHERE id_movim=@id_movim_atu;
-- o ltimo, ento gravar evento 52
UPDATE tbMovim SET evento = 52, status=@ENTSAI WHERE id_movim IN (SELECT b.id_movim FROM tbBloqAcComb b WHERE b.id_bloq=@id_bloq);
--Atualizar status
select @PRIMARIO=0, @TIPO_CONTROLE='A',@TIPOBLOQ=0,@IDGBLOQ=0;
SELECT @TIPO_CONTROLE=isnull(b.tipo_controle,'A'), @PRIMARIO=isnull(g.primario,0),
@TIPOBLOQ=isnull(b.tipo,0),@IDGBLOQ=isnull(g.id_gbloq,0)
FROM tbBloq b LEFT JOIN tbGBloq g ON b.id_gbloq=g.id_gbloq WHERE b.id_bloq=@id_bloq;
select @id_mv=0, @id_pass_mv=0, @achou=0;
SELECT TOP 1 @achou=1, @id_mv=isnull(id_movim,0), @id_pass_mv=id_pass FROM tbBloqAcComb WHERE id_bloq=@id_bloq ORDER BY id_movim;
while (@achou=1 and @id_mv>0 and @id_mv<@id_movim_atu)
begin
select @CRACHA=0,@STATUS='N',@TIPO='N',@INDGBLOQ='';
SELECT @CRACHA=isnull(cracha,0) FROM tbMovim WHERE id_movim=@id_mv;
SELECT @STATUS=isnull(status,'N'), @TIPO=isnull(tipo,'N'), @INDGBLOQ=isnull(indgbloq,'') from tbPass WHERE id_pass=@id_pass_mv;
If @PRIMARIO = 1 begin
if @ENTSAI = 0
select @STATUS='D';
else
select @STATUS='N';
end;
exec GRAVA_STATUS_PASSANTE @PRIMARIO, @id_bloq, @IDGBLOQ, @TIPOBLOQ, @id_pass_mv,
@CRACHA, @ENTSAI, @TIPO, @STATUS, 0, @INDGBLOQ, @TIPO_CONTROLE, 0, @data_atu;
select @achou=0;
SELECT TOP 1 @achou=1, @id_mv=isnull(id_movim,0), @id_pass_mv=id_pass FROM tbBloqAcComb WHERE id_bloq=@id_bloq AND id_movim>@id_mv ORDER BY id_movim;
end;
--Limpar registros de acesso combinado
DELETE FROM tbBloqAcComb WHERE id_bloq = @id_bloq;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_ESTA_NA_FAIXA_HORARIA') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.P_ESTA_NA_FAIXA_HORARIA; END
GO
CREATE PROCEDURE dbo.P_ESTA_NA_FAIXA_HORARIA (@id_pass int, @id_horario int, @primario bit, @data_hora_atual datetime, @ehferiado bit, @ehferiadoDiaAnt bit, @consist_thor bit, @na_faixa INT output) WITH ENCRYPTION AS
BEGIN
declare @id_horarioDiaAnt int;
declare @wdia int;
declare @hora float;
declare @fx1_i char(5); declare @fx1_f char(5); declare @fx2_i char(5); declare @fx2_f char(5);
declare @fx3_i char(5); declare @fx3_f char(5); declare @fx4_i char(5); declare @fx4_f char(5);
declare @fx5_i char(5); declare @fx5_f char(5); declare @fx6_i char(5); declare @fx6_f char(5);
declare @nfx1_i float; declare @nfx1_f float;   declare @nfx2_i float; declare @nfx2_f float;
declare @nfx3_i float; declare @nfx3_f float;   declare @nfx4_i float; declare @nfx4_f float;
declare @nfx5_i float; declare @nfx5_f float;   declare @nfx6_i float; declare @nfx6_f float;
declare @ultSai float; declare @ace_sema tinyint;
declare @id_escala float;
declare @achou bit; declare @dtRef datetime; declare @dom_data datetime;
declare @fx_secundario bit; declare @bloq_secundario bit;
select @id_escala = 0, @achou = 0, @na_faixa = 1;
select @dtRef = convert(datetime,convert(varchar,isnull(@data_hora_atual,'00:00:00'),101));
select @id_horarioDiaAnt = -1;
if not @id_horario is null begin
SELECT @achou = 1 from tbGHorarios where id_horario = @id_horario and escala = 1;
if @achou = 1
begin
select @id_escala = @id_horario;
select @achou = 0;
select @achou = 1, @id_horario = (case when folga = 1 then -1 else id_horario end)
from tbEscalasHorarios
where id_escala = @id_escala and data = @dtRef;
if @achou = 0
begin
select @achou = 0;
select @achou = 1, @id_horario = id_horario from tbEscalas where id_escala = @id_escala;
if @achou = 0
begin
select @id_horario = -1;
end
end
--Achar horrio do dia anterior
select @achou = 0;
select @achou = 1, @id_horarioDiaAnt = (case when folga = 1 then -1 else id_horario end)
from tbEscalasHorarios
where id_escala = @id_escala and data = dateadd(d,-1,@dtRef);
if @achou = 0
begin
select @achou = 0;
select @achou = 1, @id_horarioDiaAnt = id_horario from tbEscalas where id_escala = @id_escala;
if @achou = 0
begin
select @id_horarioDiaAnt = -1;
end
end
end else begin
select @id_horarioDiaAnt = @id_horario;
end
--Ver dia atual
if @id_horario > -1
begin
if @ehferiado = 1
begin
select @wdia = 8;
end else begin
select @wdia = DATEPART(dw,@data_hora_atual);
end
if @wdia = 1 --Domingo
begin
select @fx1_i = c1e1, @fx1_f = c1s1, @fx2_i = c1e2, @fx2_f = c1s2, @fx3_i = c1e3, @fx3_f = c1s3,
@fx4_i = c1e4, @fx4_f = c1s4, @fx5_i = c1e5, @fx5_f = c1s5, @fx6_i = c1e6, @fx6_f = c1s6
from tbHorarios where id_horario = @id_horario;
end
if @wdia = 2 --Segunda
begin
select @fx1_i = c2e1, @fx1_f = c2s1, @fx2_i = c2e2, @fx2_f = c2s2, @fx3_i = c2e3, @fx3_f = c2s3,
@fx4_i = c2e4, @fx4_f = c2s4, @fx5_i = c2e5, @fx5_f = c2s5, @fx6_i = c2e6, @fx6_f = c2s6
from tbHorarios where id_horario = @id_horario;
end
if @wdia = 3 --Tera
begin
select @fx1_i = c3e1, @fx1_f = c3s1, @fx2_i = c3e2, @fx2_f = c3s2, @fx3_i = c3e3, @fx3_f = c3s3,
@fx4_i = c3e4, @fx4_f = c3s4, @fx5_i = c3e5, @fx5_f = c3s5, @fx6_i = c3e6, @fx6_f = c3s6
from tbHorarios where id_horario = @id_horario;
end
if @wdia = 4 --Quarta
begin
select @fx1_i = c4e1, @fx1_f = c4s1, @fx2_i = c4e2, @fx2_f = c4s2, @fx3_i = c4e3, @fx3_f = c4s3,
@fx4_i = c4e4, @fx4_f = c4s4, @fx5_i = c4e5, @fx5_f = c4s5, @fx6_i = c4e6, @fx6_f = c4s6
from tbHorarios where id_horario = @id_horario;
end
if @wdia = 5 --Quinta
begin
select @fx1_i = c5e1, @fx1_f = c5s1, @fx2_i = c5e2, @fx2_f = c5s2, @fx3_i = c5e3, @fx3_f = c5s3,
@fx4_i = c5e4, @fx4_f = c5s4, @fx5_i = c5e5, @fx5_f = c5s5, @fx6_i = c5e6, @fx6_f = c5s6
from tbHorarios where id_horario = @id_horario;
end
if @wdia = 6 --Sexta
begin
select @fx1_i = c6e1, @fx1_f = c6s1, @fx2_i = c6e2, @fx2_f = c6s2, @fx3_i = c6e3, @fx3_f = c6s3,
@fx4_i = c6e4, @fx4_f = c6s4, @fx5_i = c6e5, @fx5_f = c6s5, @fx6_i = c6e6, @fx6_f = c6s6
from tbHorarios where id_horario = @id_horario;
end
if @wdia = 7 --Sbado
begin
select @fx1_i = c7e1, @fx1_f = c7s1, @fx2_i = c7e2, @fx2_f = c7s2, @fx3_i = c7e3, @fx3_f = c7s3,
@fx4_i = c7e4, @fx4_f = c7s4, @fx5_i = c7e5, @fx5_f = c7s5, @fx6_i = c7e6, @fx6_f = c7s6
from tbHorarios where id_horario = @id_horario;
end
if @wdia = 8 --Feriado
begin
select @fx1_i = c8e1, @fx1_f = c8s1, @fx2_i = c8e2, @fx2_f = c8s2, @fx3_i = c8e3, @fx3_f = c8s3,
@fx4_i = c8e4, @fx4_f = c8s4, @fx5_i = c8e5, @fx5_f = c8s5, @fx6_i = c8e6, @fx6_f = c8s6
from tbHorarios where id_horario = @id_horario;
end
--Faixas 5 e 6 para bloqueios secundrios
SELECT @fx_secundario=0;
SELECT @fx_secundario=fx_secundario FROM tbHorarios where id_horario = @id_horario;
if (@fx_secundario=1) begin
if @primario=0 begin
select @fx1_i=@fx5_i, @fx1_f=@fx5_f, @fx2_i=@fx6_i, @fx2_f=@fx6_f, @fx3_i='__:__', @fx3_f='__:__', @fx4_i='__:__', @fx4_f='__:__';
end;
select @fx5_i='__:__', @fx5_f='__:__', @fx6_i='__:__', @fx6_f='__:__';
end;
select @fx1_i = (case when isnull(@fx1_i,'__:__') = '__:__' then '00:00' else @fx1_i end);
select @fx1_f = (case when isnull(@fx1_f,'__:__') = '__:__' then '00:00' else @fx1_f end);
select @fx2_i = (case when isnull(@fx2_i,'__:__') = '__:__' then '00:00' else @fx2_i end);
select @fx2_f = (case when isnull(@fx2_f,'__:__') = '__:__' then '00:00' else @fx2_f end);
select @fx3_i = (case when isnull(@fx3_i,'__:__') = '__:__' then '00:00' else @fx3_i end);
select @fx3_f = (case when isnull(@fx3_f,'__:__') = '__:__' then '00:00' else @fx3_f end);
select @fx4_i = (case when isnull(@fx4_i,'__:__') = '__:__' then '00:00' else @fx4_i end);
select @fx4_f = (case when isnull(@fx4_f,'__:__') = '__:__' then '00:00' else @fx4_f end);
select @fx5_i = (case when isnull(@fx5_i,'__:__') = '__:__' then '00:00' else @fx5_i end);
select @fx5_f = (case when isnull(@fx5_f,'__:__') = '__:__' then '00:00' else @fx5_f end);
select @fx6_i = (case when isnull(@fx6_i,'__:__') = '__:__' then '00:00' else @fx6_i end);
select @fx6_f = (case when isnull(@fx6_f,'__:__') = '__:__' then '00:00' else @fx6_f end);
select @nfx1_i = (convert(float,left(@fx1_i,2)) * 100) + convert(float,right(@fx1_i,2))
select @nfx1_f = (convert(float,left(@fx1_f,2)) * 100) + convert(float,right(@fx1_f,2))
select @nfx2_i = (convert(float,left(@fx2_i,2)) * 100) + convert(float,right(@fx2_i,2))
select @nfx2_f = (convert(float,left(@fx2_f,2)) * 100) + convert(float,right(@fx2_f,2))
select @nfx3_i = (convert(float,left(@fx3_i,2)) * 100) + convert(float,right(@fx3_i,2))
select @nfx3_f = (convert(float,left(@fx3_f,2)) * 100) + convert(float,right(@fx3_f,2))
select @nfx4_i = (convert(float,left(@fx4_i,2)) * 100) + convert(float,right(@fx4_i,2))
select @nfx4_f = (convert(float,left(@fx4_f,2)) * 100) + convert(float,right(@fx4_f,2))
select @nfx5_i = (convert(float,left(@fx5_i,2)) * 100) + convert(float,right(@fx5_i,2))
select @nfx5_f = (convert(float,left(@fx5_f,2)) * 100) + convert(float,right(@fx5_f,2))
select @nfx6_i = (convert(float,left(@fx6_i,2)) * 100) + convert(float,right(@fx6_i,2))
select @nfx6_f = (convert(float,left(@fx6_f,2)) * 100) + convert(float,right(@fx6_f,2))
select @hora = (datepart(hh,@data_hora_atual) * 100) + datepart(mi,@data_hora_atual);
if (@nfx1_i <= @nfx1_f and @hora >= @nfx1_i and @hora <= @nfx1_f) or (@nfx1_i > @nfx1_f and (@hora >= @nfx1_i or @hora <= @nfx1_f)) or
(@nfx2_i <= @nfx2_f and @hora >= @nfx2_i and @hora <= @nfx2_f) or (@nfx2_i > @nfx2_f and (@hora >= @nfx2_i or @hora <= @nfx2_f)) or
(@nfx3_i <= @nfx3_f and @hora >= @nfx3_i and @hora <= @nfx3_f) or (@nfx3_i > @nfx3_f and (@hora >= @nfx3_i or @hora <= @nfx3_f)) or
(@nfx4_i <= @nfx4_f and @hora >= @nfx4_i and @hora <= @nfx4_f) or (@nfx4_i > @nfx4_f and (@hora >= @nfx4_i or @hora <= @nfx4_f)) or
(@nfx5_i <= @nfx5_f and @hora >= @nfx5_i and @hora <= @nfx5_f) or (@nfx5_i > @nfx5_f and (@hora >= @nfx5_i or @hora <= @nfx5_f)) or
(@nfx6_i <= @nfx6_f and @hora >= @nfx6_i and @hora <= @nfx6_f) or (@nfx6_i > @nfx6_f and (@hora >= @nfx6_i or @hora <= @nfx6_f))
begin
select @na_faixa = 1;
end else begin
select @na_faixa = 0;
end
end else begin
select @na_faixa = 2;
end
--Ver dia anterior
if @na_faixa <> 1 and @id_horarioDiaAnt > -1
begin
if @ehferiadoDiaAnt = 1
begin
select @wdia = 8;
end else begin
select @wdia = DATEPART(dw,DATEADD(day,-1,@data_hora_atual));
end
if @wdia = 1 --Domingo
begin
select @fx1_i = c1e1, @fx1_f = c1s1, @fx2_i = c1e2, @fx2_f = c1s2, @fx3_i = c1e3, @fx3_f = c1s3,
@fx4_i = c1e4, @fx4_f = c1s4, @fx5_i = c1e5, @fx5_f = c1s5, @fx6_i = c1e6, @fx6_f = c1s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
if @wdia = 2 --Segunda
begin
select @fx1_i = c2e1, @fx1_f = c2s1, @fx2_i = c2e2, @fx2_f = c2s2, @fx3_i = c2e3, @fx3_f = c2s3,
@fx4_i = c2e4, @fx4_f = c2s4, @fx5_i = c2e5, @fx5_f = c2s5, @fx6_i = c2e6, @fx6_f = c2s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
if @wdia = 3 --Tera
begin
select @fx1_i = c3e1, @fx1_f = c3s1, @fx2_i = c3e2, @fx2_f = c3s2, @fx3_i = c3e3, @fx3_f = c3s3,
@fx4_i = c3e4, @fx4_f = c3s4, @fx5_i = c3e5, @fx5_f = c3s5, @fx6_i = c3e6, @fx6_f = c3s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
if @wdia = 4 --Quarta
begin
select @fx1_i = c4e1, @fx1_f = c4s1, @fx2_i = c4e2, @fx2_f = c4s2, @fx3_i = c4e3, @fx3_f = c4s3,
@fx4_i = c4e4, @fx4_f = c4s4, @fx5_i = c4e5, @fx5_f = c4s5, @fx6_i = c4e6, @fx6_f = c4s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
if @wdia = 5 --Quinta
begin
select @fx1_i = c5e1, @fx1_f = c5s1, @fx2_i = c5e2, @fx2_f = c5s2, @fx3_i = c5e3, @fx3_f = c5s3,
@fx4_i = c5e4, @fx4_f = c5s4, @fx5_i = c5e5, @fx5_f = c5s5, @fx6_i = c5e6, @fx6_f = c5s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
if @wdia = 6 --Sexta
begin
select @fx1_i = c6e1, @fx1_f = c6s1, @fx2_i = c6e2, @fx2_f = c6s2, @fx3_i = c6e3, @fx3_f = c6s3,
@fx4_i = c6e4, @fx4_f = c6s4, @fx5_i = c6e5, @fx5_f = c6s5, @fx6_i = c6e6, @fx6_f = c6s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
if @wdia = 7 --Sbado
begin
select @fx1_i = c7e1, @fx1_f = c7s1, @fx2_i = c7e2, @fx2_f = c7s2, @fx3_i = c7e3, @fx3_f = c7s3,
@fx4_i = c7e4, @fx4_f = c7s4, @fx5_i = c7e5, @fx5_f = c7s5, @fx6_i = c7e6, @fx6_f = c7s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
if @wdia = 8 --Feriado
begin
select @fx1_i = c8e1, @fx1_f = c8s1, @fx2_i = c8e2, @fx2_f = c8s2, @fx3_i = c8e3, @fx3_f = c8s3,
@fx4_i = c8e4, @fx4_f = c8s4, @fx5_i = c8e5, @fx5_f = c8s5, @fx6_i = c8e6, @fx6_f = c8s6
from tbHorarios where id_horario = @id_horarioDiaAnt;
end
select @fx1_i = (case when isnull(@fx1_i,'__:__') = '__:__' then '00:00' else @fx1_i end);
select @fx1_f = (case when isnull(@fx1_f,'__:__') = '__:__' then '00:00' else @fx1_f end);
select @fx2_i = (case when isnull(@fx2_i,'__:__') = '__:__' then '00:00' else @fx2_i end);
select @fx2_f = (case when isnull(@fx2_f,'__:__') = '__:__' then '00:00' else @fx2_f end);
select @fx3_i = (case when isnull(@fx3_i,'__:__') = '__:__' then '00:00' else @fx3_i end);
select @fx3_f = (case when isnull(@fx3_f,'__:__') = '__:__' then '00:00' else @fx3_f end);
select @fx4_i = (case when isnull(@fx4_i,'__:__') = '__:__' then '00:00' else @fx4_i end);
select @fx4_f = (case when isnull(@fx4_f,'__:__') = '__:__' then '00:00' else @fx4_f end);
select @fx5_i = (case when isnull(@fx5_i,'__:__') = '__:__' then '00:00' else @fx5_i end);
select @fx5_f = (case when isnull(@fx5_f,'__:__') = '__:__' then '00:00' else @fx5_f end);
select @fx6_i = (case when isnull(@fx6_i,'__:__') = '__:__' then '00:00' else @fx6_i end);
select @fx6_f = (case when isnull(@fx6_f,'__:__') = '__:__' then '00:00' else @fx6_f end);
select @nfx1_i = (convert(float,left(@fx1_i,2)) * 60) + convert(float,right(@fx1_i,2))
select @nfx1_f = (convert(float,left(@fx1_f,2)) * 60) + convert(float,right(@fx1_f,2))
select @nfx2_i = (convert(float,left(@fx2_i,2)) * 60) + convert(float,right(@fx2_i,2))
select @nfx2_f = (convert(float,left(@fx2_f,2)) * 60) + convert(float,right(@fx2_f,2))
select @nfx3_i = (convert(float,left(@fx3_i,2)) * 60) + convert(float,right(@fx3_i,2))
select @nfx3_f = (convert(float,left(@fx3_f,2)) * 60) + convert(float,right(@fx3_f,2))
select @nfx4_i = (convert(float,left(@fx4_i,2)) * 60) + convert(float,right(@fx4_i,2))
select @nfx4_f = (convert(float,left(@fx4_f,2)) * 60) + convert(float,right(@fx4_f,2))
select @nfx5_i = (convert(float,left(@fx5_i,2)) * 60) + convert(float,right(@fx5_i,2))
select @nfx5_f = (convert(float,left(@fx5_f,2)) * 60) + convert(float,right(@fx5_f,2))
select @nfx6_i = (convert(float,left(@fx6_i,2)) * 60) + convert(float,right(@fx6_i,2))
select @nfx6_f = (convert(float,left(@fx6_f,2)) * 60) + convert(float,right(@fx6_f,2))
select @hora = (datepart(hh,@data_hora_atual) * 60) + datepart(mi,@data_hora_atual);
select @ultSai = -1
if @nfx1_i > @nfx1_f and @nfx1_f > 0
select @ultSai = @nfx1_f;
if @nfx2_i > @nfx2_f and @nfx2_f > 0
select @ultSai = @nfx2_f;
if @nfx3_i > @nfx3_f and @nfx3_f > 0
select @ultSai = @nfx3_f;
if @nfx4_i > @nfx4_f and @nfx4_f > 0
select @ultSai = @nfx4_f;
if @nfx5_i > @nfx5_f and @nfx5_f > 0
select @ultSai = @nfx5_f;
if @nfx6_i > @nfx6_f and @nfx6_f > 0
select @ultSai = @nfx6_f;
if @ultSai>0 and @hora<=(@ultSai + (case when @consist_thor=0 then 300 else 0 end))
begin
select @na_faixa = 3;
end
end
end
if isnull(@id_pass,0)>0 and isnull(@na_faixa,0)=1 begin
select @ace_sema=0;
if isnull(@id_horario,0)>0 begin
SELECT @ace_sema=isnull(ace_sema,0) FROM tbHorarios WHERE id_horario = @id_horario;
end else begin if isnull(@id_horarioDiaAnt,0)>0 begin
SELECT @ace_sema=isnull(ace_sema,0) FROM tbHorarios WHERE id_horario = @id_horarioDiaAnt;
end; end;
if isnull(@ace_sema,0)>0 begin
select @dom_data = dateadd(d,(DATEPART(dw,@dtRef)-1)*(-1),@dtRef);
select @wdia=0;
SELECT @wdia=COUNT(DISTINCT convert(datetime,convert(varchar,isnull(m.data,'00:00:00'),101))) FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbEventoSist e ON m.evento=e.id_evento
WHERE m.id_pass=@id_pass AND m.data>=@dom_data AND m.data<@dtRef AND e.flagimpedimento=0;
if isnull(@wdia,0)>=@ace_sema begin select @na_faixa=0; end;
end;
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.VALIDA_BLOQUEIO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.VALIDA_BLOQUEIO; END
GO
CREATE PROCEDURE dbo.VALIDA_BLOQUEIO (@TERMINAL INT output, @LIBERAR bit output, @MSGRELOGIO varchar(32) output, @EVENTO int output,
@ENTSAI char(1) output, @id_bloq smallint output, @st_bloq tinyint output,
@descricao varchar(20) output, @tipo tinyint output, @sentido varchar(1) output,
@id_gbloq int output, @tipo_controle char(1) output, @ip char(15) output, @bloqatuac tinyint output,
@bloqentr bit output, @bloqsaid bit output, @semconsstpass bit output,
@bloqueado bit output, @primario bit output, @forcarbaixa bit output,
@entradiretosecundario bit output, @naotravasequencia bit output, @visitantesaisoaqui bit output,
@naoverhorariogrupo bit output, @naoverhorariopass bit output, @comunicacao int output, @bloq_senha bit output,
@data_hora_atual datetime, @mestre bit, @saidaliberada bit,
@terleitor char(1),@tipopass char(1), @numterleitor int, @l_Funcao As int,
@consist_numacessos_vis bit, @visi_aces_p smallint) WITH ENCRYPTION AS
BEGIN
declare @achou bit;  declare @id_horario int;
declare @sim bit     declare @tanafx int;
select @achou = 0;
select top 1 @achou = 1, @id_bloq = tbBloq.id_bloq, @st_bloq = tbBloq.st_bloq,
@descricao = tbBloq.descricao, @tipo = tbBloq.tipo, @sentido = tbBloq.sentido,
@id_gbloq = tbBloq.id_gbloq, @tipo_controle = isnull(tipo_controle,'A'), @ip = tbBloq.ip,
@bloqatuac = tbBloq.atuac, @bloqentr = tbBloq.entr, @bloqsaid = tbBloq.said,
@semconsstpass = tbBloq.stpass, @entradiretosecundario = tbBloq.flagsecundario,
@naotravasequencia = tbBloq.travasequencia, @visitantesaisoaqui = tbBloq.flagvisitante,
@bloqueado = tbGBloq.bloqueado, @primario = tbGBloq.primario,
@naoverhorariopass = isnull(tbBloq.flaghorario,0),
@naoverhorariogrupo = isnull(tbGBloq.flaghorario,0),
@id_horario = id_horario, @comunicacao = isnull(tbBloq.comunicacao,0), @bloq_senha=isnull(tbBloq.senha,0)
from tbBloq inner join tbGBloq on tbBloq.id_gbloq = tbGBloq.id_gbloq
Where (tbBloq.id_bloq = @TERMINAL);
if isnull(@achou,0) = 1 and @mestre = 0
begin
if (@comunicacao = 5 OR @comunicacao = 17 OR @comunicacao = 18) begin
select @bloqatuac = 0;
end;
If @st_bloq  = 1
begin
select @LIBERAR = 0;
select @EVENTO = 37;
select @MSGRELOGIO = 'EQUIPAMENTO BLOQUEADO';
end else begin
If @bloqueado  = 1
begin
select @LIBERAR = 0;
select @EVENTO = 34;
select @MSGRELOGIO = 'GRP BLOQ BLOQUEADO';
end else begin
If @saidaliberada = 0 or @ENTSAI = 'E'
begin
exec P_ESTA_NA_FAIXA_HORARIA 0, @id_horario, @primario, @data_hora_atual, 0,0, 1, @tanafx output;
if @naoverhorariogrupo = 0 and @tanafx = 0
begin
select @LIBERAR = 0;
select @EVENTO = 35;
select @MSGRELOGIO = 'BLOQ FORA DO HORARIO';
end
if @LIBERAR = 1
begin
If @terleitor = 'S'
begin
if @tipopass = 'V'
begin
if EXISTS(SELECT id_bloq FROM tbBloqRelay WHERE id_bloq=@id_bloq AND sentido=9) begin
If @numterleitor=2 begin
select @LIBERAR = 0;
select @EVENTO = 43;
select @MSGRELOGIO = 'DEPOSITE NA URNA';
end;
end else if @consist_numacessos_vis=1 begin
If @numterleitor=2 and @visi_aces_p <= 0
begin
select @LIBERAR = 0;
select @EVENTO = 43;
select @MSGRELOGIO = 'DEPOSITE NA URNA';
end else begin
if @numterleitor=3 begin
select @forcarbaixa = 1; -- baixar o visitante (forando a baixa para visitante)
end
end
end
end else begin
if @numterleitor=3 and (@comunicacao<>5 OR EXISTS(SELECT id_bloq FROM tbBloq WHERE id_bloq=@id_bloq AND left(program,5) in ('PWBIN','PWBIO')))
begin
select @LIBERAR = 0;
select @EVENTO = 43;
select @MSGRELOGIO = 'LEITOR INVALIDO';
end
end
end
end
if @LIBERAR = 1 and not @terleitor = 'S'
begin
if @bloqatuac = 0
begin
if (@ENTSAI = 'E' And @bloqentr = 0) or (@ENTSAI = 'S' And @bloqsaid = 0)
begin
select @LIBERAR = 0;
select @EVENTO = 37;
select @MSGRELOGIO = 'SENTIDO PROIBIDO';
end
end else begin
if @bloqatuac = 1
begin
select @ENTSAI = 'E';
end else begin
select @ENTSAI = 'S';
end
end
end
end -- If @saidaliberada = 0 or @ENTSAI = 'E'
end
end
end  -- if isnull(@achou,0) = 1
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.CARREGA_CONSISTENCIAS') AND xtype = 'P') BEGIN  DROP PROCEDURE dbo.CARREGA_CONSISTENCIAS; END
GO
CREATE PROCEDURE dbo.CARREGA_CONSISTENCIAS (@idconsist int, @consist_via bit output, @consist_tbhorpas bit output,
@consist_libbloq bit output, @consist_permanencia bit output,
@consist_afastamento bit output, @consist_feriado bit output,
@consist_numacessos_vis bit output, @consist_reentrada bit output,
@consist_resaida bit output, @consist_folga bit output,
@consist_horarioindevido bit output, @consist_ausenciaminima bit output, @consist_estourodedias bit output,
@consist_acessos_dia bit output,
@consist_max_sublocal bit output, @consist_max_visitado bit output,
@consist_integracao bit output, @consist_agrefeit bit output) WITH ENCRYPTION AS
BEGIN
if not @idconsist is null
begin
select @consist_via = c6, @consist_tbhorpas = c7, @consist_libbloq = c8,
@consist_permanencia = c10, @consist_afastamento = c11, @consist_feriado = c12,
@consist_numacessos_vis = c13, @consist_reentrada = c14, @consist_resaida = c15,
@consist_folga = c16, @consist_estourodedias = c17, @consist_horarioindevido = c29, @consist_ausenciaminima = c33,
@consist_acessos_dia = c30, @consist_max_sublocal = c31, @consist_max_visitado = c32,
@consist_integracao = isnull(c9,0), @consist_agrefeit=isnull(c34,0)
from tbConsist where id_consist = @idconsist;
end
select @consist_via = isnull(@consist_via,0);
select @consist_tbhorpas = isnull(@consist_tbhorpas,0);
select @consist_libbloq = isnull(@consist_libbloq,0);
select @consist_permanencia = isnull(@consist_permanencia,0);
select @consist_afastamento = isnull(@consist_afastamento,0);
select @consist_feriado = isnull(@consist_feriado,0);
select @consist_numacessos_vis = isnull(@consist_numacessos_vis,0);
select @consist_reentrada = isnull(@consist_reentrada,0);
select @consist_resaida = isnull(@consist_resaida,0);
select @consist_folga = isnull(@consist_folga,0);
select @consist_horarioindevido = isnull(@consist_horarioindevido,0);
select @consist_ausenciaminima = isnull(@consist_ausenciaminima,0);
select @consist_agrefeit = isnull(@consist_agrefeit,0);
select @consist_estourodedias = isnull(@consist_estourodedias,0);
select @consist_acessos_dia = isnull(@consist_acessos_dia,0);
select @consist_max_sublocal = isnull(@consist_max_sublocal,0);
select @consist_max_visitado = isnull(@consist_max_visitado,0);
select @consist_integracao = isnull(@consist_integracao,0);
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_RESPONSAVEL_PRESENTE') AND xtype = 'P') BEGIN  DROP PROCEDURE dbo.P_RESPONSAVEL_PRESENTE; END
GO
CREATE PROCEDURE dbo.P_RESPONSAVEL_PRESENTE (@id_pass int, @gc_TempoEstouroPais int,
@data_hora_atual datetime, @responsavelpresente bit output) WITH ENCRYPTION AS
BEGIN
declare @status char(1);
declare @ult_acess datetime;
declare @ult_acessd datetime;
declare @achou bit;
declare @min int;
declare @min2 int;
select @responsavelpresente = 0;
if isnull(@id_pass,0) > 0
begin
select @achou = 0;
select top 1 @achou = 1, @status = status, @ult_acess = ult_acess, @ult_acessd = ult_acessd
from tbPass where id_pass = @id_pass;
if @achou = 1 and isnull(@status,'N') = 'D' and not @ult_acessd is null and not @ult_acess is null
begin
if @gc_TempoEstouroPais = 0
begin
select @responsavelpresente = 1;
end else begin
if convert(datetime,convert(varchar,isnull(@data_hora_atual,'00:00:00'),101)) = convert(datetime,convert(varchar,isnull(@ult_acessd,'00:00:00'),101))
begin
exec AP_PTO001 @data_hora_atual, @min output;
exec AP_PTO001 @ult_acess, @min2 output;
if (@min - @min2) < @gc_TempoEstouroPais
select @responsavelpresente = 1;
end else begin
exec AP_PTO001 @data_hora_atual, @min output;
exec AP_PTO001 @ult_acess, @min2 output;
if (1440 + (@min - @min2)) < @gc_TempoEstouroPais
select @responsavelpresente = 1;
end
end
end
end
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.GRAVA_TEMPLATE_SG') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.GRAVA_TEMPLATE_SG; END
GO
CREATE PROCEDURE dbo.GRAVA_TEMPLATE_SG (@id_bloq int, @cracha float, @template VARCHAR(2500)) WITH ENCRYPTION AS
BEGIN
declare @id_pass as int;
declare @digi1 as varchar(2500), @digi2 as varchar(2500);
declare @tam1 as int, @tam2 as int;
declare @achou bit;
select @id_pass=0, @digi1='', @digi2='', @tam1=0, @tam2=0;
select @achou=0;
SELECT top 1 @achou=1, @id_pass=f.id_pass FROM tbFunc f INNER JOIN tbPass p ON p.id_pass = f.id_pass
WHERE p.cracha = @cracha AND NOT EXISTS (
SELECT e.id_empresa FROM tbEmpresas e WHERE e.id_empresa = p.id_empresa AND ISNULL(e.inativo_ace,0) = 1
) AND p.inativo = 0
ORDER BY p.inativo DESC, f.dtdemissao ASC;
if @achou=0 begin
SELECT top 1 @achou=1, @id_pass=p.id_pass FROM tbPass p
WHERE p.cracha = @cracha AND p.tipo in ('T','C','A') AND NOT EXISTS (
SELECT e.id_empresa FROM tbEmpresas e WHERE e.id_empresa = p.id_empresa AND ISNULL(e.inativo_ace,0) = 1
) AND p.inativo = 0
ORDER BY p.inativo DESC
end;
if @achou=1 begin
select @tam1 = (((ascii(substring(@template,1,1))-48) * 16) + (ascii(substring(@template,2,1))-48)) * 2;
if @tam1 > 0 begin
select @digi1 = substring(@template, 3, @tam1);
if len(ltrim(@digi1)) > 0 begin
select @digi1 = '#MDDIG#' + @digi1;
select @tam2 = (((ascii(substring(@template,3 + @tam1,1))-48) * 16) + (ascii(substring(@template,4 + @tam1,1))-48)) * 2;
if @tam2 > 0 begin
select @digi2 = substring(@template, 5 + @tam1, @tam2);
if len(ltrim(@digi2)) > 0 begin
select @digi2 = '#MDDIG#' + @digi2;
end else begin
select @tam2 = 0;
end;
end;
end else begin
select @tam1 = 0;
end;
end;
end;
if isnull(@id_pass,0)>0 begin
if @tam1 > 0 begin
if not exists(SELECT id_pass FROM tbDigitais WHERE id_pass=@id_pass AND formato=0 AND ordem=1) begin
INSERT INTO tbDigitais (id_pass, ordem, digital, formato) VALUES (@id_pass, 1, @digi1, 0);
end else begin
UPDATE tbDigitais SET digital=@digi1 WHERE id_pass=@id_pass AND ordem=1 AND formato=0;
end;
end;
if @tam2 > 0 begin
if not exists(SELECT id_pass FROM tbDigitais WHERE id_pass=@id_pass AND formato=0 AND ordem=2) begin
INSERT INTO tbDigitais (id_pass, ordem, digital, formato) VALUES (@id_pass, 2, @digi2, 0);
end else begin
UPDATE tbDigitais SET digital=@digi2 WHERE id_pass=@id_pass AND ordem=2 AND formato=0;
end;
end;
if @tam1>0 begin
DELETE FROM tbIncDigi WHERE id_pass=@id_pass AND id_bloq<>@id_bloq;
if exists(SELECT id_bloq FROM tbBloq WHERE id_bloq<>@id_bloq) begin
INSERT INTO tbIncDigi (id_bloq, id_pass) SELECT id_bloq, @id_pass FROM tbBloq WHERE id_bloq<>@id_bloq;
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.RET_TEMPLATE_SG') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.RET_TEMPLATE_SG; END
GO
CREATE PROCEDURE dbo.RET_TEMPLATE_SG (@id_pass int, @retRow bit, @template VARCHAR(2500) output) WITH ENCRYPTION AS
BEGIN
declare @dedo1 int, @dedo2 int, @digi1 varchar(2500), @digi2 varchar(2500);
declare @tam1 int, @tam2 int, @pri int, @seg int;
select @template='';
select @dedo1=-1, @dedo2=-1, @digi1='', @digi2='', @tam1=0, @tam2=0;
SELECT TOP 1 @dedo1=ordem, @digi1=Right(digital, Len(digital) - 7) FROM tbDigitais
WHERE id_pass=@id_pass AND formato=0 AND isnull(digital,'') LIKE '%#MDDIG#%'
ORDER BY ordem;
if @dedo1>-1 begin
select @tam1=len(@digi1);
SELECT TOP 1 @dedo2=ordem, @digi2=Right(digital, Len(digital) - 7) FROM tbDigitais
WHERE id_pass=@id_pass AND formato=0 AND isnull(digital,'') LIKE '%#MDDIG#%'
AND ordem>@dedo1
ORDER BY ordem;
if @dedo2=-1 begin
select @dedo2=@dedo1, @digi2=@digi1
end;
select @tam2=len(@digi2);
if @dedo1>0 begin
select @dedo1=@dedo1-1;
end;
if @dedo2>0 begin
select @dedo2=@dedo2-1;
end;
if @tam1+@tam2 < 2500 begin
select @tam1 = @tam1 / 2;
select @pri = @tam1 / 16;
select @seg = @tam1 - (@pri * 16);
select @pri = @pri + 48;
select @seg = @seg + 48;
select @template = CHAR(@pri) + CHAR(@seg) + @digi1;
select @tam2 = @tam2 / 2;
select @pri = @tam2 / 16;
select @seg = @tam2 - (@pri * 16);
select @pri = @pri + 48;
select @seg = @seg + 48;
select @template = @template + CHAR(@pri) + CHAR(@seg) + @digi2;
end;
end;
if (@retRow=1)
select @template as template;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.P_INTEG_VENC') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.P_INTEG_VENC; END
GO
CREATE PROCEDURE dbo.P_INTEG_VENC(@id_pass INT, @id_bloq INT, @data_ref datetime, @vencido INT output) WITH ENCRYPTION AS
BEGIN
DECLARE @sql varchar(250);
SELECT @vencido=0;
select @sql='exec INFO_INTG_PASS ' + CONVERT(varchar,@id_pass) + ', 0, 0';
EXEC(@sql);
SELECT TOP 1 @vencido=1 FROM tbInfoIntV
WHERE id_pass=@id_pass AND tipo_info=1 AND dtvencido<=@data_ref
AND (id_info IN (
SELECT distinct e.id_emedico FROM tbRIntegraExame e
INNER JOIN tbRIntegra i ON e.id_rintegra=i.id_rintegra
WHERE (i.tbloq=1 OR i.id_rintegra IN (SELECT b.id_rintegra FROM tbRIntegraBloq b WHERE b.id_bloq=@id_bloq))
) or EXISTS(
SELECT distinct i2.id_rintegra FROM tbRIntegra i2
WHERE i2.texame=1
AND (i2.tbloq=1 OR i2.id_rintegra IN (SELECT b.id_rintegra FROM tbRIntegraBloq b WHERE b.id_bloq=@id_bloq))
))
if @vencido=0 begin
SELECT TOP 1 @vencido=1 FROM tbInfoIntV
WHERE id_pass=@id_pass AND tipo_info=2 AND dtvencido<=@data_ref
AND (id_info IN (
SELECT distinct e.id_treina FROM tbRIntegraTreina e
INNER JOIN tbRIntegra i ON e.id_rintegra=i.id_rintegra
WHERE (i.tbloq=1 OR i.id_rintegra IN (SELECT b.id_rintegra FROM tbRIntegraBloq b WHERE b.id_bloq=@id_bloq))
) or EXISTS(
SELECT distinct i2.id_rintegra FROM tbRIntegra i2
WHERE i2.ttreina=1
AND (i2.tbloq=1 OR i2.id_rintegra IN (SELECT b.id_rintegra FROM tbRIntegraBloq b WHERE b.id_bloq=@id_bloq))
))
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.GRAVA_ENV_DIGI') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.GRAVA_ENV_DIGI; END
GO
CREATE PROCEDURE dbo.GRAVA_ENV_DIGI (@id_bloq int, @id_pass int, @codigo float, @apaga bit) WITH ENCRYPTION AS
BEGIN
declare @temDigi bit;
if (@apaga=1) begin
if (@id_pass>0) begin
DELETE FROM tbEnvDigi WHERE id_bloq=@id_bloq AND id_pass=@id_pass;
end else begin
DELETE FROM tbEnvDigi WHERE id_bloq=@id_bloq AND id_pass IN (
SELECT TOP 1 id_pass FROM tbPass WHERE cracha = @codigo ORDER BY data ASC
);
end;
end else if (@id_pass>0) begin
select @temDigi=0;
if EXISTS(SELECT TOP 1 id_pass FROM tbDigitais WHERE id_pass=@id_pass) begin
select @temDigi=1;
end;
if (@temDigi=0) begin
DELETE FROM tbEnvDigi WHERE id_bloq=@id_bloq AND id_pass=@id_pass;
end else if NOT EXISTS(SELECT id_pass FROM tbEnvDigi WHERE id_bloq=@id_bloq AND id_pass=@id_pass) begin
INSERT INTO tbEnvDigi (id_bloq, id_pass, data) VALUES (@id_bloq, @id_pass, getdate());
end else begin
UPDATE tbEnvDigi SET data=GETDATE() WHERE id_bloq=@id_bloq AND id_pass=@id_pass;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.VALIDA_ACESSO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.VALIDA_ACESSO; END
GO
CREATE PROCEDURE dbo.VALIDA_ACESSO (@TERMINAL INT, @CRACHA FLOAT, @VIA INT,
@ENTSAI CHAR(1), @TERLEITOR CHAR(1), @NUMTERLEITOR INT,
@SENHA FLOAT, @CRACHATECLADO CHAR(1), @GC_TEMPOESTOUROPAIS INT,
@L_FUNCAO INT = 1, @LFUSO DATETIME = NULL) WITH ENCRYPTION AS
BEGIN
declare @data_hora_atual datetime; declare @apenas_data datetime; declare @apenas_data_antes datetime;
declare @apenas_minutos int; declare @data_hora_small smalldatetime;
declare @id_pass int;
declare @id_empresa int;           declare @crachacad float;      declare @viacad tinyint;
declare @tipo varchar(1);          declare @nome varchar(100);     declare @vip bit;
declare @nasc smalldatetime;
declare @indesejado bit;           declare @bloqueado bit; declare @stat_inativo bit;   declare @id_horario int;
declare @id_depart int;            declare @id_phorario int;
declare @per_indet bit;            declare @data_ini smalldatetime;  declare @data_fim smalldatetime;
declare @provisorio float;
declare @prov_ini smalldatetime;   declare @prov_fim smalldatetime;  declare @id_msgrel tinyint;
declare @id_msgtela int;           declare @msg_qtd_p smallint;      declare @foto varchar(25);
declare @fotodoc varchar(25);      declare @g_bloq varchar(255);     declare @data smalldatetime;
declare @horario smalldatetime;
declare @usu_resp int;             declare @status varchar(1);       declare @feriado bit;
declare @afast_ini smalldatetime;
declare @afast_fim smalldatetime;   declare @ult_acess datetime; declare @reinic bit;
declare @indgbloq varchar(300);     declare @id_consist int;  declare @senhacad float;
declare @codass varchar(15);        declare @ult_acessd datetime;   declare @ult_idbloq int;
declare @ult_direc tinyint;         declare @ult_lib datetime;
declare @sequencia varchar(1600);   declare @contador int;    declare @membership tinyint;
declare @cartaoimpresso tinyint;    declare @fotodocVerso varchar(25);   declare @via_provisorio int;
declare @achou bit;                 declare @descmestre varchar(32)
declare @tipobloq tinyint;          declare @id_bloq smallint; declare @st_bloq tinyint;
declare @descricaobloq varchar(20); declare @sentidobloq varchar(1);
declare @entradiretosecundario bit; declare @antesentradiretosecundario bit;
declare @naotravasequencia bit;
declare @naoverhorariogrupo bit;    declare @naoverhorariopass bit;
declare @id_gbloq int; declare @tipo_controle char(1) ; declare @ip char(15);
declare @bloqatuac tinyint; declare @bloqentr bit; declare @bloqsaid bit;
declare @semconsstpass bit; declare @visitantesaisoaqui bit;
declare @bloqueadobloq bit; declare @primario bit;
declare @saidaliberada bit; declare @ehferiado bit; declare @ehferiadoDiaAnt bit;
declare @consist_via bit; declare @consist_tbhorpas bit;
declare @consist_libbloq bit; declare @consist_permanencia bit;
declare @consist_afastamento bit; declare @consist_feriado bit;
declare @consist_numacessos_vis bit; declare @consist_reentrada bit;
declare @consist_resaida bit; declare @consist_folga bit;
declare @consist_horarioindevido bit; declare @consist_ausenciaminima bit; declare @consist_estourodedias bit;
declare @consist_acessos_dia bit; declare @consist_agrefeit bit;
declare @consist_max_sublocal bit; declare @consist_max_visitado bit;
declare @consist_integracao bit;
declare @forcarbaixa bit;
declare @baixa_manual bit; declare @espentr int; declare @espsaida int; declare @ver_limite_depto bit;
declare @travarsequencia bit; declare @verversao bit;
declare @visi_aces_p smallint;
declare @posicao_hor_dia int; -- 0: Fora de faixa horrio, 1: Dentro da faixa horria, 2: Em folga, 3: Horrio dia antes, 4: Limite de intervalo, 5: B. Multiplas
declare @limite_dias int; declare @limite_acessos_dia int; declare @ult_acessos_dia float;
declare @limite_dias_func int; declare @limite_dias_terc int; declare @limite_dias_visi int;
declare @limite_dias_alun int; declare @limite_dias_pais int; declare @limite_dias_cond int;
declare @limite_dias_soci int;
declare @id_gbloqantes int;  declare @id_gbloqantesPrimario bit;  declare @id_gbloqantesSentido varchar(1);
declare @EntSaiIndefinido bit, @EntSaiDefinido bit;
declare @comunicacao int; declare @bloq_senha bit;
declare @id_local int; declare @id_sublocal int; declare @pass_visi int; declare @paci_visi int; declare @visitado varchar(50);
declare @maximo_sub int; declare @maximo_vis int; declare @conta int;
declare @id_credref bigint; declare @ultDifMinutos float;
declare @TipoDia char(1); declare @TrocaHor Bit;     declare @TipoHE char(1)
declare @id_eveabo int;   declare @troca_id_phorario int;  declare @troca_id_horario int;
declare @descFeriado varchar(20);
declare @horAbono varchar(7);     declare @m_horAbono int;
declare @descHorPto varchar(100);   declare @descHorAce varchar(50);
declare @descEveAbo varchar(30);   declare @folga bit;
declare @refcred bit, @cracha_vinc float; declare @aguardaAceComb bit;
declare @acao_estaciona tinyint; declare @id_auto_pass integer; declare @id_auto_atu integer; declare @stat_auto char(1);
declare @saldoAvulso float, @vlrRef float, @repasseRef float;
declare @LIBERAR bit;
declare @MSGRELOGIO varchar(32);
declare @EVENTO int;
declare @EHMESTRE bit;
declare @msgrel varchar(32);
declare @msgtela varchar(32);
declare @cofre bit, @vsenha int, @template varchar(2500);
declare @tempo smallint;
declare @sim bit; declare @wdia int;
declare @sairesp bit; declare @resp1 float; declare @resp2 float;
declare @resp3 float; declare @resp4 float; declare @resp5 float;
declare @resp6 float; declare @resp7 float; declare @resp8 float;
declare @ultseq varchar(10); declare @ultimogrupo int; declare @i int;
declare @ref_acessos int; declare @ref_livre_a tinyint; declare @ref_nro_ref int;
declare @ref_livre_r tinyint; declare @ref_refeit  varchar(250); declare @ref_dataini datetime;
declare @ref_datafim datetime; declare @categoriaref int; declare @valor_refeit float; declare @contarefs int;
declare @ref_dataini_so_data datetime; declare @ref_datafim_so_data_prox datetime;
declare @resppres bit;  declare @tanafx int;
declare @ult_aces_visi bit, @exibirsaldorefeit bit;
declare @TemAutorizacaoAcesso int;
declare @fxRefIni datetime; declare @fxRefFim datetime; declare @fxRefMinIni integer; declare @fxRefMinFim integer;
declare @cvinculo varchar(10), @bloq_cvinc bit; declare @st_ult tinyint, @st_eve tinyint;
declare @id_modelo int; declare @id_grefeit int; declare @tmpAtuac varchar(4);
select @data_hora_atual = isnull(@LFUSO,getdate());  -- Data/Hora atual
select @apenas_data = convert(datetime,convert(varchar,isnull(@data_hora_atual,'00:00:00'),101));
select @apenas_data_antes = dateadd(d,-1,@apenas_data);
select @data_hora_small = convert(smalldatetime, convert(varchar,@data_hora_atual,101) + ' ' + left(convert(varchar,@data_hora_atual,108),5));
EXEC AP_PTO001 @data_hora_atual, @apenas_minutos output;
select @LIBERAR = 1;
select @MSGRELOGIO = 'ACESSO LIBERADO'; select @msgrel = space(32); select @msgtela = space(32), @cofre=0, @vsenha=0, @template='';
select @EVENTO = 1;
select @EHMESTRE = 0;
select @descmestre = space(32);
select @tipobloq = 0; select @id_bloq = 0; select @st_bloq = 0;
select @descricaobloq = space(20); select @sentidobloq = ' ';
select @id_gbloq = 0; select @tipo_controle = 'A'; select @ip = space(15);
select @bloqueadobloq = 0; select @primario = 0;
select @entradiretosecundario = 0; select @antesentradiretosecundario = 0;
select @naotravasequencia = 0; select @visitantesaisoaqui = 0;
select @naoverhorariogrupo = 0; select @naoverhorariopass = 0;
select @saidaliberada = 0; select @ehferiado = 0; select @ehferiadoDiaAnt = 0;
select @consist_via = 0; select @consist_tbhorpas = 0;
select @consist_libbloq = 0; select @consist_permanencia = 0;
select @consist_afastamento = 0; select @consist_feriado = 0;
select @consist_numacessos_vis = 0; select @consist_reentrada = 0;
select @consist_resaida = 0; select @consist_folga = 0;
select @consist_horarioindevido = 0; select @consist_ausenciaminima = 0; select @consist_estourodedias = 0;
select @consist_acessos_dia = 0; select @consist_agrefeit = 0;
select @consist_max_sublocal = 0; select @consist_max_visitado = 0;
select @consist_integracao = 0;
select @forcarbaixa = 0;  select @limite_dias = 0; select @limite_acessos_dia = 0; select @ult_acessos_dia = 0;
select @baixa_manual = 0; select @espentr = 0; select @espsaida = 0;
select @ver_limite_depto = 0;
select @travarsequencia = 0; select @verversao = 0;
select @visi_aces_p = 0;
select @posicao_hor_dia = 1;
select @limite_dias_func = 0; select @limite_dias_terc = 0; select @limite_dias_visi = 0;
select @limite_dias_alun = 0; select @limite_dias_pais = 0; select @limite_dias_cond = 0;
select @limite_dias_soci = 0;
select @id_gbloqantes = 0;   select @id_gbloqantesPrimario = 0;   select @id_gbloqantesSentido = ' ';
select @exibirsaldorefeit = 0;
select @TemAutorizacaoAcesso = 0;
select @EntSaiIndefinido = 0, @EntSaiDefinido=0;
select @comunicacao = 0;
select @id_local = 0; select @id_sublocal = 0; select @pass_visi = 0; select @paci_visi = 0; select @visitado = '';
select @fxRefIni = @data_hora_atual; select @fxRefFim = @fxRefIni; select @fxRefMinIni = 0; select @fxRefMinFim = 0;
select @categoriaref = 0, @valor_refeit = 0;
select @id_modelo=0, @id_grefeit=0;
select @id_auto_pass=0, @id_auto_atu=0, @stat_auto='', @tmpAtuac='0000';
SELECT @refcred=0, @cvinculo='', @bloq_cvinc=0, @acao_estaciona=99;
select @baixa_manual = isnull(baixa_manual,0), @espentr = isnull(espentr,0), @espsaida = isnull(espsaida,0),
@travarsequencia = isnull(travaseq,0), @verversao = isnull(versao,0),
@limite_dias_func = isnull(limite_dias_func,0), @limite_dias_terc = isnull(limite_dias_terc,0), @limite_dias_visi = isnull(limite_dias_visi,0),
@limite_dias_alun = isnull(limite_dias_alun,0), @limite_dias_pais = isnull(limite_dias_pais,0), @limite_dias_cond = isnull(limite_dias_cond,0),
@limite_dias_soci = isnull(limite_dias_soci,0), @ver_limite_depto = isnull(ver_limite_depto,0), @exibirsaldorefeit = isnull(exibirsaldorefeit,0),
@refcred=ISNULL(refeitcred,0), @cvinculo=isnull(cvinculo,'')
from tbParSist;
SELECT TOP 1 @tipo_controle=isnull(tipo_controle,'A'), @bloq_cvinc=isnull(bloq_cvinc,0), @id_modelo=isnull(id_modelo,0), @id_grefeit=isnull(id_grefeit,0), @acao_estaciona=isnull(ace_comb,99),@tmpAtuac=isnull(tmpAtuac,'0000') FROM tbBloq WHERE id_bloq = @TERMINAL;
if @ENTSAI = 'A'
begin
select @EntSaiIndefinido=1;
select @ENTSAI = 'E';
end;
/* Verificar vnculo de cracha */
if (@CRACHATECLADO <> 'I') begin
select @cracha_vinc = 0;
if @bloq_cvinc=1 and len(ltrim(@cvinculo)) > 0 begin
SELECT @cracha_vinc=isnull(cracha,0) FROM tbCVinculado WHERE vinculado=@CRACHA;
if @cracha_vinc>0 begin
select @CRACHA=@cracha_vinc;
end;
end;
end;
-- Verificar se o cracha existe na tabela tbPass
select @achou = 0;
if (@CRACHATECLADO = 'I') begin
select @CRACHATECLADO='C';
select top 1 @achou = 1, @id_pass = id_pass, @id_empresa = id_empresa, @CRACHA = cracha, @crachacad = cracha, @viacad = via,
@tipo = tipo, @nome = nome, @vip = vip, @nasc = nasc, @indesejado = indesejado,
@bloqueado = bloqueado, @stat_inativo=isnull(stat_inativo,0), @id_horario = id_horario, @id_phorario = id_phorario, @id_depart = id_depart,
@per_indet = per_indet, @data_ini = data_ini, @data_fim = data_fim, @provisorio = provisorio,
@prov_ini = prov_ini, @prov_fim = prov_fim, @id_msgrel = id_msgrel, @id_msgtela = id_msgtela,
@msg_qtd_p = msg_qtd_p, @foto = foto, @fotodoc = fotodoc, @g_bloq = g_bloq, @data = data,
@horario = horario, @usu_resp = usu_resp, @status = status, @feriado = feriado,
@afast_ini = afast_ini, @afast_fim = afast_fim, @afast_fim = afast_fim, @ult_acess = ult_acess,
@reinic = reinic, @indgbloq = indgbloq, @id_consist = id_consist, @senhacad = senha, @codass = codass,
@ult_acessd = ult_acessd, @ult_idbloq = ult_idbloq, @ult_direc=ult_direc, @ult_lib=ult_lib,
@sequencia=sequencia, @contador=contador, @membership=membership, @cartaoimpresso=cartaoimpresso,
@fotodocVerso=fotodocVerso, @via_provisorio=via_provisorio, @limite_acessos_dia=isnull(acessos_dia,0),
@id_local = id_local, @id_sublocal = id_sublocal, @pass_visi = pass_visi, @paci_visi = paci_visi, @visitado = visitado
From tbPass WHERE id_pass=@CRACHA;
end else if @CRACHATECLADO <> 'S' begin
select top 1 @achou = 1, @id_pass = id_pass, @id_empresa = id_empresa, @crachacad = cracha, @viacad = via,
@tipo = tipo, @nome = nome, @vip = vip, @nasc = nasc, @indesejado = indesejado,
@bloqueado = bloqueado, @stat_inativo=isnull(stat_inativo,0), @id_horario = id_horario, @id_phorario = id_phorario, @id_depart = id_depart,
@per_indet = per_indet, @data_ini = data_ini, @data_fim = data_fim, @provisorio = provisorio,
@prov_ini = prov_ini, @prov_fim = prov_fim, @id_msgrel = id_msgrel, @id_msgtela = id_msgtela,
@msg_qtd_p = msg_qtd_p, @foto = foto, @fotodoc = fotodoc, @g_bloq = g_bloq, @data = data,
@horario = horario, @usu_resp = usu_resp, @status = status, @feriado = feriado,
@afast_ini = afast_ini, @afast_fim = afast_fim, @afast_fim = afast_fim, @ult_acess = ult_acess,
@reinic = reinic, @indgbloq = indgbloq, @id_consist = id_consist, @senhacad = senha, @codass = codass,
@ult_acessd = ult_acessd, @ult_idbloq = ult_idbloq, @ult_direc=ult_direc, @ult_lib=ult_lib,
@sequencia=sequencia, @contador=contador, @membership=membership, @cartaoimpresso=cartaoimpresso,
@fotodocVerso=fotodocVerso, @via_provisorio=via_provisorio, @limite_acessos_dia=isnull(acessos_dia,0),
@id_local = id_local, @id_sublocal = id_sublocal, @pass_visi = pass_visi, @paci_visi = paci_visi, @visitado = visitado
From tbPass WHERE cracha=@CRACHA and isnull(inativo,0)=0 AND NOT EXISTS (
SELECT e.id_empresa FROM tbEmpresas e WHERE e.id_empresa = tbPass.id_empresa AND ISNULL(e.inativo_ace,0) = 1
);
end
if isnull(@achou,0) = 0 and (@CRACHATECLADO = 'T' or @CRACHATECLADO = 'S')
begin
if @CRACHATECLADO = 'S' or exists(select tipo from tbBloq Where (id_bloq = @TERMINAL) and tipo = 5)
begin
select @achou = 0;
select top 1 @achou = 1, @id_pass = id_pass, @id_empresa = id_empresa, @crachacad = cracha, @viacad = via,
@tipo = tipo, @nome = nome, @vip = vip, @nasc = nasc, @indesejado = indesejado,
@bloqueado = bloqueado, @stat_inativo=isnull(stat_inativo,0), @id_horario = id_horario, @id_phorario = id_phorario, @id_depart = id_depart,
@per_indet = per_indet, @data_ini = data_ini, @data_fim = data_fim, @provisorio = provisorio,
@prov_ini = prov_ini, @prov_fim = prov_fim, @id_msgrel = id_msgrel, @id_msgtela = id_msgtela,
@msg_qtd_p = msg_qtd_p, @foto = foto, @fotodoc = fotodoc, @g_bloq = g_bloq, @data = data,
@horario = horario, @usu_resp = usu_resp, @status = status, @feriado = feriado,
@afast_ini = afast_ini, @afast_fim = afast_fim, @afast_fim = afast_fim, @ult_acess = ult_acess,
@reinic = reinic, @indgbloq = indgbloq, @id_consist = id_consist, @senhacad = senha, @codass = codass,
@ult_acessd = ult_acessd, @ult_idbloq = ult_idbloq, @ult_direc=ult_direc, @ult_lib=ult_lib,
@sequencia=sequencia, @contador=contador, @membership=membership, @cartaoimpresso=cartaoimpresso,
@fotodocVerso=fotodocVerso, @via_provisorio=via_provisorio, @limite_acessos_dia=isnull(acessos_dia,0),
@id_local = id_local, @id_sublocal = id_sublocal, @pass_visi = pass_visi, @paci_visi = paci_visi, @visitado = visitado
From tbPass WHERE senha = @CRACHA and isnull(inativo,0)=0 AND NOT EXISTS (
SELECT e.id_empresa FROM tbEmpresas e WHERE e.id_empresa = tbPass.id_empresa AND ISNULL(e.inativo_ace,0) = 1
);
end
end
if @CRACHA=0 begin
select @achou = 0;
end;
if isnull(@achou,0) = 0
begin
-- Verifica Provisorio
select @achou = 0;
select top 1 @achou = 1, @id_pass = id_pass, @id_empresa = id_empresa, @crachacad = cracha, @viacad = via,
@tipo = tipo, @nome = nome, @vip = vip, @nasc = nasc, @indesejado = indesejado,
@bloqueado = bloqueado, @stat_inativo=isnull(stat_inativo,0), @id_horario = id_horario, @id_phorario = id_phorario, @id_depart = id_depart,
@per_indet = per_indet, @data_ini = data_ini, @data_fim = data_fim, @provisorio = provisorio,
@prov_ini = prov_ini, @prov_fim = prov_fim, @id_msgrel = id_msgrel, @id_msgtela = id_msgtela,
@msg_qtd_p = msg_qtd_p, @foto = foto, @fotodoc = fotodoc, @g_bloq = g_bloq, @data = data,
@horario = horario, @usu_resp = usu_resp, @status = status, @feriado = feriado,
@afast_ini = afast_ini, @afast_fim = afast_fim, @afast_fim = afast_fim, @ult_acess = ult_acess,
@reinic = reinic, @indgbloq = indgbloq, @id_consist = id_consist, @senhacad = senha, @codass = codass,
@ult_acessd = ult_acessd, @ult_idbloq = ult_idbloq, @ult_direc=ult_direc, @ult_lib=ult_lib,
@sequencia=sequencia, @contador=contador, @membership=membership, @cartaoimpresso=cartaoimpresso,
@fotodocVerso=fotodocVerso, @via_provisorio=via_provisorio, @limite_acessos_dia=isnull(acessos_dia,0),
@id_local = id_local, @id_sublocal = id_sublocal, @pass_visi = pass_visi, @paci_visi = paci_visi,  @visitado = visitado
From tbPass WHERE provisorio = @CRACHA and isnull(inativo,0)=0 AND NOT EXISTS (
SELECT e.id_empresa FROM tbEmpresas e WHERE e.id_empresa = tbPass.id_empresa AND ISNULL(e.inativo_ace,0) = 1
);
if isnull(@achou,0) = 0
begin
select @achou = 0;
SELECT top 1 @achou = 1, @descmestre = LEFT('MESTRE - ' + descricao,32), @bloqueado = isnull(bloqueado,0)
From tbCMestre Where cracha = @CRACHA And via = @VIA
if isnull(@achou,0) = 1
begin
select @EHMESTRE = 1;
select @tipo = 'M';
select @MSGRELOGIO = left(@descmestre,32);
select @nome = @descmestre;
end else begin
select @LIBERAR = 0;
select @EVENTO = 99;
select @MSGRELOGIO = 'NAO CADASTRADO';
select @nome = 'NO CADASTRADO';
end
end
end;
if @tipo_controle='V' AND @EHMESTRE=0 begin
if not exists(SELECT id_bloq FROM tbBloqSPark WHERE id_bloq=@TERMINAL) begin INSERT INTO tbBloqSPark (id_bloq, id_pass, id_auto, cracha, data) VALUES (@TERMINAL, 0, 0, 0, getdate()); end;
if @EVENTO=99 begin
SELECT TOP 1 @id_auto_pass=isnull(h.id_pass,0), @id_auto_atu=isnull(a.id_auto,0), @stat_auto=isnull(a.status,'') FROM tbAuto a
INNER JOIN tbHistAuto h ON a.id_auto = h.id_auto AND h.inativo = 0
INNER JOIN tbPass p ON p.id_pass = h.id_pass
WHERE a.cracha=@CRACHA ORDER BY h.data_fim DESC;
if @id_auto_pass>0 begin
if @acao_estaciona=1 begin
select @id_auto_pass=0;
select @LIBERAR = 0;
select @EVENTO = 53;
select @MSGRELOGIO = 'CRACHA INCORRETO';
end else if @acao_estaciona=3 begin
select @id_auto_pass=0;
SELECT TOP 1 @id_auto_pass=id_pass FROM tbBloqSPark WHERE id_bloq=@TERMINAL AND cracha<>@CRACHA AND data BETWEEN DATEADD(ss,-15, GETDATE()) AND GETDATE();
if @id_auto_pass=0 begin
select @LIBERAR = 0;
select @EVENTO = 53;
select @MSGRELOGIO = 'SE IDENTIFIQUE';
end;
end;
end;
end else begin
select @id_auto_pass=@id_pass;
if @acao_estaciona=2 begin
select @LIBERAR = 0;
select @EVENTO = 53;
select @MSGRELOGIO = 'CRACHA INCORRETO';
end else if @acao_estaciona=3 begin
select @LIBERAR = 0;
select @EVENTO = 51;
select @MSGRELOGIO = 'PROXIMO CRACHA..';
end;
end;
if @id_auto_pass>0 AND @id_auto_pass<>isnull(@id_pass,0) begin
select @achou=0;
select top 1 @achou = 1, @id_pass = id_pass, @id_empresa = id_empresa, @crachacad = cracha, @viacad = via,
@tipo = tipo, @nome = nome, @vip = vip, @nasc = nasc, @indesejado = indesejado,
@bloqueado = bloqueado, @stat_inativo=isnull(stat_inativo,0), @id_horario = id_horario, @id_phorario = id_phorario, @id_depart = id_depart,
@per_indet = per_indet, @data_ini = data_ini, @data_fim = data_fim, @provisorio = provisorio,
@prov_ini = prov_ini, @prov_fim = prov_fim, @id_msgrel = id_msgrel, @id_msgtela = id_msgtela,
@msg_qtd_p = msg_qtd_p, @foto = foto, @fotodoc = fotodoc, @g_bloq = g_bloq, @data = data,
@horario = horario, @usu_resp = usu_resp, @status = status, @feriado = feriado,
@afast_ini = afast_ini, @afast_fim = afast_fim, @afast_fim = afast_fim, @ult_acess = ult_acess,
@reinic = reinic, @indgbloq = indgbloq, @id_consist = id_consist, @senhacad = senha, @codass = codass,
@ult_acessd = ult_acessd, @ult_idbloq = ult_idbloq, @ult_direc=ult_direc, @ult_lib=ult_lib,
@sequencia=sequencia, @contador=contador, @membership=membership, @cartaoimpresso=cartaoimpresso,
@fotodocVerso=fotodocVerso, @via_provisorio=via_provisorio, @limite_acessos_dia=isnull(acessos_dia,0),
@id_local = id_local, @id_sublocal = id_sublocal, @pass_visi = pass_visi, @paci_visi = paci_visi, @visitado = visitado
FROM tbPass WHERE id_pass=@id_auto_pass;
if @achou=1 begin
select @LIBERAR = 1;
select @EVENTO = 1;
select @MSGRELOGIO = 'ACESSO LIBERADO';
end;
end;
UPDATE tbBloqSPark SET id_pass=isnull(@id_pass,0), id_auto=isnull(@id_auto_atu,0), cracha=isnull(@CRACHA,0), data=getdate() WHERE id_bloq=@TERMINAL;
if @LIBERAR = 1 AND @EntSaiIndefinido = 1 AND isnull(@id_pass,0)>0 begin
if ISNULL((SELECT TOP 1 m.status FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbMHAuto mh ON m.id_movim = mh.id_movim
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento = 0
WHERE m.id_pass = @id_pass AND m.data BETWEEN dateadd(hh,-24,@data_hora_atual) AND @data_hora_atual ORDER BY data DESC),1)=0 begin
select @ENTSAI = 'S';
end else begin
select @ENTSAI = 'E';
end;
select @EntSaiIndefinido = 0;
end;
end;
if @LIBERAR=1 begin
exec CARREGA_CONSISTENCIAS @id_consist, @consist_via output, @consist_tbhorpas output,
@consist_libbloq output, @consist_permanencia output,
@consist_afastamento output, @consist_feriado output,
@consist_numacessos_vis output, @consist_reentrada output,
@consist_resaida output, @consist_folga output,
@consist_horarioindevido output, @consist_ausenciaminima output, @consist_estourodedias output,
@consist_acessos_dia output,
@consist_max_sublocal output, @consist_max_visitado output, @consist_integracao output, @consist_agrefeit output;
select @saidaliberada = 0;
if (@ENTSAI = 'S' or @EntSaiIndefinido = 1) and not @id_empresa is null begin
select top 1 @saidaliberada = sai_lib from tbEmpresas where id_empresa = @id_empresa;
end
if @tipo = 'V' begin
if @consist_numacessos_vis = 1 begin
select @visi_aces_p=isnull(aces_p,0) from tbVisi where id_pass = @id_pass;
/* Verificar se h marcao em batch */
if @visi_aces_p=1 AND @primario=1 AND (@ENTSAI='S' or @EntSaiIndefinido=1) begin
select @st_ult=2, @st_eve=0;
SELECT TOP 1 @st_ult=isnull(m.status,2), @st_eve=isnull(m.evento,0) FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento=0
INNER JOIN tbBloq b ON b.id_bloq = m.relogio
INNER JOIN tbGBloq g ON g.id_gbloq = b.id_gbloq AND g.primario=1
WHERE m.id_pass=@id_pass
AND m.data BETWEEN convert(datetime,convert(varchar,@data_hora_atual,101)) AND @data_hora_atual
ORDER BY m.data DESC
if @st_ult=0 and @st_eve=5 begin
select @visi_aces_p=0;
end;
end;
end else begin
select @visi_aces_p = 99;
end;
end
exec VALIDA_BLOQUEIO @TERMINAL output, @LIBERAR output, @MSGRELOGIO output, @EVENTO output,
@ENTSAI output, @id_bloq output, @st_bloq output, @descricaobloq output,
@tipobloq output, @sentidobloq output, @id_gbloq output,
@tipo_controle output, @ip output,
@bloqatuac output, @bloqentr output, @bloqsaid output,
@semconsstpass output, @bloqueadobloq output, @primario output,
@forcarbaixa output, @entradiretosecundario output, @naotravasequencia output,
@visitantesaisoaqui output, @naoverhorariogrupo output, @naoverhorariopass output,
@comunicacao output, @bloq_senha output, @data_hora_atual, @EHMESTRE, @saidaliberada,
@TERLEITOR, @tipo, @NUMTERLEITOR, @L_FUNCAO, @consist_numacessos_vis, @visi_aces_p;
if @EHMESTRE = 0
begin
select @indgbloq = left(ltrim(rtrim(isnull(@indgbloq,''))+replicate('0',300)),300);
select @sequencia = isnull(@sequencia,'');
select @ultseq = '';
select @i = len(@sequencia);
while (@i > 1)
begin --Ultimo grupo
if  @ultseq <> '' and substring(@sequencia,@i,1) = ','
begin
select @i = 1;
end else begin
if substring(@sequencia,@i,1) <> ','
begin
select @ultseq = substring(@sequencia,@i,1) + @ultseq;
end
end
select @i = @i - 1;
end
if @ultseq <> ''
begin
select @ultimogrupo = convert(int,@ultseq);
end
select @limite_dias = 0;
if @ver_limite_depto = 1 and isnull(@id_depart,0) > 0  --Pegar do departamento
begin
select @limite_dias = limite_dias_depto
from tbDepart
where id_depart = @id_depart and isnull(limite_dias_depto,0) > 0;
select @limite_dias = isnull(@limite_dias,0);
end
if @limite_dias = 0
begin
if @tipo = 'F'
select @limite_dias = @limite_dias_func;
if @tipo = 'T'
select @limite_dias = @limite_dias_terc;
if @tipo = 'V'
select @limite_dias = @limite_dias_visi;
if @tipo = 'A'
select @limite_dias = @limite_dias_alun;
if @tipo = 'P'
select @limite_dias = @limite_dias_pais;
if @tipo = 'C'
select @limite_dias = @limite_dias_cond;
if @tipo = 'S'
select @limite_dias = @limite_dias_soci;
end
EXEC AP_PTO005 @apenas_data_antes, @id_empresa, @id_pass, @TipoDia out, @TrocaHor out, @TipoHE out,
@id_eveabo out, @troca_id_phorario out, @troca_id_horario out, @descFeriado out, @descEveAbo out, @horAbono out, @m_horAbono out, @folga out;
select @ehferiadoDiaAnt = 0;
if @TipoDia = 'V' or @TipoDia = 'P'
begin
select @ehferiadoDiaAnt = 1;
end;
EXEC AP_PTO005 @apenas_data, @id_empresa, @id_pass, @TipoDia out, @TrocaHor out, @TipoHE out,
@id_eveabo out, @troca_id_phorario out, @troca_id_horario out, @descFeriado out, @descEveAbo out, @horAbono out, @m_horAbono out, @folga out;
select @ehferiado = 0;
if @TipoDia = 'V' or @TipoDia = 'P'
begin
select @ehferiado = 1;
end;
if @TrocaHor=1 begin
if @troca_id_horario > 0 begin
select @id_horario = @troca_id_horario;
end;
if @troca_id_phorario > 0 begin
select @id_phorario = @troca_id_phorario;
end;
end;
end -- @EHMESTRE = 0
if @tipo_controle='P' and @LIBERAR=1 begin
select @MSGRELOGIO = 'PONTO  LIBERADO';
end;
if @EntSaiIndefinido = 1 and @EHMESTRE = 0
begin
if @primario=1 and @tipo_controle<>'R' begin
if isnull(@status,' ') = 'D' begin
select  @ENTSAI = 'S';
end else begin
select  @ENTSAI = 'E';
end;
end else begin if @tipo_controle='R' begin
select @ENTSAI='E',@EntSaiIndefinido=0;
if @semconsstpass=0 begin
select @st_ult=2;
SELECT TOP 1 @st_ult=isnull(m.status,2) FROM tbMRefeit m WITH (NOLOCK)
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento=0
INNER JOIN tbBloq b ON b.id_bloq = m.relogio AND (isnull(@id_gbloq,0)=0 OR b.id_gbloq=@id_gbloq)
WHERE m.id_pass=@id_pass
AND m.data BETWEEN dateadd(n,-90,getdate()) AND getdate()
ORDER BY m.data DESC
if @st_ult=0 begin select  @ENTSAI='S'; end;
end;
end; end;
end;
if @LIBERAR = 1 and @tipo_controle = 'P' and @tipo <> 'F' begin
select @LIBERAR = 0;
select @EVENTO = 44;
select @MSGRELOGIO = 'PONTO PROIBIDO';
end;
if (@ENTSAI = 'E' or @saidaliberada = 0) and @EHMESTRE = 0 and @LIBERAR = 1
begin
exec P_ACESSO_AUTORIZADO @id_pass, @id_gbloq, @data_hora_atual, @TemAutorizacaoAcesso output;
if @TemAutorizacaoAcesso = 1
begin
select @EVENTO = 2;
end
select @id_gbloqantes = @id_gbloq;
select @id_gbloqantesPrimario = @primario;
if not @ult_idbloq is null
begin
if @ult_idbloq <> @id_bloq
begin
select top 1 @id_gbloqantes = tbGBloq.id_gbloq,
@id_gbloqantesPrimario = tbGBloq.primario,
@antesentradiretosecundario = tbBloq.flagsecundario
from tbBloq inner join tbGBloq on tbBloq.id_gbloq = tbGBloq.id_gbloq
Where tbBloq.id_bloq = @ult_idbloq;
if @id_gbloqantes > 0 and @id_gbloqantes <> @id_gbloq
begin
select @id_gbloqantesSentido = substring(@indgbloq,@id_gbloqantes,1);
end
end
end
if @LIBERAR = 1 and @consist_libbloq = 1 and @bloqueado = 1
begin
select @LIBERAR = 0;
select @EVENTO = 8;
if isnull(@stat_inativo,0)=0 begin
select @MSGRELOGIO = '** BLOQUEADO **';
end else begin
select @MSGRELOGIO = '**  INATIVO  **';
end;
end
if @LIBERAR = 1 and @TemAutorizacaoAcesso <> 1 and @consist_estourodedias = 1 and @limite_dias > 0 and not @ult_acess is null
begin
if datediff(day,@ult_acess, @data_hora_atual) > @limite_dias
begin
select @LIBERAR = 0;
select @EVENTO = 39;
select @MSGRELOGIO = 'EST. LIMITE DE DIAS';
end
end
if @LIBERAR = 1 begin
if (@id_gbloq=0) OR (@vip = 0 AND patindex('%'+right('000'+rtrim(ltrim(convert(char(3),@id_gbloq))),3)+'*%',isnull(@g_bloq,'')) = 0)
begin
select @LIBERAR = 0;
select @EVENTO = 9;
select @MSGRELOGIO = 'FORA DO GRUPO';
end
end
if @id_modelo<>11 and @id_modelo<>13 and @id_modelo<>20 and @CRACHATECLADO <> 'B' begin
if @LIBERAR = 1 and (@bloq_senha=1 or @CRACHATECLADO = 'T') and (@SENHA <> isnull(@senhacad,0) OR @SENHA=0)
begin
select @LIBERAR = 0;
select @EVENTO = 33;
select @MSGRELOGIO = 'SENHA INCORRETA';
end;
end
if NOT @id_modelo IN (11, 12, 20, 21, 25, 26, 27) and @CRACHATECLADO <> 'B' begin
if @LIBERAR = 1 and @consist_via = 1 and @verversao = 1 and @CRACHATECLADO = 'C'
begin
If @crachacad =  @CRACHA and @viacad <> @VIA
begin
select @LIBERAR = 0;
select @EVENTO = 6;
select @MSGRELOGIO = 'VIA INVALIDA';
end else begin
If @provisorio = @CRACHA and @via_provisorio <> @VIA
begin
select @LIBERAR = 0;
select @EVENTO = 32;
select @MSGRELOGIO = 'VIA PROV.INVALIDA';
end
end
end
end
if @LIBERAR = 1 and @tipo_controle <> 'P' and @consist_numacessos_vis = 1 and @tipo = 'V' and @ENTSAI = 'E' and @primario = 1 and @visi_aces_p <= 0
begin
select @LIBERAR = 0;
select @EVENTO = 13;
select @MSGRELOGIO = 'ACESSO VENCIDO';
end
if @LIBERAR = 1 and @CRACHATECLADO <> 'B' and isnull(@provisorio,0) <> 0 and isnull(@crachacad,0) = @CRACHA
begin
select @LIBERAR = 0;
select @EVENTO = 31;
select @MSGRELOGIO = 'UTILIZE O PROVISORIO';
end
if @LIBERAR = 1 and isnull(@provisorio,0) <> 0 and not @prov_fim is null
begin
if @data_hora_small > @prov_fim
begin
select @LIBERAR = 0;
select @EVENTO = 30;
select @MSGRELOGIO = 'ENTREGAR PROVISORIO';
end
end
if isnull(@reinic,0) = 0 begin
if @ult_lib is not null and @ult_lib>=DATEADD(s,-15,GETDATE()) and @ult_lib<=GETDATE() begin
select @status='E';
end
if @LIBERAR = 1 and isnull(@status,' ') = 'E'
begin
select @LIBERAR = 0;
select @EVENTO = 54;
select @MSGRELOGIO = 'IMPEDIDO, EM ESPERA';
end
end
if @tipo_controle='R' or @tipo_controle='S' /*@ Para ponto e acesso ser verificado o horrio de sada da tabela do dia anterior (ver abaixo) */
begin
if @LIBERAR = 1 and @consist_afastamento = 1
begin
if exists(select id_pass from tbAfast where id_pass = @id_pass and convert(datetime,convert(varchar,isnull(@data_hora_atual,'00:00:00'),101)) between convert(datetime,convert(varchar,isnull(dataini,'00:00:00'),101)) and convert(datetime,convert(varchar,isnull(datafim,'00:00:00'),101)))
begin
select @LIBERAR = 0;
select @EVENTO = 11;
select @MSGRELOGIO = 'AFASTADO';
end;
if exists(SELECT id_pass FROM tbFunc WHERE id_pass = @id_pass and (isnull(admissao,@apenas_data) > @apenas_data or isnull(dtdemissao,'01/01/2079') <= @apenas_data)) begin
select @LIBERAR = 0;
select @EVENTO = 11;
select @MSGRELOGIO = 'AFASTADO';
end;
end;
end;
if @LIBERAR = 1 and @tipo_controle <> 'P' and @consist_permanencia = 1 and isnull(@per_indet,0) = 0 and not @data_ini is null and not @data_fim is null
begin
if not (@apenas_data >= convert(datetime,convert(varchar,isnull(@data_ini,'00:00:00'),101)) and @apenas_data <= convert(datetime,convert(varchar,isnull(@data_fim,'00:00:00'),101)))
begin
select @LIBERAR = 0;
select @EVENTO = 10;
select @MSGRELOGIO = 'DATA NAO PERMITIDA';
end
end
if @tipo_controle<>'R' and @tipo_controle<>'S'
begin
if @LIBERAR = 1 and @tipo_controle <> 'P' and @consist_reentrada = 1 and (@ENTSAI = 'E' or @EntSaiIndefinido=1) and @semconsstpass = 0 and isnull(@reinic,0) = 0
begin
if @tipo_controle = 'V' begin
if @stat_auto='D' begin
if @EntSaiIndefinido = 0
begin
select @LIBERAR = 0;
select @EVENTO = 14;
select @MSGRELOGIO = 'REENTRADA';
end else begin
select @ENTSAI = 'S';
select @EntSaiIndefinido=0, @EntSaiDefinido=1;
end;
end;
end else begin
if (@primario = 0 and substring(@indgbloq,@id_gbloq,1) = '1')
or (@primario = 1 and @id_gbloqantesPrimario = 1 and @id_gbloqantesSentido = '1')
or (@primario = 1 and @status = 'D')
begin
if @EntSaiIndefinido = 0
begin
select @LIBERAR = 0;
select @EVENTO = 14;
select @MSGRELOGIO = 'REENTRADA';
end else begin
select @ENTSAI = 'S';
select @EntSaiIndefinido=0, @EntSaiDefinido=1;
end;
end
end;
end;
if @LIBERAR = 1 and @tipo_controle <> 'P' and @consist_resaida = 1 and ((@ENTSAI='S' or @EntSaiIndefinido=1) AND @EntSaiDefinido=0) and @semconsstpass = 0 and isnull(@reinic,0) = 0
begin
if @tipo_controle = 'V' begin
if @stat_auto='N' begin
if @EntSaiIndefinido = 0 begin
select @LIBERAR = 0;
select @EVENTO = 15;
select @MSGRELOGIO = 'TENTATIVA DE SAIDA';
end else if (@primario=0 OR @status='N') begin
select @ENTSAI = 'E';
select @EntSaiIndefinido=0,@EntSaiDefinido=1;
end;
end;
end else begin
if (@primario=0 and substring(@indgbloq,@id_gbloq,1)='0') OR (@primario=1 and @status='N')
begin
if @EntSaiIndefinido = 0 begin
select @st_ult=0;
SELECT TOP 1 @st_ult=isnull(m.status,0) FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbEventoSist e ON m.evento = e.id_evento AND e.flagimpedimento=0
INNER JOIN tbBloq b ON b.id_bloq = m.relogio
INNER JOIN tbGBloq g ON g.id_gbloq = b.id_gbloq AND g.primario=1
WHERE m.id_pass=@id_pass
AND m.data BETWEEN dateadd(hh,-18,@data_hora_atual) AND @data_hora_atual
ORDER BY m.data DESC;
if (@st_ult=1) begin
select @LIBERAR = 0;
select @EVENTO = 15;
select @MSGRELOGIO = 'TENTATIVA DE SAIDA';
end;
end else if (@primario=0 OR @status='N') begin
select @ENTSAI = 'E';
select @EntSaiIndefinido=0,@EntSaiDefinido=1;
end;
end;
end;
end
if @LIBERAR = 1 and @tipo_controle <> 'P' and @TemAutorizacaoAcesso <> 1 and @consist_horarioindevido = 1 and @reinic = 0 and not @ult_acess is null and not @ult_acessd is null
begin
if @ENTSAI = 'E'
begin
select @tempo = @espentr;
end else begin
select @tempo = @espsaida;
end
if @tempo > 0 and @id_gbloq = isnull(@id_gbloqantes,0) and datediff(day, @ult_acessd, @data_hora_atual) < 2
begin
if datediff(s,@ult_acess,@data_hora_atual) < @tempo
begin
select @LIBERAR = 0;
select @EVENTO = 29;
select @MSGRELOGIO = 'HORARIO INDEVIDO';
end
end
end;
if @LIBERAR = 1 and @ENTSAI = 'E' and @primario=1 and @status='N' and @tipo_controle <> 'P' and @TemAutorizacaoAcesso <> 1 and @consist_ausenciaminima = 1 and @reinic = 0 and not @ult_acess is null and not @ult_acessd is null
begin
select @tempo = 0;
SELECT @tempo = CONVERT(INT,left(ausencia_ini,2))*60 + CONVERT(INT,right(ausencia_ini,2)) FROM tbParSist WHERE not ausencia_ini is null;
if (@tempo > 0) and (datediff(day, @ult_acessd, @data_hora_atual) < 2) and (datediff(mi,@ult_acess,@data_hora_atual) >= @tempo) begin
select @tempo = 0;
SELECT @tempo = CONVERT(INT,left(ausencia_lmt,2))*60 + CONVERT(INT,right(ausencia_lmt,2)) FROM tbParSist WHERE not ausencia_lmt is null;
if (@tempo > 0) and (datediff(mi,@ult_acess,@data_hora_atual) < @tempo) begin
select @LIBERAR = 0;
select @EVENTO = 47;
select @MSGRELOGIO = 'AUSENCIA MINIMA';
end
end
end;
if @LIBERAR = 1 and @ENTSAI = 'E' and isnull(@reinic,0) = 0
begin
if (@primario = 0 and @entradiretosecundario = 0 and isnull(@status,' ') = 'N')
begin
select @LIBERAR = 0;
select @EVENTO = 36;
select @MSGRELOGIO = 'FORA DA SEQUENCIA';
end
end
if @LIBERAR = 1 and @travarsequencia = 1 and @naotravasequencia = 0 and isnull(@reinic,0) = 0
begin
if (@ENTSAI = 'S' and @ultimogrupo > 0 and @ultimogrupo <> @id_gbloq)
begin
if not (@ENTSAI = 'S' and @primario = 1 and @ultimogrupo > 0
and exists(select id_gbloq from tbGBloq where id_gbloq = @ultimogrupo and primario = 1))
begin
select @LIBERAR = 0;
select @EVENTO = 36;
select @MSGRELOGIO = 'FORA DA SEQUENCIA';
end
end
end
if @LIBERAR = 1 and @tipo = 'V' and @ENTSAI = 'S' and @primario = 1 and @visitantesaisoaqui = 0
begin
if exists(select id_bloq from tbBloq where flagvisitante = 1)
begin
select @LIBERAR = 0;
select @EVENTO = 38;
select @MSGRELOGIO = 'ACESSO PROIBIDO';
end
end
if @LIBERAR = 1 begin
if @consist_feriado = 1 and isnull(@feriado,0) = 1 begin
if @consist_tbhorpas=1 and @naoverhorariopass=0
exec P_ESTA_NA_FAIXA_HORARIA @id_pass, @id_horario, @primario, @data_hora_atual, @ehferiado, @ehferiadoDiaAnt, 1, @tanafx output;
else
exec P_ESTA_NA_FAIXA_HORARIA @id_pass, @id_horario, @primario, @data_hora_atual, @ehferiado, @ehferiadoDiaAnt, 0, @tanafx output;
end else begin
if @consist_tbhorpas=1 and @naoverhorariopass=0
exec P_ESTA_NA_FAIXA_HORARIA @id_pass, @id_horario, @primario, @data_hora_atual, 0, 0, 1, @tanafx output;
else
exec P_ESTA_NA_FAIXA_HORARIA @id_pass, @id_horario, @primario, @data_hora_atual, 0, 0, 0, @tanafx output;
end;
select @posicao_hor_dia = @tanafx;
end;
if @LIBERAR = 1 AND @TemAutorizacaoAcesso <> 1 AND @ENTSAI='E' AND @primario=1 AND @consist_feriado = 1 AND isnull(@feriado,0) = 0 AND @ehferiado = 1 AND @posicao_hor_dia <> 3
begin
select @LIBERAR = 0;
select @EVENTO = 12;
select @MSGRELOGIO = 'IMPEDIDO, FERIADO';
end
if @ENTSAI='E' AND @primario=1 AND @posicao_hor_dia <> 3 /*@ Para ponto e acesso  verificado o horrio de sada da tabela do dia anterior */
begin
if @LIBERAR = 1 and @consist_afastamento = 1
begin
if exists(select id_pass from tbAfast where id_pass = @id_pass and convert(datetime,convert(varchar,isnull(@data_hora_atual,'00:00:00'),101)) between convert(datetime,convert(varchar,isnull(dataini,'00:00:00'),101)) and convert(datetime,convert(varchar,isnull(datafim,'00:00:00'),101)))
begin
select @LIBERAR = 0;
select @EVENTO = 11;
select @MSGRELOGIO = 'AFASTADO';
end;
if exists(SELECT id_pass FROM tbFunc WHERE id_pass = @id_pass and (isnull(admissao,@apenas_data) > @apenas_data or isnull(dtdemissao,'01/01/2079') <= @apenas_data)) begin
select @LIBERAR = 0;
select @EVENTO = 11;
select @MSGRELOGIO = 'AFASTADO';
end;
end;
end;
if @LIBERAR = 1 and @TemAutorizacaoAcesso <> 1 and @consist_tbhorpas = 1 and ((@tipo_controle<>'P' and not @id_horario is null) or (@tipo_controle='P' and not @id_phorario is null)) and @naoverhorariopass = 0
begin
if @posicao_hor_dia = 0
begin
select @LIBERAR = 0;
select @EVENTO = 7;
select @MSGRELOGIO = 'FORA DO HORARIO';
end else begin if @posicao_hor_dia = 4 begin
select @LIBERAR = 0;
select @EVENTO = 45;
select @MSGRELOGIO = 'INTERVALO LIMITE';
end else begin if @posicao_hor_dia = 5 begin
select @LIBERAR = 0;
select @EVENTO = 46;
select @MSGRELOGIO = 'MARC. MULTIPLA';
end; end; end;
end;
if @LIBERAR = 1 and @TemAutorizacaoAcesso <> 1 AND @ENTSAI='E' AND @primario=1 AND @consist_folga = 1 and @posicao_hor_dia<>3 and (@posicao_hor_dia = 2 OR @TipoDia = 'F' or @folga=1) and (not @status = 'D' or @tipo_controle='P')
begin
select @LIBERAR = 0;
select @EVENTO = 7;
select @MSGRELOGIO = 'FOLGA';
end
if @LIBERAR = 1 and @TemAutorizacaoAcesso <> 1 AND @ENTSAI='E' AND @consist_integracao=1
begin
select @achou=0;
exec P_INTEG_VENC @id_pass, @id_bloq, @apenas_data, @achou output;
if @achou=1 begin
select @LIBERAR = 0;
select @EVENTO = 55;
select @MSGRELOGIO = 'INTEGRACAO VENCIDA';
end;
end
if @LIBERAR = 1 and @TemAutorizacaoAcesso <> 1 and @consist_tbhorpas=1 begin
select @tanafx=0;
if @ENTSAI='S' begin
exec P_CONSIST_ITV @id_pass, @data_hora_atual, 1, @id_bloq, @tanafx out
end else begin
exec P_CONSIST_ITV @id_pass, @data_hora_atual, 0, @id_bloq, @tanafx out
end;
if @tanafx=2 or @tanafx=3 begin
select @LIBERAR = 0;
select @EVENTO = 45;
select @MSGRELOGIO = 'INTERVALO LIMITE';
end else begin if @tanafx>0 begin
select @LIBERAR = 0;
select @EVENTO = 7;
select @MSGRELOGIO = 'FORA DO HORARIO';
end;end;
end;
if @tipo <> 'V' and @LIBERAR = 1 and @TemAutorizacaoAcesso <> 1
and @consist_acessos_dia = 1 and @ENTSAI = 'E'
and (@primario = 1 or (@entradiretosecundario = 1 and @status <> 'D'))
and @limite_acessos_dia > 0 and not @ult_acess is null
begin
if datediff(day,@ult_acess, @data_hora_atual) = 0
begin
select @ult_acessos_dia = count(0) from tbMovim tm WITH (NOLOCK)
where tm.id_pass = @id_pass and tm.cracha = @crachacad
and datediff(day,tm.data, @data_hora_atual) = 0
and tm.status = 0 and tm.evento in (select te.id_evento from tbEventoSist te where te.flagimpedimento = 0)
and tm.relogio in (
select tb.id_bloq from tbBloq tb
inner join tbGBloq tg on tb.id_gbloq = tg.id_gbloq and tg.primario=1
where isnull(tb.tipo_controle,'A')='A'
);
select @ult_acessos_dia = isnull(@ult_acessos_dia,0);
if @ult_acessos_dia >= @limite_acessos_dia
begin
select @LIBERAR = 0;
select @EVENTO = 40;
select @MSGRELOGIO = 'LMT. ACESSOS NO DIA';
end
end
end
if @LIBERAR = 1 and @tipo = 'A' and @ENTSAI = 'S' and @primario = 1
begin
select top 1 @sairesp = sairesp, @resp1 = resp1, @resp2 = resp2,
@resp3 = resp3, @resp4 = resp4, @resp5 = resp5,
@resp6 = resp6, @resp7 = resp7, @resp8 = resp8
from tbAlun where id_pass = @id_pass;
if isnull(@sairesp,0) = 1 and (isnull(@resp1,0) > 0 or isnull(@resp2,0) > 0 or isnull(@resp3,0) > 0 or
isnull(@resp4,0) > 0 or isnull(@resp5,0) > 0 or isnull(@resp6,0) > 0 or
isnull(@resp7,0) > 0 or isnull(@resp8,0) > 0)
begin
select @sim = 1;
exec P_RESPONSAVEL_PRESENTE @resp1, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
exec P_RESPONSAVEL_PRESENTE @resp2, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
exec P_RESPONSAVEL_PRESENTE @resp3, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
exec P_RESPONSAVEL_PRESENTE @resp4, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
exec P_RESPONSAVEL_PRESENTE @resp5, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
exec P_RESPONSAVEL_PRESENTE @resp6, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
exec P_RESPONSAVEL_PRESENTE @resp7, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
exec P_RESPONSAVEL_PRESENTE @resp8, @GC_TEMPOESTOUROPAIS, @data_hora_atual, @resppres output
if @resppres = 0
begin
select @sim = 0;
end
end
end
end
end
end
end
end
if @sim = 0
begin
select @LIBERAR = 0;
select @EVENTO = 16;
select @MSGRELOGIO = 'SEM RESPONSAVEL';
end
end
end
if @LIBERAR = 1 and @tipo = 'V' and @TemAutorizacaoAcesso <> 1
and isnull(@id_local,0) > 0 and isnull(@id_sublocal,0) > 0
and ( @consist_max_sublocal = 1 or @consist_max_visitado = 1 )
and @ENTSAI = 'E' and (@primario = 1 or (@entradiretosecundario = 1 and @status <> 'D'))
begin
select @achou = 0;
select top 1 @achou = 1, @maximo_sub = isnull(maximo_sub,0), @maximo_vis = isnull(maximo_vis,0)
from tbSubLocais where id_sublocal = @id_sublocal;
if @achou = 0
begin
select @maximo_sub = 0;
select @maximo_vis = 1;
end
if @LIBERAR = 1 and @consist_max_sublocal = 1 and @maximo_sub > 0
begin
select @conta = 0;
select @conta = count(0) from tbPass
where id_sublocal = @id_sublocal and status <> 'N'
and isnull(bloqueado,0) = 0;
if @conta >= @maximo_sub
begin
select @LIBERAR = 0;
select @EVENTO = 41;
select @MSGRELOGIO = 'LIMITE SUBLOCAL';
end
end
if @LIBERAR = 1 and @consist_max_visitado = 1 and @maximo_vis > 0 and isnull(@paci_visi,0) > 0
begin
select @conta = 0;
select @conta = count(0) from tbPass
where id_sublocal = @id_sublocal and status <> 'N'
and isnull(paci_visi,0) = @paci_visi
and isnull(bloqueado,0) = 0;
if @conta >= @maximo_vis
begin
select @LIBERAR = 0;
select @EVENTO = 42;
select @MSGRELOGIO = 'LIMITE VISITADO';
end
end
end
if @LIBERAR=1 AND @tipo = 'C' AND @TemAutorizacaoAcesso <> 1
begin
if EXISTS(SELECT pu.id_pass FROM tbPassUnid pu INNER JOIN tbUnidades u ON pu.id_unidade = u.id_unidade
WHERE pu.id_pass = @id_pass AND @apenas_data <= u.rest_fim AND @apenas_data >= u.rest_ini
AND u.id_unidade NOT IN (
SELECT x.id_unidade FROM tbRestAce x WHERE id_pass=@id_pass
)) begin
select @LIBERAR = 0;
select @EVENTO = 8;
select @MSGRELOGIO = 'REST. DE ACESSO';
end;
end
if @LIBERAR=1 begin
select @aguardaAceComb=0;
exec ACESSO_COMBINADO @TERMINAL, 1, 0, @id_pass, @data_hora_atual, @L_FUNCAO, 0, @aguardaAceComb output;
if @aguardaAceComb=1 begin
select @LIBERAR=0;
select @EVENTO = 51;
select @MSGRELOGIO = 'PROXIMO CRACHA..';
end;
end;
if @LIBERAR=1 and @ENTSAI = 'S' and @primario = 1 and @tipo IN ('F','T') begin
if EXISTS(SELECT TOP 1 id_bloq FROM tbBloq WHERE program='PWBIN04') begin
select @st_eve=0;
SELECT TOP 1 @st_eve=isnull(m.evento,0) FROM tbMovim m WITH (NOLOCK)
INNER JOIN tbBloq b ON b.id_bloq = m.relogio
INNER JOIN tbGBloq g ON g.id_gbloq = b.id_gbloq AND g.primario=1
WHERE m.id_pass=@id_pass
AND m.data BETWEEN dateadd(hh,-2,@data_hora_atual) AND @data_hora_atual
AND m.status=1
ORDER BY m.data DESC;
if (@st_eve<>48) and ((RAND()*100)<=5) begin --5% de chances de cair em revista
if EXISTS(SELECT TOP 1 id_bloq FROM tbBloq WHERE program='PWBIN04' AND id_bloq=@TERMINAL) begin
select @st_eve=48;
end;
end;
if (@st_eve=48) begin
select @LIBERAR = 0;
select @EVENTO = 48;
select @MSGRELOGIO = '**  REVISTA  **';
end;
end;
end;
end else if @tipo_controle = 'S' begin
select @EVENTO = 8;
select @LIBERAR = 0;
select @MSGRELOGIO = '[' + RIGHT('00' + LTRIM(RTRIM(CONVERT(VARCHAR,@L_FUNCAO))),2) + '] SEM SALDO';
-- Procurar saldos na categoria
if @refcred = 1
begin
select @categoriaref = @L_FUNCAO;
if (@categoriaref = 0)
begin
select @EVENTO = 27;
select @MSGRELOGIO = 'DIGITE O CODIGO';
END ELSE BEGIN
select @achou = 0;
select top 1 @achou = 1 from tbRefeit
where id_refeit = @categoriaref;
if (@achou = 0)
begin
select @EVENTO = 27;
select @MSGRELOGIO = 'CODIGO INVALIDO';
SELECT @categoriaref = 0;
END
END
select @achou = 0;
if @categoriaref > 0
BEGIN
select @achou = 1, @ref_refeit = id_refeit, @ref_acessos = limite_diario
from tbFaixasRefeitPass
where id_pass = @id_pass and id_refeit = @categoriaref;
END
if @achou <> 0
BEGIN
--Calcular saldo na categoria
select @ref_nro_ref = 0;
select @ref_nro_ref = sum(saldo) from tbCredRefeit
where id_pass = @id_pass and id_refeit = @categoriaref
and saldo > 0 and isnull(dtvalidade,'01/01/2200') > @data_hora_atual
and cancelado = 0;
--Achar registro de crdito para abater
if isnull(@ref_nro_ref,0) > 0
begin
select @achou = 0;
select top 1 @achou = 1, @id_credref=id_credref, @valor_refeit = isnull(vlunitario,0)
from tbCredRefeit
where id_pass = @id_pass and id_refeit = @categoriaref
and saldo > 0 and isnull(dtvalidade,'01/01/2200') > @data_hora_atual
and cancelado = 0
order by dtlancado;
if @achou = 0
begin
SELECT @ref_nro_ref = 0;
end
end
if isnull(@ref_nro_ref,0) > 0
BEGIN
select @MSGRELOGIO = LEFT(@MSGRELOGIO,4) + ' SALDO: ' + ltrim(rtrim(convert(varchar(4),isnull(@ref_nro_ref,0))));
END
END
END ELSE BEGIN -- @refcred = 0
select @achou = 0;
select @achou = 1, @ref_acessos = acessos, @ref_livre_a = isnull(livre_a,0),
@ref_nro_ref = isnull(nro_ref,0), @ref_livre_r = isnull(livre_r,0),
@ref_refeit = refeit,  @ref_dataini = dataini,
@ref_datafim = datafim from tbRefeitPass
where id_pass = @id_pass;
if @achou = 1
BEGIN
if (rtrim(isnull(@ref_refeit,'')) <> '') AND (@ref_livre_r > 0 or @ref_nro_ref > 0 )
AND convert(datetime,convert(varchar,isnull(@ref_dataini,'00:00:00'),101)) <= @apenas_data
AND convert(datetime,convert(varchar,isnull(@ref_datafim,'01/01/2100 00:00:00'),101)) >= @apenas_data
BEGIN
if @ref_livre_r > 0
begin
select @MSGRELOGIO = 'SALDO: ILIMITADO';
end else begin
select @MSGRELOGIO = 'SALDO: ' + ltrim(rtrim(convert(varchar(4),isnull(@ref_nro_ref,0))));
end;
end;
end;
-- Verificar crditos avulsos
select @achou=0, @saldoAvulso=0;
SELECT TOP 1 @achou=1 FROM tbRefAvulsa WHERE id_pass = @id_pass;
if @achou=1 begin
select @MSGRELOGIO = 'SALDO: 0.00';
SELECT @saldoAvulso=ROUND(SUM(valor),2) FROM tbRefAvulsa WHERE id_pass = @id_pass;
select @saldoAvulso = isnull(@saldoAvulso,0);
if @saldoAvulso>0 begin
select @MSGRELOGIO = 'SALDO: ' + replace(convert(decimal(10, 2), @saldoAvulso),'.','.');
end;
end;
end;
END ELSE BEGIN
if @LIBERAR = 1 and @ENTSAI = 'E' and isnull(@reinic,0) = 0
begin
if (@primario = 0 and @entradiretosecundario = 0 and isnull(@status,' ') = 'N')
begin
select @LIBERAR = 0;
select @EVENTO = 36;
select @MSGRELOGIO = 'FORA DA SEQUENCIA';
end
end
if @LIBERAR = 1 and @ENTSAI = 'E'
begin
select @EVENTO = 24;
select @MSGRELOGIO = 'BOM  APETITE';
if @refcred = 1
begin
-- Achar a categoria da refeio
if @ehferiado = 1
begin
select @wdia = 8;
end else begin
select @wdia = DATEPART(dw,@data_hora_atual);
end
select @categoriaref = 0;
select top 1 @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim
from tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND
( (
((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
<= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and @apenas_minutos between ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
and ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
) or (
((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
> ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and (@apenas_minutos >= ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
or @apenas_minutos <= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
)
)
)
and
(
(f.feriado = 1 and @wdia = 8)
or (@wdia = 1 and f.d1 = 1)
or (@wdia = 2 and f.d2 = 1) or (@wdia = 3 and f.d3 = 1) or (@wdia = 4 and f.d4 = 1)
or (@wdia = 5 and f.d5 = 1) or (@wdia = 6 and f.d6 = 1) or (@wdia = 7 and f.d7 = 1)
)
and f.id_refeit in (select fPass.id_refeit from tbFaixasRefeitPass fPass where fPass.id_pass = @id_pass)
if (@categoriaref = 0)
begin
-- No achou a categoria da refeio
select @LIBERAR = 0;
select @EVENTO = 27;
select @MSGRELOGIO = 'FORA DE TABELA';
end else begin
select @achou = 0;
select @achou = 1, @ref_refeit = id_refeit, @ref_acessos = limite_diario
from tbFaixasRefeitPass
where id_pass = @id_pass and id_refeit = @categoriaref;
if @achou = 0
begin
select @LIBERAR = 0;
select @EVENTO = 27;
select @MSGRELOGIO = 'FORA DE TABELA';
end else begin
exec AUTOLANC_REFEITORIO @id_pass, @categoriaref;
--Calcular saldo na categoria
select @ref_nro_ref = 0;
select @ref_nro_ref = sum(saldo) from tbCredRefeit
where id_pass = @id_pass and id_refeit = @categoriaref
and saldo > 0 and isnull(dtvalidade,'01/01/2200') > @data_hora_atual
and cancelado = 0;
if isnull(@ref_nro_ref,0) <= 0
begin
if exists(select top 1 saldo from tbCredRefeit where id_pass = @id_pass and id_refeit = @categoriaref and
saldo > 0 and isnull(dtvalidade,'01/01/2200') <= @data_hora_atual and cancelado = 0)
begin
select @LIBERAR = 0;
select @EVENTO = 28;
select @MSGRELOGIO = 'FORA DO PERIODO';
end else begin
select @LIBERAR = 0;
select @EVENTO = 25;
select @MSGRELOGIO = 'FIM DE REFEICOES';
end;
end
--Achar registro de crdito para abater
if @LIBERAR = 1
begin
select @achou = 0;
select top 1 @achou = 1, @id_credref=id_credref, @valor_refeit = isnull(vlunitario,0)
from tbCredRefeit
where id_pass = @id_pass and id_refeit = @categoriaref
and saldo > 0 and isnull(dtvalidade,'01/01/2200') > @data_hora_atual
and cancelado = 0
order by dtlancado;
if @achou = 0
begin
select @LIBERAR = 0;
select @EVENTO = 25;
select @MSGRELOGIO = 'FIM DE REFEICOES';
end
end
-- Ver nmero de acessos por categoria no dia
if @LIBERAR = 1 and isnull(@ref_acessos,0) > 0
begin
select @contarefs = 0;
if @fxRefIni <= @fxRefFim
begin
select top 1 @contarefs = count(tbMRefeit.id_pass) from tbMRefeit WITH (NOLOCK)
Where id_pass = @id_pass and @apenas_data = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101))
and id_refeit = @categoriaref
and status = 0 and evento in (SELECT id_evento FROM tbEventoSist WHERE flagimpedimento = 0);
end else begin
EXEC AP_PTO001 @fxRefIni, @fxRefMinIni output;
EXEC AP_PTO001 @fxRefFim, @fxRefMinFim output;
if @apenas_minutos >= (@fxRefMinIni - 120)
begin
select top 1 @contarefs = count(tbMRefeit.id_pass) from tbMRefeit WITH (NOLOCK)
Where id_pass = @id_pass and @apenas_data = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101))
and id_refeit = @categoriaref
and status = 0 and evento in (SELECT id_evento FROM tbEventoSist WHERE flagimpedimento = 0)
and (datepart(hh,isnull(tbMRefeit.data,'00:00:00'))*60)+datepart(mi,isnull(tbMRefeit.data,'00:00:00')) >= (@fxRefMinIni - 120);
end else begin
select top 1 @contarefs = count(tbMRefeit.id_pass) from tbMRefeit WITH (NOLOCK)
Where id_pass = @id_pass
and (
(@apenas_data = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101)) and (datepart(hh,isnull(tbMRefeit.hora,'00:00:00'))*60)+datepart(mi,isnull(tbMRefeit.hora,'00:00:00')) <= (@fxRefMinFim + 120))
or
(dateadd(d,-1,@apenas_data) = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101)) and (datepart(hh,isnull(tbMRefeit.data,'00:00:00'))*60)+datepart(mi,isnull(tbMRefeit.data,'00:00:00')) >= (@fxRefMinFim - 120))
)
and id_refeit = @categoriaref
and status = 0 and evento in (SELECT id_evento FROM tbEventoSist WHERE flagimpedimento = 0);
end
end -- if @fxRefIni <= @fxRefFim
if @contarefs >= @ref_acessos
begin
select @LIBERAR = 0;
select @EVENTO = 26;
select @MSGRELOGIO = 'REFEICAO JA EFETUADA';
end
end --if @LIBERAR = 1 and isnull(@ref_acessos,0) > 0
if @LIBERAR = 1
begin
if @exibirsaldorefeit = 1
begin
select @MSGRELOGIO = 'SALDO: ' + right('0000'+ltrim(rtrim(convert(varchar(4),isnull(@ref_nro_ref,1)-1))),4);
end else begin
select @MSGRELOGIO = 'BOM  APETITE';
end
end
end -- if @achou = 0
end -- if (@categoriaref = 0)
end else begin
select @achou = 0;
select @achou = 1, @ref_acessos = acessos, @ref_livre_a = isnull(livre_a,0),
@ref_nro_ref = isnull(nro_ref,0), @ref_livre_r = isnull(livre_r,0),
@ref_refeit = refeit,  @ref_dataini = dataini,
@ref_datafim = datafim from tbRefeitPass
where id_pass = @id_pass;
if @achou=1
begin
if @LIBERAR = 1 and rtrim(isnull(@ref_refeit,'')) = ''
begin
select @LIBERAR = 0;
select @EVENTO = 27;
select @MSGRELOGIO = 'FORA DE TABELA';
end
if @LIBERAR = 1 and @ref_livre_r = 0 and @ref_nro_ref <= 0
begin
select @LIBERAR = 0;
select @EVENTO = 25;
select @MSGRELOGIO = 'FIM DE REFEICOES';
end
if @LIBERAR = 1 and not @ref_dataini is null and not @ref_datafim is null
begin
If convert(datetime,convert(varchar,isnull(@ref_dataini,'00:00:00'),101)) > @apenas_data Or convert(datetime,convert(varchar,isnull(@ref_datafim,'00:00:00'),101)) < @apenas_data
begin
select @LIBERAR = 0;
select @EVENTO = 28;
select @MSGRELOGIO = 'FORA DO PERIODO';
end
end
select @categoriaref = 0;
if @LIBERAR = 1
begin
-- Achar a categoria da refeio
if @ehferiado = 1
begin
select @wdia = 8;
end else begin
select @wdia = DATEPART(dw,@data_hora_atual);
end
select @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim
from tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND
(
(
((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
<= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and @apenas_minutos between ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
and ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
) or (
((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
> ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and (@apenas_minutos >= ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
or @apenas_minutos <= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
)
)
)
and
(
(f.feriado = 1 and @wdia = 8)
or (@wdia = 1 and f.d1 = 1)
or (@wdia = 2 and f.d2 = 1) or (@wdia = 3 and f.d3 = 1) or (@wdia = 4 and f.d4 = 1)
or (@wdia = 5 and f.d5 = 1) or (@wdia = 6 and f.d6 = 1) or (@wdia = 7 and f.d7 = 1)
)
and patindex('%'+right('000'+ltrim(rtrim(convert(char(3),f.id_refeit))),3)+'*%',@ref_refeit) > 0
AND charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0;
if (@categoriaref = 0)
begin
-- No achou a categoria da refeio
select @LIBERAR = 0;
select @EVENTO = 27;
select @MSGRELOGIO = 'FORA DE TABELA';
end else begin
-- Ver nmero de acessos por categoria no dia
if @LIBERAR = 1 and @ref_livre_a = 0
begin
if @ref_acessos > 0
begin
select @contarefs = 0;
if @fxRefIni <= @fxRefFim
begin
select top 1 @contarefs = count(tbMRefeit.id_pass) from tbMRefeit WITH (NOLOCK)
Where id_pass = @id_pass and @apenas_data = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101))
and id_refeit = @categoriaref
and status = 0 and evento in (SELECT id_evento FROM tbEventoSist WHERE flagimpedimento = 0);
end else begin
EXEC AP_PTO001 @fxRefIni, @fxRefMinIni output;
EXEC AP_PTO001 @fxRefFim, @fxRefMinFim output;
if @apenas_minutos >= (@fxRefMinIni - 120)
begin
select top 1 @contarefs = count(tbMRefeit.id_pass) from tbMRefeit WITH (NOLOCK)
Where id_pass = @id_pass and @apenas_data = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101))
and id_refeit = @categoriaref
and status = 0 and evento in (SELECT id_evento FROM tbEventoSist WHERE flagimpedimento = 0)
and (datepart(hh,isnull(tbMRefeit.data,'00:00:00'))*60)+datepart(mi,isnull(tbMRefeit.data,'00:00:00')) >= (@fxRefMinIni - 120);
end else begin
select top 1 @contarefs = count(tbMRefeit.id_pass) from tbMRefeit WITH (NOLOCK)
Where id_pass = @id_pass
and (
(@apenas_data = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101)) and (datepart(hh,isnull(tbMRefeit.hora,'00:00:00'))*60)+datepart(mi,isnull(tbMRefeit.hora,'00:00:00')) <= (@fxRefMinFim + 120))
or
(dateadd(d,-1,@apenas_data) = convert(datetime,convert(varchar,isnull(tbMRefeit.data,'00:00:00'),101)) and (datepart(hh,isnull(tbMRefeit.data,'00:00:00'))*60)+datepart(mi,isnull(tbMRefeit.data,'00:00:00')) >= (@fxRefMinFim - 120))
)
and id_refeit = @categoriaref
and status = 0 and evento in (SELECT id_evento FROM tbEventoSist WHERE flagimpedimento = 0);
end
end
end else begin
select @contarefs = @ref_acessos;
end
if @contarefs >= @ref_acessos
begin
select @LIBERAR = 0;
select @EVENTO = 26;
select @MSGRELOGIO = 'REFEICAO JA EFETUADA';
end
end
if @LIBERAR = 1 and isnull(@categoriaref,0) > 0 and @TemAutorizacaoAcesso <> 1 and @consist_agrefeit=1
begin
if not exists(select top 1 id_pass from tbAgRefeit where id_pass = @id_pass and data = @apenas_data and id_refeit = @categoriaref) begin
select @LIBERAR = 0;
select @EVENTO = 27;
select @MSGRELOGIO = 'FORA DE TABELA';
end;
end;
if @LIBERAR = 1
begin
if @exibirsaldorefeit = 1 and not(@ref_livre_r = 1 and @ref_livre_a = 1)
begin
select @MSGRELOGIO = 'SALDO: ' + right('0000'+ltrim(rtrim(convert(varchar(4),isnull(@ref_nro_ref,0) - isnull(@contarefs,0)))),4);
end else begin
select @MSGRELOGIO = 'BOM  APETITE';
end
end
end
end
end else begin
select @LIBERAR = 0;
select @EVENTO = 27;
select @MSGRELOGIO = 'FORA DE TABELA';
end -- if @achou = 1
if (@LIBERAR=0) begin
select @categoriaref = 0, @id_credref=0;
-- Verificar crditos avulsos
select @achou=0, @saldoAvulso=0;
SELECT TOP 1 @achou=1 FROM tbRefAvulsa WHERE id_pass = @id_pass;
if @achou=1 begin
SELECT @saldoAvulso=ROUND(SUM(valor),2) FROM tbRefAvulsa WHERE id_pass = @id_pass;
select @saldoAvulso = isnull(@saldoAvulso,0);
if @exibirsaldorefeit = 1 begin
select @MSGRELOGIO = 'SALDO: ' + replace(convert(decimal(10, 2), @saldoAvulso),'.','.');
end;
end;
if @saldoAvulso>0 begin
-- Achar a categoria da refeio
select @wdia = DATEPART(dw,@data_hora_atual);
if @ehferiado = 1
select @wdia = 8;
select @categoriaref=0;
if isnull(@id_pass,0)>0 begin
-- Com valor diferenciado para o agrupamento da pessoa
SELECT TOP 1 @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim FROM tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND
( (((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
<= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and @apenas_minutos between ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
and ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
) or (((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
> ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and (@apenas_minutos >= ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
or @apenas_minutos <= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
)
)) and  ((f.feriado = 1 and @wdia = 8) or (@wdia = 1 and f.d1 = 1) or (@wdia = 2 and f.d2 = 1) or (@wdia = 3 and f.d3 = 1) or (@wdia = 4 and f.d4 = 1)
or (@wdia = 5 and f.d5 = 1) or (@wdia = 6 and f.d6 = 1) or (@wdia = 7 and f.d7 = 1)
) AND charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0
AND EXISTS(SELECT top 1 ra.id_refeit FROM tbRefAgrup ra
INNER JOIN tbPass pa ON pa.id_agrupamento = ra.id_agrupamento and pa.id_pass = @id_pass
where ra.id_refeit = f.id_refeit);
end;
if @categoriaref=0 begin
-- Achar categoria no mesmo refeitrio
SELECT TOP 1 @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim FROM tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND
( (((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
<= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and @apenas_minutos between ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
and ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
) or (((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
> ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and (@apenas_minutos >= ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
or @apenas_minutos <= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
)
)) and  ((f.feriado = 1 and @wdia = 8) or (@wdia = 1 and f.d1 = 1) or (@wdia = 2 and f.d2 = 1) or (@wdia = 3 and f.d3 = 1) or (@wdia = 4 and f.d4 = 1)
or (@wdia = 5 and f.d5 = 1) or (@wdia = 6 and f.d6 = 1) or (@wdia = 7 and f.d7 = 1)
) AND charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0;
end;
if @categoriaref>0 begin
select @vlrRef=0, @repasseRef=0;
EXEC OBTER_VREF @id_pass, @categoriaref, @data_hora_atual, @vlrRef output, @repasseRef output, 0, 1;
if @vlrRef>0 and @vlrRef<=@saldoAvulso begin
select @saldoAvulso = @saldoAvulso - @vlrRef;
select @LIBERAR = 1;
select @EVENTO = 101;
if @exibirsaldorefeit = 1 begin
select @MSGRELOGIO = 'SALDO: ' + replace(convert(decimal(10, 2), @saldoAvulso),'.','.');
end else begin
select @MSGRELOGIO = 'BOM  APETITE';
end;
end else if @vlrRef=0 begin
select @EVENTO = 26;
select @MSGRELOGIO = 'REFEICAO JA EFETUADA';
end;
end;
end;
end;
end -- if @refcred = 1
end else begin
if @LIBERAR = 1 and @EntSaiIndefinido = 0 and @consist_resaida = 1 and @ENTSAI = 'S' and @semconsstpass = 0 and isnull(@reinic,0) = 0
begin
if substring(@indgbloq,@id_gbloq,1) = '0'
begin
select @LIBERAR = 0;
select @EVENTO = 15;
select @MSGRELOGIO = 'TENTATIVA DE SAIDA';
end else begin
if not @ult_idbloq is null and not isnull(0,@ult_direc) = 0 and @apenas_data = convert(datetime,convert(varchar,isnull(@ult_acessd,'00:00:00'),101))
begin
select @id_gbloqantes = @id_gbloq;
select top 1 @id_gbloqantes = tbGBloq.id_gbloq
from tbBloq inner join tbGBloq on tbBloq.id_gbloq = tbGBloq.id_gbloq
Where tbBloq.id_bloq = @ult_idbloq;
if @id_gbloqantes > 0 and @id_gbloqantes = @id_gbloq
begin
select @LIBERAR = 0;
select @EVENTO = 15;
select @MSGRELOGIO = 'TENTATIVA DE SAIDA';
end
end
end
end
end -- if @LIBERAR = 1 and @ENTSAI = 'E'
if @LIBERAR = 1 and @TemAutorizacaoAcesso <> 1 and @consist_tbhorpas=1 begin
select @tanafx=0;
if @ENTSAI='S' begin
exec P_CONSIST_ITV @id_pass, @data_hora_atual, 1, @id_bloq, @tanafx out
end else begin
exec P_CONSIST_ITV @id_pass, @data_hora_atual, 0, @id_bloq, @tanafx out
end;
if @tanafx=2 or @tanafx=3 begin
select @LIBERAR = 0;
select @EVENTO = 45;
select @MSGRELOGIO = 'INTERVALO LIMITE';
end else begin if @tanafx>0 begin
select @LIBERAR = 0;
select @EVENTO = 7;
select @MSGRELOGIO = 'FORA DO HORARIO';
end; end;
end;
end --if @tipo_controle<>'R'
end else begin  -- else do (@ENTSAI = 'E' or @saidaliberada = 0) and @EHMESTRE = 0 and @LIBERAR = 1
if @LIBERAR = 1 and @bloqueado = 1
begin
select @LIBERAR = 0;
select @EVENTO = 8;
select @MSGRELOGIO = '** BLOQUEADO **';
end
if @EntSaiIndefinido=1 and @saidaliberada=1 and @EHMESTRE = 0 and @LIBERAR = 1
begin
if @tipo_controle<>'R' and @tipo_controle<>'S' begin
if @LIBERAR = 1 and @tipo_controle <> 'P' and @consist_reentrada = 1 and (@ENTSAI = 'E' or @EntSaiIndefinido=1) and @semconsstpass = 0 and isnull(@reinic,0) = 0
begin
if (@primario = 0 and substring(@indgbloq,@id_gbloq,1) = '1')
or (@primario = 1 and @id_gbloqantesPrimario = 1 and @id_gbloqantesSentido = '1')
or (@primario = 1 and @status = 'D')
begin
select @ENTSAI = 'S';
select @EntSaiIndefinido=0, @EntSaiDefinido=1;
end
end
if @LIBERAR = 1 and @tipo_controle <> 'P' and @consist_resaida = 1 and ((@ENTSAI='S' or @EntSaiIndefinido=1) AND @EntSaiDefinido=0) and @semconsstpass = 0 and isnull(@reinic,0) = 0
begin
if substring(@indgbloq,@id_gbloq,1)='0'
begin
select @ENTSAI = 'E';
select @EntSaiIndefinido=0,@EntSaiDefinido=1;
end;
end
end;
end; -- @EntSaiIndefinido=1 and @saidaliberada=1 and @EHMESTRE = 0 and @LIBERAR = 1
if (@EHMESTRE = 1 and @LIBERAR = 1 and @ENTSAI = 'E' and @tipo_controle='R')
begin
select @EVENTO = 24;
select @MSGRELOGIO = 'BOM  APETITE';
select @categoriaref = 0;  -- Achar a categoria da refeio
if @ehferiado = 1
begin
select @wdia = 8;
end else begin
select @wdia = DATEPART(dw,@data_hora_atual);
end
select @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim
from tbRefeit f inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND
(
(
((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
<= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and @apenas_minutos between ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
and ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
) or (
((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
> ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and (@apenas_minutos >= ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00')))
or @apenas_minutos <= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
)
)
)
and ((f.feriado = 1 and @wdia = 8)
or (@wdia = 1 and f.d1 = 1)
or (@wdia = 2 and f.d2 = 1) or (@wdia = 3 and f.d3 = 1) or (@wdia = 4 and f.d4 = 1)
or (@wdia = 5 and f.d5 = 1) or (@wdia = 6 and f.d6 = 1) or (@wdia = 7 and f.d7 = 1)
) AND charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0;
--Aproximar
if (@categoriaref = 0)
begin
select @ultDifMinutos = 50000;
--Faixa menor
select top 1 @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim
from tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND @apenas_minutos >= (datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60) + datepart(mi,isnull(fh.hora_fim,'00:00:00'))
and ((f.feriado = 1 and @wdia = 8)
or (@wdia = 1 and f.d1 = 1)
or (@wdia = 2 and f.d2 = 1) or (@wdia = 3 and f.d3 = 1) or (@wdia = 4 and f.d4 = 1)
or (@wdia = 5 and f.d5 = 1) or (@wdia = 6 and f.d6 = 1) or (@wdia = 7 and f.d7 = 1)
) AND charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0
order by fh.hora_fim desc;
if (@categoriaref > 0)
begin
select @ultDifMinutos = (@apenas_minutos - ((datepart(hh,isnull(@fxRefFim,'00:00:00'))*60)+datepart(mi,isnull(@fxRefFim,'00:00:00'))));
end
--Faixa Maior
select top 1 @categoriaref = isnull(f.id_refeit,@categoriaref), @fxRefIni = isnull(fh.hora_ini,@fxRefIni), @fxRefFim = isnull(fh.hora_fim,@fxRefFim)
from tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND @apenas_minutos <= (datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00'))
and (@categoriaref = 0 Or @ultDifMinutos > ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00'))) - @apenas_minutos)
and ((f.feriado = 1 and @wdia = 8)
or (@wdia = 1 and f.d1 = 1)
or (@wdia = 2 and f.d2 = 1) or (@wdia = 3 and f.d3 = 1) or (@wdia = 4 and f.d4 = 1)
or (@wdia = 5 and f.d5 = 1) or (@wdia = 6 and f.d6 = 1) or (@wdia = 7 and f.d7 = 1)
) AND charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0
order by fh.hora_ini asc;
if (@categoriaref = 0)
begin
select @ultDifMinutos = 50000;
--Faixa menor
select top 1 @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim
from tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND @apenas_minutos >= ((datepart(hh,isnull(fh.hora_fim,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_fim,'00:00:00')))
and charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0
order by fh.hora_fim desc;
if (@categoriaref > 0)
begin
select @ultDifMinutos = (@apenas_minutos - ((datepart(hh,isnull(@fxRefFim,'00:00:00'))*60)+datepart(mi,isnull(@fxRefFim,'00:00:00'))))
end
--Faixa Maior
select top 1 @categoriaref = f.id_refeit, @fxRefIni = fh.hora_ini, @fxRefFim = fh.hora_fim
from tbRefeit f
inner join tbRefeitHors fh on f.id_refeit = fh.id_refeit
where isnull(f.id_grefeit,0) = @id_grefeit AND @apenas_minutos <= (datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00'))
and charindex(@tipo,ISNULL(f.tp_pass,@tipo))>0
and (@categoriaref = 0 Or @ultDifMinutos > ((datepart(hh,isnull(fh.hora_ini,'00:00:00'))*60)+datepart(mi,isnull(fh.hora_ini,'00:00:00'))) - @apenas_minutos)
order by fh.hora_ini asc;
end
end
end
end --(@ENTSAI = 'E' or @saidaliberada = 0) and @EHMESTRE = 0 and @LIBERAR = 1
end  -- if @EVENTO <> 99
select @msgrel = @MSGRELOGIO; select @msgtela = replace(@MSGRELOGIO,'NAO CADASTRADO','NO CADASTRADO');
if @LIBERAR <> 1 and @EVENTO <> 8
begin
select @msg_qtd_p = 0;
end
if isnull(@msg_qtd_p,0) > 0
begin
If isnull(@id_msgrel,0) > 0
begin
select @msgrel = isnull(descricao,@msgrel) from tbMsgRel where id_msgrel = @id_msgrel;
End
If isnull(@id_msgtela,0) > 0
begin
select @msgtela = isnull(descricao,@msgtela) from tbMsgTela where id_msgtela = @id_msgtela;
End
end
select @ult_aces_visi = 0;
if @tipo = 'V'
begin
if isnull(@visi_aces_p,0) <= 0 and @consist_numacessos_vis = 1
begin
select @ult_aces_visi = 1;
end
end
if @EntSaiIndefinido = 1
begin
select @ENTSAI = 'A';
end
if @comunicacao <> 2 begin
select @msgrel = left(@msgrel,20)
select @msgtela = left(@msgtela,20);
select @MSGRELOGIO = left(@MSGRELOGIO,20);
end
if @id_modelo=11 and @LIBERAR=1 begin
if @EHMESTRE=0 AND @CRACHATECLADO <> 'B' AND @id_pass>0 begin
if (@ENTSAI<>'S' and SUBSTRING(@tmpAtuac+'00',1,1) IN ('5','6','7')) or
(@ENTSAI<>'E' and SUBSTRING(@tmpAtuac+'00',2,1) IN ('5','6','7'))
begin
exec RET_TEMPLATE_SG @id_pass, 0, @template output;
end;
end;
if len(@template)=0 and (@bloq_senha=1 or @CRACHATECLADO = 'T') begin
select @vsenha=@senhacad;
end;
end;
if @id_modelo=13 and @LIBERAR=1 and @bloq_senha=1 begin
select @vsenha=@senhacad;
end;
if @tipo_controle<>'S' begin
if @LIBERAR=1 and @tipo = 'V' AND @ENTSAI = 'S' and @primario = 1 AND (@consist_numacessos_vis = 1 and @visi_aces_p <= 0) begin
IF EXISTS(SELECT id_bloq FROM tbBloq WHERE id_bloq=@id_bloq AND comunicacao in (0,1,12,15) AND (funis>2 or tipo=4 or tipo=6)) or
EXISTS(SELECT id_bloq FROM tbBloq WHERE id_bloq=@id_bloq AND comunicacao in (11, 13) AND (funis>2 OR tipo=15 OR tipo=16)) or
EXISTS(SELECT id_bloq FROM tbBloq WHERE id_bloq=@id_bloq AND comunicacao = 25 AND tipo IN (4,5,6,9)) OR
EXISTS(SELECT id_bloq FROM tbBloq WHERE id_bloq=@id_bloq AND comunicacao = 27 AND tipo IN (9, 10)) OR
EXISTS(SELECT TOP 1 id_bloq FROM tbBloqLeitor WHERE id_bloq=@id_bloq AND cofre=1)
begin
SELECT @cofre=1, @forcarbaixa=1;
end;
end;
end;
select @CRACHA as cracha, isnull(@tipo,'') as tipopas,  isnull(@id_pass,0) as id_pass, isnull(@nome,'Nome no localizado') as nome,
@LIBERAR as liberar, @MSGRELOGIO as msgrelogio, @EVENTO as evento, @ENTSAI as entsai,
isnull(@crachacad,0) as crachacad, isnull(@status, '') as status,
isnull(@id_empresa,0) as id_empresa, isnull(@indgbloq,replicate('0',300)) as indgbloq,
isnull(@id_depart,0) as id_depart, isnull(@sequencia,'') as sequencia,
@bloqueado as bloqueado,
@TERMINAL as terminal, @bloqueadobloq as bloqueadobloq,
@primario as primario, @id_gbloq as id_gbloq, @tipo_controle as tipo_controle,
@tipobloq as tipobloq, @st_bloq as st_bloq,
@descricaobloq as descricaobloq, @sentidobloq as sentidobloq, @ip as ipbloq,
isnull(@id_msgrel,0) as id_msgrel, isnull(@id_msgtela,0) as id_msgtela, isnull(@msg_qtd_p,0) as msg_qtd_p, isnull(@foto,'') as foto,
@forcarbaixa as forcarbaixa, isnull(@categoriaref,0) as categoriaref, isnull(@valor_refeit,0) as valor_refeit,
isnull(@bloqatuac,0) as bloqatuac, @msgrel as msgrel, @msgtela as msgtela, @ult_aces_visi as ult_aces_visi, isnull(@id_credref,0) as id_credref, @cofre as cofre, @vsenha as vsenha, @template as template;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.GRAVA_STATUS_EVENTO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.GRAVA_STATUS_EVENTO; END
GO
CREATE PROCEDURE dbo.GRAVA_STATUS_EVENTO (@ID_CEVENTO FLOAT,  @CRACHA FLOAT, @STATUS CHAR(1),
@DATAHORA DATETIME, @ID_OCOR INTEGER, @RELOGIO SMALLINT, @LFUSO DATETIME = null) WITH ENCRYPTION AS
BEGIN
if @DATAHORA is null begin select @DATAHORA = isnull(@LFUSO,getdate()); end;
if exists(select cracha from tbCrachaCEvento where id_cevento = @ID_CEVENTO and cracha = @CRACHA) begin
update tbCrachaCEvento set
status = @STATUS,
ultacesso_dt = case when @STATUS = 'E' then ultacesso_dt else @DATAHORA end,
ultacesso_ocor = case when @STATUS = 'E' then ultacesso_ocor else @ID_OCOR end,
ultacesso_bloq = case when @STATUS = 'E' then ultacesso_bloq else @RELOGIO end,
reinic = 0
where id_cevento = @ID_CEVENTO and cracha = @CRACHA;
end else begin
insert into tbCrachaCEvento (id_cevento,cracha,status,
ultacesso_dt,ultacesso_ocor, ultacesso_bloq)
values (@ID_CEVENTO, @CRACHA, @STATUS, @DATAHORA,@ID_OCOR, @RELOGIO);
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.INSERE_MOVIMENTO_EVENTO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.INSERE_MOVIMENTO_EVENTO; END
GO
CREATE PROCEDURE dbo.INSERE_MOVIMENTO_EVENTO (@ID_CEVENTO FLOAT, @ID_DINGRESSOS FLOAT, @CRACHA FLOAT, @DATAHORA DATETIME,
@ID_OCOR INTEGER, @RELOGIO SMALLINT) WITH ENCRYPTION AS
BEGIN
declare @ent integer;  declare @sai integer;
declare @util integer; declare @impedido bit;
declare @mestre bit;   declare @entsai integer;
select @ent = 0; select @sai = 0; select @util = 0;
select @impedido = 0;
select @mestre = 0;
select top 1 @impedido = isnull(flagimpedimento,0),
@mestre = isnull(mestre,0), @entsai = isnull(entsai,0)
from tbOcorCEvento where id_ocor = @ID_OCOR;
if (@entsai = 0) begin select @sai = 1; end else begin select @ent = 1; end;
--Atualiza totais dos eventos
if @impedido = 0 and @mestre = 0
begin
if NOT EXISTS(select cracha from tbMCEvento
where id_cevento = @ID_CEVENTO and cracha = @CRACHA
and id_ocor in (select e.id_ocor from tbOcorCEvento e where e.flagimpedimento = 0)
)
begin
select @util = 1;
end;
update tbIngressos set
entradas = entradas + @ent, saidas = saidas + @sai,
utilizados = utilizados + @util
where id_cevento = @ID_CEVENTO and id_dingressos = @ID_DINGRESSOS
and @CRACHA between cracha_ini and cracha_fim;
end else if (@impedido = 0 and @mestre = 1) begin
--  mestre
update tbCEvento set
ent_mestre = isnull(ent_mestre,0) + @ent, sai_mestre = isnull(sai_mestre,0) + @sai
where id_cevento = @ID_CEVENTO;
end;
--Gravar marcao
if @impedido = 0 or @ID_CEVENTO = 0 or EXISTS(select gravaimp from tbCEvento where id_cevento = @ID_CEVENTO and gravaimp = 1)
begin
if @DATAHORA is null
begin
select @DATAHORA = getdate();
end
insert into tbMCEvento (id_cevento, cracha, datahora, id_ocor,relogio, id_dingressos)
values (@ID_CEVENTO, @CRACHA, @DATAHORA, @ID_OCOR, @RELOGIO, @ID_DINGRESSOS);
end;
END
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.VALIDA_ACESSO_EVENTO') AND xtype = 'P')
BEGIN DROP PROCEDURE dbo.VALIDA_ACESSO_EVENTO; END
GO
CREATE PROCEDURE dbo.VALIDA_ACESSO_EVENTO(@DTBATCH DATETIME, @TERMINAL INT, @CRACHA FLOAT, @ENTSAI CHAR(1)) WITH ENCRYPTION AS
BEGIN
declare @batch bit; declare @apenas_data datetime;
declare @data_hora_atual datetime; declare @wd integer; declare @feriado bit;
declare @minutos integer;
declare @id_ocor integer; declare @display varchar(20); declare @bloqueado bit;
declare @achou bit; declare @id_cevento float; declare @EntSaiIndefinido bit;
declare @desc_evento varchar(50); declare @unicoacesso bit;
declare @saida bit; declare @gravaimp bit;
declare @resaida bit; declare @reentrada bit;
declare @fx1 varchar(40);  declare @fx2 varchar(40);  declare @fx3 varchar(40);
declare @fx4 varchar(40);  declare @fx5 varchar(40);  declare @fx6 varchar(40);
declare @fx7 varchar(40);  declare @fx8 varchar(40);  declare @fx varchar(40);
declare @nafx integer; declare @ifx integer;
declare @status char(1);  declare @ultacesso_dt datetime;  declare @ultacesso_ocor integer;
declare @id_dingressos float; declare @crachaBloq bit;
declare @reinic bit;
declare @TipoDia char(1); declare @TrocaHor Bit;     declare @TipoHE char(1)
declare @id_eveabo int;   declare @troca_id_phorario int;  declare @troca_id_horario int;
declare @descFeriado varchar(20);
declare @horAbono varchar(7);     declare @m_horAbono int;
declare @descHorPto varchar(100);   declare @descHorAce varchar(50);
declare @descEveAbo varchar(30); declare @folga bit;
select @reinic = 0;
-- Data/Hora atual
if @DTBATCH is not null
begin
select @batch = 1; --Marcao em Batch
select @data_hora_atual = @DTBATCH;
end else begin
select @batch = 0;
select @data_hora_atual = getdate();
end;
select @apenas_data = convert(datetime,convert(varchar,isnull(@data_hora_atual,'00:00:00'),101));
select @wd = datepart(dw,@data_hora_atual); --Dia da semana
exec AP_PTO001 @data_hora_atual, @minutos output;
EXEC AP_PTO005 @apenas_data, 0, 0, @TipoDia out, @TrocaHor out, @TipoHE out,
@id_eveabo out, @troca_id_phorario out, @troca_id_horario out, @descFeriado out, @descEveAbo out, @horAbono out, @m_horAbono out, @folga out;
select @feriado = 0;
if @TipoDia = 'V' or @TipoDia = 'P'
begin
select @feriado = 1;
end;
select @id_cevento = 0; select @id_dingressos = 0;
select @id_ocor = 0; select @display = 'ACESSO LIBERADO'; select @bloqueado = 0;
select @achou = 0;
select @desc_evento = 'NO CADASTRADO'; select @unicoacesso = 1;
select @saida = 1; select @gravaimp = 0;
select @reentrada = 1; select @resaida = 1;
select @fx1 = replicate('0',40); select @fx2 = replicate('0',40);
select @fx3 = replicate('0',40); select @fx4 = replicate('0',40);
select @fx5 = replicate('0',40); select @fx6 = replicate('0',40);
select @fx7 = replicate('0',40); select @fx8 = replicate('0',40);
select @fx = replicate('0',40);
select @nafx = 0; select @ifx = 0;
select @status = 'P', @ultacesso_dt = '01/01/1900' , @ultacesso_ocor = 0;
select @EntSaiIndefinido = 0;
select @crachaBloq = 0;
if @ENTSAI = 'A'
begin
select @EntSaiIndefinido = 1;
select @ENTSAI = 'E';
end
if @id_ocor = 0
begin
select @achou = 0;
select top 1 @achou = 1, @id_cevento = e.id_cevento, @id_dingressos = i.id_dingressos,
@desc_evento = e.descricao, @unicoacesso = e.unicoacesso, @crachaBloq = i.status,
@saida = e.saida, @gravaimp = e.gravaimp,
@reentrada = e.reentrada, @resaida = e.resaida,
@fx1 = left(rtrim(isnull(e.fx1,''))+replicate('0',40),40),
@fx2 = left(rtrim(isnull(e.fx2,''))+replicate('0',40),40),
@fx3 = left(rtrim(isnull(e.fx3,''))+replicate('0',40),40),
@fx4 = left(rtrim(isnull(e.fx4,''))+replicate('0',40),40),
@fx5 = left(rtrim(isnull(e.fx5,''))+replicate('0',40),40),
@fx6 = left(rtrim(isnull(e.fx6,''))+replicate('0',40),40),
@fx7 = left(rtrim(isnull(e.fx7,''))+replicate('0',40),40),
@fx8 = left(rtrim(isnull(e.fx8,''))+replicate('0',40),40)
from tbIngressos i
inner join tbCEvento e on i.id_cevento = e.id_cevento
where i.cracha_ini <= @CRACHA and i.cracha_fim >= @CRACHA
and e.data_ini <= @data_hora_atual and (e.data_fim >= @data_hora_atual or e.semfim = 1);
if @achou = 1
begin
-- Achar status do cracha
select @status = isnull(status,'P'), @ultacesso_dt = ultacesso_dt , @ultacesso_ocor = ultacesso_ocor, @reinic = isnull(reinic,0)
from tbCrachaCEvento
where id_cevento = @id_cevento and cracha = @CRACHA;
if @EntSaiIndefinido = 1 and @status = 'D'
begin
select @ENTSAI = 'S'
end
if @crachaBloq = 1
begin
if @batch = 0
begin
select @id_ocor = 49;
end else begin
if @ENTSAI = 'E'
begin
select @id_ocor = 33;
end else begin
select @id_ocor = 34;
end;
end;
select @display = 'CRACHA BLOQUEADO';
select @bloqueado = 1;
end else if @reinic = 0 and @status = 'E' and not @batch = 1  begin
select @id_ocor = 48;
select @display = 'IMPEDIDO EM ESPERA';
select @bloqueado = 1;
end else begin
if @ENTSAI = 'E'
begin
if @status = 'P'
begin
if @batch = 0
select @id_ocor = 1;
else
select @id_ocor = 20;
end else begin
if @batch = 0
select @id_ocor = 2;
else
select @id_ocor = 21;
end
select @display = 'ACESSO LIBERADO';
select @bloqueado = 0;
if @status = 'D'
begin
if @unicoacesso = 0
begin
if @reinic = 0 and @reentrada = 1 and @batch = 0
begin
select @id_ocor = 42;
select @display = 'REENTRADA';
select @bloqueado = 1;
end
end else begin
if @batch = 0
select @id_ocor = 41;
else
select @id_ocor = 27;
select @display = 'CRACHA JA UTILIZADO';
select @bloqueado = 1;
end
end else begin
if @status = 'N'
begin
-- No  a primeira entrada
if @unicoacesso = 0
begin
if @batch = 0
select @id_ocor = 2;
else
select @id_ocor = 21;
end else begin
if @batch = 0
select @id_ocor = 41;
else
select @id_ocor = 27;
select @display = 'CRACHA JA UTILIZADO';
select @bloqueado = 1;
end
end
end
--Ver faixas horrias
if @bloqueado = 0
begin
if @feriado = 1
begin
select @fx = @fx8;
end else begin
select @fx = case
when @wd = 1 then @fx1 when @wd = 2 then @fx2
when @wd = 3 then @fx3 when @wd = 4 then @fx4
when @wd = 5 then @fx5 when @wd = 6 then @fx6
when @wd = 7 then @fx7
end
end
select @nafx = 0;
select @ifx = 1;
while (@nafx = 0 and @ifx < 40)
begin
if convert(int, substring(@fx, @ifx,4)) <= @minutos and
@minutos <= convert(int, substring(@fx, @ifx+4,4))
begin
select @nafx = @ifx;
end
select @ifx = @ifx + 8;
end
if @nafx = 0
begin
if @batch = 0
select @id_ocor = 45;
else
select @id_ocor = 28;
select @display = 'FORA DO HORARIO';
select @bloqueado = 1;
end
end
end else begin --Se no @ENTSAI = 'E'
--Ver se pode marcar sada
if @saida = 0
begin
if @batch = 0
select @id_ocor = 47;
else
select @id_ocor = 32;
select @display = 'SENTIDO PROIBIDO';
select @bloqueado = 1;
end else begin
if @batch = 0
select @id_ocor = 3;
else
select @id_ocor = 22;
select @display = 'ACESSO LIBERADO';
select @bloqueado = 0;
if @batch = 0
begin
if @status = 'P'
begin
select @id_ocor = 44;
select @display = 'SAIDA SEM ENTRADA';
select @bloqueado = 1;
end else begin
if @reinic = 0 and @status = 'N' and @resaida = 1
begin
select @id_ocor = 43;
select @display = 'TENTATIVA DE SAIDA';
select @bloqueado = 1;
end
end
end
end -- se pode marcar saida
end -- se  entrada ou saida
end -- Se esta em espera
end -- Crach dentro da faixa e dentro do perodo
end -- Verificou se crach dentro da faixa e dentro do perodo
if @id_ocor = 0
begin
select top 1 @achou = 1, @id_cevento = e.id_cevento, @id_dingressos = i.id_dingressos,
@desc_evento = e.descricao, @unicoacesso = e.unicoacesso, @crachaBloq = i.status,
@saida = e.saida, @gravaimp = e.gravaimp,
@reentrada = e.reentrada, @resaida = e.resaida,
@fx1 = left(rtrim(isnull(e.fx1,''))+replicate('0',40),40),
@fx2 = left(rtrim(isnull(e.fx2,''))+replicate('0',40),40),
@fx3 = left(rtrim(isnull(e.fx3,''))+replicate('0',40),40),
@fx4 = left(rtrim(isnull(e.fx4,''))+replicate('0',40),40),
@fx5 = left(rtrim(isnull(e.fx5,''))+replicate('0',40),40),
@fx6 = left(rtrim(isnull(e.fx6,''))+replicate('0',40),40),
@fx7 = left(rtrim(isnull(e.fx7,''))+replicate('0',40),40),
@fx8 = left(rtrim(isnull(e.fx8,''))+replicate('0',40),40)
from tbIngressos i
inner join tbCEvento e on i.id_cevento = e.id_cevento
where i.cracha_ini <= @CRACHA and i.cracha_fim >= @CRACHA
if @achou = 1
begin
if @batch = 0
select @id_ocor = 46;
else
if @ENTSAI = 'S'
select @id_ocor = 31;
else
select @id_ocor = 30;
select @display = 'FORA DO PERIODO';
select @bloqueado = 1;
end
end --Crach dentro da faixa e fora do perodo
if @id_ocor = 0
begin
select top 1 @achou = 1, @id_cevento = e.id_cevento, @id_dingressos = 0,
@desc_evento = e.descricao, @unicoacesso = e.unicoacesso,
@saida = e.saida, @gravaimp = e.gravaimp,
@reentrada = e.reentrada, @resaida = e.resaida,
@fx1 = left(rtrim(isnull(e.fx1,''))+replicate('0',40),40),
@fx2 = left(rtrim(isnull(e.fx2,''))+replicate('0',40),40),
@fx3 = left(rtrim(isnull(e.fx3,''))+replicate('0',40),40),
@fx4 = left(rtrim(isnull(e.fx4,''))+replicate('0',40),40),
@fx5 = left(rtrim(isnull(e.fx5,''))+replicate('0',40),40),
@fx6 = left(rtrim(isnull(e.fx6,''))+replicate('0',40),40),
@fx7 = left(rtrim(isnull(e.fx7,''))+replicate('0',40),40),
@fx8 = left(rtrim(isnull(e.fx8,''))+replicate('0',40),40)
from tbCEvento e
WHERE e.data_ini <= @data_hora_atual and (e.data_fim >= @data_hora_atual or e.semfim = 1);
if @achou = 1
begin
if exists(select cracha from tbCMestre where cracha = @CRACHA)
begin
if @ENTSAI = 'S'
begin
if @batch = 0
select @id_ocor = 5;
else
select @id_ocor = 24;
end else begin
if @batch = 0
select @id_ocor = 4;
else
select @id_ocor = 23;
end
select @display = 'CARTAO MESTRE';
select @bloqueado = 0;
end else begin
if @batch = 0
select @id_ocor = 40;
else
if @ENTSAI = 'S'
select @id_ocor = 26;
else
select @id_ocor = 25;
select @display = 'NAO CADASTRADO';
select @bloqueado = 1;
end
end
end -- Crach fora da faixa do evento atual
if @id_ocor = 0
begin
if exists(select cracha from tbCMestre where cracha = @CRACHA)
begin
if @ENTSAI = 'S'
begin
if @batch = 0
select @id_ocor = 5;
else
select @id_ocor = 24;
end else begin
if @batch = 0
select @id_ocor = 4;
else
select @id_ocor = 23;
end
select @display = 'CARTAO MESTRE';
select @bloqueado = 0;
end else begin
if @batch = 0
select @id_ocor = 40;
else
if @ENTSAI = 'S'
select @id_ocor = 26;
else
select @id_ocor = 25;
select @display = 'NAO CADASTRADO';
select @bloqueado = 1;
end;
end -- Crach fora da faixa e fora de evento
select @id_cevento as id_cevento, @desc_evento as desc_evento, @id_dingressos as id_dingressos,
@ENTSAI as entsai, @id_ocor as id_ocor, @display as display, @status as status,
@bloqueado as bloqueado, @gravaimp as gravaimp, @ultacesso_dt as ultacesso_dt,
@ultacesso_ocor as ultacesso_ocor;
END
GO
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbLstBatch') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
CREATE TABLE [dbo].[tbLstBatch] (
[id_bloq] int NOT NULL,
[cracha] [float] NOT NULL,
[via] tinyint NOT NULL, [senha] int NOT NULL,
[data]   [datetime] NOT NULL,
[tipodia] char(1) NOT NULL,
[fxini_1] char(5) NOT NULL, [fxfim_1] char(5) NOT NULL,
[fxini_2] char(5) NOT NULL, [fxfim_2] char(5) NOT NULL,
[fxini_3] char(5) NOT NULL, [fxfim_3] char(5) NOT NULL,
[fxini_4] char(5) NOT NULL, [fxfim_4] char(5) NOT NULL,
[fxini_5] char(5) NOT NULL, [fxfim_5] char(5) NOT NULL,
[fxini_6] char(5) NOT NULL, [fxfim_6] char(5) NOT NULL
) ON [PRIMARY];
CREATE CLUSTERED INDEX [IX_tbLstBatch] ON  [dbo].[tbLstBatch](id_bloq, cracha, via, data) ON [PRIMARY];
end
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO035') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO035; END
GO
CREATE PROCEDURE dbo.AP_PTO035(@id_pass int,  @id_bloq int, @data datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @achou bit; declare @wdia tinyint;
declare @data_ant datetime; declare @wdia_ant tinyint;
declare @TipoHE char(1);
declare @id_horario int; declare @tipodia char(1);
declare @folga int; declare @id_phorario int;
declare @flexivel bit;  declare @trabalhado bit;
declare @TipoHE_ant char(1);
declare @id_horario_ant int; declare @tipodia_ant char(1);
declare @folga_ant int; declare @id_phorario_ant int;
declare @flexivel_ant bit;  declare @trabalhado_ant bit;
declare @listas varchar(16); declare @tipo_controle char(1);
declare @id_empresa int;
declare @cracha float; declare @via tinyint; declare @tipodia_fim char(1); declare @senhacad int
declare @fxantes char(5); declare @afastado bit; declare @afastado_ant bit;
declare @fxini_1 char(5); declare @fxfim_1 char(5); declare @fxini_2 char(5); declare @fxfim_2 char(5);
declare @fxini_3 char(5); declare @fxfim_3 char(5); declare @fxini_4 char(5); declare @fxfim_4 char(5);
declare @fxini_5 char(5); declare @fxfim_5 char(5); declare @fxini_6 char(5); declare @fxfim_6 char(5);
declare @per_indet bit;     declare @data_ini smalldatetime;  declare @data_fim smalldatetime;
declare @provisorio float;  declare @prov_ini smalldatetime;   declare @prov_fim smalldatetime;
declare @feriado_pass bit;  declare @id_consist int; declare @via_provisorio int;
declare @consist_via bit; declare @consist_tbhorpas bit;
declare @consist_libbloq bit; declare @consist_permanencia bit;
declare @consist_afastamento bit; declare @consist_feriado bit;
declare @consist_numacessos_vis bit; declare @consist_reentrada bit;
declare @consist_resaida bit; declare @consist_folga bit;
declare @consist_horarioindevido bit; declare @consist_ausenciaminima bit; declare @consist_estourodedias bit;
declare @consist_acessos_dia bit;  declare @consist_agrefeit bit;
declare @consist_max_sublocal bit; declare @consist_max_visitado bit; declare @consist_integracao bit;
declare @LIBERAR bit; declare @TemAutorizacaoAcesso bit; declare @id_gbloq bit;
declare @cvinculo varchar(10), @cracha_vinc float; declare @fx_secundario bit; declare @bloq_secundario bit;
select @data_ant = dateadd(d,-1,@data);
select @cracha = 0, @via = 0, @tipodia_fim = 'N', @fxantes = '__:__',
@fxini_1='00:00',@fxfim_1='23:59',@fxini_2='__:__',@fxfim_2='__:__',
@fxini_3='__:__',@fxfim_3='__:__',@fxini_4='__:__',@fxfim_4='__:__',
@fxini_5='__:__',@fxfim_5='__:__',@fxini_6='__:__',@fxfim_6='__:__';
SELECT @listas='0000000000', @tipo_controle = 'A', @id_gbloq=0;
SELECT top 1 @listas=isnull(listas,'0000000000'), @tipo_controle = isnull(tipo_controle,'A'), @id_gbloq=isnull(id_gbloq,0)
FROM tbBloq WHERE id_bloq = @id_bloq;
select @bloq_secundario=0;
SELECT TOP 1 @bloq_secundario=1 FROM tbGBloq g INNER JOIN tbBloq b ON g.id_gbloq = b.id_gbloq AND g.primario=0
WHERE b.id_bloq = @id_bloq;
select @LIBERAR=0;
SELECT top 1 @LIBERAR=1, @id_empresa=id_empresa, @cracha=cracha, @via=isnull(via,0),
@per_indet = per_indet, @data_ini = data_ini, @data_fim = data_fim, @provisorio = provisorio, @via_provisorio=via_provisorio,
@prov_ini = prov_ini, @prov_fim = prov_fim, @feriado_pass = feriado, @id_consist=isnull(id_consist,0), @senhacad = isnull(senha,0)
FROM tbPass WHERE id_pass = @id_pass and isnull(bloqueado,0)=0 and isnull(inativo,0)=0;
select @cvinculo='';
select @cvinculo=isnull(cvinculo,'') from tbParSist;
/* Verificar vnculo de cracha */
select @cracha_vinc = 0;
if len(ltrim(@cvinculo)) > 0 begin
SELECT TOP 1 @cracha_vinc=isnull(vinculado,0) FROM tbCVinculado WHERE cracha=@cracha ORDER BY vinculado;
if @cracha_vinc>0 begin
select @cracha=@cracha_vinc;
end;
end;
select @TemAutorizacaoAcesso = 0;
SELECT @TemAutorizacaoAcesso = 1 FROM tbLibAcesso
WHERE id_pass = @id_pass
AND @data between convert(datetime,convert(varchar,data,101)) and convert(datetime,convert(varchar,dataf,101))
AND patindex('%'+right('000'+rtrim(ltrim(convert(char(3),@id_gbloq))),3)+'*%',isnull(grupo,'')) > 0;
exec CARREGA_CONSISTENCIAS @id_consist, @consist_via output, @consist_tbhorpas output,
@consist_libbloq output, @consist_permanencia output,
@consist_afastamento output, @consist_feriado output,
@consist_numacessos_vis output, @consist_reentrada output,
@consist_resaida output, @consist_folga output,
@consist_horarioindevido output, @consist_ausenciaminima output, @consist_estourodedias output,
@consist_acessos_dia output,
@consist_max_sublocal output, @consist_max_visitado output, @consist_integracao output, @consist_agrefeit output;
if substring(@listas,2,1)<>'1' begin select @LIBERAR = 0; end; --No tem lista de liberados
if substring(@listas,3,1)<>'1' begin select @consist_tbhorpas = 0; end;
if substring(@listas,6,1)<>'1' begin select @consist_folga = 0; end;
if substring(@listas,7,1)<>'1' begin select @consist_feriado = 0; end;
if substring(@listas,9,1)<>'1' begin select @consist_afastamento = 0; end;
if @LIBERAR = 1 and @tipo_controle <> 'P' and @consist_permanencia = 1 and isnull(@per_indet,0) = 0 and not @data_ini is null and not @data_fim is null begin
if not (@data >= convert(datetime,convert(varchar,isnull(@data_ini,'00:00:00'),101)) and @data <= convert(datetime,convert(varchar,isnull(@data_fim,'00:00:00'),101))) begin
select @LIBERAR = 0;
end;
end;
select @afastado=0,@afastado_ant=0;
if @LIBERAR = 1 and @consist_afastamento = 1 and @TemAutorizacaoAcesso = 0 begin
if exists(select id_pass from tbAfast where id_pass = @id_pass and @data_ant between convert(datetime,convert(varchar,isnull(dataini,'00:00:00'),101)) and convert(datetime,convert(varchar,isnull(datafim,'00:00:00'),101))) begin
select @afastado_ant=1;
end;
if exists(select id_pass from tbAfast where id_pass = @id_pass and @data between convert(datetime,convert(varchar,isnull(dataini,'00:00:00'),101)) and convert(datetime,convert(varchar,isnull(datafim,'00:00:00'),101))) begin
select @afastado=1;
end;
end;
if @LIBERAR = 1 and @consist_afastamento = 1 and @TemAutorizacaoAcesso = 0 begin
if exists(SELECT id_pass FROM tbFunc WHERE id_pass = @id_pass and (isnull(admissao,@data) > @data or isnull(dtdemissao,'01/01/2079') <= @data)) begin
select @LIBERAR = 0;
end;
end;
if @LIBERAR=1 AND @TemAutorizacaoAcesso=0 and @afastado=0 and (@consist_tbhorpas=1 or @consist_folga=1 or @consist_feriado=1) begin
EXEC AP_PTO005 @data_ant, @id_empresa, @id_pass, @tipodia_ant out, 0, @TipoHE_ant out,
0, @id_phorario_ant out, @id_horario_ant out, '', '', '', 0, @folga_ant out;
select @flexivel_ant = 0;
if @tipo_controle = 'P' begin
SELECT top 1 @flexivel_ant = 1 from tbPGHorarios where id_phorario = @id_phorario_ant and tipo = 'F';
end;
select @trabalhado_ant = 0;
if @folga_ant=0 and (@tipodia_ant='N' or @tipodia_ant='A' or @tipodia_ant='C' or @tipodia_ant='V' or @tipodia_ant='P') and ((isnull(@id_phorario_ant,0) > 0 and @tipo_controle = 'P') or (isnull(@id_horario_ant,0) > 0 and @tipo_controle <> 'P'))
begin
select @trabalhado_ant = 1; select @wdia_ant = DATEPART(dw,@data_ant);
if @tipo_controle='P' begin
if @flexivel_ant = 0 begin
if not exists(SELECT m_entrada1 FROM tbFxPHorarios WHERE id_phorario=@id_phorario_ant AND wdia=@wdia_ant AND m_entrada1 > -1) begin
select @trabalhado_ant = 0;
end;
end else begin
if not exists(SELECT id_pflex FROM tbPHorFlex WHERE id_pflex = @id_phorario_ant AND SUBSTRING(dias_normais,@wdia_ant,1) = '1') begin
select @trabalhado_ant = 0;
end;
end;
end else begin
if (@tipodia_ant='V' or @tipodia_ant='P') and @feriado_pass=1 begin select @wdia_ant=8; end;
if not exists(select id_horario from tbHorarios WHERE id_horario = @id_horario_ant and
(case when @wdia_ant=2 then c2e1 when @wdia_ant=3 then c3e1
when @wdia_ant=4 then c4e1 when @wdia_ant=5 then c5e1
when @wdia_ant=6 then c6e1 when @wdia_ant=7 then c7e1
when @wdia_ant=8 then c8e1 else c1e1 end) <> '__:__') begin
select @trabalhado_ant = 0;
end;
end;
end;
EXEC AP_PTO005 @data, @id_empresa, @id_pass, @tipodia out, 0, @TipoHE out,
0, @id_phorario out, @id_horario out, '', '', '', 0, @folga out;
select @flexivel = 0;
if @tipo_controle = 'P' begin
SELECT top 1 @flexivel = 1 from tbPGHorarios where id_phorario = @id_phorario and tipo = 'F';
end;
select @trabalhado = 0;
if @folga=0 and (@tipodia='N' or @tipodia='A' or @tipodia='C' or @tipodia='V' or @tipodia='P') and ((isnull(@id_phorario,0) > 0 and @tipo_controle = 'P') or (isnull(@id_horario,0) > 0 and @tipo_controle <> 'P'))
begin
select @trabalhado = 1; select @wdia = DATEPART(dw,@data);
if @tipo_controle='P' begin
if @flexivel = 0 begin
if not exists(SELECT m_entrada1 FROM tbFxPHorarios WHERE id_phorario=@id_phorario AND wdia=@wdia AND m_entrada1 > -1) begin
select @trabalhado = 0;
end;
end else begin
if not exists(SELECT id_pflex FROM tbPHorFlex WHERE id_pflex = @id_phorario AND SUBSTRING(dias_normais,@wdia,1) = '1') begin
select @trabalhado = 0;
end;
end;
end else begin
if (@tipodia='V' or @tipodia='P') and @feriado_pass=1 begin select @wdia=8; end;
if not exists(select id_horario from tbHorarios WHERE id_horario = @id_horario and
(case when @wdia=2 then c2e1+c2e2 when @wdia=3 then c3e1+c3e2
when @wdia=4 then c4e1+c4e2 when @wdia=5 then c5e1+c5e2
when @wdia=6 then c6e1+c6e2 when @wdia=7 then c7e1+c7e2
when @wdia=8 then c8e1+c8e2 else c1e1+c1e2 end) <> '__:____:__') begin
select @trabalhado = 0;
end;
end;
end;
if @TemAutorizacaoAcesso=0 and (@TipoHE='N' or @TipoHE='X') begin
select @wdia = DATEPART(dw,@data);
select @wdia_ant = DATEPART(dw,@data_ant);
if @tipo_controle<>'P' begin
if @consist_tbhorpas = 1 begin
select @fxini_1='__:__',@fxfim_1='__:__';
if (@tipodia='V' or @tipodia='P') and @feriado_pass=1 begin select @wdia=8; end;
if @id_horario > 0 and @trabalhado=1 begin
SELECT @fx_secundario=fx_secundario,
@fxini_1=(case when @wdia=2 then c2e1 when @wdia=3 then c3e1 when @wdia=4 then c4e1 when @wdia=5 then c5e1 when @wdia=6 then c6e1 when @wdia=7 then c7e1 when @wdia=8 then c8e1 else c1e1 end),
@fxfim_1=(case when @wdia=2 then c2s1 when @wdia=3 then c3s1 when @wdia=4 then c4s1 when @wdia=5 then c5s1 when @wdia=6 then c6s1 when @wdia=7 then c7s1 when @wdia=8 then c8s1 else c1s1 end),
@fxini_2=(case when @wdia=2 then c2e2 when @wdia=3 then c3e2 when @wdia=4 then c4e2 when @wdia=5 then c5e2 when @wdia=6 then c6e2 when @wdia=7 then c7e2 when @wdia=8 then c8e2 else c1e2 end),
@fxfim_2=(case when @wdia=2 then c2s2 when @wdia=3 then c3s2 when @wdia=4 then c4s2 when @wdia=5 then c5s2 when @wdia=6 then c6s2 when @wdia=7 then c7s2 when @wdia=8 then c8s2 else c1s2 end),
@fxini_3=(case when @wdia=2 then c2e3 when @wdia=3 then c3e3 when @wdia=4 then c4e3 when @wdia=5 then c5e3 when @wdia=6 then c6e3 when @wdia=7 then c7e3 when @wdia=8 then c8e3 else c1e3 end),
@fxfim_3=(case when @wdia=2 then c2s3 when @wdia=3 then c3s3 when @wdia=4 then c4s3 when @wdia=5 then c5s3 when @wdia=6 then c6s3 when @wdia=7 then c7s3 when @wdia=8 then c8s3 else c1s3 end),
@fxini_4=(case when @wdia=2 then c2e4 when @wdia=3 then c3e4 when @wdia=4 then c4e4 when @wdia=5 then c5e4 when @wdia=6 then c6e4 when @wdia=7 then c7e4 when @wdia=8 then c8e4 else c1e4 end),
@fxfim_4=(case when @wdia=2 then c2s4 when @wdia=3 then c3s4 when @wdia=4 then c4s4 when @wdia=5 then c5s4 when @wdia=6 then c6s4 when @wdia=7 then c7s4 when @wdia=8 then c8s4 else c1s4 end),
@fxini_5=(case when @wdia=2 then c2e5 when @wdia=3 then c3e5 when @wdia=4 then c4e5 when @wdia=5 then c5e5 when @wdia=6 then c6e5 when @wdia=7 then c7e5 when @wdia=8 then c8e5 else c1e5 end),
@fxfim_5=(case when @wdia=2 then c2s5 when @wdia=3 then c3s5 when @wdia=4 then c4s5 when @wdia=5 then c5s5 when @wdia=6 then c6s5 when @wdia=7 then c7s5 when @wdia=8 then c8s5 else c1s5 end),
@fxini_6=(case when @wdia=2 then c2e6 when @wdia=3 then c3e6 when @wdia=4 then c4e6 when @wdia=5 then c5e6 when @wdia=6 then c6e6 when @wdia=7 then c7e6 when @wdia=8 then c8e6 else c1e6 end),
@fxfim_6=(case when @wdia=2 then c2s6 when @wdia=3 then c3s6 when @wdia=4 then c4s6 when @wdia=5 then c5s6 when @wdia=6 then c6s6 when @wdia=7 then c7s6 when @wdia=8 then c8s6 else c1s6 end)
FROM tbHorarios WHERE id_horario = @id_horario;
if @fx_secundario=1 begin
if @bloq_secundario=1 begin
select @fxini_1=@fxini_5, @fxfim_1=@fxfim_5, @fxini_2=@fxini_6, @fxfim_2=@fxfim_6, @fxini_3='__:__', @fxfim_3='__:__', @fxini_4='__:__', @fxfim_4='__:__';
end;
select @fxini_5='__:__', @fxfim_5='__:__', @fxini_6='__:__', @fxfim_6='__:__';
end;
if @fxfim_1 = '__:__' begin
select @fxini_1=@fxini_2, @fxini_2 = '__:__', @fxfim_1=@fxfim_2, @fxfim_2 = '__:__';
end;
select @fxfim_1 = (CASE WHEN @fxfim_1 = '__:__' THEN '__:__'
WHEN @fxini_1 > @fxfim_1 or (@fxfim_1 > @fxini_2 and @fxini_2 <> '__:__')
or @fxini_2 > @fxfim_2 or (@fxfim_2 > @fxini_3 and @fxini_3 <> '__:__')
or @fxini_3 > @fxfim_3 or (@fxfim_3 > @fxini_4 and @fxini_4 <> '__:__')
or @fxini_4 > @fxfim_4 or (@fxfim_4 > @fxini_5 and @fxini_5 <> '__:__')
or @fxini_5 > @fxfim_5 or (@fxfim_5 > @fxini_6 and @fxini_6 <> '__:__')
or @fxini_6 > @fxfim_6 THEN '23:59' ELSE @fxfim_1 END);
if @fxfim_1 = '23:59' begin
select @fxini_2='__:__', @fxfim_2='__:__',@fxini_3='__:__', @fxfim_3='__:__',@fxini_4='__:__', @fxfim_4='__:__',@fxini_5='__:__', @fxfim_5='__:__',@fxini_6='__:__', @fxfim_6='__:__';
end;
end;
end;
if @trabalhado_ant=1 and @id_horario_ant > 0 and @afastado_ant=0 begin
if (@tipodia_ant='V' or @tipodia_ant='P') and @feriado_pass=1 begin select @wdia_ant=8; end;
SELECT @fxantes=(case when @wdia_ant=2 then prx2 when @wdia_ant=3 then prx3 when @wdia_ant=4 then prx4 when @wdia_ant=5 then prx5 when @wdia_ant=6 then prx6 when @wdia_ant=7 then prx7 when @wdia_ant=8 then prx8 else prx1 end)
FROM tbHorarios WHERE id_horario = @id_horario_ant;
if @fxantes <> '__:__' begin
select @fxini_6=@fxini_5, @fxfim_6=@fxfim_5;
select @fxini_5=@fxini_4, @fxfim_5=@fxfim_4;
select @fxini_4=@fxini_3, @fxfim_4=@fxfim_3;
select @fxini_3=@fxini_2, @fxfim_3=@fxfim_2;
select @fxini_2=@fxini_1, @fxfim_2=@fxfim_1;
select @fxini_1='00:00', @fxfim_1=@fxantes;
end;
end;
end;
end;
if (@tipodia='V' or @tipodia='P') and @TemAutorizacaoAcesso=0 and (@TipoHE='N' or @TipoHE='X') and @consist_feriado=1 and (@feriado_pass=0 or @tipo_controle='P') begin
if (@tipo_controle<>'P' or
(
not exists(SELECT feriado_normal FROM tbPHorarios WHERE id_phorario=@id_phorario AND feriado_normal=1)
and not exists(SELECT feriado_normal FROM tbFunc WHERE id_pass=@id_pass AND feriado_normal=1 AND categoria=1)
)
) begin
select @tipodia_fim = 'V';
select @fxini_6='__:__', @fxfim_6='__:__', @fxini_5='__:__', @fxfim_5='__:__',
@fxini_4='__:__', @fxfim_4='__:__', @fxini_3='__:__', @fxfim_3='__:__',
@fxini_2='__:__', @fxfim_2='__:__';
if @fxantes = '__:__' begin
select @fxini_1='__:__', @fxfim_1='__:__';
end;
end;
end;
if (@tipodia='V' or @tipodia='P') and @TemAutorizacaoAcesso=0 and (@TipoHE='N' or @TipoHE='X') and @consist_folga=1 and ((@tipodia = 'F' or @tipodia = 'P') or @folga=1) begin
select @tipodia_fim = 'F';
select @fxini_6='__:__', @fxfim_6='__:__', @fxini_5='__:__', @fxfim_5='__:__',
@fxini_4='__:__', @fxfim_4='__:__', @fxini_3='__:__', @fxfim_3='__:__',
@fxini_2='__:__', @fxfim_2='__:__';
if @fxantes = '__:__' begin
select @fxini_1='__:__', @fxfim_1='__:__';
end;
end;
end;
if @LIBERAR = 1 begin
if isnull(@provisorio,0) > 0 and not @prov_ini is null  begin
if convert(datetime,convert(varchar,@prov_ini,101)) <= @data and
convert(datetime,convert(varchar,isnull(@prov_fim,@data),101)) >= @data
begin
select @cracha=@provisorio, @via=isnull(@via_provisorio,0);
end;
end;
if @afastado=1 begin
select @tipodia_fim='Z';
end;
INSERT INTO dbo.tbLstBatch (id_bloq,cracha,via,senha,data,tipodia,
fxini_1,fxfim_1,fxini_2,fxfim_2,fxini_3,fxfim_3,
fxini_4,fxfim_4,fxini_5,fxfim_5,fxini_6,fxfim_6) VALUES (
@id_bloq,@cracha,@via,@senhacad,@data,@tipodia_fim,
@fxini_1,@fxfim_1,@fxini_2,@fxfim_2,@fxini_3,@fxfim_3,
@fxini_4,@fxfim_4,@fxini_5,@fxfim_5,@fxini_6,@fxfim_6
);
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO059') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO059; END;
GO
CREATE PROCEDURE dbo.AP_PTO059(@id_pass int,  @dtini datetime, @dtfim datetime, @reapontar bit) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @data datetime
declare @ult_apt datetime;
declare @demissao datetime;
declare @achou bit;
declare @hab32 bit;
select @hab32=0;
if (@dtini<@dtfim or @reapontar=1 or @dtfim=convert(datetime,convert(varchar,getdate(),101))) begin
select @hab32=1;
end;
select @data=@dtini;
while @data<=@dtfim begin
if @reapontar=0 and @data < dateadd(d,1,Getdate()) begin
select @ult_apt=null;
SELECT @ult_apt=ult_apt, @demissao=dtdemissao FROM tbFunc WHERE id_pass=@id_pass;
if not @ult_apt is null begin
if @ult_apt < dateadd(d,-1,@data) and @ult_apt < isnull(@demissao,@data) begin
select @reapontar=1;
end;
end;
if @reapontar=0 begin
select @achou=0;
SELECT TOP 1 @achou=isnull(apontado,0)
FROM tbPtoDia WHERE id_pass=@id_pass AND data=@data;
if @achou=0 begin select @reapontar=1; end;
end;
end;
if @reapontar=1 begin
if @data=@dtfim and @hab32=1 begin
EXEC AP_PTO032 @id_pass, @data, 0;
end else begin
EXEC AP_PTO031 @id_pass output, @data output;
end;
end;
select @data=dateadd(d,1,@data);
end; --while
end;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO042') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO042; END;
GO
CREATE PROCEDURE dbo.AP_PTO042(@id_empresa int, @id_pass int, @data datetime, @clresumo bit=0, @reapontar bit=0) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @marcacoesOriginais bit;
declare @wdiaAtual tinyint; declare @dataDomAntes datetime; declare @dataDomDepois datetime; declare @tipo_chk tinyint; declare @obs_chk varchar(30); declare @str_obs varchar(30);
declare @trabalhado bit;    declare @id_phorario int;  declare @desc_horario varchar(100);
declare @id_pescala int;  declare @desc_escala varchar(100);
declare @desc_tolera varchar(40); declare @desc_tabhe varchar(100);
declare @desc_tabdsr varchar(100); declare @desc_tabadicnot varchar(100); declare @desc_tabhnorm varchar(100); declare @desc_tabarred varchar(100);
declare @desc_tabbco varchar(100);
declare @flexivel bit;      declare @tipodia char(1);  declare @tipohe char(1);       declare @folga bit;
declare @id_eveafa int;     declare @desc_afast varchar(100); declare @id_eveabo int; declare @id_eveabo_lcd int; declare @desc_eveabo varchar(100);
declare @desc_feriado varchar(100); declare @admissao bit; declare @demissao bit; declare @observacao varchar(100);
declare @hprev varchar(7); declare @hreais varchar(7); declare @hnorm varchar(7);
declare @hreais_tot varchar(7); declare @hnorm_tot varchar(7);
declare @prev_ent01 varchar(6); declare @prev_sai01 varchar(6); declare @prev_ent02 varchar(6); declare @prev_sai02 varchar(6);
declare @prev_ent03 varchar(6); declare @prev_sai03 varchar(6); declare @prev_ent04 varchar(6); declare @prev_sai04 varchar(6);
declare @prev_flex_ini varchar(6); declare @prev_flex_fim varchar(6);
declare @prev_flex_tempo varchar(6);
declare @ent01 varchar(5); declare @sai01 varchar(5); declare @ent02 varchar(5); declare @sai02 varchar(5);
declare @ent03 varchar(5); declare @sai03 varchar(5); declare @ent04 varchar(5); declare @sai04 varchar(5);
declare @ent05 varchar(5); declare @sai05 varchar(5); declare @ent06 varchar(5); declare @sai06 varchar(5);
declare @ent07 varchar(5); declare @sai07 varchar(5); declare @ent08 varchar(5); declare @sai08 varchar(5);
declare @diaUltAntes int; declare @diaPriDepois int; declare @contaMc tinyint;
declare @ult_he_ent tinyint; declare @pri_he_sai tinyint;
declare @norm_ini int; declare @norm_fim int;
declare @psi_norm_ini int; declare @psi_norm_fim int;
declare @fimper1 tinyint; declare @fimper2 tinyint; declare @fimper3 tinyint;
declare @fimper4 tinyint; declare @iniflex tinyint; declare @fimflex tinyint;
declare @id_he int, @id_tolera int, @id_dsr int, @id_adicional int, @id_hnormais int, @id_arredonda int, @id_tabbco int;
declare @m_ent01 int; declare @m_sai01 int; declare @m_ent02 int; declare @m_sai02 int;
declare @m_ent03 int; declare @m_sai03 int; declare @m_ent04 int; declare @m_sai04 int;
declare @m_ent05 int; declare @m_sai05 int; declare @m_ent06 int; declare @m_sai06 int;
declare @m_ent07 int; declare @m_sai07 int; declare @m_ent08 int; declare @m_sai08 int;
declare @tem_divs bit;
declare @i int; declare @achou bit; declare @conta int;
declare @clresumoTipo1 int, @clresumoTipo2 int, @clresumoTipo3 int, @clresumoTipo4 int, @clresumoTipo5 int, @vlr int, @vlr2 int;
declare @clresumoBanco bit;
select @marcacoesOriginais=0;
select @wdiaAtual=0, @tipo_chk=0, @obs_chk='', @str_obs='';
select @trabalhado=0, @id_phorario=0, @desc_horario='', @id_pescala=0, @desc_escala='', @desc_tolera='',@desc_tabhe='', @desc_tabdsr='', @desc_tabadicnot='';
select @desc_tabhnorm='',@desc_tabarred='',@desc_tabbco='',@flexivel=0,@tipodia='',@tipohe='',@folga=0,@id_eveafa=0;
select @desc_afast='',@id_eveabo=0,@desc_eveabo='',@desc_feriado='',@admissao=0,@demissao=0,@observacao='';
select @hprev='  00:00',@hreais='  00:00',@hnorm='  00:00',@hreais_tot='  00:00',@hnorm_tot='  00:00';
select @prev_ent01='',@prev_sai01='',@prev_ent02='',@prev_sai02='',@prev_ent03='',@prev_sai03='',@prev_ent04='';
select @prev_sai04='',@prev_flex_ini='',@prev_flex_fim='',@prev_flex_tempo='';
select @ent01='',@sai01='',@ent02='',@sai02='',@ent03='',@sai03='',@ent04='',@sai04='';
select @ent05='',@sai05='',@ent06='',@sai06='',@ent07='',@sai07='',@ent08='',@sai08='';
select @diaUltAntes=0,@diaPriDepois=0,@contaMc=0,@ult_he_ent=0,@pri_he_sai=0;
select @norm_ini=0,@norm_fim=4320,@psi_norm_ini=0,@psi_norm_fim=16;
select @fimper1=0,@fimper2=0,@fimper3=0,@fimper4=0,@iniflex=0,@fimflex=0;
select @id_he=0, @id_tolera=0, @id_dsr=0, @id_adicional=0,@id_hnormais=0,@id_arredonda=0,@id_tabbco=0;
select @tem_divs=0;
select @clresumoTipo1=null, @clresumoTipo2=null, @clresumoTipo3=null, @clresumoTipo4=null, @clresumoTipo5=null;
select @wdiaAtual=DATEPART(dw,@data);
select @i=(DATEPART(dw,@data)-1)*(-1);
select @dataDomAntes = dateadd(d,@i,@data);
select @dataDomDepois = dateadd(d,7,@dataDomAntes);
EXEC AP_PTO059 @id_pass, @data, @data, @reapontar;
SELECT @id_pescala=isnull(e.id_pescala,0), @desc_escala=e.descricao FROM tbPass p
INNER JOIN tbPEscalas e on e.id_pescala = p.id_phorario
WHERE p.id_pass=@id_pass;
select @achou=0;
SELECT TOP 1 @achou=1, @trabalhado=trabalhado, @id_phorario=isnull(id_phorario,0), @id_tolera=isnull(id_tolera,0), @id_he=id_he,@id_dsr=id_dsr,
@id_adicional=id_adicional,@id_hnormais=id_hnormais,@id_arredonda=id_arredonda, @id_tabbco=id_tabbco,
@tipodia=tipodia,@tipohe=tipohe,@folga=folga,@id_eveafa=isnull(id_eveafa,0),@id_eveabo=isnull(id_eveabo,0),
@desc_feriado=isnull(desc_feriado,''),@admissao=admissao,@demissao=demissao,
@prev_ent01=entrada1,@prev_sai01=saida1,@prev_ent02=entrada2,@prev_sai02=saida2,@prev_ent03=entrada3,@prev_sai03=saida3,
@prev_ent04=entrada4,@prev_sai04=saida4,@prev_flex_ini=flex_ini,@prev_flex_fim=flex_fim,@prev_flex_tempo=flex_tempo,
@observacao=isnull(obs,''),@hprev=hrs_prev,@norm_ini=norm_ini,@norm_fim=norm_fim
FROM tbPtoDia WHERE id_pass=@id_pass AND data=@data;
if @achou=1 begin
SELECT @tipo_chk=isnull(tipo_chk,0), @obs_chk=isnull(obs_chk,'') FROM tbPtoChkDia WHERE id_pass=@id_pass and data=@data;
SELECT @flexivel=(CASE WHEN tipo='F' THEN 1 ELSE 0 END), @desc_horario=isnull(descricao,'')
FROM tbPGHorarios WHERE id_phorario=@id_phorario;
select @achou=0, @i=0;
SELECT @achou=1, @i=codigo FROM tbPGHorarios WHERE id_phorario=@id_phorario;
if @achou=1 and isnull(@i,0) > 0 begin
if @i < 1000 begin
if @flexivel=1 begin
select @desc_horario=right('000'+ltrim(str(@i)),3)+'F - '+@desc_horario;
end else begin
select @desc_horario=right('000'+ltrim(str(@i)),3)+' - '+@desc_horario;
end;
end else begin
if @flexivel=1 begin
select @desc_horario=right('0000'+ltrim(str(@i)),4)+'F - '+@desc_horario;
end else begin
select @desc_horario=right('0000'+ltrim(str(@i)),4)+' - '+@desc_horario;
end;
end;
end;
if isnull(@id_tolera,0) > 0
SELECT @desc_tolera=descricao FROM tbTolera WHERE id_tolera=@id_tolera;
if isnull(@id_he,0) > 0
SELECT @desc_tabhe=descricao FROM tbHE WHERE id_he=@id_he;
if isnull(@id_dsr,0) > 0
SELECT @desc_tabdsr=descricao FROM tbDSR WHERE id_dsr=@id_dsr;
if isnull(@id_adicional,0) > 0
SELECT @desc_tabadicnot=descricao FROM tbAdicNot WHERE id_adicional=@id_adicional;
if isnull(@id_hnormais,0) > 0
SELECT @desc_tabhnorm=descricao FROM tbHNormais WHERE id_hnormais=@id_hnormais;
if isnull(@id_arredonda,0) > 0
SELECT @desc_tabarred=descricao FROM tbArredonda WHERE id_arredonda=@id_arredonda;
if isnull(@id_eveabo,0) > 0
SELECT @desc_eveabo=descricao FROM tbEvsAbono WHERE id_eveabo=@id_eveabo;
if isnull(@id_tabbco,0) > 0
SELECT @desc_tabbco=descricao FROM tbTabBco WHERE id_tabbco=@id_tabbco;
select @id_eveabo_lcd=0;
SELECT TOP 1 @observacao=isnull(e.descricao,@observacao), @id_eveabo_lcd=e.id_eveabo FROM tbPtoAboDia a
INNER JOIN tbPtoDivsDia evs ON a.id_pass = evs.id_pass AND a.data = evs.data AND a.id_diverg = evs.id_diverg AND evs.id_associ = 0
INNER JOIN tbEvsAbono e ON a.id_eveabo=e.id_eveabo AND e.espelho=1
WHERE a.id_pass=@id_pass AND a.data=@data ORDER BY e.descricao
select @str_obs = '';
SELECT TOP 1 @str_obs = isnull(obs,@str_obs) FROM tbPtoAboDia WHERE id_pass=@id_pass AND data=@data AND len(obs)>0;
if (LEN(@str_obs)=0) begin
SELECT TOP 1 @str_obs = isnull(obs,@str_obs) FROM tbAfast WHERE id_pass=@id_pass
AND @data BETWEEN convert(datetime,convert(varchar,isnull(dataini,'00:00:00'),101))
AND convert(datetime,convert(varchar,isnull(datafim,'00:00:00'),101));
end;
if (LEN(@str_obs)=0) begin
SELECT TOP 1 @str_obs = isnull(obs,@str_obs) FROM tbCalendario WHERE id_pass=@id_pass AND data=@data AND id_eveabo>0;
end;
if (LEN(@str_obs)=0) begin
SELECT TOP 1 @str_obs = isnull(obs,@str_obs) FROM tbCalendario WHERE (id_empresa = @id_empresa OR id_empresa = 0) AND id_pass=0 AND data=@data AND id_eveabo>0;
end;
if isnull(@id_eveabo_lcd,0)>0 and @id_eveabo=0 begin
select @id_eveabo=@id_eveabo_lcd;
end;
SELECT TOP 1 @hnorm=hrs_norm,@hnorm_tot=hn_tot,@hreais_tot=trab_tot
FROM tbPtoApDia
WHERE id_pass=@id_pass AND data=@data
if @norm_ini=-1 begin select @psi_norm_ini=-1,@psi_norm_fim=-1; end;
if @id_eveafa>0 begin
SELECT @desc_afast=descricao FROM tbEvsAbono WHERE id_eveabo=@id_eveafa;
if ltrim(isnull(@desc_afast,''))<>''
select @observacao=@desc_afast
end;
if exists(SELECT TOP 1 id_pass FROM tbPtoDivsDia WHERE id_pass=@id_pass AND data=@data) begin select @tem_divs=1; end;
select @achou=0;
SELECT TOP 1 @achou=1,@marcacoesOriginais=original,@contaMc=contamc,@ult_he_ent=isnull(ult_he_ent,0),@pri_he_sai=isnull(pri_he_sai,0),
@ent01=isnull(ent01,''),@sai01=isnull(sai01,''),@ent02=isnull(ent02,''),@sai02=isnull(sai02,''),
@ent03=isnull(ent03,''),@sai03=isnull(sai03,''),@ent04=isnull(ent04,''),@sai04=isnull(sai04,''),
@ent05=isnull(ent05,''),@sai05=isnull(sai05,''),@ent06=isnull(ent06,''),@sai06=isnull(sai06,''),
@ent07=isnull(ent07,''),@sai07=isnull(sai07,''),@ent08=isnull(ent08,''),@sai08=isnull(sai08,''),
@hreais=hrs_trab,@m_ent01=m_ent01,@m_sai01=m_sai01,@m_ent02=m_ent02,@m_sai02=m_sai02,@m_ent03=m_ent03,@m_sai03=m_sai03,
@m_ent04=m_ent04,@m_sai04=m_sai04,@m_ent05=m_ent05,@m_sai05=m_sai05,@m_ent06=m_ent06,@m_sai06=m_sai06,
@m_ent07=m_ent07,@m_sai07=m_sai07,@m_ent08=m_ent08,@m_sai08=m_sai08,
@fimper1=fimper1,@fimper2=fimper2,@fimper3=fimper3,@fimper4=fimper4,@iniflex=iniflex,@fimflex=fimflex
FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data ORDER BY original
if @achou=1 begin
select @conta=0, @diaUltAntes=0;
if @norm_ini>-1 begin
select @achou=0;
select @conta=@conta+1; if @m_ent01>-1 and @m_ent01<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent01>-1 and @m_ent01>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai01>-1 and @m_sai01<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai01>-1 and @m_sai01>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
select @conta=@conta+1; if @m_ent02>-1 and @m_ent02<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent02>-1 and @m_ent02>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai02>-1 and @m_sai02<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai02>-1 and @m_sai02>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
select @conta=@conta+1; if @m_ent03>-1 and @m_ent03<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent03>-1 and @m_ent03>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai03>-1 and @m_sai03<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai03>-1 and @m_sai03>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
select @conta=@conta+1; if @m_ent04>-1 and @m_ent04<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent04>-1 and @m_ent04>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai04>-1 and @m_sai04<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai04>-1 and @m_sai04>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
select @conta=@conta+1; if @m_ent05>-1 and @m_ent05<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent05>-1 and @m_ent05>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai05>-1 and @m_sai05<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai05>-1 and @m_sai05>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
select @conta=@conta+1; if @m_ent06>-1 and @m_ent06<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent06>-1 and @m_ent06>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai06>-1 and @m_sai06<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai06>-1 and @m_sai06>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
select @conta=@conta+1; if @m_ent07>-1 and @m_ent07<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent07>-1 and @m_ent07>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai07>-1 and @m_sai07<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai07>-1 and @m_sai07>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
select @conta=@conta+1; if @m_ent08>-1 and @m_ent08<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_ent08>-1 and @m_ent08>@norm_fim begin select @psi_norm_fim=@conta-2, @achou=1; end;
select @conta=@conta+1; if @m_sai08>-1 and @m_sai08<@norm_ini begin select @psi_norm_ini=@conta; end;
if @achou=0 and @m_sai08>-1 and @m_sai08>@norm_fim begin select @psi_norm_fim=@conta-2,@achou=1; end;
end;
select @conta=0, @diaUltAntes=0;
select @conta=@conta+1; if @m_ent01>-1 and @m_ent01<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai01>-1 and @m_sai01<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_ent02>-1 and @m_ent02<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai02>-1 and @m_sai02<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_ent03>-1 and @m_ent03<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai03>-1 and @m_sai03<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_ent04>-1 and @m_ent04<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai04>-1 and @m_sai04<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_ent05>-1 and @m_ent05<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai05>-1 and @m_sai05<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_ent06>-1 and @m_ent06<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai06>-1 and @m_sai06<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_ent07>-1 and @m_ent07<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai07>-1 and @m_sai07<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_ent08>-1 and @m_ent08<1440 begin select @diaUltAntes=@conta; end;
select @conta=@conta+1; if @m_sai08>-1 and @m_sai08<1440 begin select @diaUltAntes=@conta; end;
select @conta=0, @diaPriDepois=0;
select @conta=16; if @m_sai08>-1 and @m_sai08>=2880 begin select @diaPriDepois=@conta; end;
select @conta=15; if @m_ent08>-1 and @m_ent08>=2880 begin select @diaPriDepois=@conta; end;
select @conta=14; if @m_sai07>-1 and @m_sai07>=2880 begin select @diaPriDepois=@conta; end;
select @conta=13; if @m_ent07>-1 and @m_ent07>=2880 begin select @diaPriDepois=@conta; end;
select @conta=12; if @m_sai06>-1 and @m_sai06>=2880 begin select @diaPriDepois=@conta; end;
select @conta=11; if @m_ent06>-1 and @m_ent06>=2880 begin select @diaPriDepois=@conta; end;
select @conta=10; if @m_sai05>-1 and @m_sai05>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 9; if @m_ent05>-1 and @m_ent05>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 8; if @m_sai04>-1 and @m_sai04>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 7; if @m_ent04>-1 and @m_ent04>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 6; if @m_sai03>-1 and @m_sai03>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 5; if @m_ent03>-1 and @m_ent03>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 4; if @m_sai02>-1 and @m_sai02>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 3; if @m_ent02>-1 and @m_ent02>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 2; if @m_sai01>-1 and @m_sai01>=2880 begin select @diaPriDepois=@conta; end;
select @conta= 1; if @m_ent01>-1 and @m_ent01>=2880 begin select @diaPriDepois=@conta; end;
end;
end;
if @clresumo=1 begin
--Divergncias
select @i=0;
while (@i<5) begin
select @i=@i+1;
select @vlr=0, @vlr2=0;
if exists(SELECT TOP 1 id_clresumo FROM tbClResumoDiv WHERE id_empresa = @id_empresa AND id_clresumo=@i)
begin
SELECT @vlr=SUM(CASE WHEN d.soma=1 THEN (a.m_valor-a.m_abonado) ELSE (a.m_valor-a.m_abonado) * (-1) END)
FROM tbPtoDivsDia a
INNER JOIN tbClResumoDiv r ON r.id_empresa = @id_empresa AND r.id_clresumo=@i AND r.id_diverg = a.id_diverg
INNER JOIN tbDivergencias d ON a.id_diverg = d.id_diverg AND d.ativada = 1
WHERE a.id_pass = @id_pass AND a.data = @data AND a.id_associ = 0;
end;
if exists(SELECT TOP 1 id_clresumo FROM tbClResumoAbo WHERE id_empresa = @id_empresa AND id_clresumo=@i)
begin
SELECT @vlr2=SUM(isnull(a.m_valor,0))
FROM vwPtoAboDia a
INNER JOIN tbClResumoAbo r ON r.id_empresa = @id_empresa AND r.id_clresumo=@i AND r.id_eveabo = a.id_eveabo
WHERE a.id_pass = @id_pass AND a.data = @data;
select @vlr=isnull(@vlr,0)+isnull(@vlr2,0);
end;
select @clresumoBanco=0
SELECT top 1 @clresumoBanco=isnull(banco,0) FROM tbClResumo WHERE id_empresa=@id_empresa AND id_clresumo=@i;
if @clresumoBanco=1 begin
SELECT @vlr=isnull(@vlr,0)+isnull(SUM(m_horas),0) FROM tbPtoBco WHERE id_pass=@id_pass AND data=@data;
end;
if (isnull(@vlr,0)<>0) begin
if @i=1
select @clresumoTipo1=isnull(@clresumoTipo1,0)+@vlr;
else if @i=2
select @clresumoTipo2=isnull(@clresumoTipo2,0)+@vlr;
else if @i=3
select @clresumoTipo3=isnull(@clresumoTipo3,0)+@vlr;
else if @i=4
select @clresumoTipo4=isnull(@clresumoTipo4,0)+@vlr;
else
select @clresumoTipo5=isnull(@clresumoTipo5,0)+@vlr;
end;
end;
--Horas reais
select @i=0, @vlr=0
SELECT TOP 1 @i=r.id_clresumo, @vlr=a.m_hrs_trab FROM tbPtoEnq a
INNER JOIN tbClResumoDiv r ON r.id_empresa = @id_empresa AND r.id_diverg=8000
WHERE a.id_pass = @id_pass AND a.data = @data ORDER BY a.original;
if (isnull(@vlr,0)<>0) begin
if @i=1
select @clresumoTipo1=isnull(@clresumoTipo1,0)+@vlr;
else if @i=2
select @clresumoTipo2=isnull(@clresumoTipo2,0)+@vlr;
else if @i=3
select @clresumoTipo3=isnull(@clresumoTipo3,0)+@vlr;
else if @i=4
select @clresumoTipo4=isnull(@clresumoTipo4,0)+@vlr;
else
select @clresumoTipo5=isnull(@clresumoTipo5,0)+@vlr;
end;
--Horas previstas
select @i=0, @vlr=0
SELECT TOP 1 @i=r.id_clresumo, @vlr=a.m_hrs_prev FROM tbPtoDia a
INNER JOIN tbClResumoDiv r ON r.id_empresa = @id_empresa AND r.id_diverg=8001
WHERE a.id_pass = @id_pass AND a.data = @data;
if (isnull(@vlr,0)<>0) begin
if @i=1
select @clresumoTipo1=isnull(@clresumoTipo1,0)+@vlr;
else if @i=2
select @clresumoTipo2=isnull(@clresumoTipo2,0)+@vlr;
else if @i=3
select @clresumoTipo3=isnull(@clresumoTipo3,0)+@vlr;
else if @i=4
select @clresumoTipo4=isnull(@clresumoTipo4,0)+@vlr;
else
select @clresumoTipo5=isnull(@clresumoTipo5,0)+@vlr;
end;
--Horas normais
select @i=0, @vlr=0
SELECT TOP 1 @i=r.id_clresumo, @vlr=a.m_hrs_norm FROM tbPtoApDia a
INNER JOIN tbClResumoDiv r ON r.id_empresa = @id_empresa AND r.id_diverg=8002
WHERE a.id_pass = @id_pass AND a.data = @data;
if (isnull(@vlr,0)<>0) begin
if @i=1
select @clresumoTipo1=isnull(@clresumoTipo1,0)+@vlr;
else if @i=2
select @clresumoTipo2=isnull(@clresumoTipo2,0)+@vlr;
else if @i=3
select @clresumoTipo3=isnull(@clresumoTipo3,0)+@vlr;
else if @i=4
select @clresumoTipo4=isnull(@clresumoTipo4,0)+@vlr;
else
select @clresumoTipo5=isnull(@clresumoTipo5,0)+@vlr;
end;
end;
SELECT @marcacoesOriginais as marcacoesOriginais, @tipo_chk as tipo_chk, @obs_chk as obs_chk, @str_obs as str_obs,
@trabalhado as trabalhado, @id_phorario as id_phorario, @desc_horario as desc_horario, @id_pescala as id_pescala, @desc_escala as desc_escala, @desc_tolera as desc_tolera,
@desc_tabhe as desc_tabhe, @desc_tabdsr as desc_tabdsr, @desc_tabadicnot as desc_tabadicnot,
@desc_tabhnorm as desc_tabhnorm, @desc_tabarred as desc_tabarred, @desc_tabbco as desc_tabbco, @flexivel as flexivel,
@tipodia as tipodia, @tipohe as tipohe, @folga as folga, @id_eveafa as id_eveafa,
@desc_afast as desc_afast, @id_eveabo as id_eveabo, @desc_eveabo as desc_eveabo,
@desc_feriado as desc_feriado, @admissao as admissao, @demissao as demissao, @observacao as observacao,
@hprev as hprev, @hreais as hreais, @hnorm as hnorm, @hreais_tot  as hreais_tot, @hnorm_tot as hnorm_tot,
@prev_ent01 as prev_ent01, @prev_sai01 as prev_sai01, @prev_ent02 as prev_ent02, @prev_sai02 as prev_sai02,
@prev_ent03 as prev_ent03, @prev_sai03 as prev_sai03, @prev_ent04 as prev_ent04, @prev_sai04 as prev_sai04,
@prev_flex_ini as prev_flex_ini, @prev_flex_fim as prev_flex_fim, @prev_flex_tempo as prev_flex_tempo,
@ent01 as ent01, @sai01 as sai01, @ent02 as ent02, @sai02 as sai02, @ent03 as ent03, @sai03 as sai03,
@ent04 as ent04, @sai04 as sai04, @ent05 as ent05, @sai05 as sai05, @ent06 as ent06, @sai06 as sai06,
@ent07 as ent07, @sai07 as sai07, @ent08 as ent08, @sai08 as sai08, @diaUltAntes as diaUltAntes,
@diaPriDepois as diaPriDepois, @contaMc as contaMc, @ult_he_ent as ult_he_ent, @pri_he_sai as pri_he_sai,
@norm_ini as norm_ini, @norm_fim as norm_fim, @psi_norm_ini as psi_norm_ini, @psi_norm_fim as psi_norm_fim,
@fimper1 as fimper1, @fimper2 as fimper2, @fimper3 as fimper3, @fimper4 as fimper4, @iniflex as iniflex,
@fimflex as fimflex, @tem_divs as tem_divs, @clresumoTipo1 as clresumo1, @clresumoTipo2 as clresumo2,
@clresumoTipo3 as clresumo3, @clresumoTipo4 as clresumo4, @clresumoTipo5 as clresumo5;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO043') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO043; END;
GO
CREATE PROCEDURE dbo.AP_PTO043(@id_pass int, @data datetime, @m_marc int, @acao tinyint, @original bit) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @marc datetime;
declare @ordem int; declare @id_jstjrn int;
if isnull(@m_marc,-1)>-1 begin
select @id_jstjrn=0, @ordem=0, @marc=dateadd(n,@m_marc-1440,@data);
SELECT TOP 1 @id_jstjrn=id_jstjrn,@ordem=ordem FROM tbAltJorn WHERE id_pass=@id_pass AND marc=@marc AND acao=@acao AND afd=0;
if @acao=2 and @id_jstjrn=0 begin
SELECT TOP 1 @id_jstjrn=id_jstjrn,@ordem=ordem FROM tbAltJorn WHERE id_pass=@id_pass AND marc=@marc AND acao=1 AND afd=0;
end;
if @id_jstjrn>0 begin
UPDATE tbAltJorn SET afd=1, data=@data WHERE id_pass=@id_pass AND marc=@marc AND ordem=@ordem;
end else begin
if @acao=0 begin select @id_jstjrn=2; end;
if @acao=1 begin select @id_jstjrn=6; end;
if @acao=2 begin select @id_jstjrn=5; end;
if @original=0 or @acao=0 begin SELECT TOP 1 @id_jstjrn=isnull(id_jstjrn,@id_jstjrn) FROM tbJustJorn WHERE ocor=@acao AND padrao=1; end;
if @id_jstjrn>0 begin
select @ordem=0;
SELECT TOP 1 @id_jstjrn=id_jstjrn,@ordem=ordem FROM tbAltJorn WHERE id_pass=@id_pass AND marc=@marc AND acao=@acao AND afd=0;
SELECT TOP 1 @ordem=ordem FROM tbAltJorn WHERE id_pass=@id_pass AND marc=@marc ORDER BY ordem DESC;
select @ordem=@ordem+1;
INSERT INTO tbAltJorn (id_pass,  marc, ordem, data, acao, id_jstjrn, data_alt, id_usuario, afd)
VALUES (@id_pass,@marc,@ordem,@data,@acao,@id_jstjrn,getdate(),0,1);
end;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO044') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO044; END;
GO
CREATE PROCEDURE dbo.AP_PTO044(@id_pass int, @data datetime, @exibir_mcs bit=0, @reprocessar bit=0) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @ultima_ant datetime; declare @ultima_atu datetime;
declare @data_ant datetime;  declare @data_prx datetime;
declare @data_mxant datetime; declare @data_miatu datetime;
declare @rep CHAR(17); declare @r305 CHAR(12); declare @marc DATETIME; declare @r301 CHAR(9);
declare @ordem_dia int; declare @m_marc int; declare @ordem int;
declare @e1 int; declare @s1 int; declare @e2 int; declare @s2 int;
declare @e3 int; declare @s3 int; declare @e4 int; declare @s4 int;
declare @e5 int; declare @s5 int; declare @e6 int; declare @s6 int;
declare @e7 int; declare @s7 int; declare @e8 int; declare @s8 int;
declare @eo1 int; declare @so1 int; declare @eo2 int; declare @so2 int;
declare @eo3 int; declare @so3 int; declare @eo4 int; declare @so4 int;
declare @eo5 int; declare @so5 int; declare @eo6 int; declare @so6 int;
declare @eo7 int; declare @so7 int; declare @eo8 int; declare @so8 int;
declare @batidas_multiplas int; declare @de int; declare @ate int;
declare @achou bit; declare @achou_mc bit; declare @id_jstjrn int; declare @original bit;
if isnull(@id_pass,0)>0 and not @data is null and
(@reprocessar=1 or
not exists(SELECT afd_dia FROM tbPtoDia WHERE id_pass=@id_pass AND data=@data AND isnull(afd_dia,0)=1))
begin
select @data_ant = dateadd(d,-1,@data);
select @data_prx = dateadd(d,1,@data);
select @data_mxant=convert(datetime,convert(varchar,@data_ant,101)+ ' 22:59:59.950');
select @data_miatu=convert(datetime,convert(varchar,@data,101)+ ' 22:59:59.950');
select @ultima_ant=convert(datetime,convert(varchar,@data_ant,101)+ ' 23:59:59.950');
SELECT TOP 1 @ultima_ant=isnull(ultima,@ultima_ant) FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data_ant AND original=1;
select @ultima_atu=convert(datetime,convert(varchar,@data,101)+ ' 23:59:59.950');
SELECT TOP 1 @ultima_atu=isnull(ultima,@ultima_atu) FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data AND original=1;
if @ultima_ant<@data_mxant begin select @ultima_ant=@data_mxant; end;
if @ultima_atu<@data_miatu begin select @ultima_atu=@data_miatu; end;
if @ultima_ant>@ultima_atu begin
if @ultima_ant < @data_prx begin
select @ultima_atu=convert(datetime,convert(varchar,@data,101)+ ' 23:59:59.950');
end else begin
select @ultima_ant=@data;
select @ultima_atu=convert(datetime,convert(varchar,@data,101)+ ' 23:59:59.950');
end;
end;
UPDATE tbAFDR3 SET dtref=@data,ordem=0 WHERE id_pass=@id_pass AND marc>@ultima_ant AND marc<=@ultima_atu;
DELETE FROM tbAltJorn WHERE id_pass=@id_pass AND data=@data AND id_usuario=0;
UPDATE tbAltJorn SET afd=0 WHERE id_pass=@id_pass AND data=@data;
select @original=1,@eo1=-1,@so1=-1,@eo2=-1,@so2=-1,@eo3=-1,@so3=-1,@eo4=-1,@so4=-1,@eo5=-1,@so5=-1,@eo6=-1,@so6=-1,@eo7=-1,@so7=-1,@eo8=-1,@so8=-1;
SELECT TOP 1 @eo1=m_ent01,@so1=m_sai01,@eo2=m_ent02,@so2=m_sai02,@eo3=m_ent03,@so3=m_sai03,@eo4=m_ent04,@so4=m_sai04,
@eo5=m_ent05,@so5=m_sai05,@eo6=m_ent06,@so6=m_sai06,@eo7=m_ent07,@so7=m_sai07,@eo8=m_ent08,@so8=m_sai08, @original=original
FROM tbPtoEnq WHERE id_pass=@id_pass AND data=@data ORDER BY original;
select @e1=@eo1,@s1=@so1,@e2=@eo2,@s2=@so2,@e3=@eo3,@s3=@so3,@e4=@eo4,@s4=@so4,@e5=@eo5,@s5=@so5,@e6=@eo6,@s6=@so6,@e7=@eo7,@s7=@so7,@e8=@eo8,@s8=@so8;
select @achou=1, @ordem_dia=0;
while (@achou=1) begin
select @achou=0;
SELECT TOP 1 @achou=1,@rep=rep, @r305=r305, @marc=marc, @r301=r301 FROM tbAFDR3
WHERE id_pass=@id_pass AND marc>@ultima_ant AND marc<=@ultima_atu AND ordem=0
ORDER BY marc;
if @achou=1 begin
exec AP_PTO001 @marc, @m_marc output;
if @marc>@data begin select @m_marc=@m_marc+1440; end;
if @marc>@data_prx begin select @m_marc=@m_marc+1440; end;
select @achou_mc=0;
if @achou_mc=0 and @e1>-1 and @m_marc=@e1 begin select @achou_mc=1, @e1=-1; end; if @achou_mc=0 and @s1>-1 and @m_marc=@s1 begin select @achou_mc=1, @s1=-1; end;
if @achou_mc=0 and @e2>-1 and @m_marc=@e2 begin select @achou_mc=1, @e2=-1; end; if @achou_mc=0 and @s2>-1 and @m_marc=@s2 begin select @achou_mc=1, @s2=-1; end;
if @achou_mc=0 and @e3>-1 and @m_marc=@e3 begin select @achou_mc=1, @e3=-1; end; if @achou_mc=0 and @s3>-1 and @m_marc=@s3 begin select @achou_mc=1, @s3=-1; end;
if @achou_mc=0 and @e4>-1 and @m_marc=@e4 begin select @achou_mc=1, @e4=-1; end; if @achou_mc=0 and @s4>-1 and @m_marc=@s4 begin select @achou_mc=1, @s4=-1; end;
if @achou_mc=0 and @e5>-1 and @m_marc=@e5 begin select @achou_mc=1, @e5=-1; end; if @achou_mc=0 and @s5>-1 and @m_marc=@s5 begin select @achou_mc=1, @s5=-1; end;
if @achou_mc=0 and @e6>-1 and @m_marc=@e6 begin select @achou_mc=1, @e6=-1; end; if @achou_mc=0 and @s6>-1 and @m_marc=@s6 begin select @achou_mc=1, @s6=-1; end;
if @achou_mc=0 and @e7>-1 and @m_marc=@e7 begin select @achou_mc=1, @e7=-1; end; if @achou_mc=0 and @s7>-1 and @m_marc=@s7 begin select @achou_mc=1, @s7=-1; end;
if @achou_mc=0 and @e8>-1 and @m_marc=@e8 begin select @achou_mc=1, @e8=-1; end; if @achou_mc=0 and @s8>-1 and @m_marc=@s8 begin select @achou_mc=1, @s8=-1; end;
if @achou_mc=0 begin
select @id_jstjrn=0,@ordem=0;
SELECT TOP 1 @id_jstjrn=id_jstjrn,@ordem=ordem FROM tbAltJorn WHERE id_pass=@id_pass AND marc=@marc AND acao=0 AND afd=0;
if @id_jstjrn>0 begin
UPDATE tbAltJorn SET afd=1, data=@data WHERE id_pass=@id_pass AND marc=@marc AND ordem=@ordem;
end else begin
select @batidas_multiplas=0;
SELECT @batidas_multiplas=isnull(batidas_multiplas,0) FROM tbEmpresas WHERE id_empresa IN (SELECT p.id_empresa FROM tbPass p WHERE p.id_pass=@id_pass);
select @de=@m_marc-@batidas_multiplas,@ate=@m_marc+@batidas_multiplas;
if @batidas_multiplas>=0 and @de>-1 and @ate >-1 begin
if (@eo1>-1 and @eo1>=@de and @eo1 <=@ate) or (@so1>-1 and @so1>=@de and @so1 <=@ate) or
(@eo2>-1 and @eo2>=@de and @eo2 <=@ate) or (@so2>-1 and @so2>=@de and @so2 <=@ate) or
(@eo3>-1 and @eo3>=@de and @eo3 <=@ate) or (@so3>-1 and @so3>=@de and @so3 <=@ate) or
(@eo4>-1 and @eo4>=@de and @eo4 <=@ate) or (@so4>-1 and @so4>=@de and @so4 <=@ate) or
(@eo5>-1 and @eo5>=@de and @eo5 <=@ate) or (@so5>-1 and @so5>=@de and @so5 <=@ate) or
(@eo6>-1 and @eo6>=@de and @eo6 <=@ate) or (@so6>-1 and @so6>=@de and @so6 <=@ate) or
(@eo7>-1 and @eo7>=@de and @eo7 <=@ate) or (@so7>-1 and @so7>=@de and @so7 <=@ate) or
(@eo8>-1 and @eo8>=@de and @eo8 <=@ate) or (@so8>-1 and @so8>=@de and @so8 <=@ate)
begin
select @id_jstjrn=1;
end;
end;
if @id_jstjrn=0 begin
SELECT TOP 1 @id_jstjrn=id_jstjrn FROM tbJustJorn WHERE ocor=0 AND padrao=1;
end;
if @id_jstjrn>0 begin
select @ordem=0;
SELECT TOP 1 @ordem=ordem FROM tbAltJorn WHERE id_pass=@id_pass AND marc=@marc ORDER BY ordem DESC;
select @ordem=@ordem+1;
INSERT INTO tbAltJorn (id_pass, marc, ordem, data, acao, id_jstjrn, data_alt, id_usuario, afd) VALUES (@id_pass,@marc,@ordem,@data,0,@id_jstjrn,getdate(),0,1);
end;
end;
end;
select @ordem_dia=@ordem_dia+1;
UPDATE tbAFDR3 SET ordem=@ordem_dia WHERE rep=@rep AND r305=@r305 AND marc=@marc AND r301=@r301;
end;
end;
if @e1>-1 begin exec AP_PTO043 @id_pass, @data, @e1, 1, @original; end;
if @s1>-1 and @e2>-1 and @original=0 begin
exec AP_PTO043 @id_pass, @data, @s1, 2, @original;
exec AP_PTO043 @id_pass, @data, @e2, 2, @original;
end else begin
if @s1>-1 begin exec AP_PTO043 @id_pass, @data, @s1, 1, @original; end;
if @e2>-1 begin exec AP_PTO043 @id_pass, @data, @e2, 1, @original; end;
end;
if @s2>-1 begin exec AP_PTO043 @id_pass, @data, @s2, 1, @original; end;
if @e3>-1 begin exec AP_PTO043 @id_pass, @data, @e3, 1, @original; end;
if @s3>-1 begin exec AP_PTO043 @id_pass, @data, @s3, 1, @original; end;
if @e4>-1 begin exec AP_PTO043 @id_pass, @data, @e4, 1, @original; end;
if @s4>-1 begin exec AP_PTO043 @id_pass, @data, @s4, 1, @original; end;
if @e5>-1 begin exec AP_PTO043 @id_pass, @data, @e5, 1, @original; end;
if @s5>-1 begin exec AP_PTO043 @id_pass, @data, @s5, 1, @original; end;
if @e6>-1 begin exec AP_PTO043 @id_pass, @data, @e6, 1, @original; end;
if @s6>-1 begin exec AP_PTO043 @id_pass, @data, @s6, 1, @original; end;
if @e7>-1 begin exec AP_PTO043 @id_pass, @data, @e7, 1, @original; end;
if @s7>-1 begin exec AP_PTO043 @id_pass, @data, @s7, 1, @original; end;
if @e8>-1 begin exec AP_PTO043 @id_pass, @data, @e8, 1, @original; end;
if @s8>-1 begin exec AP_PTO043 @id_pass, @data, @s8, 1, @original; end;
UPDATE tbPtoDia SET afd_dia=1 WHERE id_pass=@id_pass AND data=@data;
end;
if @exibir_mcs=1 begin
SELECT r.marc as marcacao, -1 as tipo, 'Original' as justificativa, r.rep FROM tbAFDR3 r
WHERE r.id_pass=@id_pass AND r.dtref=@data
UNION ALL
SELECT a.marc as marcacao, a.acao as tipo, j.descricao as justificativa, '00000000000000000' as rep FROM tbAltJorn a
INNER JOIN tbJustJorn j ON a.id_jstjrn=j.id_jstjrn
WHERE a.id_pass=@id_pass AND a.data=@data AND a.afd=1
ORDER BY marcacao, tipo;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO048') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO048; END;
GO
CREATE PROCEDURE dbo.AP_PTO048(@acao tinyint, @id_ptocp bigint, @id_empresa int, @id_pass int, @data datetime, @id_diverg int, @id_eveabo_div int, @id_eveabo_cmp int,
@dt_ini_cmp datetime, @dt_fim_cmp datetime, @dias_comp varchar(10),
@m_min_comp_dia int, @m_max_comp_dia int, @hrs_tot bit,
@m_horas int, @id_usuario int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
SET LANGUAGE English
declare @reap_ini datetime, @reap_fim datetime, @reap bit, @dtAtu datetime;
declare @m_compensado int, @m_pagodesc int, @m_saldo int;
declare @min_comp_dia varchar(8), @max_comp_dia varchar(8), @horas varchar(8), @compensado varchar(8), @pagodesc varchar(8), @saldo varchar(8);
declare @soma bit, @m_valor int, @dtIniOld datetime, @dtFimOld datetime;
select @reap=0;
select @m_min_comp_dia=isnull(@m_min_comp_dia,0);
select @m_max_comp_dia=isnull(@m_max_comp_dia,0);
select @m_horas=isnull(@m_horas,0);
select @m_compensado=0;
select @m_pagodesc=0;
select @m_saldo=@m_horas;
if @id_diverg>0 begin
SELECT top 1 @soma=t.soma, @m_valor=d.m_valor FROM tbPtoDivsDia d
INNER JOIN tbDivergencias t ON t.id_diverg = d.id_diverg
WHERE d.id_pass=@id_pass AND d.data=@data AND d.id_diverg=@id_diverg;
end;
SELECT @soma=isnull(@soma,0), @m_valor=isnull(@m_valor,@m_horas);
if @hrs_tot=1 begin
select @m_horas=@m_valor;
select @m_saldo=@m_horas;
end;
if @soma=0 begin
select @m_horas=abs(@m_horas)*(-1),@m_pagodesc=abs(@m_pagodesc)*(-1),@m_saldo=abs(@m_saldo)*(-1);
end else begin
select @m_compensado=abs(@m_compensado)*(-1);
end;
exec AP_PTO004 @m_min_comp_dia, @min_comp_dia output;
exec AP_PTO004 @m_max_comp_dia, @max_comp_dia output;
exec AP_PTO004 @m_horas, @horas output;
exec AP_PTO004 @m_compensado, @compensado output;
exec AP_PTO004 @m_pagodesc, @pagodesc output;
exec AP_PTO004 @m_saldo, @saldo output;
select @m_horas=abs(@m_horas),@m_pagodesc=abs(@m_pagodesc),@m_saldo=abs(@m_saldo), @m_compensado=abs(@m_compensado);
select @dtIniOld=@data, @dtFimOld=@data;
if isnull(@id_ptocp,0) > 0 begin
SELECT @dtIniOld=(CASE WHEN dt_ini_cmp<data THEN dt_ini_cmp ELSE data END), @dtFimOld=dt_fim_cmp
FROM tbPtoCp WHERE id_ptocp=@id_ptocp;
end;
if @acao=0 begin
select @reap=1,@reap_ini=@data, @reap_fim=@dt_fim_cmp;
DELETE FROM tbPtoAboDia WHERE id_pass = @id_pass AND data=@data AND id_diverg=@id_diverg;
DELETE FROM tbPtoCpCmp WHERE id_ptocp IN (SELECT p.id_ptocp FROM tbPtoCp p WHERE p.id_pass = @id_pass AND p.data=@data AND p.id_diverg=@id_diverg);
DELETE FROM tbPtoCp WHERE id_pass = @id_pass AND data=@data AND id_diverg=@id_diverg;
INSERT INTO tbPtoCp (id_pass,data,id_diverg,soma,id_eveabo_div,id_eveabo_cmp,dt_ini_cmp,dt_fim_cmp,dias_comp,min_comp_dia,m_min_comp_dia,max_comp_dia,
m_max_comp_dia,hrs_tot,horas,m_horas,compensado,m_compensado,pagodesc,m_pagodesc,saldo,m_saldo,id_usuario,gerado)
VALUES (
@id_pass,@data,@id_diverg,@soma,@id_eveabo_div,@id_eveabo_cmp,@dt_ini_cmp,@dt_fim_cmp, @dias_comp,@min_comp_dia,@m_min_comp_dia,@max_comp_dia,
@m_max_comp_dia,@hrs_tot,@horas,@m_horas,@compensado,@m_compensado,@pagodesc,@m_pagodesc,@saldo,
@m_saldo,@id_usuario,0);
SELECT @id_ptocp=@@IDENTITY;
exec AP_PTO041 @id_empresa output, @id_pass output, @data output, @id_diverg,  @id_eveabo_div, 599999, @id_ptocp, 0;
end else if @acao=1 begin
if @id_ptocp>0 begin
select @reap=1,@reap_ini=@data, @reap_fim=@dt_fim_cmp;
if @reap_ini>@dt_ini_cmp begin select @reap_ini=@dt_ini_cmp; end;
if @reap_ini>@dtIniOld begin select @reap_ini=@dtIniOld; end;
if @reap_fim<@dtFimOld begin select @reap_fim=@dtFimOld; end;
if @reap_fim<@reap_ini begin select @reap_fim=@reap_ini; end;
DELETE FROM tbPtoAboDia WHERE id_ptocp=@id_ptocp;
DELETE FROM tbPtoCpCmp WHERE id_ptocp=@id_ptocp;
UPDATE tbPtoCp SET
id_eveabo_div = @id_eveabo_div, id_eveabo_cmp = @id_eveabo_cmp,dt_ini_cmp = @dt_ini_cmp,dt_fim_cmp = @dt_fim_cmp,
dias_comp = @dias_comp,min_comp_dia = @min_comp_dia,m_min_comp_dia = @m_min_comp_dia,max_comp_dia = @max_comp_dia,
m_max_comp_dia = @m_max_comp_dia,hrs_tot = @hrs_tot,horas = @horas,m_horas = @m_horas,compensado = @compensado,
m_compensado = @m_compensado,pagodesc = @pagodesc,m_pagodesc = @m_pagodesc,saldo = @saldo,m_saldo = @m_saldo,
id_usuario = @id_usuario
WHERE id_ptocp=@id_ptocp;
exec AP_PTO041 @id_empresa output, @id_pass output, @data output, @id_diverg,  @id_eveabo_div, 599999, @id_ptocp, 0;
end;
end else if @acao=2 begin
if @id_ptocp>0 begin
select @reap=1, @reap_ini=@data, @reap_fim=@dt_fim_cmp;
if @reap_ini>@dt_ini_cmp begin select @reap_ini=@dt_ini_cmp; end;
if @reap_ini>@dtIniOld begin select @reap_ini=@dtIniOld; end;
if @reap_fim<@dtFimOld begin select @reap_fim=@dtFimOld; end;
if @reap_fim<@reap_ini begin select @reap_fim=@reap_ini; end;
DELETE FROM tbPtoAboDia WHERE id_ptocp=@id_ptocp;
DELETE FROM tbPtoCpCmp WHERE id_ptocp=@id_ptocp;
DELETE FROM tbPtoCp WHERE id_ptocp=@id_ptocp;
end;
end;
if @reap=1 begin
if not @reap_ini is null and not @reap_fim is null begin
select @dtAtu=@reap_ini;
while @dtAtu<=@reap_fim begin
EXEC AP_PTO031 @id_pass output, @dtAtu output;
select @dtAtu=DATEADD(d,1,@dtAtu);
end;
EXEC AP_PTO032 @id_pass, @reap_fim, 0;
end;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.AP_PTO050') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.AP_PTO050; END;
GO
CREATE PROCEDURE dbo.AP_PTO050(@id_pass int, @data datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
SET LANGUAGE English
declare @fechamento_ini datetime, @fechamento_fim datetime;
declare @psi int, @id_empresa int, @achou bit;
declare @m_antes int, @m_periodo int, @m_compensado int, @m_compantes int, @m_descontado int, @m_acumulado int;
declare @antes varchar(8), @periodo varchar(8), @compensado varchar(8), @descontado varchar(8), @acumulado varchar(8);
select @m_antes=0, @m_periodo=0, @m_compensado=0, @m_compantes=0, @m_descontado=0, @m_acumulado=0;
select @achou=0;
SELECT @achou=1, @id_empresa=p.id_empresa FROM tbPass p WHERE id_pass=@id_pass
if @achou=1 begin
SELECT @fechamento_ini=fechamento_ini, @fechamento_fim=fechamento_fim FROM tbPerEmpresas WHERE id_empresa=@id_empresa AND @data BETWEEN fechamento_ini AND fechamento_fim;
if @fechamento_ini is null begin
select @psi=(day(@data)-1)*(-1);
select @fechamento_ini = dateadd(d,@psi,@data);
select @fechamento_fim = dateadd(d,-1,dateadd(m,1,@fechamento_ini));
end;
SELECT @m_antes=isnull(SUM(m_horas),0) FROM tbPtoCp WHERE soma=0 AND id_pass=@id_pass AND data < @fechamento_ini;
SELECT @m_compantes=ISNULL(SUM(m_compensado),0) FROM tbPtoCpCmp WHERE id_ptocp IN (
SELECT cp.id_ptocp FROM tbPtoCp cp WHERE cp.soma=0 AND cp.id_pass=@id_pass AND cp.data < @fechamento_ini
) AND data < @fechamento_ini;
if isnull(@m_compantes,0)>0 begin
if @m_compantes > @m_antes begin
select @m_antes=0;
end else begin
select @m_antes=@m_antes-@m_compantes;
end;
end;
SELECT @m_periodo=isnull(SUM(m_horas),0) FROM tbPtoCp
WHERE soma=0 AND id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim;
SELECT @m_compensado=isnull(SUM(m_compensado),0),  @m_descontado=isnull(SUM(m_pagodesc),0)
FROM tbPtoCpCmp WHERE id_pass=@id_pass AND data BETWEEN @fechamento_ini AND @fechamento_fim;
select @m_acumulado = ((@m_antes+@m_periodo)-@m_compensado)-@m_descontado;
if @m_acumulado < 0 begin select @m_acumulado=0; end;
end;
select @m_antes=@m_antes*(-1);
select @m_periodo=@m_periodo*(-1);
select @m_descontado=@m_descontado*(-1);
select @m_acumulado=@m_acumulado*(-1);
EXEC AP_PTO004 @m_antes, @antes output;
EXEC AP_PTO004 @m_periodo, @periodo output;
EXEC AP_PTO004 @m_compensado, @compensado output;
EXEC AP_PTO004 @m_descontado, @descontado output;
EXEC AP_PTO004 @m_acumulado, @acumulado output;
SELECT @antes as antes, @periodo as periodo, @compensado as compensado, @descontado as descontado, @acumulado as acumulado;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.CONSULTA_VISITANTE') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.CONSULTA_VISITANTE; END;
GO
CREATE PROCEDURE dbo.CONSULTA_VISITANTE(@id_pass int, @cracha float, @id_agvisi int) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @empvisi varchar(100);  declare @descricao varchar(70); declare @id_empresa int;
declare @via tinyint ;  declare @tipo varchar(1);  declare @nome varchar(100);
declare @vip bit ;   declare @nasc smalldatetime ;  declare @indesejado bit;
declare @bloqueado bit;  declare @id_horario int;  declare @id_depart int;
declare @per_indet bit;  declare @data_ini smalldatetime;  declare @data_fim smalldatetime;
declare @provisorio float;  declare @prov_ini smalldatetime;  declare @prov_fim smalldatetime;
declare @id_msgrel tinyint ;  declare @id_msgtela int;  declare @msg_qtd_p smallint;
declare @foto varchar(25);  declare @fotodoc varchar(25);  declare @g_bloq varchar(255);
declare @data smalldatetime ;  declare @horario smalldatetime;  declare @usu_resp int;
declare @status varchar(1);  declare @feriado bit;  declare @afast_ini smalldatetime;
declare @afast_fim smalldatetime;  declare @ult_acess datetime;  declare @reinic bit;
declare @indgbloq varchar(300);  declare @id_consist int;  declare @senha float;
declare @codass varchar(15);  declare @ult_acessd datetime;  declare @ult_idbloq int;
declare @ult_direc tinyint;  declare @doc varchar(50);  declare @sequencia varchar(1600);
declare @contador int;  declare @membership tinyint;  declare @cartaoimpresso tinyint;
declare @fotodocVerso varchar(25);  declare @via_provisorio int;   declare @acessos_dia int;
declare @id_local int;  declare @id_sublocal int;  declare @pass_visi int;
declare @visitado varchar(50);  declare @paci_visi int;   declare @id_phorario float;
declare @id_agrupamento int;  declare @id_custo int;  declare @doc_rg varchar(50);
declare @doc_cic varchar(50);  declare @doc_outros varchar(50);  declare @id_visitado int;
declare @NomeVisitado varchar(100);  declare @obs varchar(250);  declare @aces_p smallint; declare @aces_lmt int;
declare @tipoVisitado varchar(1);  declare @id_eventvisi int;  declare @DescEvento varchar(20);
declare @id_agpass int;  declare @permanente bit;
declare @ag_dtini datetime;  declare @ag_dtfim datetime;  declare @achou int;
declare @baixado bit;
select @achou=0,@baixado=0, @permanente=0, @id_agpass=0;
if @id_pass > 0 begin
SELECT  top 1 @achou=1,@baixado=1, @id_pass=p.id_pass, @cracha=0, @via=p.via, @tipo=p.tipo, @nome=p.nome,@vip=p.vip, @nasc=p.nasc, @indesejado=p.indesejado,
@bloqueado=p.bloqueado, @id_horario=p.id_horario, @id_depart=p.id_depart, @per_indet=p.per_indet, @data_ini=p.data_ini, @data_fim=p.data_fim,
@provisorio=p.provisorio, @prov_ini=null, @prov_fim=null, @id_msgrel=p.id_msgrel, @id_msgtela=p.id_msgtela, @msg_qtd_p=p.msg_qtd_p,
@foto=p.foto, @fotodoc=p.fotodoc, @g_bloq=p.g_bloq, @data=p.data, @horario=null, @usu_resp=p.usu_resp, @status=p.status,
@feriado=p.feriado, @afast_ini=null, @afast_fim=null, @ult_acess=p.ult_acess, @reinic=p.reinic, @indgbloq=p.indgbloq, @id_consist=p.id_consist,
@senha=p.senha, @codass=p.codass, @ult_acessd=p.ult_acessd, @ult_idbloq=p.ult_idbloq, @ult_direc=p.ult_direc, @id_agrupamento=p.id_agrupamento,@id_custo=p.id_custo, @doc=p.doc,
@sequencia=p.sequencia, @contador=p.contador, @membership=null, @cartaoimpresso=null, @fotodocVerso=p.fotodocVerso,
@via_provisorio=0, @doc_rg=tbVisi.doc_rg, @doc_cic=tbVisi.doc_cic, @doc_outros=tbVisi.doc_outros, @aces_p=tbVisi.aces_p, @aces_lmt=tbVisi.aces_lmt, @obs=tbVisi.obs,
@empvisi=tbEmpVisi.descricao, @pass_visi=tbVisi.pass_visi, @id_empresa=p.id_empresa, @descricao=tbEmpresas.descricao, @NomeVisitado=p_1.nome, @id_visitado=p_1.id_pass, @tipoVisitado=p_1.tipo,
@id_eventvisi=tbVisi.id_eventvisi, @DescEvento=tbEventVisi.descricao
FROM tbVisiBai p
INNER JOIN      tbVisi          ON p.id_pass       = tbVisi.id_pass
INNER JOIN      tbEmpresas      ON p.id_empresa    = tbEmpresas.id_empresa
LEFT OUTER JOIN tbPass p_1      ON tbVisi.pass_visi     = p_1.id_pass
LEFT JOIN       tbEventVisi     ON tbVisi.id_eventvisi  = tbEventVisi.id_eventvisi
LEFT JOIN       tbEmpVisi       ON tbVisi.id_empvisi    = tbEmpVisi.id_empvisi
WHERE p.id_pass = @id_pass
if @achou=0 begin
SELECT  top 1 @achou=1,@baixado=0, @id_pass=p.id_pass, @cracha=p.cracha, @via=p.via, @tipo=p.tipo, @nome=p.nome,@vip=p.vip, @nasc=p.nasc, @indesejado=p.indesejado,
@bloqueado=p.bloqueado, @id_horario=p.id_horario, @id_depart=p.id_depart, @per_indet=p.per_indet, @data_ini=p.data_ini, @data_fim=p.data_fim,
@provisorio=p.provisorio, @prov_ini=p.prov_ini, @prov_fim=p.prov_fim, @id_msgrel=p.id_msgrel, @id_msgtela=p.id_msgtela, @msg_qtd_p=p.msg_qtd_p,
@foto=p.foto, @fotodoc=p.fotodoc, @g_bloq=p.g_bloq, @data=p.data, @horario=p.horario, @usu_resp=p.usu_resp, @status=p.status,
@feriado=p.feriado, @afast_ini=p.afast_ini, @afast_fim=p.afast_fim, @ult_acess=p.ult_acess, @reinic=p.reinic, @indgbloq=p.indgbloq, @id_consist=p.id_consist,
@senha=p.senha, @codass=p.codass, @ult_acessd=p.ult_acessd, @ult_idbloq=p.ult_idbloq, @ult_direc=p.ult_direc, @id_agrupamento=p.id_agrupamento,@id_custo=p.id_custo, @doc=p.doc,
@sequencia=p.sequencia, @contador=p.contador, @membership=p.membership, @cartaoimpresso=p.cartaoimpresso, @fotodocVerso=p.fotodocVerso,
@via_provisorio=p.via_provisorio, @doc_rg=tbVisi.doc_rg, @doc_cic=tbVisi.doc_cic, @doc_outros=tbVisi.doc_outros, @aces_p=tbVisi.aces_p, @aces_lmt=tbVisi.aces_lmt, @obs=tbVisi.obs,
@empvisi=tbEmpVisi.descricao, @pass_visi=tbVisi.pass_visi, @id_empresa=p.id_empresa, @descricao=tbEmpresas.descricao, @NomeVisitado=p_1.nome, @id_visitado=p_1.id_pass, @tipoVisitado=p_1.tipo,
@id_eventvisi=tbVisi.id_eventvisi, @DescEvento=tbEventVisi.descricao
FROM tbPass p
INNER JOIN      tbVisi          ON p.id_pass       = tbVisi.id_pass
INNER JOIN      tbEmpresas      ON p.id_empresa    = tbEmpresas.id_empresa
LEFT OUTER JOIN tbPass p_1      ON tbVisi.pass_visi     = p_1.id_pass
LEFT JOIN       tbEventVisi     ON tbVisi.id_eventvisi  = tbEventVisi.id_eventvisi
LEFT JOIN       tbEmpVisi       ON tbVisi.id_empvisi    = tbEmpVisi.id_empvisi
WHERE p.id_pass = @id_pass
end;
end else begin
SELECT  top 1 @achou=1,@baixado=0, @id_pass=p.id_pass, @cracha=p.cracha, @via=p.via, @tipo=p.tipo, @nome=p.nome,@vip=p.vip, @nasc=p.nasc, @indesejado=p.indesejado,
@bloqueado=p.bloqueado, @id_horario=p.id_horario, @id_depart=p.id_depart, @per_indet=p.per_indet, @data_ini=p.data_ini, @data_fim=p.data_fim,
@provisorio=p.provisorio, @prov_ini=p.prov_ini, @prov_fim=p.prov_fim, @id_msgrel=p.id_msgrel, @id_msgtela=p.id_msgtela, @msg_qtd_p=p.msg_qtd_p,
@foto=p.foto, @fotodoc=p.fotodoc, @g_bloq=p.g_bloq, @data=p.data, @horario=p.horario, @usu_resp=p.usu_resp, @status=p.status,
@feriado=p.feriado, @afast_ini=p.afast_ini, @afast_fim=p.afast_fim, @ult_acess=p.ult_acess, @reinic=p.reinic, @indgbloq=p.indgbloq, @id_consist=p.id_consist,
@senha=p.senha, @codass=p.codass, @ult_acessd=p.ult_acessd, @ult_idbloq=p.ult_idbloq, @ult_direc=p.ult_direc, @id_agrupamento=p.id_agrupamento,@id_custo=p.id_custo, @doc=p.doc,
@sequencia=p.sequencia, @contador=p.contador, @membership=p.membership, @cartaoimpresso=p.cartaoimpresso, @fotodocVerso=p.fotodocVerso,
@via_provisorio=p.via_provisorio, @doc_rg=tbVisi.doc_rg, @doc_cic=tbVisi.doc_cic, @doc_outros=tbVisi.doc_outros, @aces_p=tbVisi.aces_p, @aces_lmt=tbVisi.aces_lmt, @obs=tbVisi.obs,
@empvisi=tbEmpVisi.descricao, @pass_visi=tbVisi.pass_visi, @id_empresa=p.id_empresa, @descricao=tbEmpresas.descricao, @NomeVisitado=p_1.nome, @id_visitado=p_1.id_pass, @tipoVisitado=p_1.tipo,
@id_eventvisi=tbVisi.id_eventvisi, @DescEvento=tbEventVisi.descricao
FROM tbPass p
INNER JOIN      tbVisi          ON p.id_pass       = tbVisi.id_pass
INNER JOIN      tbEmpresas      ON p.id_empresa    = tbEmpresas.id_empresa
LEFT OUTER JOIN tbPass p_1      ON tbVisi.pass_visi     = p_1.id_pass
LEFT JOIN       tbEventVisi     ON tbVisi.id_eventvisi  = tbEventVisi.id_eventvisi
LEFT JOIN       tbEmpVisi       ON tbVisi.id_empvisi    = tbEmpVisi.id_empvisi
WHERE p.cracha = @cracha AND NOT EXISTS (
SELECT e.id_empresa FROM tbEmpresas e WHERE e.id_empresa = p.id_empresa AND ISNULL(e.inativo_ace,0) = 1
)
end
if isnull(@id_agvisi,0) = 0 begin
select @id_agvisi=0;
end;
if @achou=1 and @baixado=1 begin
if @id_agvisi = 0 begin
select @id_agvisi=0;
SELECT top 1 @id_agvisi=id_agvisi, @id_agpass=id_pass,@permanente=permanente, @ag_dtini=data_ini, @ag_dtfim=data_fim
FROM tbAgVisi WHERE id_visi=@id_pass AND (permanente=1 OR
GETDATE() BETWEEN data_ini and data_fim
);
end else begin
SELECT @id_agpass=id_pass,@permanente=permanente, @ag_dtini=data_ini, @ag_dtfim=data_fim
FROM tbAgVisi WHERE id_agvisi=@id_agvisi;
end;
if isnull(@id_agpass,0) > 0 begin
SELECT @id_visitado=p.id_pass, @tipoVisitado=p.tipo, @NomeVisitado=p.nome,
@empvisi=e.descricao, @id_depart=p.id_depart, @id_custo=id_custo
FROM tbPass p LEFT JOIN tbEmpresas e ON p.id_empresa=e.id_empresa
WHERE p.id_pass=@id_agpass;
end;
end;
SELECT  @achou as achou,@baixado as baixado,@id_pass as id_pass, @cracha as cracha, @via as via,@tipo as tipo, @nome as nome,@vip as vip, @nasc as nasc, @indesejado as indesejado,
@bloqueado as bloqueado, @id_horario as id_horario, @id_depart as id_depart, @per_indet as per_indet, @data_ini as data_ini, @data_fim as data_fim,
@provisorio as provisorio, @prov_ini as prov_ini, @prov_fim as prov_fim, @id_msgrel as id_msgrel, @id_msgtela as id_msgtela, @msg_qtd_p as msg_qtd_p,
@foto as foto, @fotodoc as fotodoc, @g_bloq as g_bloq, @data as data, @horario as horario, @usu_resp as usu_resp, @status as status,
@feriado as feriado, @afast_ini as afast_ini, @afast_fim as afast_fim, @ult_acess as ult_acess, @reinic as reinic, @indgbloq as indgbloq, @id_consist as id_consist,
@senha as senha, @codass as codass, @ult_acessd as ult_acessd, @ult_idbloq as ult_idbloq, @ult_direc as ult_direc, @id_agrupamento as id_agrupamento,@id_custo as id_custo, @doc as doc,
@sequencia as sequencia, @contador as contador, @membership as membership, @cartaoimpresso as cartaoimpresso, @fotodocVerso as fotodocVerso,
@via_provisorio as via_provisorio, @doc_rg as doc_rg, @doc_cic as doc_cic, @doc_outros as doc_outros, @aces_p as aces_p, @aces_lmt as aces_lmt, @obs as obs,
@empvisi as empvisi, @pass_visi as pass_visi, @id_empresa as id_empresa, @descricao as descricao, @NomeVisitado as NomeVisitado, @id_visitado as id_visitado, @tipoVisitado as tipoVisitado,
@id_eventvisi as id_eventvisi, @DescEvento as DescEvento, @permanente as permanente, @ag_dtini as ag_dtini, @ag_dtfim as ag_dtfim;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.FAIXAS_RELOGS') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.FAIXAS_RELOGS; END;
GO
CREATE PROCEDURE dbo.FAIXAS_RELOGS(@ponto bit) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_fx int; declare @id_min int; declare @id_max int; declare @id_atu int;
declare @faixas varchar(70); declare @fx1 int; declare @fx2 int; declare @fx3 int;
declare @achou bit;
if @ponto=1 begin
DELETE FROM tbPFxRelogs;
INSERT INTO tbPFxRelogs (id_pfxrelog, faixas) VALUES (1,'00002359000023590000235900002359000023590000235900002359');
end else begin
DELETE FROM tbAFxRelogs;
INSERT INTO tbAFxRelogs (id_afxrelog, faixas) VALUES (1,'00002359000023590000235900002359000023590000235900002359');
end;
DELETE FROM tbRFxRelogs WHERE ponto=@ponto;
select @id_fx=2;
if @ponto=0 begin
SELECT @id_min=min(id_horario), @id_max=max(id_horario) FROM tbHorarios;
select @id_min=isnull(@id_min,0), @id_max=isnull(@id_max,0);
select @id_atu=@id_min;
while (@id_atu>0 and @id_atu>=@id_min and @id_atu<=@id_max) begin
if exists(SELECT id_horario FROM tbHorarios WHERE id_horario=@id_atu) begin
select @fx1=0, @fx2=0, @fx3=0;
select @faixas='';
SELECT @faixas=c1e1+c1s1+c2e1+c2s1+c3e1+c3s1+c4e1+c4s1+c5e1+c5s1+c6e1+c6s1+c7e1+c7s1 FROM tbHorarios WHERE id_horario=@id_atu;  select @faixas=REPLACE(@faixas,'_','0'); select @faixas=REPLACE(@faixas,':','');
if len(isnull(@faixas,''))=56 AND @faixas<>'00002359000023590000235900002359000023590000235900002359' AND @faixas<>'00000000000000000000000000000000000000000000000000000000' begin
select @achou=0;
select @achou=1, @fx1=id_afxrelog FROM tbAFxRelogs WHERE faixas=@faixas;
if @achou=0 begin select @fx1=@id_fx; INSERT INTO tbAFxRelogs (id_afxrelog, faixas) VALUES (@id_fx,@faixas); select @id_fx=@id_fx+1; end;
end;
select @faixas='';
SELECT @faixas=c1e2+c1s2+c2e2+c2s2+c3e2+c3s2+c4e2+c4s2+c5e2+c5s2+c6e2+c6s2+c7e2+c7s2 FROM tbHorarios WHERE id_horario=@id_atu;  select @faixas=REPLACE(@faixas,'_','0'); select @faixas=REPLACE(@faixas,':','');
if len(isnull(@faixas,''))=56 AND @faixas<>'00002359000023590000235900002359000023590000235900002359' AND @faixas<>'00000000000000000000000000000000000000000000000000000000' begin
select @achou=0;
select @achou=1, @fx2=id_afxrelog FROM tbAFxRelogs WHERE faixas=@faixas;
if @achou=0 begin select @fx2=@id_fx; INSERT INTO tbAFxRelogs (id_afxrelog, faixas) VALUES (@id_fx,@faixas); select @id_fx=@id_fx+1; end;
end;
select @faixas='';
SELECT @faixas=c1e3+c1s3+c2e3+c2s3+c3e3+c3s3+c4e3+c4s3+c5e3+c5s3+c6e3+c6s3+c7e3+c7s3 FROM tbHorarios WHERE id_horario=@id_atu;  select @faixas=REPLACE(@faixas,'_','0'); select @faixas=REPLACE(@faixas,':','');
if len(isnull(@faixas,''))=56 AND @faixas<>'00002359000023590000235900002359000023590000235900002359' AND @faixas<>'00000000000000000000000000000000000000000000000000000000' begin
select @achou=0;
select @achou=1, @fx3=id_afxrelog FROM tbAFxRelogs WHERE faixas=@faixas;
if @achou=0 begin select @fx3=@id_fx; INSERT INTO tbAFxRelogs (id_afxrelog, faixas) VALUES (@id_fx,@faixas); select @id_fx=@id_fx+1; end;
end;
if @fx1>0 or @fx2 >0 or @fx3>0 begin
INSERT INTO tbRFxRelogs (ponto, id_hor, fxrelog) VALUES (0,@id_atu,ltrim(str(@fx1))+':'+ltrim(str(@fx2))+':'+ltrim(str(@fx3)));
end;
end;
select @id_atu=@id_atu+1;
end;
end;
END;
GO
if exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbEMedicoAux') and OBJECTPROPERTY(id, N'IsUserTable') = 1) begin exec('DROP TABLE tbEMedicoAux'); end;
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbInfoIntV') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
CREATE TABLE tbInfoIntV (
[id_pass] [int] NOT NULL,
[tipo_info] [int] NOT NULL,
[id_info] [int] NOT NULL,
[dt_proc] [datetime] NOT NULL,
[descricao] [varchar](50) NOT NULL,
[dtinicio] [datetime] NOT NULL,
[ativo] [bit] NOT NULL,
[tipo_item] [tinyint] NOT NULL,
[opt_per] [tinyint] NOT NULL,
[dias] [int] NOT NULL,
[meses] [tinyint] NOT NULL,
[dia] [tinyint] NOT NULL,
[mes] [tinyint] NOT NULL,
[qtde_min] [tinyint] NOT NULL,
[qtde_realizado]   [int] NOT NULL,
[dtultimo] [datetime] NULL,
[dtvencido] [datetime] NULL
)
ALTER TABLE [dbo].[tbInfoIntV] WITH NOCHECK ADD CONSTRAINT [PK_tbInfoIntV] PRIMARY KEY CLUSTERED (id_pass, tipo_info, id_info) ON [PRIMARY];
CREATE INDEX [IX_tbInfoIntV_tipo_exame] ON [dbo].[tbInfoIntV](id_pass, tipo_info, tipo_item) ON [PRIMARY];
CREATE INDEX [IX_tbInfoIntV_dt_vencido] ON [dbo].[tbInfoIntV](id_pass, tipo_info, dtvencido) ON [PRIMARY];
end;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.OBTER_EXAMES') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.OBTER_EXAMES; END;
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.INFO_INTG_PASS') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.INFO_INTG_PASS; END;
GO
CREATE PROCEDURE dbo.INFO_INTG_PASS(@id_pass int, @info int, @result bit) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @id_empresa int, @admissao as datetime, @dtdemissao as datetime, @id_cargo int, @inativo bit;
declare @achouP bit, @tpass varchar(1);
select @achouP=0, @id_empresa=0, @admissao=null, @dtdemissao=null, @id_cargo=0;
if exists(
SELECT top 1 dt_proc FROM tbInfoIntV WHERE id_pass=@id_pass AND datediff(dd,dt_proc,getdate())=0 and datediff(ss,dt_proc,getdate())<3
) begin
if @result=1 begin
SELECT * FROM tbInfoIntV WHERE id_pass=@id_pass AND (tipo_info=@info or @info=0) ORDER BY tipo_info, tipo_item, dtvencido;
end;
RETURN(0);
end;
SELECT @achouP=1, @id_empresa=isnull(id_empresa,0), @inativo=isnull(inativo,0), @tpass=tipo, @admissao=data
FROM tbPass WHERE id_pass=@id_pass;
if @achouP=0 begin
SELECT @achouP=1, @id_empresa=isnull(id_empresa,0), @inativo=0, @tpass='V', @admissao=data
FROM tbVisiBai WHERE id_pass=@id_pass;
end;
select @admissao=convert(datetime,convert(varchar,isnull(@admissao,getdate()),101));
if @achouP=1 begin
if @tpass='F' begin
SELECT @admissao=isnull(admissao,@admissao), @dtdemissao=dtdemissao, @id_cargo=isnull(id_cargo,0)
FROM tbFunc WHERE id_pass=@id_pass;
end;
if @tpass='T' begin
SELECT @admissao=isnull(admissao,@admissao), @id_cargo=isnull(id_cargo,0)
FROM tbTerc WHERE id_pass=@id_pass;
end;
end;
if @info=0 or @info=1 begin
DELETE FROM tbInfoIntV WHERE id_pass=@id_pass AND tipo_info=1;
if @achouP=1 begin
INSERT INTO tbInfoIntV (id_pass, tipo_info, dt_proc, id_info, descricao, dtinicio, ativo, tipo_item, opt_per, dias, meses, dia, mes, qtde_min, qtde_realizado, dtultimo, dtvencido)
SELECT @id_pass, 1 as tipo_info, getdate(), em.id_emedico, em.descricao, em.dtinicio, em.ativo, em.tipo_exame, em.opt_per, em.dias, em.meses, em.dia, em.mes, em.qtde_min, 0, null, null
FROM tbEMedico em
WHERE em.ativo=1
AND NOT EXISTS(
SELECT TOP 1 ii.id_info FROM tbInfoIntV ii WHERE ii.id_pass=@id_pass AND ii.tipo_info=1 AND ii.id_info=em.id_emedico
)
AND (@inativo=0 OR em.tipo_exame=99)
AND (isnull(@dtdemissao,getdate())>=dtinicio OR em.tipo_exame<>99)
AND (em.todos_cargos=1 OR @tpass NOT IN ('F','T') OR em.id_emedico IN (
SELECT ec.id_emedico FROM tbEMedicoCargos ec WHERE ec.id_cargo = @id_cargo))
AND patindex('%#'+@tpass+'#%',isnull(em.tpass,'')) > 0
AND (em.id_empresa=0 or em.id_empresa=@id_empresa);
UPDATE tbInfoIntV SET qtde_realizado = isnull(
(SELECT count(h.data) FROM tbEMedicoHist h WHERE h.id_pass=@id_pass AND h.id_emedico=tbInfoIntV.id_info AND h.avaliacao=0),qtde_realizado)
WHERE id_pass=@id_pass AND tipo_info=1;
UPDATE tbInfoIntV SET dtultimo = isnull(
(SELECT max(h.data) FROM tbEMedicoHist h WHERE h.id_pass=@id_pass AND h.id_emedico=tbInfoIntV.id_info AND h.avaliacao=0),dtultimo)
WHERE id_pass=@id_pass AND tipo_info=1;
if @tpass='F' or @tpass='T' begin
if (@dtdemissao IS NULL) or (@tpass='T') begin
DELETE FROM tbInfoIntV WHERE id_pass=@id_pass AND tipo_info=1 AND tipo_item=99;
end else begin
DELETE FROM tbInfoIntV WHERE id_pass=@id_pass AND tipo_info=1 AND tipo_item<>99;
end;
DELETE FROM tbInfoIntV WHERE id_pass=@id_pass AND tipo_info=1 AND (tipo_item=0 OR tipo_item=99) AND qtde_realizado>0;
UPDATE tbInfoIntV SET dtvencido=@admissao WHERE id_pass=@id_pass AND tipo_info=1 AND tipo_item=0;
if not @dtdemissao is null begin UPDATE tbInfoIntV SET dtvencido=@dtdemissao WHERE id_pass=@id_pass AND tipo_info=1 AND tipo_item=99; end;
end else begin
DELETE FROM tbInfoIntV WHERE id_pass=@id_pass AND tipo_info=1 AND tipo_item IN (0, 99);
end;
if (NOT @dtdemissao IS NULL) OR (@inativo=1) begin
DELETE FROM tbInfoIntV WHERE id_pass=@id_pass AND tipo_info=1 AND tipo_item=2;
end;
UPDATE tbInfoIntV SET dtvencido=dateadd(dd,dias,dtultimo) WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=1 AND NOT dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido=@admissao WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=1 AND dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = dateadd(dd,1,dateadd(mm,meses,dtultimo)) WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=2 AND NOT dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = @admissao WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=2 AND dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = dtultimo WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=3 AND NOT dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = dateadd(yy,-1,@admissao) WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=3 AND dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = convert(datetime,'01/01/'+ltrim(str(YEAR(dtvencido)+1))) WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=3;
UPDATE tbInfoIntV SET dtvencido = dateadd(mm,mes-1,dtvencido) WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=3;
UPDATE tbInfoIntV SET dtvencido = dateadd(dd,dia-1,dtvencido) WHERE id_pass=@id_pass AND tipo_info=1 AND opt_per=3;
UPDATE tbInfoIntV SET dtvencido = @admissao WHERE id_pass=@id_pass AND tipo_info=1 AND NOT dtvencido IS NULL AND dtvencido<@admissao;
UPDATE tbInfoIntV SET dtvencido = dtinicio WHERE id_pass=@id_pass AND tipo_info=1 AND NOT dtvencido IS NULL AND dtvencido<dtinicio;
end;
end; --if @info=0 or @info=1 begin
if @info=0 or @info=2 begin
DELETE FROM tbInfoIntV WHERE id_pass=@id_pass AND tipo_info=2;
if (@achouP=1) AND (@dtdemissao IS NULL) AND (@inativo=0) begin
INSERT INTO tbInfoIntV (id_pass, tipo_info, dt_proc, id_info, descricao, dtinicio, ativo, tipo_item, opt_per, dias, meses, dia, mes, qtde_min, qtde_realizado, dtultimo, dtvencido)
SELECT @id_pass, 2 as tipo_info, getdate(), tr.id_treina, tr.descricao, tr.dtinicio, tr.ativo, 2 as tipo_exame, tr.opt_per, tr.dias, tr.meses, tr.dia, tr.mes, 0 as qtde_min, 0, null, null
FROM tbTreina tr
WHERE tr.ativo=1
AND NOT EXISTS(
SELECT TOP 1 ii.id_info FROM tbInfoIntV ii WHERE ii.id_pass=@id_pass AND ii.tipo_info=2 AND ii.id_info=tr.id_treina
)
AND (tr.todos_cargos=1 OR @tpass NOT IN ('F','T') OR tr.id_treina IN (
SELECT ec.id_treina FROM tbTreinaCargos ec WHERE ec.id_cargo = @id_cargo))
AND patindex('%#'+@tpass+'#%',isnull(tr.tpass,'')) > 0
AND (tr.id_empresa=0 or tr.id_empresa=@id_empresa);
UPDATE tbInfoIntV SET qtde_realizado = isnull(
(SELECT count(h.data) FROM tbTreinaHist h WHERE h.id_pass=@id_pass AND h.id_treina=tbInfoIntV.id_info AND h.avaliacao=0),qtde_realizado)
WHERE id_pass=@id_pass AND tipo_info=2;
UPDATE tbInfoIntV SET dtultimo = isnull(
(SELECT max(h.data) FROM tbTreinaHist h WHERE h.id_pass=@id_pass AND h.id_treina=tbInfoIntV.id_info AND h.avaliacao=0),dtultimo)
WHERE id_pass=@id_pass AND tipo_info=2;
UPDATE tbInfoIntV SET dtvencido=dateadd(dd,dias,dtultimo) WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=1 AND NOT dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido=@admissao WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=1 AND dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = dateadd(dd,1,dateadd(mm,meses,dtultimo)) WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=2 AND NOT dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = @admissao WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=2 AND dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = dtultimo WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=3 AND NOT dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = dateadd(yy,-1,@admissao) WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=3 AND dtultimo IS NULL;
UPDATE tbInfoIntV SET dtvencido = convert(datetime,'01/01/'+ltrim(str(YEAR(dtvencido)+1))) WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=3;
UPDATE tbInfoIntV SET dtvencido = dateadd(mm,mes-1,dtvencido) WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=3;
UPDATE tbInfoIntV SET dtvencido = dateadd(dd,dia-1,dtvencido) WHERE id_pass=@id_pass AND tipo_info=2 AND opt_per=3;
UPDATE tbInfoIntV SET dtvencido = @admissao WHERE id_pass=@id_pass AND tipo_info=2 AND NOT dtvencido IS NULL AND dtvencido<@admissao;
UPDATE tbInfoIntV SET dtvencido = dtinicio WHERE id_pass=@id_pass AND tipo_info=2 AND NOT dtvencido IS NULL AND dtvencido<dtinicio;
end;
end; --if @info=0 or @info=2 begin
if @result=1 begin
SELECT * FROM tbInfoIntV WHERE id_pass=@id_pass AND (tipo_info=@info or @info=0) ORDER BY tipo_info, tipo_item, dtvencido;
end;
END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.OBTER_INTJRELATIVA') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.OBTER_INTJRELATIVA; END;
GO
CREATE PROCEDURE dbo.OBTER_INTJRELATIVA(@id_pass int, @dtRef datetime) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
declare @data datetime;
declare @tipodia char(1);
declare @dia_tipo tinyint, @dia_previsto bit, @id_eveafa int, @folga bit;
declare @achou bit;
declare @m_intejor int;
declare @e1 int;
select @m_intejor=-1;
select @data = convert(datetime,convert(varchar,isnull(@dtRef,'00:00:00'),101));
select @data = dateadd(d,1,@data);
if not EXISTS(SELECT id_pass FROM tbPtoDia WHERE id_pass=@id_pass AND data = @data AND apontado=1) begin
EXEC AP_PTO032 @id_pass, @data, 1;
end;
select @tipodia='N', @dia_tipo=0, @dia_previsto=0, @id_eveafa=0;
select @achou=0;
SELECT @achou=1,
@tipodia=isnull(tipodia,'Z'),
@dia_tipo=(CASE WHEN isnull(p.admissao,0)=1 THEN 1 WHEN isnull(p.demissao,0)=1 THEN 4 ELSE 0 END),
@dia_previsto=isnull(p.trabalhado,0),
@id_eveafa=isnull(p.id_eveafa,0),
@folga=isnull(p.folga,0), @e1=e1
FROM tbPtoDia p WHERE p.id_pass=@id_pass AND p.data=@data;
if @achou=1 begin
if @dia_tipo=0 AND @dia_previsto=1 AND @id_eveafa=0 AND @e1>=0 begin
if @e1>1440 begin
select @e1=@e1-1440;
end;
select @m_intejor=DATEDIFF(mi,@dtRef,DATEADD(mi,@e1,@data));
end;
end;
SELECT @m_intejor;
END;
GO
/*
viewApontado
*/
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.PROC_REAP_PTO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.PROC_REAP_PTO; END;
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.viewApontado') AND xtype = 'V') BEGIN DROP VIEW dbo.viewApontado; END;
GO
CREATE VIEW dbo.viewApontado
AS
SELECT p.id_empresa, p.id_pass, e.data, e.original as enqoriginal, enc.ult_data FROM tbPtoEnq e
INNER JOIN tbPass p ON e.id_pass=p.id_pass
LEFT JOIN tbEncEmp enc ON p.id_empresa=enc.id_empresa
WHERE e.apontado=0 AND e.data>isnull(enc.ult_data,dateadd(d,-1,e.data))
UNION
SELECT p.id_empresa, p.id_pass, e.data, 0 as enqoriginal, enc.ult_data  FROM tbPtoDia e
INNER JOIN tbPass p ON e.id_pass=p.id_pass
LEFT JOIN tbEncEmp enc ON p.id_empresa=enc.id_empresa
WHERE e.apontado=0 AND e.data>isnull(enc.ult_data,dateadd(d,-1,e.data))
GO
/*
Feedback - Categorias
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFBCategoria') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
CREATE TABLE [dbo].[tbFBCategoria] (
[id_fbcategoria] [int] NOT NULL, [descricao] [varchar] (50) NOT NULL,
[duvida] BIT NOT NULL, [elogio] BIT NOT NULL, [reclamacao] BIT NOT NULL, [sugestao] BIT NOT NULL
) ON [PRIMARY];
ALTER TABLE [dbo].[tbFBCategoria] WITH NOCHECK
ADD CONSTRAINT [PK_tbFBCategoria] PRIMARY KEY CLUSTERED ([id_fbcategoria]) ON [PRIMARY];
end
GO
/*
Feedback - Mensagens
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFBResposta') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
CREATE TABLE [dbo].[tbFBResposta] (
[id_fbresp] bigint IDENTITY(1,1) NOT NULL,
[id_fbprotocolo] bigint NOT NULL,
[data] datetime NOT NULL,
[mensagem] varchar(140) NOT NULL,
[status] int NOT NULL, --1:Resposta enviada, 2:Resposta lida, 3: Mensagem enviada, 4: Mensagem lida
[data_lido] datetime NULL,
[id_usuario] int NULL
) ON [PRIMARY];
ALTER TABLE [dbo].[tbFBResposta] WITH NOCHECK ADD CONSTRAINT [PK_tbFBResposta] PRIMARY KEY CLUSTERED ([id_fbresp]) ON [PRIMARY];
CREATE INDEX [IX_tbFBResposta] ON [dbo].[tbFBResposta](id_fbprotocolo, [status]) ON [PRIMARY];
end
GO
/*
Feedback - Protocolos
*/
if not exists (select * from dbo.sysobjects where id = object_id(N'dbo.tbFBProtocolo') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
begin
CREATE TABLE [dbo].[tbFBProtocolo] (
[id_fbprotocolo] bigint NOT NULL,
[id_fbtipo] int NOT NULL, --1:dvida, 2:elogio, 3:reclamao, 4:sugesto
[id_fbcategoria] int NOT NULL,
[id_pass] int NOT NULL,
[data] datetime NOT NULL,
[mensagem] varchar(140) NOT NULL,
[status] int NOT NULL, --1:Aberto aguardando, 2: Aberto com resposta, 3:Finalizado pelo solicitante, 4:Finalizado pelo operador
[data_lido] datetime NULL,
[data_fim] datetime NULL,
[id_usuario] int NULL
) ON [PRIMARY];
ALTER TABLE [dbo].[tbFBProtocolo] WITH NOCHECK ADD CONSTRAINT [PK_tbFBProtocolo] PRIMARY KEY CLUSTERED ([id_fbprotocolo]) ON [PRIMARY];
CREATE INDEX [IX_tbFBProtocolo] ON [dbo].[tbFBProtocolo](id_pass, [status]) ON [PRIMARY];
end
GO
IF EXISTS(SELECT * FROM sysobjects WHERE id = OBJECT_ID(N'dbo.PROC_REAP_PTO') AND xtype = 'P') BEGIN DROP PROCEDURE dbo.PROC_REAP_PTO; END;
GO
CREATE PROCEDURE dbo.PROC_REAP_PTO(@alerta bit) WITH ENCRYPTION AS
BEGIN
SET NOCOUNT ON;
SET LANGUAGE English
declare @dtAtu datetime; declare @dtIni datetime; declare @dtFim datetime; declare @dtRef datetime;
declare @id_pass int;    declare @achou bit;
declare @ult_reapon datetime; declare @ult_reapon_status int;
declare @id_empresa int; declare @tempo_max int; declare @ult_status datetime;
SELECT TOP 1 @ult_reapon=ult_reapon, @ult_reapon_status=isnull(ult_reapon_status,0), @ult_status=isnull(ult_status,getdate()) FROM tbParSist;
if @ult_reapon_status>0 and not @ult_reapon is null begin
if abs(datediff(mi,@ult_status,getdate())) < 10 begin
return(0);
end;
end;
select @tempo_max=20;
if @alerta=1 begin
select @tempo_max=420;
end;
select @ult_reapon=GetDate();
UPDATE tbParSist SET ult_reapon=@ult_reapon, ult_reapon_status=1, ult_status=getdate(), ult_reapon_perc=(CASE WHEN isnull(ult_reapon_perc,0)>90 THEN 1 ELSE isnull(ult_reapon_perc,0)+1 END);
select @dtAtu = Convert(datetime,Convert(varchar,Getdate(),101));
select @dtAtu = Dateadd(dd,-2,@dtAtu); --referncia na antevspera
select @achou=0, @dtIni=null;
SELECT TOP 1 @achou=1, @id_empresa=p.id_empresa, @id_pass=f.id_pass, @dtIni=isnull(f.ult_apt,DateAdd(m, -2, @dtAtu)) FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE isnull(f.ult_apt,dateadd(d,-1,@dtAtu)) < @dtAtu AND isnull(f.dtdemissao,@dtAtu) >= isnull(f.ult_apt,Convert(datetime,'01/01/2000')) ORDER BY f.id_pass;
if @dtIni>=@dtAtu begin select @dtIni=dateadd(d,-1,@dtAtu); end;
if (@achou=1) begin
UPDATE tbParSist SET ult_reapon_perc=(CASE WHEN isnull(ult_reapon_perc,0)>50 THEN 5 ELSE isnull(ult_reapon_perc,0)+1 END), ult_status=getdate();
end;
while (@achou=1) begin
select @dtFim = DateAdd(d, 15, @dtAtu);
if @dtIni <= @dtFim begin
if DateDiff(d,@dtIni,@dtFim) > 120
select @dtIni = DateAdd(d, -120, @dtFim);
select @dtRef=@dtIni;
while (@dtRef<@dtFim) begin
EXEC AP_PTO032 @id_pass,@dtRef,1;
select @dtRef=DateAdd(d,1,@dtRef);
end;
EXEC AP_PTO032 @id_pass,@dtFim,0;
UPDATE tbFunc SET ult_apt=@dtAtu WHERE id_pass = @id_pass;
UPDATE tbParSist SET ult_status=getdate();
end; --if @dtIni <= @dtFim begin
select @achou=0, @dtIni=null;
SELECT TOP 1 @achou=1, @id_empresa=p.id_empresa, @id_pass=f.id_pass, @dtIni=isnull(f.ult_apt,DateAdd(m, -2, @dtAtu)) FROM tbFunc f INNER JOIN tbPass p ON f.id_pass = p.id_pass
WHERE f.id_pass>@id_pass AND isnull(f.ult_apt,dateadd(d,-1,@dtAtu)) < @dtAtu AND isnull(f.dtdemissao,@dtAtu) >= isnull(f.ult_apt,Convert(datetime,'01/01/2000'))  ORDER BY f.id_pass;
if @dtIni>=@dtAtu begin select @dtIni=dateadd(d,-1,@dtAtu); end;
UPDATE tbParSist SET ult_status=getdate();
if datediff(s,@ult_reapon,getdate()) >= @tempo_max begin select @achou=0;  end;
end; --while (@achou=1) begin
if datediff(s,@ult_reapon,getdate()) < @tempo_max begin
select @dtAtu = Convert(datetime,Convert(varchar,Getdate(),101));
select @dtIni = DateAdd(d, -100, @dtAtu);
select @dtFim = DateAdd(m, 1, @dtAtu);
select @achou=0,@id_pass=0, @dtRef=null;
SELECT TOP 1 @achou=1, @id_empresa=id_empresa, @id_pass=id_pass, @dtRef=data FROM viewApontado WHERE data >= @dtIni AND data <= @dtFim
ORDER BY id_pass, data, enqoriginal;
if (@achou=1) begin
UPDATE tbParSist SET ult_reapon_perc=(CASE WHEN isnull(ult_reapon_perc,0)>90 THEN 70 ELSE isnull(ult_reapon_perc,0)+1 END), ult_status=getdate();
end else begin
UPDATE tbParSist SET ult_reapon_perc=100, ult_status=getdate();
end;
while (@achou=1) begin
while (@achou=1 AND NOT @dtRef IS NULL) begin
EXEC AP_PTO032 @id_pass, @dtRef,0;
if @dtRef< DateAdd(m, -12, @dtAtu) begin
UPDATE tbPtoEnq SET apontado=1 WHERE id_pass=@id_pass AND data=@dtRef;
UPDATE tbPtoDia SET apontado=1 WHERE id_pass=@id_pass AND data=@dtRef;
end;
select @achou=0;
SELECT TOP 1 @achou=1, @id_empresa=id_empresa, @id_pass=id_pass, @dtRef=data FROM viewApontado
WHERE id_pass=@id_pass and data >= @dtIni AND data <= @dtFim AND data>@dtRef
ORDER BY id_pass, data, enqoriginal;
end;
select @achou=0;
SELECT TOP 1 @achou=1, @id_empresa=id_empresa, @id_pass=id_pass, @dtRef=data FROM viewApontado
WHERE id_pass>@id_pass and data >= @dtIni AND data <= @dtFim
ORDER BY id_pass, data, enqoriginal;
UPDATE tbParSist SET ult_status=getdate();
if datediff(s,@ult_reapon,getdate()) >= @tempo_max begin select @achou=0;  end;
end;
end;
UPDATE tbParSist SET ult_reapon_status=0, ult_status=getdate();
END;
GO
EXEC('UPDATE tbParSist SET ult_reapon_status=0, ult_reapon=null');
GO
/*
-------------------------------------
 PASSO 3: Valores padres
-------------------------------------
*/
if not exists(select * from tbEventVisi)
begin
   insert into tbEventVisi (id_eventvisi,descricao,codigo) values (1,'Visita Comum',1);
end;
GO
if not exists(select * from tbHorarios) and not exists (select * from tbGHorarios)
begin
   insert into tbHorarios (id_horario,id_empresa,descricao,codigo,geral,c1e1,c1s1,c2e1,c2s1,c3e1,c3s1,c4e1,c4s1,c5e1,c5s1,c6e1,c6s1,c7e1,c7s1,c8e1,c8s1) values (1,0,'Horrio Padro',1,1,'00:00','23:59','00:00','23:59','00:00','23:59','00:00','23:59','00:00','23:59','00:00','23:59','00:00','23:59','00:00','23:59');
   insert into tbGHorarios (id_empresa,id_horario,escala,descricao,geral) values (0,1,0,'Horrio Padro',1);
end;
GO
if not exists(select * from tbConsist)
begin
   insert into tbConsist (id_consist,id_empresa,descricao,geral,c6,c7,c8,c10,c11,c12,c13,c14,c15,c16,c17,c29,c30,c31,c32) values (1,0,'Geral',1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0);
end;
GO
if not exists(select * from tbGBloq) and not exists(select * from tbBloq)
begin
   insert into tbGBloq (id_gbloq, id_horario, descricao, entrada, saida, bloqueado, primario, flaghorario) values (1,0,'Geral', 1, 1, 0, 1, 1);
   insert into tbBloq (id_bloq, st_bloq, descricao, tipo, id_gbloq, funis, sentido, entr, said, tipo_controle, ponto) values (1,0,'Principal', 0, 1, 1,'D',1,1, 'A',0);
end;
GO
if not exists(select * from tbDepart)
begin
   insert into tbDepart (id_depart,id_empresa,codigo,descricao,geral, cor_fonte, cor_tarja) values (1,0,1,'Geral',1,1,12632256);
end;
GO

/*
-------------------------------------
 PASSO 4: ATUALIZAR VERSO
-------------------------------------
*/
delete from tbVersao;
Insert Into tbVersao (Atual, AtualPto, databco) values (310, 310, '01/28/2019');
GO
